@@ -35,6 +35,8 @@
 
 #include <LTconfig.h>
 
+#include <string.h>
+
 #include <Xm/Xm.h>
 #include <Xm/MwmUtil.h>
 #include "mwm.h"
@@ -404,8 +406,8 @@ DEC_SelectDecorations(ScreenInfo *scr, MwmWindow *t)
 {
     int border_width, resize_width;
 
-    border_width = Mwm.frame_border_width;
-    resize_width = Mwm.resize_border_width;
+    border_width = scr->frame_border_width;
+    resize_width = scr->resize_border_width;
 
     if (t->mwm_hints && (t->mwm_hints->flags & MWM_HINTS_FUNCTIONS))
     {
@@ -427,13 +429,13 @@ DEC_SelectDecorations(ScreenInfo *scr, MwmWindow *t)
 	}
 
 	if (t->flags & TRANSIENT)
-	    t->functions &= Mwm.transient_functions;
+	    t->functions &= scr->transient_functions;
 	else
 	    t->functions &= t->client_functions;
 
     }
     else if (t->flags & TRANSIENT)
-	t->functions = Mwm.transient_functions;
+	t->functions = scr->transient_functions;
     else
 	t->functions = t->client_functions;
 
@@ -457,13 +459,13 @@ DEC_SelectDecorations(ScreenInfo *scr, MwmWindow *t)
 	}
 
 	if (t->flags & TRANSIENT)
-	    t->decorations &= Mwm.transient_decoration;
+	    t->decorations &= scr->transient_decoration;
 	else
 	    t->decorations &= t->client_decoration;
 
     }
     else if (t->flags & TRANSIENT)
-	t->decorations = Mwm.transient_decoration;
+	t->decorations = scr->transient_decoration;
     else
 	t->decorations = t->client_decoration;
 
@@ -540,8 +542,8 @@ DEC_ReselectDecorations(ScreenInfo *scr, MwmWindow *t)
     unsigned long valuemask;	/* mask for create windows */
     XSetWindowAttributes attributes;	/* attributes for create windows */
 
-    border_width = Mwm.frame_border_width;
-    resize_width = Mwm.resize_border_width;
+    border_width = scr->frame_border_width;
+    resize_width = scr->resize_border_width;
 
     if (t->mwm_hints && (t->mwm_hints->flags & MWM_HINTS_FUNCTIONS))
     {
@@ -563,13 +565,13 @@ DEC_ReselectDecorations(ScreenInfo *scr, MwmWindow *t)
 	}
 
 	if (t->flags & TRANSIENT)
-	    t->functions &= Mwm.transient_functions;
+	    t->functions &= scr->transient_functions;
 	else
 	    t->functions &= t->client_functions;
 
     }
     else if (t->flags & TRANSIENT)
-	t->functions = Mwm.transient_functions;
+	t->functions = scr->transient_functions;
     else
 	t->functions = t->client_functions;
 
@@ -593,13 +595,13 @@ DEC_ReselectDecorations(ScreenInfo *scr, MwmWindow *t)
 	}
 
 	if (t->flags & TRANSIENT)
-	    t->decorations &= Mwm.transient_decoration;
+	    t->decorations &= scr->transient_decoration;
 	else
 	    t->decorations &= t->client_decoration;
 
     }
     else if (t->flags & TRANSIENT)
-	t->decorations = Mwm.transient_decoration;
+	t->decorations = scr->transient_decoration;
     else
 	t->decorations = t->client_decoration;
 
@@ -669,7 +671,7 @@ DEC_ReselectDecorations(ScreenInfo *scr, MwmWindow *t)
 
 	    for (i = 0; i < 4; i++)
 	    {
-		if (Mwm.resize_cursors)
+		if (scr->resize_cursors)
 		    attributes.cursor = scr->cursors[TOP_CURS + i];
 		else
 		    attributes.cursor = scr->cursors[DEFAULT_CURS];
@@ -734,7 +736,7 @@ DEC_ReselectDecorations(ScreenInfo *scr, MwmWindow *t)
 	     */
 	    for (i = 0; i < 4; i++)
 	    {
-		if (Mwm.resize_cursors)
+		if (scr->resize_cursors)
 		    attributes.cursor = scr->cursors[TOP_LEFT_CURS + i];
 		else
 		    attributes.cursor = scr->cursors[DEFAULT_CURS];
@@ -1673,7 +1675,7 @@ DEC_DrawTitleBar(ScreenInfo *scr, MwmWindow *t, Bool onoroff, Bool NewTitle)
 
     if (t->name != (char *)NULL)
     {
-	if (Mwm.clean_text)
+	if (scr->clean_text)
 	{
 	    XClearArea(dpy, t->title,
 		       hor_off - 2, 0, w + 4, t->title_height, False);
