@@ -1,4 +1,4 @@
-/* $Id: windows.c,v 1.19 2001/05/17 13:03:27 amai Exp $ */
+/* $Id: windows.c,v 1.21 2001/10/24 12:06:44 amai Exp $ */
 /*****************************************************************************/
 /**       Copyright 1988 by Evans & Sutherland Computer Corporation,        **/
 /**                          Salt Lake City, Utah                           **/
@@ -46,6 +46,8 @@
 
 #include <LTconfig.h>
 
+#include <stdio.h>
+
 #ifdef HAVE_UNISTD_H
 #include <unistd.h>
 #endif
@@ -55,6 +57,7 @@
 
 #include <Xm/Xm.h>
 #include <Xm/MwmUtil.h>
+
 #include "mwm.h"
 
 /*
@@ -70,7 +73,6 @@
 static Boolean PPosOverride = False;
 static long isIconicState = 0;
 
-extern Bool NeedToResizeToo;
 char NoName[] = "Untitled";	/* name if no name is specified */
 
 /*
@@ -1101,7 +1103,7 @@ WIN_ReleaseWindows(ScreenInfo *scr)
 }
 
 /*
- * find the MwmWindow strcture associated with a Window
+ * find the MwmWindow structure associated with a Window
  */
 MwmWindow *
 WIN_WindowToStruct(ScreenInfo *scr, Window target)
