@@ -1,8 +1,9 @@
 /**
  * 
- * $Id: LayoutT.h,v 1.1 1998/12/29 13:13:59 pgw Exp $
+ * $Id: LayoutT.h,v 1.3 2000/11/07 12:33:13 amai Exp $
  *
  * Copyright (C) 1998 Free Software Foundation, Inc.
+ * Copyright (C) 1998-2000 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -22,8 +23,10 @@
  *
  **/
 
-#ifndef XM_LAYOUT_T_H
-#define XM_LAYOUT_T_H
+/* this file is not part of Motif 2.1 anymore! */
+
+#ifndef _XM_LAYOUTT_H
+#define _XM_LAYOUTT_H
 
 #include <Xm/Xm.h>
 
@@ -44,5 +47,4 @@ typedef struct {
 }
 #endif
 
-#endif
-
+#endif /* _XM_LAYOUTT_H */
