@@ -1,8 +1,9 @@
 /**
  *
- * $Id: ToggleBGP.h,v 1.4 1998/10/24 21:57:31 danny Exp $
+ * $Header: /cvsroot/lesstif/lesstif/include/Motif-2.0/Xm/ToggleBGP.h,v 1.10 2002/03/25 18:54:49 dannybackx Exp $
  * 
  * Copyright (C) 1995 Free Software Foundation, Inc.
+ * Copyright  1995-2001, 2002 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -21,8 +22,9 @@
  * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
  **/
-#ifndef XM_TOGGLEBG_P_H
-#define XM_TOGGLEBG_P_H
+
+#ifndef _XM_TOGGLEBGP_H
+#define _XM_TOGGLEBGP_H
 
 #include <Xm/ToggleBG.h>
 #include <Xm/LabelGP.h>
@@ -35,41 +37,41 @@ extern "C" {
  * gadget cache class and instance structures
  */
 typedef struct _XmToggleButtonGCacheObjClassPart {
-    int foo;
+	int foo;
 } XmToggleButtonGCacheObjClassPart;
 
 typedef struct _XmToggleButtonGCacheObjClassRec {
-    ObjectClassPart object_class;
-    XmExtClassPart ext_class;
-    XmLabelGCacheObjClassPart label_class_cache;
-    XmToggleButtonGCacheObjClassPart toggle_class_cache;
+	ObjectClassPart object_class;
+	XmExtClassPart ext_class;
+	XmLabelGCacheObjClassPart label_class_cache;
+	XmToggleButtonGCacheObjClassPart toggle_class_cache;
 } XmToggleButtonGCacheObjClassRec;
 
 extern XmToggleButtonGCacheObjClassRec xmToggleButtonGCacheObjClassRec;
 
 typedef struct _XmToggleButtonGCacheObjPart {
-    unsigned char ind_type;
-    Boolean visible;
-    Dimension spacing;
-    Dimension indicator_dim;
-    Pixmap on_pixmap;
-    Pixmap insen_pixmap;
-#if LESSTIF_BACK_COMPAT
-    Boolean ind_on;
-#else
-    unsigned char ind_on;  /* type changed in 2.0 */
-#endif
-    Boolean fill_on_select;
-    Pixel select_color;
-    GC select_GC;
-    GC background_GC;
+	unsigned char ind_type;
+	Boolean visible;
+	Dimension spacing;
+	Dimension indicator_dim;
+	Pixmap on_pixmap;
+	Pixmap insen_pixmap;
+
+	unsigned char ind_on;  /* type changed in 2.0 */
+
+	Boolean fill_on_select;
+	Pixel select_color;
+	GC select_GC;
+	GC background_GC;
+	Pixel unselect_color;
+	GC			unselect_GC;
 } XmToggleButtonGCacheObjPart;
 
 typedef struct _XmToggleButtonGCacheObjRec {
-    ObjectPart object;
-    XmExtPart ext;
-    XmLabelGCacheObjPart label_cache;
-    XmToggleButtonGCacheObjPart toggle_cache;
+	ObjectPart object;
+	XmExtPart ext;
+	XmLabelGCacheObjPart label_cache;
+	XmToggleButtonGCacheObjPart toggle_cache;
 } XmToggleButtonGCacheObjRec;
 
 
@@ -77,14 +79,14 @@ typedef struct _XmToggleButtonGCacheObjRec {
  * gadget class and instance records
  */
 typedef struct {
-    XtPointer extension;
+	XtPointer extension;
 } XmToggleButtonGadgetClassPart;
 
 typedef struct _XmToggleButtonGadgetClassRec {
-    RectObjClassPart rect_class;
-    XmGadgetClassPart gadget_class;
-    XmLabelGadgetClassPart label_class;
-    XmToggleButtonGadgetClassPart toggle_class;
+	RectObjClassPart rect_class;
+	XmGadgetClassPart gadget_class;
+	XmLabelGadgetClassPart label_class;
+	XmToggleButtonGadgetClassPart toggle_class;
 } XmToggleButtonGadgetClassRec;
 
 extern XmToggleButtonGadgetClassRec xmToggleButtonGadgetClassRec;
@@ -103,21 +105,19 @@ typedef struct {
     XmToggleButtonGCacheObjPart *cache;
 
 /* 2.0 novelties */
-#if LESSTIF_BACK_COMPAT
-#else
     Dimension detail_shadow_thickness; /* new for 2.0 */
-#endif
+
     Pixmap              indeterminate_pixmap;
     unsigned char       toggle_mode;
 } XmToggleButtonGadgetPart;
 
 /* Define the full instance record */
 typedef struct _XmToggleButtonGadgetRec {
-    ObjectPart object;
-    RectObjPart rectangle;
-    XmGadgetPart gadget;
-    XmLabelGadgetPart label;
-    XmToggleButtonGadgetPart toggle;
+	ObjectPart object;
+	RectObjPart rectangle;
+	XmGadgetPart gadget;
+	XmLabelGadgetPart label;
+	XmToggleButtonGadgetPart toggle;
 } XmToggleButtonGadgetRec;
 
 /*
@@ -150,6 +150,12 @@ typedef struct _XmToggleButtonGadgetRec {
 #define TBG_SelectColor(w) \
     (((XmToggleButtonGadget)(w))->toggle.cache->select_color)
 
+#define TBG_UnselectColor(w) \
+    (((XmToggleButtonGadget)(w))->toggle.cache->unselect_color)
+
+#define TBG_UnselectGC(w) \
+    (((XmToggleButtonGadget)(w))->toggle.cache->unselect_GC)
+
 #define TBG_SelectGC(w) \
     (((XmToggleButtonGadget)(w))->toggle.cache->select_GC)
 
@@ -199,4 +205,4 @@ extern void _XmToggleButtonGadgetSetState(Widget, Boolean, Boolean);
 }
 #endif
 
-#endif /* XM_TOGGLEBG_P_H */
+#endif /* _XM_TOGGLEBGP_H */
