@@ -1,6 +1,6 @@
 /**
  *
- * $Header: /cvsroot/lesstif/lesstif/lib/Xm-2.0/ComboBox.c,v 1.56 2001/05/22 09:46:21 amai Exp $
+ * $Header: /cvsroot/lesstif/lesstif/lib/Xm-2.0/ComboBox.c,v 1.58 2002/05/14 00:03:46 amai Exp $
  *
  * Copyright (C) 1997 Free Software Foundation, Inc.
  * Copyright (C) 1997-2001 LessTif Development Team
@@ -23,7 +23,7 @@
  *
  **/
 
-static const char rcsid[] = "$Header: /cvsroot/lesstif/lesstif/lib/Xm-2.0/ComboBox.c,v 1.56 2001/05/22 09:46:21 amai Exp $";
+static const char rcsid[] = "$Header: /cvsroot/lesstif/lesstif/lib/Xm-2.0/ComboBox.c,v 1.58 2002/05/14 00:03:46 amai Exp $";
 
 #include <LTconfig.h>
 
@@ -342,8 +342,8 @@ static XtResource resources[] = {
 #if XmVersion >= 2001
    {
      XmNpositionMode,
-     XmCpositionMode,
-     XmRpositionMode,
+     XmCPositionMode,
+     XmRPositionMode,
      sizeof(XtEnum),
      Offset(position_mode),
      XmRImmediate,
@@ -534,7 +534,7 @@ CallSelectionCallbacks(Widget w, XtPointer client_data, XtPointer data)
 
    Unused(client_data);
 
-   DEBUGOUT(_LtDebugDebug(__FILE__, w, "%s:CallSelectionCallbacks ...\n",
+   DEBUGOUT(_LtDebug(__FILE__, w, "%s:CallSelectionCallbacks ...\n",
    	__FILE__));
 
    if (CB_SelectionCB(w))
@@ -573,7 +573,7 @@ CBActivate(
    String *params, 
    Cardinal *num_params)
 {
-   DEBUGOUT(_LtDebugDebug(__FILE__, w, "%s:CBActivate ...\n",
+   DEBUGOUT(_LtDebug(__FILE__, w, "%s:CBActivate ...\n",
    	__FILE__));
 #if 0
    FindComboBox();
@@ -597,7 +597,7 @@ CBArmAndDropDownList(
 {
    Widget w_passed;
 
-   DEBUGOUT(_LtDebugDebug(__FILE__, w, "%s:CBArmAndDropDownList ...\n",
+   DEBUGOUT(_LtDebug(__FILE__, w, "%s:CBArmAndDropDownList ...\n",
    	__FILE__));
    w_passed = w;
    /* Find self because child may have generated event */
@@ -689,7 +689,7 @@ CBDropDownList(
 static void 
 CBFocusIn(Widget w, XEvent *event, String *params, Cardinal *num_params)
 {
-   DEBUGOUT(_LtDebugDebug(__FILE__, w, "CBFocusIn ...\n"));
+   DEBUGOUT(_LtDebug(__FILE__, w, "CBFocusIn ...\n"));
 
    w = FindComboBox(w);
    if(!XmIsComboBox(w))
@@ -704,7 +704,7 @@ CBFocusIn(Widget w, XEvent *event, String *params, Cardinal *num_params)
 static void 
 CBFocusOut(Widget w, XEvent *event, String *params, Cardinal *num_params)
 {
-   DEBUGOUT(_LtDebugDebug(__FILE__, w, "CBFocusOut ...\n"));
+   DEBUGOUT(_LtDebug(__FILE__, w, "CBFocusOut ...\n"));
 
    w = FindComboBox(w);
    if(!XmIsComboBox(w))
@@ -760,7 +760,7 @@ CBListAction(
    int *selected_pos;
    int item_cnt;
 
-   DEBUGOUT(_LtDebugDebug(__FILE__, w, "CBListAction ...\n"));
+   DEBUGOUT(_LtDebug(__FILE__, w, "CBListAction ...\n"));
 
    w = FindComboBox(w);
    if(!XmIsComboBox(w))
@@ -831,7 +831,7 @@ CBListAction(
          }
       }
 
-      DEBUGOUT(_LtDebugDebug(__FILE__, w, "XmListSelectPos(%s,%d,True)\n",XtName(CB_List(w)),pos));
+      DEBUGOUT(_LtDebug(__FILE__, w, "XmListSelectPos(%s,%d,True)\n",XtName(CB_List(w)),pos));
       XmListSelectPos(CB_List(w), pos, True);
       break;
 
@@ -844,7 +844,7 @@ CBListAction(
       break;
    }
 
-   DEBUGOUT(_LtDebugDebug(__FILE__, w, "CBListAction return\n"));
+   DEBUGOUT(_LtDebug(__FILE__, w, "CBListAction return\n"));
 }
 
 
@@ -907,7 +907,7 @@ ChangeManaged(Widget w)
    XtWidgetGeometry geo;
    XtGeometryResult result;
 
-   DEBUGOUT(_LtDebugDebug(__FILE__, w, "ChangeManaged ...\n"));
+   DEBUGOUT(_LtDebug(__FILE__, w, "ChangeManaged ...\n"));
 
 #if 0
    if (!XtIsManaged(w))
@@ -1030,7 +1030,7 @@ ComputeArrowSize(Widget w)
    Dimension arrowSize = 0;
    int fudge_factor = 1;
 
-   DEBUGOUT(_LtDebugDebug(__FILE__, w, "ComputeArrowSize ...\n"));
+   DEBUGOUT(_LtDebug(__FILE__, w, "ComputeArrowSize ...\n"));
 
    if (CB_Type(w) == XmDROP_DOWN_LIST
        || CB_Type(w) == XmDROP_DOWN_COMBO_BOX)
@@ -1056,26 +1056,26 @@ ComputeArrowSize(Widget w)
                    ); 
    }
 
-   DEBUGOUT(_LtDebugDebug(__FILE__, w, "ComputeArrowSize: text margin height(%d) ...\n",
+   DEBUGOUT(_LtDebug(__FILE__, w, "ComputeArrowSize: text margin height(%d) ...\n",
       TextF_MarginHeight(CB_EditBox(w))));
-   DEBUGOUT(_LtDebugDebug(__FILE__, w, "ComputeArrowSize: text margin width(%d) ...\n",
+   DEBUGOUT(_LtDebug(__FILE__, w, "ComputeArrowSize: text margin width(%d) ...\n",
       TextF_MarginWidth(CB_EditBox(w))));
-   DEBUGOUT(_LtDebugDebug(__FILE__, w, "ComputeArrowSize: text height(%d) ...\n",
+   DEBUGOUT(_LtDebug(__FILE__, w, "ComputeArrowSize: text height(%d) ...\n",
       XtHeight(CB_EditBox(w))));
-   DEBUGOUT(_LtDebugDebug(__FILE__, w, "ComputeArrowSize: text width(%d) ...\n",
+   DEBUGOUT(_LtDebug(__FILE__, w, "ComputeArrowSize: text width(%d) ...\n",
       XtWidth(CB_EditBox(w))));
-   DEBUGOUT(_LtDebugDebug(__FILE__, w, "ComputeArrowSize: text border width(%d) ...\n",
+   DEBUGOUT(_LtDebug(__FILE__, w, "ComputeArrowSize: text border width(%d) ...\n",
       XtBorderWidth(CB_EditBox(w))));
-   DEBUGOUT(_LtDebugDebug(__FILE__, w, "ComputeArrowSize: text highlight thickness(%d) ...\n",
+   DEBUGOUT(_LtDebug(__FILE__, w, "ComputeArrowSize: text highlight thickness(%d) ...\n",
       Prim_HighlightThickness(CB_EditBox(w))));
-   DEBUGOUT(_LtDebugDebug(__FILE__, w, "ComputeArrowSize: text shadow thickness(%d) ...\n",
+   DEBUGOUT(_LtDebug(__FILE__, w, "ComputeArrowSize: text shadow thickness(%d) ...\n",
       Prim_ShadowThickness(CB_EditBox(w))));
-   DEBUGOUT(_LtDebugDebug(__FILE__, w, "ComputeArrowSize: text ascent (%d) ...\n",
+   DEBUGOUT(_LtDebug(__FILE__, w, "ComputeArrowSize: text ascent (%d) ...\n",
       TextF_FontAscent(CB_EditBox(w))));
-   DEBUGOUT(_LtDebugDebug(__FILE__, w, "ComputeArrowSize: text average char width (%d) ...\n",
+   DEBUGOUT(_LtDebug(__FILE__, w, "ComputeArrowSize: text average char width (%d) ...\n",
       TextF_FontAverageWidth(CB_EditBox(w)))); 
 
-   DEBUGOUT(_LtDebugDebug(__FILE__, w, "ComputeArrowSize: arrow_size(%d) ...\n", arrowSize));
+   DEBUGOUT(_LtDebug(__FILE__, w, "ComputeArrowSize: arrow_size(%d) ...\n", arrowSize));
 
    return arrowSize;
 }
@@ -1092,7 +1092,7 @@ static void
 PreferredGeo(Widget w, XtWidgetGeometry *reply)
 {
    XtQueryGeometry(w, NULL, reply);
-   DEBUGOUT(_LtDebugDebug(__FILE__, w,
+   DEBUGOUT(_LtDebug(__FILE__, w,
                      "get preferred size of child %s\n",
                      _LtDebugWidgetGeometry2String(reply)));
 }
@@ -1231,9 +1231,9 @@ ComputeSizeDropDown(Widget w, XtWidgetGeometry *reply)
       reply->height = CB_ArrowSize(w);
    }
 
-   DEBUGOUT(_LtDebugDebug(__FILE__, w, "ComputeSize: arrow_spacing(%d) ...\n", 
+   DEBUGOUT(_LtDebug(__FILE__, w, "ComputeSize: arrow_spacing(%d) ...\n", 
             CB_ArrowSpacing(w)));
-   DEBUGOUT(_LtDebugDebug(__FILE__, w, "ComputeSize: arrow_size(%d) ...\n",
+   DEBUGOUT(_LtDebug(__FILE__, w, "ComputeSize: arrow_size(%d) ...\n",
             CB_ArrowSize(w)));
 
    /* add the width and spacing for the arrow button */
@@ -1256,7 +1256,7 @@ ComputeSizeDropDown(Widget w, XtWidgetGeometry *reply)
 static void
 ComputeSize(Widget w, XtWidgetGeometry *reply)
 {
-   DEBUGOUT(_LtDebugDebug(__FILE__, w, "ComputeSize ...\n"));
+   DEBUGOUT(_LtDebug(__FILE__, w, "ComputeSize ...\n"));
 
    if (CB_Type(w) == XmCOMBO_BOX)
    {
@@ -1276,7 +1276,7 @@ ComputeSize(Widget w, XtWidgetGeometry *reply)
 static void
 ConstraintDestroy(Widget w)
 {
-   DEBUGOUT(_LtDebugDebug(__FILE__, w, "ConstraintDestroy ...\n"));
+   DEBUGOUT(_LtDebug(__FILE__, w, "ConstraintDestroy ...\n"));
 
    /* FIXTHIS: ConstraintDestroy needs to be implemented. */
    Unused(w);
@@ -1296,7 +1296,7 @@ CreateArrowGC(Widget w)
    XGCValues values;
    XtGCMask mask;
 
-   DEBUGOUT(_LtDebugDebug(__FILE__, w, "CreateArrowGC ...\n"));
+   DEBUGOUT(_LtDebug(__FILE__, w, "CreateArrowGC ...\n"));
 
    mask = GCForeground | GCBackground;
 
@@ -1326,7 +1326,7 @@ CreateArrowGC(Widget w)
 static void
 CreateChildren(Widget w)
 {
-   DEBUGOUT(_LtDebugDebug(__FILE__, w, "CreateChildren ...\n"));
+   DEBUGOUT(_LtDebug(__FILE__, w, "CreateChildren ...\n"));
 
    CreateEditBox(w);
    CreatePulldown(w);
@@ -1348,7 +1348,7 @@ CreateEditBox(Widget w)
    Arg args[10];
    int n = 0;
  
-   DEBUGOUT(_LtDebugDebug(__FILE__, w, "CreateEditBox ...\n"));
+   DEBUGOUT(_LtDebug(__FILE__, w, "CreateEditBox ...\n"));
 
    if (CB_Type(w) == XmDROP_DOWN_LIST)
    {  /* force these settings */
@@ -1397,7 +1397,7 @@ CreatePulldown(Widget w)
    Arg args[10];
    int n = 0;
 
-   DEBUGOUT(_LtDebugDebug(__FILE__, w, "CreatePulldown ...\n"));
+   DEBUGOUT(_LtDebug(__FILE__, w, "CreatePulldown ...\n"));
 
    if (CB_Type(w) == XmDROP_DOWN_LIST
        || CB_Type(w) == XmDROP_DOWN_COMBO_BOX)
@@ -1452,7 +1452,7 @@ CreateScrolledList(Widget w)
    Arg args[15];
    int n = 0;
 
-   DEBUGOUT(_LtDebugDebug(__FILE__, w, "CreateScrolledList ...\n"));
+   DEBUGOUT(_LtDebug(__FILE__, w, "CreateScrolledList ...\n"));
 
    /* force settings */
    if (CB_Type(w) == XmCOMBO_BOX)
@@ -1514,7 +1514,7 @@ CreateScrolledList(Widget w)
 static void
 Destroy(Widget w)
 {
-   DEBUGOUT(_LtDebugDebug(__FILE__, w, "Destroy ...\n"));
+   DEBUGOUT(_LtDebug(__FILE__, w, "Destroy ...\n"));
 
    if (CB_SelectedItem(w))
    {
@@ -1606,7 +1606,7 @@ DetectAndFixChangesToReadOnlySettings(Widget ow, Widget nw)
 static void
 DoLayout(Widget w)
 {
-   DEBUGOUT(_LtDebugDebug(__FILE__, w, "DoLayout ...\n"));
+   DEBUGOUT(_LtDebug(__FILE__, w, "DoLayout ...\n"));
 
    /* if the kids are not valid then return */
    if(!KidsValid(w))
@@ -1643,7 +1643,7 @@ DrawArrow(Widget w)
    Position margin_left, margin_top;
 
 
-   DEBUGOUT(_LtDebugDebug(__FILE__, w, "DrawArrow ...\n"));
+   DEBUGOUT(_LtDebug(__FILE__, w, "DrawArrow ...\n"));
 
    /*
       REMARK:
@@ -1652,7 +1652,7 @@ DrawArrow(Widget w)
       END:
    */
 
-   DEBUGOUT(_LtDebugDebug(__FILE__, 
+   DEBUGOUT(_LtDebug(__FILE__, 
             w, 
             "DrawArrow: x(%d), y(%d), width(%d), height(%d) ...\n",
             (int) CB_HitRect(w).x,
@@ -1691,7 +1691,7 @@ DrawArrow(Widget w)
       normal_arrow_thickness = 1;
    }
 
-   DEBUGOUT(_LtDebugDebug(__FILE__, 
+   DEBUGOUT(_LtDebug(__FILE__, 
             w, 
             "DrawArrow: computed: x(%d), y(%d), width(%d), height(%d)\n",
             (int) normal_arrow_x,
@@ -1756,7 +1756,7 @@ DrawArrow(Widget w)
 static void
 DrawBorder(Widget w)
 {
-   DEBUGOUT(_LtDebugDebug(__FILE__, w, "DrawBorder ...\n"));
+   DEBUGOUT(_LtDebug(__FILE__, w, "DrawBorder ...\n"));
 
    if (CB_Highlighted(w) == True)
    {
@@ -1801,7 +1801,7 @@ DrawShadows(Widget w)
    Position normal_shadow_x, normal_shadow_y;
    Dimension normal_shadow_width, normal_shadow_height;
 
-   DEBUGOUT(_LtDebugDebug(__FILE__, w, "DrawShadows ...\n"));
+   DEBUGOUT(_LtDebug(__FILE__, w, "DrawShadows ...\n"));
 
    /* adjust for highlight and margins */
    normal_shadow_x = CB_HighlightThickness(w);
@@ -1809,7 +1809,7 @@ DrawShadows(Widget w)
    normal_shadow_width = XtWidth(w) - 2*normal_shadow_x;
    normal_shadow_height = XtHeight(w) - 2*normal_shadow_y;
 
-   DEBUGOUT(_LtDebugDebug(__FILE__, 
+   DEBUGOUT(_LtDebug(__FILE__, 
             w, 
             "DrawShadows: x(%d), y(%d), width(%d), height(%d) ...\n",
             (int) normal_shadow_x,
@@ -1844,7 +1844,7 @@ _FindComboBox(Widget w)
 {
    Widget ww = w;
 
-   DEBUGOUT(_LtDebugDebug(__FILE__, w, "_FindComboBox ...\n"));
+   DEBUGOUT(_LtDebug(__FILE__, w, "_FindComboBox ...\n"));
 
    while(ww && !XmIsComboBox(ww))
    {
@@ -1898,7 +1898,7 @@ _FindVendorShell(Widget w)
 {
    Widget ww = w;
 
-   DEBUGOUT(_LtDebugDebug(__FILE__, w, "_FindVendorShell ...\n"));
+   DEBUGOUT(_LtDebug(__FILE__, w, "_FindVendorShell ...\n"));
 
    while(ww && !XtIsVendorShell(ww))
    {
@@ -1913,7 +1913,7 @@ _FindVendorShell(Widget w)
 static XtGeometryResult 
 GeometryManager(Widget w, XtWidgetGeometry *request, XtWidgetGeometry *reply)
 {
-   DEBUGOUT(_LtDebugDebug2(__FILE__, XtParent(w), w, "%s:GeometryManager %s\n",
+   DEBUGOUT(_LtDebug2(__FILE__, XtParent(w), w, "%s:GeometryManager %s\n",
    		__FILE__,
    		_LtDebugWidgetGeometry2String(request)));
 
@@ -1970,7 +1970,7 @@ HighlightBorder(Widget w)
       return;
    }
 
-   DEBUGOUT(_LtDebugDebug(__FILE__, w, "HighlightBorder ...\n"));
+   DEBUGOUT(_LtDebug(__FILE__, w, "HighlightBorder ...\n"));
 
    XmeDrawHighlight(XtDisplayOfObject(w),
                     XtWindowOfObject(w),
@@ -1998,7 +1998,7 @@ Initialize(Widget request,
            ArgList args,
            Cardinal *num_args)
 {
-    DEBUGOUT(_LtDebugDebug(__FILE__, c_new,
+    DEBUGOUT(_LtDebug(__FILE__, c_new,
 		      "%s:Initialize: %i args\n"
 		      "\trequest X %5i Y %5i W %5i H %5i\n"
 		      "\t  c_new X %5i Y %5i W %5i H %5i\n",
@@ -2028,9 +2028,9 @@ Initialize(Widget request,
    /* Set focus change handler */
    SetFocusChangeHandler(c_new);
 
-   DEBUGOUT(_LtDebugDebug(__FILE__, c_new, "Initialize: IdealEBHeight(%d) ...\n",
+   DEBUGOUT(_LtDebug(__FILE__, c_new, "Initialize: IdealEBHeight(%d) ...\n",
             CB_IdealEBHeight(c_new)));
-   DEBUGOUT(_LtDebugDebug(__FILE__, c_new, "Initialize: IdealEBWidth(%d) ...\n",
+   DEBUGOUT(_LtDebug(__FILE__, c_new, "Initialize: IdealEBWidth(%d) ...\n",
             CB_IdealEBWidth(c_new)));
 
    /* The following must be done after creating the children */
@@ -2070,7 +2070,7 @@ InsertChild(Widget w)
 {
    Widget parent = XtParent(w);
 
-   DEBUGOUT(_LtDebugDebug2(__FILE__, (Widget)parent, w, "InsertChild\n"));
+   DEBUGOUT(_LtDebug2(__FILE__, (Widget)parent, w, "InsertChild\n"));
 
    /*
       REMARK: 
@@ -2103,7 +2103,7 @@ ListSelectionCB(Widget w, XtPointer client_data, XtPointer data)
    Widget cb = (Widget) client_data;
    XmString v;
 
-   DEBUGOUT(_LtDebugDebug(__FILE__, w, "%s:ListSelectionCB ...\n",
+   DEBUGOUT(_LtDebug(__FILE__, w, "%s:ListSelectionCB ...\n",
    	__FILE__));
 
    v = GetEditBoxValue(cb);
@@ -2146,7 +2146,7 @@ ListSelectionCB(Widget w, XtPointer client_data, XtPointer data)
 static void
 PopdownList(Widget w, XEvent *event)
 {
-   DEBUGOUT(_LtDebugDebug(__FILE__, w, "%s:PopdownList ...\n",
+   DEBUGOUT(_LtDebug(__FILE__, w, "%s:PopdownList ...\n",
    	__FILE__));
 
    XtCallActionProc(CB_ListShell(w), "GrabShellPopdown", event, NULL, 0);
@@ -2166,7 +2166,7 @@ PopupEH(Widget w, XtPointer udata, XEvent *xev, Boolean *pb)
    XButtonPressedEvent *xbp = (XButtonPressedEvent *)xev;
    XRectangle *rect;
 
-   DEBUGOUT(_LtDebugDebug(__FILE__, w, "PopupEH ...\n"));
+   DEBUGOUT(_LtDebug(__FILE__, w, "PopupEH ...\n"));
 
    Unused(udata);
 
@@ -2178,9 +2178,9 @@ PopupEH(Widget w, XtPointer udata, XEvent *xev, Boolean *pb)
       return;
    }
 
-   DEBUGOUT(_LtDebugDebug(__FILE__, w, "PopupEH: hit at: x(%d), y(%d)\n",
+   DEBUGOUT(_LtDebug(__FILE__, w, "PopupEH: hit at: x(%d), y(%d)\n",
             (int)xbp->x,(int)xbp->y));
-   DEBUGOUT(_LtDebugDebug(__FILE__, w, 
+   DEBUGOUT(_LtDebug(__FILE__, w, 
             "PopupEH: hit area: x(%d), y(%d), width(%d), height(%d)\n",
             (int) CB_HitRect(w).x,
             (int) CB_HitRect(w).y,
@@ -2200,7 +2200,7 @@ PopupEH(Widget w, XtPointer udata, XEvent *xev, Boolean *pb)
    /* Is the grab shell managed? */
    if (!XtIsManaged(CB_ListShell(w)))
    {
-      DEBUGOUT(_LtDebugDebug(__FILE__, w, "PopupEH: Not managed so show grab shell\n"));
+      DEBUGOUT(_LtDebug(__FILE__, w, "PopupEH: Not managed so show grab shell\n"));
 
       /* display grab shell */
       XtPopup(CB_ListShell(w), XtGrabNone);
@@ -2210,7 +2210,7 @@ PopupEH(Widget w, XtPointer udata, XEvent *xev, Boolean *pb)
    }
    else
    {
-      DEBUGOUT(_LtDebugDebug(__FILE__, w, "PopupEH: Managed so hide grab shell\n"));
+      DEBUGOUT(_LtDebug(__FILE__, w, "PopupEH: Managed so hide grab shell\n"));
 
       XtUnmanageChild(CB_ListShell(w));
       /*
@@ -2233,7 +2233,7 @@ QueryGeometry(Widget w, XtWidgetGeometry *proposed, XtWidgetGeometry *answer)
    XtGeometryResult result = XtGeometryYes;
    XtWidgetGeometry geo;
 
-   DEBUGOUT(_LtDebugDebug(__FILE__, w, "%s:QueryGeometry %s\n",
+   DEBUGOUT(_LtDebug(__FILE__, w, "%s:QueryGeometry %s\n",
 		      __FILE__,
 		      _LtDebugWidgetGeometry2String(proposed)));
 
@@ -2283,7 +2283,7 @@ QueryGeometry(Widget w, XtWidgetGeometry *proposed, XtWidgetGeometry *answer)
 static void 
 Redisplay(Widget w, XEvent *event, Region region)
 {
-   DEBUGOUT(_LtDebugDebug(__FILE__, w, "%s:Redisplay ...\n",
+   DEBUGOUT(_LtDebug(__FILE__, w, "%s:Redisplay ...\n",
    	__FILE__));
 
    Unused(event);
@@ -2302,7 +2302,7 @@ Redisplay(Widget w, XEvent *event, Region region)
 static void 
 Resize(Widget w)
 {
-   DEBUGOUT(_LtDebugDebug(__FILE__, w, "%s:Resize %ix%i\n",
+   DEBUGOUT(_LtDebug(__FILE__, w, "%s:Resize %ix%i\n",
    	__FILE__,
    	XtWidth(w), XtHeight(w)));
 
@@ -2435,7 +2435,7 @@ SetHitAreaHandler(Widget w)
 {
    EventMask mask;
 
-   DEBUGOUT(_LtDebugDebug(__FILE__, w, "SetHitAreaHandler ...\n"));
+   DEBUGOUT(_LtDebug(__FILE__, w, "SetHitAreaHandler ...\n"));
 
    if (CB_Type(w) == XmDROP_DOWN_LIST
        || CB_Type(w) == XmDROP_DOWN_COMBO_BOX)
@@ -2452,7 +2452,7 @@ RemoveHitAreaHandler(Widget w)
 {
    EventMask mask;
 
-   DEBUGOUT(_LtDebugDebug(__FILE__, w, "RemoveHitAreaHandler ...\n"));
+   DEBUGOUT(_LtDebug(__FILE__, w, "RemoveHitAreaHandler ...\n"));
 
    if (CB_Type(w) == XmDROP_DOWN_LIST
        || CB_Type(w) == XmDROP_DOWN_COMBO_BOX)
@@ -2473,7 +2473,7 @@ RemoveHitAreaHandler(Widget w)
 static void
 SetHitAreaSize(Widget w)
 {
-   DEBUGOUT(_LtDebugDebug(__FILE__, w, "SetHitAreaSize ...\n"));
+   DEBUGOUT(_LtDebug(__FILE__, w, "SetHitAreaSize ...\n"));
 
    /* Always use CB_ArrowSize for the width */
    CB_HitRect(w).width = CB_ArrowSize(w);
@@ -2502,7 +2502,7 @@ SetHitAreaSize(Widget w)
 static void
 SetIdealTextSize(Widget w)
 {
-   DEBUGOUT(_LtDebugDebug(__FILE__, w, "SetIdealTextSize ...\n"));
+   DEBUGOUT(_LtDebug(__FILE__, w, "SetIdealTextSize ...\n"));
 
    CB_IdealEBHeight(w) = XtHeight(CB_EditBox(w));
    CB_IdealEBWidth(w) = XtWidth(CB_EditBox(w));
@@ -2531,7 +2531,7 @@ SetValues(Widget old,
 
    /* FIXTHIS: */
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, c_new,
+    DEBUGOUT(_LtDebug(__FILE__, c_new,
 		      "%s:SetValues: %i args\n"
 		      "\t    old X %5i Y %5i W %5i H %5i\n"
 		      "\trequest X %5i Y %5i W %5i H %5i\n"
@@ -2571,7 +2571,7 @@ ShellFocusMovedCB(Widget w, XtPointer client_data, XtPointer call_data)
    Widget find_self;
    XmFocusMovedCallbackStruct *cbs = (XmFocusMovedCallbackStruct *) call_data;
 
-   DEBUGOUT(_LtDebugDebug(__FILE__, self, "ShellFocusMovedCB ...\n"));
+   DEBUGOUT(_LtDebug(__FILE__, self, "ShellFocusMovedCB ...\n"));
 
    /* we will find ourself if new focus widget is a child */
    find_self = _FindComboBox(cbs->new_focus);
@@ -2630,7 +2630,7 @@ ShellPopupCB(Widget w, XtPointer client_data, XtPointer data)
 static void
 TextChangedCB(Widget w, XtPointer client_data, XtPointer data)
 {
-   DEBUGOUT(_LtDebugDebug(__FILE__, w, "TextChangedCB ...\n"));
+   DEBUGOUT(_LtDebug(__FILE__, w, "TextChangedCB ...\n"));
 
    Unused(w);
    Unused(client_data);
@@ -2655,9 +2655,9 @@ UnhighlightBorder(Widget w)
       return;
    }
 
-   DEBUGOUT(_LtDebugDebug(__FILE__, w, "UnhighlightBorder ...\n"));
+   DEBUGOUT(_LtDebug(__FILE__, w, "UnhighlightBorder ...\n"));
 
-   DEBUGOUT(_LtDebugDebug(__FILE__, 
+   DEBUGOUT(_LtDebug(__FILE__, 
             w, 
             "UnhighlightBorder: x(%d), y(%d), width(%d), height(%d) ...\n",
             (int) highlight_offset,
@@ -2715,7 +2715,7 @@ AdjustKidsComboBox(Widget w)
    int edit_x, edit_y, edit_height, edit_width;
    int scrolledw_x, scrolledw_y, scrolledw_width, scrolledw_height;
 
-   DEBUGOUT(_LtDebugDebug(__FILE__, w, "AdjustKidsComboBox ...\n"));
+   DEBUGOUT(_LtDebug(__FILE__, w, "AdjustKidsComboBox ...\n"));
 
    /* Perform adjustments to the edit box */
    edit_x = edit_y = 0;
@@ -2805,7 +2805,7 @@ AdjustKidsDropDown(Widget w)
    int edit_x, edit_y, edit_height, edit_width;
    int shell_x, shell_y, shell_height, shell_width;
 
-   DEBUGOUT(_LtDebugDebug(__FILE__, w, "AdjustKidsDropDown ...\n"));
+   DEBUGOUT(_LtDebug(__FILE__, w, "AdjustKidsDropDown ...\n"));
    /*
       FIXTHIS: Confirm if docs are correct.
       REMARK:
@@ -3013,7 +3013,7 @@ ComboBoxFocusMovedCB(Widget w, XtPointer client_data, XtPointer call_data)
    Boolean to_self = False, from_self = False;
    XmFocusMovedCallbackStruct *cbs = (XmFocusMovedCallbackStruct *) call_data;
 
-   DEBUGOUT(_LtDebugDebug(__FILE__, self, "ComboBoxFocusMovedCB ...\n"));
+   DEBUGOUT(_LtDebug(__FILE__, self, "ComboBoxFocusMovedCB ...\n"));
 
    /* continue ? */
    if(!cbs->cont)
@@ -3270,7 +3270,7 @@ __LTShellSmartPlacement(Widget w, int *ret_x, int *ret_y)
     int x,y,width,height;
     int dpy_width, dpy_height, scr;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "__LTShellSmartPlacement...\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "__LTShellSmartPlacement...\n"));
 
     /* Is shell realized? */
     if(!XtIsRealized(w))
@@ -3302,7 +3302,7 @@ __LTShellSmartPlacement(Widget w, int *ret_x, int *ret_y)
     *ret_x = x;
     *ret_y = y;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "__LTShellSmartPlacement...x=%d,y=%d\n",x,y));
+    DEBUGOUT(_LtDebug(__FILE__, w, "__LTShellSmartPlacement...x=%d,y=%d\n",x,y));
 }
 
 /*
