@@ -1,6 +1,6 @@
 /**
  *
- * $Header: /cvsroot/lesstif/lesstif/lib/Xm-2.0/GrabShell.c,v 1.22 2001/05/14 19:46:11 amai Exp $
+ * $Header: /cvsroot/lesstif/lesstif/lib/Xm-2.0/GrabShell.c,v 1.23 2001/07/27 18:55:20 dannybackx Exp $
  *
  * Copyright (C) 1997 Free Software Foundation, Inc.
  * Copyright (C) 1997-2001 LessTif Development Team
@@ -23,7 +23,7 @@
  *
  **/
 
-static const char rcsid[] = "$Header: /cvsroot/lesstif/lesstif/lib/Xm-2.0/GrabShell.c,v 1.22 2001/05/14 19:46:11 amai Exp $";
+static const char rcsid[] = "$Header: /cvsroot/lesstif/lesstif/lib/Xm-2.0/GrabShell.c,v 1.23 2001/07/27 18:55:20 dannybackx Exp $";
 
 
 #include <LTconfig.h>
@@ -311,7 +311,7 @@ BtnDown(
    XButtonEvent *bev;
    Position rootx_return, rooty_return;
 
-   DEBUGOUT(_LtDebugDebug(__FILE__, w, "%s:BtnDown\n",
+   DEBUGOUT(_LtDebug(__FILE__, w, "%s:BtnDown\n",
    	__FILE__));
 
    /* Check to see if mapped yet */
@@ -330,7 +330,7 @@ BtnDown(
        && (bev->y_root >= rooty_return 
            && bev->y_root <= rooty_return + XtHeight(w)))
    {
-      DEBUGOUT(_LtDebugDebug(__FILE__, w, "BtnDown: In grab shell window.\n"));
+      DEBUGOUT(_LtDebug(__FILE__, w, "BtnDown: In grab shell window.\n"));
 
       event_mode = (GS_GrabStyle(w) == GrabModeSync) ? SyncBoth : AsyncBoth;
       _XmAllowEvents(w, event_mode, CurrentTime);
@@ -361,7 +361,7 @@ BtnUp(
 {
    int event_mode;
 
-   DEBUGOUT(_LtDebugDebug(__FILE__, w, "BtnUp\n"));
+   DEBUGOUT(_LtDebug(__FILE__, w, "BtnUp\n"));
 
    /* Check to see if mapped yet */
    if(GS_Mapped(w) == False)
@@ -392,7 +392,7 @@ ChangeManaged(Widget w)
    XtGeometryResult res;
    Dimension adjustment;
 
-   DEBUGOUT(_LtDebugDebug(__FILE__, w,
+   DEBUGOUT(_LtDebug(__FILE__, w,
                      "ChangeManaged: dimensions are %d %d\n",
                       XtWidth(w), XtHeight(w)));
 
@@ -402,14 +402,14 @@ ChangeManaged(Widget w)
    if(!child)
    {
       /* This will happen if being realized and there are no managed child */
-      DEBUGOUT(_LtDebugDebug(__FILE__, w, 
+      DEBUGOUT(_LtDebug(__FILE__, w, 
                         "ChangeManaged: No managed child bye.\n"));
       return;
    } 
   
    /* Get the preferred size of the child */
    XtQueryGeometry(child, NULL, &pref);
-   DEBUGOUT(_LtDebugDebug(__FILE__, child,
+   DEBUGOUT(_LtDebug(__FILE__, child,
                      "get preferred size of parent from child %s\n",
                      _LtDebugWidgetGeometry2String(&pref)));
 
@@ -424,7 +424,7 @@ ChangeManaged(Widget w)
    res = _XmMakeGeometryRequest(w, &pref);
    if (res == XtGeometryNo)
    {
-       DEBUGOUT(_LtDebugDebug(__FILE__, w,
+       DEBUGOUT(_LtDebug(__FILE__, w,
                         "XtGeometryNo returned... THIS SHOULD NOT HAPPEN\n"));
    }
 
@@ -539,13 +539,13 @@ DoLayout(Widget w)
    Dimension child_width, child_height;
    Dimension adjustment;
 
-   DEBUGOUT(_LtDebugDebug(__FILE__, w, "DoLayout ...\n"));
+   DEBUGOUT(_LtDebug(__FILE__, w, "DoLayout ...\n"));
 
    child = GetFirstManagedChild(w);
 
    if(child != NULL)
    {
-      DEBUGOUT(_LtDebugDebug(__FILE__, w,
+      DEBUGOUT(_LtDebug(__FILE__, w,
                         "DoLayout: dimensions before change are %u %u\n",
                         XtWidth(w), XtHeight(w)));
 
@@ -579,7 +579,7 @@ DoLayout(Widget w)
 static void
 DrawBorder(Widget w, XEvent *xev, Region region)
 {
-   DEBUGOUT(_LtDebugDebug(__FILE__, w, "DrawBorder ...\n"));
+   DEBUGOUT(_LtDebug(__FILE__, w, "DrawBorder ...\n"));
 
    XmeDrawShadows(XtDisplayOfObject(w),       /* display */
                   XtWindowOfObject(w),        /* window */
@@ -672,7 +672,7 @@ GeometryManager(Widget w, XtWidgetGeometry *request, XtWidgetGeometry *reply)
    XtWidgetGeometry wants;
    Widget me = XtParent(w);
 
-   DEBUGOUT(_LtDebugDebug(__FILE__, me,
+   DEBUGOUT(_LtDebug(__FILE__, me,
                      "geometry_manager: request %s, allow_shell_resize %s\n",
                      _LtDebugWidgetGeometry2String(request),
                      ((XmGrabShellWidget)me)->shell.allow_shell_resize
@@ -691,7 +691,7 @@ GeometryManager(Widget w, XtWidgetGeometry *request, XtWidgetGeometry *reply)
        return XtGeometryNo;
    }
 
-   DEBUGOUT(_LtDebugDebug(__FILE__, me,
+   DEBUGOUT(_LtDebug(__FILE__, me,
                      "geometry_manager: %s\n",
                      _LtDebugWidgetGeometry2String(request)));
 
@@ -701,7 +701,7 @@ GeometryManager(Widget w, XtWidgetGeometry *request, XtWidgetGeometry *reply)
 
    if (res == XtGeometryNo)
    {
-       DEBUGOUT(_LtDebugDebug(__FILE__, w,
+       DEBUGOUT(_LtDebug(__FILE__, w,
                         "XtGeometryNo returned... THIS SHOULD NOT HAPPEN\n"));
    }
    *reply = wants;
@@ -717,7 +717,7 @@ GeometryManager(Widget w, XtWidgetGeometry *request, XtWidgetGeometry *reply)
        }
    }
 
-   DEBUGOUT(_LtDebugDebug(__FILE__, w,
+   DEBUGOUT(_LtDebug(__FILE__, w,
                      "geometry_manager: size %dx%d => Yes\n",
                      reply->width, reply->height));
 
@@ -737,8 +737,8 @@ static int
 IgnoreError(Display *d, XErrorEvent *e)
 {
 
-   DEBUGOUT(_LtDebugDebug(__FILE__, NULL, "In IgnoreError\n"));
-   DEBUGOUT(_LtDebugDebug(__FILE__, NULL, 
+   DEBUGOUT(_LtDebug(__FILE__, NULL, "In IgnoreError\n"));
+   DEBUGOUT(_LtDebug(__FILE__, NULL, 
                      "type: %d\n"
                      "display: %p\n"
                      "resourceid: %p\n"
@@ -806,7 +806,7 @@ Initialize(Widget request,
 #ifdef  FAKE_NONZERO
    if (XtWidth(c_new) == 0 || XtHeight(c_new) == 0)
    {
-      DEBUGOUT(_LtDebugDebug(__FILE__, c_new,
+      DEBUGOUT(_LtDebug(__FILE__, c_new,
                         "Initialize: dimensions %d %d changed to 1x1\n",
                         XtWidth(c_new), XtHeight(c_new)));
 
@@ -845,7 +845,7 @@ MapNotifyHandler(Widget w, XtPointer cdata, XEvent *xev, Boolean *pb)
       return;
    }
 
-   DEBUGOUT(_LtDebugDebug(__FILE__, w,
+   DEBUGOUT(_LtDebug(__FILE__, w,
                      "MapNotifyHandler ...\n"));
 
    /* Set internal flag to on.  Shut it off in popdown */
@@ -906,7 +906,7 @@ Popdown(
 {
    XErrorHandler old_handler;
 
-   DEBUGOUT(_LtDebugDebug(__FILE__, w, "Popdown\n"));
+   DEBUGOUT(_LtDebug(__FILE__, w, "Popdown\n"));
 
    /* Check to see if mapped yet */
    if(GS_Mapped(w) == False)
@@ -955,7 +955,7 @@ Popdown(
 static void 
 Resize(Widget w)
 {
-   DEBUGOUT(_LtDebugDebug(__FILE__, w, "%s:Resize %ix%i\n",
+   DEBUGOUT(_LtDebug(__FILE__, w, "%s:Resize %ix%i\n",
         __FILE__,
         XtWidth(w), XtHeight(w)));
 
@@ -989,7 +989,7 @@ SetValues(Widget old,
 
    /* FIXTHIS: SetValues is not implemented yet. */
 
-   DEBUGOUT(_LtDebugDebug(__FILE__, old, "SetValues ...\n"));
+   DEBUGOUT(_LtDebug(__FILE__, old, "SetValues ...\n"));
 
    Unused(request);
    Unused(args);
@@ -1051,7 +1051,7 @@ _XmGrabShellFocus(Widget w, int operation, Time _time)
       if (GS_OldFocus(w) != window_return
           || GS_OldRevertTo(w) != revert_to_return)
       {
-         DEBUGOUT(_LtDebugDebug(__FILE__, w, "  SetInputFocus call failed.\n"));
+         DEBUGOUT(_LtDebug(__FILE__, w, "  SetInputFocus call failed.\n"));
       }
       break;
 
@@ -1068,7 +1068,7 @@ _XmGrabShellFocus(Widget w, int operation, Time _time)
       if (window_return != XtWindow(w)
           || revert_to_return != RevertToPointerRoot)
       {
-          DEBUGOUT(_LtDebugDebug(__FILE__, w, "  setting input focus failed\n"));
+          DEBUGOUT(_LtDebug(__FILE__, w, "  setting input focus failed\n"));
           _XmUngrabKeyboard(w, _time);
           return;
       }
