@@ -1,9 +1,9 @@
 /**
  *
- * $Id: BulletinBoard.c,v 1.61 2001/05/28 08:35:18 amai Exp $
+ * $Header: /cvsroot/lesstif/lesstif/lib/Xm/BulletinBoard.c,v 1.66 2002/03/23 08:37:19 dannybackx Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
- * Copyright (C) 1995-2001 LessTif Development Team
+ * Copyright  1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -23,7 +23,7 @@
  *
  **/
 
-static const char rcsid[] = "$Id: BulletinBoard.c,v 1.61 2001/05/28 08:35:18 amai Exp $";
+static const char rcsid[] = "$Header: /cvsroot/lesstif/lesstif/lib/Xm/BulletinBoard.c,v 1.66 2002/03/23 08:37:19 dannybackx Exp $";
 
 #include <LTconfig.h>
 
@@ -502,7 +502,9 @@ initialize(Widget request, Widget new_w, ArgList args, Cardinal *num_args)
 
     if (XmIsDialogShell(XtParent(new_w)))
     {
-
+	DEBUGOUT(_LtDebug(__FILE__, new_w, "Init(%s)\n",
+		_LtDebugDialogStyle2String(BB_DialogStyle(new_w))));
+#if 0
 	switch (BB_DialogStyle(new_w))
 	{
 	case XmDIALOG_MODELESS:
@@ -525,7 +527,7 @@ initialize(Widget request, Widget new_w, ArgList args, Cardinal *num_args)
 			  MWM_INPUT_SYSTEM_MODAL, NULL);
 	    break;
 	}
-
+#endif
 	/*
 	 * --aldi: Better do the realize call of our parent -- which is a
 	 * shell -- first here. Otherwise we have *real trouble* with
@@ -599,7 +601,7 @@ destroy(Widget w)
 {
   Widget ve;
 
-    DEBUGOUT(_LtDebugDebug("RWS", w,"%s:destroy(%d)\n",
+    DEBUGOUT(_LtDebug("RWS", w,"%s:destroy(%d)\n",
     	__FILE__, __LINE__
     	));
 
@@ -630,7 +632,7 @@ set_values(Widget old,
     XmBulletinBoardWidget nw = (XmBulletinBoardWidget)new_w;
     Boolean need_refresh = False;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, new_w,
+    DEBUGOUT(_LtDebug(__FILE__, new_w,
 		      "%s(%d):set_values - %i args\n"
 		      "\t    old X %5i Y %5i W %5i H %5i\n"
 		      "\trequest X %5i Y %5i W %5i H %5i\n"
@@ -716,6 +718,9 @@ set_values(Widget old,
     {
 	if (BB_DialogStyle(new_w) != BB_DialogStyle(old))
 	{
+	    DEBUGOUT(_LtDebug(__FILE__, new_w, "SetValues(%s)\n",
+	    	_LtDebugDialogStyle2String(BB_DialogStyle(new_w))));
+
 	    switch (BB_DialogStyle(new_w))
 	    {
 	    case XmDIALOG_MODELESS:
@@ -782,7 +787,7 @@ query_geometry(Widget w, XtWidgetGeometry *proposed, XtWidgetGeometry *answer)
     XmBulletinBoardWidgetClass bbc = (XmBulletinBoardWidgetClass)XtClass(w);
     XtGeometryResult res;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "%s:query_geometry(%d) - proposed %s\n",
+    DEBUGOUT(_LtDebug(__FILE__, w, "%s:query_geometry(%d) - proposed %s\n",
     		__FILE__, __LINE__,
     		_LtDebugWidgetGeometry2String(proposed)));
 
@@ -798,7 +803,7 @@ query_geometry(Widget w, XtWidgetGeometry *proposed, XtWidgetGeometry *answer)
 				   BB_MarginWidth(w), BB_MarginHeight(w),
 				   BB_ResizePolicy(w));
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, w,
+    DEBUGOUT(_LtDebug(__FILE__, w,
 		      "BB wants %d %d\n", answer->width, answer->height));
 
     return res;
@@ -846,7 +851,7 @@ resize(Widget w)
 {
     XmBulletinBoardClassRec *bb = (XmBulletinBoardClassRec *)XtClass(w);
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "resize\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "resize\n"));
 
     if (bb->bulletin_board_class.geo_matrix_create)
     {
@@ -909,7 +914,7 @@ handle_geometry_manager(Widget w,
     Widget bb = XtParent(w);
     XtGeometryResult res;
 
-    DEBUGOUT(_LtDebugDebug2(__FILE__, bb, w,
+    DEBUGOUT(_LtDebug2(__FILE__, bb, w,
 		       "handle_geometry_manager\n\tdesired %s\n",
 		       	_LtDebugWidgetGeometry2String(desired)));
 
@@ -964,7 +969,7 @@ geometry_manager(Widget w, XtWidgetGeometry *desired, XtWidgetGeometry *allowed)
     Widget bb = XtParent(w);
     XmBulletinBoardWidgetClass bbc = (XmBulletinBoardWidgetClass)XtClass(bb);
 
-    DEBUGOUT(_LtDebugDebug2(__FILE__, bb, w, "GeometryManager\n"));
+    DEBUGOUT(_LtDebug2(__FILE__, bb, w, "GeometryManager\n"));
 
     if (bbc->bulletin_board_class.geo_matrix_create)
     {
@@ -1049,7 +1054,7 @@ handle_change_managed(Widget w, XmGeoCreateProc mat_make)
     XtGeometryResult res;
 
 	res = _XmMakeGeometryRequest(w, &request);
-	DEBUGOUT(_LtDebugDebug(__FILE__, w, "handle_change_managed request %s %s\n",
+	DEBUGOUT(_LtDebug(__FILE__, w, "handle_change_managed request %s %s\n",
 		_LtDebugWidgetGeometry2String(&request),
 		_LtDebugGeometryResult2String(res)));
     	if (res == XtGeometryNo)
@@ -1094,46 +1099,71 @@ handle_change_managed(Widget w, XmGeoCreateProc mat_make)
 static void
 change_managed(Widget w)
 {
-    XmBulletinBoardClassRec *bb = (XmBulletinBoardClassRec *)XtClass(w);
+	XmBulletinBoardClassRec *bb = (XmBulletinBoardClassRec *)XtClass(w);
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "ChangeManaged\n"));
+#if 0
+	DEBUGOUT(_LtDebug(__FILE__, w, "BB-ChangeManaged\n"));
+#else
+	/*
+	 * Try to get the MODAL behaviour rolling.
+	 */
+	DEBUGOUT(_LtDebug(__FILE__, w, "BB-ChangeManaged(%s)\n",
+		_LtDebugDialogStyle2String(BB_DialogStyle(w))));
 
-    if (bb->bulletin_board_class.geo_matrix_create)
-    {
-	handle_change_managed(w, bb->bulletin_board_class.geo_matrix_create);
-	return;
-    }
+	switch (BB_DialogStyle(w))
+	{
+	case XmDIALOG_MODELESS:
+	    XtVaSetValues(XtParent(w), XmNmwmInputMode,
+			  MWM_INPUT_MODELESS, NULL);
+	    break;
 
-    _XmGMEnforceMargin(w,
-		       BB_MarginWidth(w), BB_MarginHeight(w),
-		       False);
+	case XmDIALOG_PRIMARY_APPLICATION_MODAL:
+	    XtVaSetValues(XtParent(w), XmNmwmInputMode,
+			  MWM_INPUT_PRIMARY_APPLICATION_MODAL, NULL);
+	    break;
 
-    _XmClearShadowType(w, BB_OldWidth(w), BB_OldHeight(w),
-		       BB_OldShadowThickness(w), 0);
+	case XmDIALOG_FULL_APPLICATION_MODAL:
+	    XtVaSetValues(XtParent(w), XmNmwmInputMode,
+			  MWM_INPUT_FULL_APPLICATION_MODAL, NULL);
+	    break;
 
-    BB_OldShadowThickness(w) = 0;
+	case XmDIALOG_SYSTEM_MODAL:
+	    XtVaSetValues(XtParent(w), XmNmwmInputMode,
+			  MWM_INPUT_SYSTEM_MODAL, NULL);
+	    break;
+	}
+#endif
 
-    /* mainw/test13 */
-    if (/* XtIsRealized(w) || */ XtWidth(w) == 0 || XtHeight(w) == 0)
-    {
-	_XmGMDoLayout(w, BB_MarginWidth(w), BB_MarginHeight(w),
-		      BB_ResizePolicy(w), False);
-    }
+	if (bb->bulletin_board_class.geo_matrix_create) {
+		handle_change_managed(w, bb->bulletin_board_class.geo_matrix_create);
+		return;
+	}
 
-    if ((XtWidth(w) < BB_OldWidth(w) || XtHeight(w) < BB_OldHeight(w)) &&
-	XtIsRealized(w))
-    {
-	_XmDrawShadows(XtDisplay(w), XtWindow(w),
-		       MGR_TopShadowGC(w), MGR_BottomShadowGC(w),
-		       0, 0, XtWidth(w), XtHeight(w),
-		       MGR_ShadowThickness(w), BB_ShadowType(w));
-    }
+	_XmGMEnforceMargin(w, BB_MarginWidth(w), BB_MarginHeight(w), False);
 
-    BB_OldWidth(w) = XtWidth(w);
-    BB_OldHeight(w) = XtHeight(w);
-    BB_OldShadowThickness(w) = MGR_ShadowThickness(w);
+	_XmClearShadowType(w, BB_OldWidth(w), BB_OldHeight(w), BB_OldShadowThickness(w), 0);
 
-    _XmNavigChangeManaged(w);
+	BB_OldShadowThickness(w) = 0;
+
+	/* mainw/test13 */
+	if (/* XtIsRealized(w) || */ XtWidth(w) == 0 || XtHeight(w) == 0) {
+		_XmGMDoLayout(w, BB_MarginWidth(w), BB_MarginHeight(w),
+			BB_ResizePolicy(w), False);
+	}
+
+	if ((XtWidth(w) < BB_OldWidth(w) || XtHeight(w) < BB_OldHeight(w)) &&
+			XtIsRealized(w)) {
+		_XmDrawShadows(XtDisplay(w), XtWindow(w),
+			MGR_TopShadowGC(w), MGR_BottomShadowGC(w),
+			0, 0, XtWidth(w), XtHeight(w),
+			MGR_ShadowThickness(w), BB_ShadowType(w));
+	}
+
+	BB_OldWidth(w) = XtWidth(w);
+	BB_OldHeight(w) = XtHeight(w);
+	BB_OldShadowThickness(w) = MGR_ShadowThickness(w);
+
+	_XmNavigChangeManaged(w);
 }
 
 Widget
@@ -1169,8 +1199,8 @@ XmCreateBulletinBoardDialog(Widget parent, char *name,
 static void
 constraint_initialize(Widget request, Widget new_w, Arg *args, Cardinal *nargs)
 {
-    DEBUGOUT(_LtDebugDebug(__FILE__, new_w, "constraint_initialize\n"));
-    DEBUGOUT(_LtDebugDebug2(__FILE__, XtParent(new_w), new_w,
+    DEBUGOUT(_LtDebug(__FILE__, new_w, "constraint_initialize\n"));
+    DEBUGOUT(_LtDebug2(__FILE__, XtParent(new_w), new_w,
 		       "_XmBulletinBoardconstraint_initialize: %i args\n\t"
 		       "request X %5i Y %5i W %5i H %5i\n\t  new_w X %5i Y %5i"
 		       " W %5i H %5i\n\t   BB W %5i H %5i\n",
@@ -1197,9 +1227,9 @@ static Boolean
 constraint_set_values(Widget old, Widget request, Widget new_w,
 		      Arg *args, Cardinal *nargs)
 {
-    DEBUGOUT(_LtDebugDebug2(__FILE__, XtParent(new_w), new_w,
+    DEBUGOUT(_LtDebug2(__FILE__, XtParent(new_w), new_w,
 		       "constraint_set_values\n"));
-    DEBUGOUT(_LtDebugDebug2(__FILE__, XtParent(new_w), new_w,
+    DEBUGOUT(_LtDebug2(__FILE__, XtParent(new_w), new_w,
 		       "_XmBulletinBoardconstraint_set_values: %i args\n\t"
 		       "current X %5i Y %5i W %5i H %5i\n\trequest X %5i Y %5i"
 		       " W %5i H %5i\n\t  new_w X %5i Y %5i W %5i H %5i\n\t"
@@ -1304,7 +1334,7 @@ realize(Widget w,
     if (XtHeight(w) == 0) XtHeight(w) = 1;
 #endif
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "%s:realize(%d) - %dx%d\n",
+    DEBUGOUT(_LtDebug(__FILE__, w, "%s:realize(%d) - %dx%d\n",
     	__FILE__, __LINE__,
     	XtWidth(w), XtHeight(w)));
 
@@ -1354,7 +1384,7 @@ realize(Widget w,
 static void
 expose(Widget w, XEvent *event, Region region)
 {
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "expose\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "expose\n"));
 
     if (BB_OldWidth(w) != XtWidth(w) ||
         BB_OldHeight(w) != XtHeight(w) ||
@@ -1385,7 +1415,7 @@ _XmBbButton(Widget w, XtPointer client, XtPointer call)
 {
     XmBulletinBoardWidget bb = (XmBulletinBoardWidget)XtParent(w);
 
-    DEBUGOUT(_LtDebugDebug2(__FILE__, (Widget)bb, w, "XmBbButton\n"));
+    DEBUGOUT(_LtDebug2(__FILE__, (Widget)bb, w, "XmBbButton\n"));
 
     /*
      * How do we make sure the APPLY or HELP buttons don't
@@ -1401,7 +1431,7 @@ _XmBbButton(Widget w, XtPointer client, XtPointer call)
 	if (XtIsSubclass(s, xmDialogShellWidgetClass))
 	{
 	    XtUnmanageChild((Widget)bb);
-	    DEBUGOUT(_LtDebugDebug2(__FILE__, (Widget)bb, w, "AutoUnmanage\n"));
+	    DEBUGOUT(_LtDebug2(__FILE__, (Widget)bb, w, "AutoUnmanage\n"));
 
 #if 0
 	    /* rws 19 Sep 1998
@@ -1441,7 +1471,7 @@ delete_child(Widget w)
 {
     Widget bb = XtParent(w);
 
-    DEBUGOUT(_LtDebugDebug2(__FILE__, bb, w, "delete_child\n"));
+    DEBUGOUT(_LtDebug2(__FILE__, bb, w, "delete_child\n"));
 
 #define	superclass	(&xmManagerClassRec)
     (*superclass->composite_class.delete_child) (w);
@@ -1469,7 +1499,7 @@ delete_child(Widget w)
 static Boolean
 _XmBBParentProcess(Widget widget, XmParentProcessData data)
 {
-    DEBUGOUT(_LtDebugDebug(__FILE__, widget, "_XmBBParentProcess\n"));
+    DEBUGOUT(_LtDebug(__FILE__, widget, "_XmBBParentProcess\n"));
 
     if (data->input_action.process_type == XmINPUT_ACTION)
     {
@@ -1497,10 +1527,10 @@ _XmBBParentProcess(Widget widget, XmParentProcessData data)
 	}
 	else if (data->input_action.action == XmPARENT_CANCEL)
 	{
-	    DEBUGOUT(_LtDebugDebug(__FILE__, widget, "_XmBBParentProcess CANCEL\n"));
+	    DEBUGOUT(_LtDebug(__FILE__, widget, "_XmBBParentProcess CANCEL\n"));
 	    if (BB_CancelButton(widget))
 	    {
-		DEBUGOUT(_LtDebugDebug(__FILE__, widget, "_XmBBParentProcess CANCEL %s\n",XtName(BB_CancelButton(widget))));
+		DEBUGOUT(_LtDebug(__FILE__, widget, "_XmBBParentProcess CANCEL %s\n",XtName(BB_CancelButton(widget))));
 		_XmBulletinBoardCancel(widget,
 				       data->input_action.event,
 				       data->input_action.params,
@@ -1513,7 +1543,7 @@ _XmBBParentProcess(Widget widget, XmParentProcessData data)
 	    Widget w = XtParent(widget);
 	    XmManagerWidgetClass mwc = (XmManagerWidgetClass)w->core.widget_class;
 
-		DEBUGOUT(_LtDebugDebug(__FILE__, widget, "_XmBBParentProcess CANCEL no button\n"));
+		DEBUGOUT(_LtDebug(__FILE__, widget, "_XmBBParentProcess CANCEL no button\n"));
 		if (XmIsManager(w) && mwc->manager_class.parent_process)
 		{
 		    return((*mwc->manager_class.parent_process) (w, data));
@@ -1620,7 +1650,7 @@ _XmBulletinBoardFocusMoved(Widget wid, XtPointer client_data, XtPointer data)
     Widget default_button = NULL;
     Widget par;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, wid, "%s:%d - %s %s %s\n",
+    DEBUGOUT(_LtDebug(__FILE__, wid, "%s:%d - %s %s %s\n",
     	__FILE__, __LINE__,
     	cbs->cont ? "True" : "False",
     	cbs->old_focus ? XtName(cbs->old_focus) : "NULL",
@@ -1835,7 +1865,7 @@ _XmBulletinBoardSetDynDefaultButton(Widget wid, Widget newDefaultButton)
 {
     Arg argl[2];
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, wid, "%s:%d - %s\n",
+    DEBUGOUT(_LtDebug(__FILE__, wid, "%s:%d - %s\n",
     	__FILE__, __LINE__,
     	newDefaultButton ? XtName(newDefaultButton) : "NULL"));
 
@@ -1873,7 +1903,7 @@ _XmBulletinBoardSetDynDefaultButton(Widget wid, Widget newDefaultButton)
 void
 _XmBBUpdateDynDefaultButton(Widget bb)
 {
-    DEBUGOUT(_LtDebugDebug(__FILE__, bb, "%s:_XmBBUpdateDynDefault(%d) - %s(%smanaged) %s\n",
+    DEBUGOUT(_LtDebug(__FILE__, bb, "%s:_XmBBUpdateDynDefault(%d) - %s(%smanaged) %s\n",
     	__FILE__, __LINE__,
     	BB_DynamicDefaultButton(bb) ? XtName(BB_DynamicDefaultButton(bb)) : "NULL",
     	BB_DynamicDefaultButton(bb) ? XtIsManaged(BB_DynamicDefaultButton(bb)) ? "" : "not " : "not ",
