@@ -1,6 +1,6 @@
 /**
  *
- * $Id: CutPaste.c,v 1.22 2001/05/14 19:46:08 amai Exp $
+ * $Id: CutPaste.c,v 1.23 2001/07/27 18:51:55 dannybackx Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
  * Copyright (C) 1995-2001 LessTif Development Team
@@ -23,7 +23,7 @@
  *
  **/
 
-static const char rcsid[] = "$Id: CutPaste.c,v 1.22 2001/05/14 19:46:08 amai Exp $";
+static const char rcsid[] = "$Id: CutPaste.c,v 1.23 2001/07/27 18:51:55 dannybackx Exp $";
 
 #include <LTconfig.h>
 
@@ -132,7 +132,7 @@ _XmClipboardGetAtomFromId(Display *display, int id)
 {
     char buf[128];
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, NULL, "_XmClipboardGetAtomFromId(id=%i)\n",
+    DEBUGOUT(_LtDebug(__FILE__, NULL, "_XmClipboardGetAtomFromId(id=%i)\n",
                       id));
     if (id == XmCLIP_HEADER)
     {
@@ -332,7 +332,7 @@ _XmClipboardDeleteFormats(Display *display, Window window, int id)
     Atom hdr;
     XmClipboardItem *item;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, NULL, "_XmClipboardDeleteFormats\n"));
+    DEBUGOUT(_LtDebug(__FILE__, NULL, "_XmClipboardDeleteFormats\n"));
 
     _XmClipboardFindItem(display, id, &data, &len, NULL, XmCLIP_PROP_ITEM);
 
@@ -571,7 +571,7 @@ _XmClipboardGetWindowProperty(Display *display, Window win, Atom item,
 
 	    XtFree((char *)ret_buf);
 
-	    DEBUGOUT(_LtDebugDebug(__FILE__, NULL,
+	    DEBUGOUT(_LtDebug(__FILE__, NULL,
 		"_XmClipboardGetWindowProperty: XmClipboardFail (alloc_size %d)\n",
 			alloc_size));
 	    return XmClipboardFail;
@@ -637,7 +637,7 @@ _XmClipboardGetWindowProperty(Display *display, Window win, Atom item,
 	*type_return = actual_type;
     }
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, NULL,
+    DEBUGOUT(_LtDebug(__FILE__, NULL,
 	"_XmClipboardGetWindowProperty: XmClipboardSuccess (alloc_size %d)\n",
 		alloc_size));
     return XmClipboardSuccess;
@@ -749,7 +749,7 @@ _XmClipboardRequestDataAndWait(Display *display, Window win,
     XmMatchFormat arg;
     int status;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, NULL, "_XmClipboardRequestDataAndWait\n"));
+    DEBUGOUT(_LtDebug(__FILE__, NULL, "_XmClipboardRequestDataAndWait\n"));
 
     XGetWindowAttributes(display, root, &attr);
 
@@ -1265,7 +1265,7 @@ _XmAssertClipboardSelection(Display *display, Window window,
 
     w = XtWindowToWidget(display, window);
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "_XmAssertClipboardSelection\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "_XmAssertClipboardSelection\n"));
 
     if (w == NULL || clip->current_item == 0)
     {
@@ -1807,7 +1807,7 @@ _XmClipboardEventHandler(Widget widget, XtPointer client_data,
     int reason, len;
     XmCutPasteProc cb;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, widget, "Call to ClipboardEventHandler\n"));
+    DEBUGOUT(_LtDebug(__FILE__, widget, "Call to ClipboardEventHandler\n"));
 
     if (event->type != ClientMessage)
     {
@@ -1824,7 +1824,7 @@ _XmClipboardEventHandler(Widget widget, XtPointer client_data,
     fid = event->data.l[1];
     pid = event->data.l[2];
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, widget, "ClipboardEventHandler: Find Item\n"));
+    DEBUGOUT(_LtDebug(__FILE__, widget, "ClipboardEventHandler: Find Item\n"));
 
     status = _XmClipboardFindItem(event->display, fid, &data, &len,
 				  NULL, XmCLIP_PROP_FORMAT);
@@ -1834,7 +1834,7 @@ _XmClipboardEventHandler(Widget widget, XtPointer client_data,
 	return;
     }
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, widget, "ClipboardEventHandler: Found Item\n"));
+    DEBUGOUT(_LtDebug(__FILE__, widget, "ClipboardEventHandler: Found Item\n"));
 
     cb = ((XmClipboardFormat *) data)->callback;
 
@@ -1842,7 +1842,7 @@ _XmClipboardEventHandler(Widget widget, XtPointer client_data,
 
     if (!cb)
     {
-	DEBUGOUT(_LtDebugDebug(__FILE__, widget,
+	DEBUGOUT(_LtDebug(__FILE__, widget,
 			  "ClipboardEventHandler: No Callback\n"));
 
 	return;
@@ -1862,7 +1862,7 @@ _XmClipboardEventHandler(Widget widget, XtPointer client_data,
     }
     else
     {
-	DEBUGOUT(_LtDebugDebug(__FILE__, widget,
+	DEBUGOUT(_LtDebug(__FILE__, widget,
 			  "ClipboardEventHandler: Bad Atom\n"));
 
 	return;
@@ -1872,7 +1872,7 @@ _XmClipboardEventHandler(Widget widget, XtPointer client_data,
 
     if (reason == XmCR_CLIPBOARD_DATA_REQUEST)
     {
-	DEBUGOUT(_LtDebugDebug(__FILE__, widget,
+	DEBUGOUT(_LtDebug(__FILE__, widget,
 			  "ClipboardEventHandler: Data Request\n"));
 
 	return;
@@ -1898,7 +1898,7 @@ _XmClipboardSendMessage(Display *display, Window window,
     unsigned *data;
     int len;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, NULL, "_XmClipboardSendMEssage: %d\n", id));
+    DEBUGOUT(_LtDebug(__FILE__, NULL, "_XmClipboardSendMEssage: %d\n", id));
 
     if (format->widget_window == None)
     {
@@ -1934,7 +1934,7 @@ _XmClipboardSendMessage(Display *display, Window window,
 	event.data.l[2] = format->private_id;
 	if (format->window == window && format->display == display)
 	{
-	    DEBUGOUT(_LtDebugDebug(__FILE__, NULL,
+	    DEBUGOUT(_LtDebug(__FILE__, NULL,
 			      "Call _XmClipboardEventHandler direct\n"));
 
 	    _XmClipboardEventHandler(format->widget, NULL,
@@ -2032,7 +2032,7 @@ XmClipboardCopy(Display *display,
     int fmt;
     XtPointer nbuf;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, NULL,
+    DEBUGOUT(_LtDebug(__FILE__, NULL,
 	"XmClipboardCopy(win 0x%X, item_id %ld, format %s)\n",
 	window, item_id, format_name));
 
@@ -2268,7 +2268,7 @@ XmClipboardEndCopy(Display *display,
     int len;
     XmClipboardItem *item;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, NULL,
+    DEBUGOUT(_LtDebug(__FILE__, NULL,
 	"XmClipboardEndCopy(win 0x%X, item %ld)\n",
 	window, item_id));
 
@@ -2319,7 +2319,7 @@ XmClipboardEndCopy(Display *display,
 
     if (item && item->widget)
     {
-	DEBUGOUT(_LtDebugDebug(__FILE__, NULL, "Add EventHandler from EndCopy\n"));
+	DEBUGOUT(_LtDebug(__FILE__, NULL, "Add EventHandler from EndCopy\n"));
 
 	XtAddEventHandler(item->widget, None, True,
 			  _XmClipboardEventHandler, NULL);
@@ -2757,12 +2757,12 @@ XmClipboardRetrieve(Display *display,
     status = _XmClipboardLock(display, window);
     if (status == XmClipboardLocked)
     {
-	DEBUGOUT(_LtDebugDebug(__FILE__, XtWindowToWidget(display, window),
+	DEBUGOUT(_LtDebug(__FILE__, XtWindowToWidget(display, window),
 		"XmClipboardRetrieve => XmClipboardLocked\n"));
 	return status;
     }
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, XtWindowToWidget(display, window),
+    DEBUGOUT(_LtDebug(__FILE__, XtWindowToWidget(display, window),
 	"XmClipboardRetrieve(fmt %s, maxlen %d)\n",
 	format_name ? format_name : "(null)", length));
 
@@ -2775,7 +2775,7 @@ XmClipboardRetrieve(Display *display,
 
     if (_XmClipboardWeOwnSelection(display, clip))
     {
-	DEBUGOUT(_LtDebugDebug(__FILE__, XtWindowToWidget(display, window),
+	DEBUGOUT(_LtDebug(__FILE__, XtWindowToWidget(display, window),
 	    "XmClipboardRetrieve: we own selection\n"));
 
 	format = _XmClipboardFindFormat(display, clip, format_name, 0, 0,
@@ -2785,14 +2785,14 @@ XmClipboardRetrieve(Display *display,
 
 	if (format != NULL)
 	{
-	    DEBUGOUT(_LtDebugDebug(__FILE__, XtWindowToWidget(display, window),
+	    DEBUGOUT(_LtDebug(__FILE__, XtWindowToWidget(display, window),
 		"XmClipboardRetrieve: format != NULL\n"));
 
 	    format_id = format->format_id;
 
 	    if (format->by_name)
 	    {
-		DEBUGOUT(_LtDebugDebug(__FILE__, XtWindowToWidget(display, window),
+		DEBUGOUT(_LtDebug(__FILE__, XtWindowToWidget(display, window),
 		    "XmClipboardRetrieve: by name\n"));
 
 		got_format = _XmClipboardRequestDataAndWait(display, window,
@@ -2800,7 +2800,7 @@ XmClipboardRetrieve(Display *display,
 
 		if (got_format)
 		{
-		    DEBUGOUT(_LtDebugDebug(__FILE__,
+		    DEBUGOUT(_LtDebug(__FILE__,
 			XtWindowToWidget(display, window),
 			"XmClipboardRetrieve: got format\n"));
 
@@ -2816,7 +2816,7 @@ XmClipboardRetrieve(Display *display,
 
 	    if (got_format)
 	    {
-		DEBUGOUT(_LtDebugDebug(__FILE__, XtWindowToWidget(display, window),
+		DEBUGOUT(_LtDebug(__FILE__, XtWindowToWidget(display, window),
 			"XmClipboardRetrieve: got format 2\n"));
 
 		_XmClipboardFindItem(display, format->data_id, &data, &dlen,
@@ -2834,7 +2834,7 @@ XmClipboardRetrieve(Display *display,
 		    fetchlen = dlen - format->offset;
 		}
 
-		DEBUGOUT(_LtDebugDebug(__FILE__, XtWindowToWidget(display, window),
+		DEBUGOUT(_LtDebug(__FILE__, XtWindowToWidget(display, window),
 			"XmClipboardRetrieve: fetchlen %d partial_copy %s\n",
 			fetchlen, _LtDebugBoolean2String(partial_copy)));
 
@@ -2862,7 +2862,7 @@ XmClipboardRetrieve(Display *display,
     }
     else
     {
-	DEBUGOUT(_LtDebugDebug(__FILE__, XtWindowToWidget(display, window),
+	DEBUGOUT(_LtDebug(__FILE__, XtWindowToWidget(display, window),
 	    "XmClipboardRetrieve: we don't own selection !!\n"));
 
         /* amai: At least when clipboard is messed up from remaining LT bugs
@@ -2945,7 +2945,7 @@ XmClipboardStartCopy(Display *display,
     unsigned new_item_id, new_label_id;
     int llen;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, NULL,
+    DEBUGOUT(_LtDebug(__FILE__, NULL,
 	"XmClipboardStartCopy(win 0x%X, clip 0x%X, time %ld)\n",
 	window, clip_label, timestamp));
 
