@@ -1,9 +1,9 @@
 /**
  *
- * $Header: /cvsroot/lesstif/lesstif/lib/Xm/FileSB.c,v 1.105 2001/05/14 19:46:08 amai Exp $
+ * $Header: /cvsroot/lesstif/lesstif/lib/Xm/FileSB.c,v 1.113 2002/04/12 23:38:44 amai Exp $
  *
  * Copyright (C) 1997 Free Software Foundation, Inc.
- * Copyright (C) 1997-2001 LessTif Development Team
+ * Copyright  1997, 1998, 1999, 2000, 2001, 2002 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -23,7 +23,7 @@
  *
  **/
 
-static const char rcsid[] = "$Header: /cvsroot/lesstif/lesstif/lib/Xm/FileSB.c,v 1.105 2001/05/14 19:46:08 amai Exp $";
+static const char rcsid[] = "$Header: /cvsroot/lesstif/lesstif/lib/Xm/FileSB.c,v 1.113 2002/04/12 23:38:44 amai Exp $";
 
 #include <LTconfig.h>
 
@@ -34,12 +34,10 @@ static const char rcsid[] = "$Header: /cvsroot/lesstif/lesstif/lib/Xm/FileSB.c,v
 #endif
 #ifdef HAVE_LIBGEN_H
 #include <libgen.h>    /* for basename() */
-#else
-#include "LTmisc.h"
 #endif
 
+
 #include <XmI/XmI.h>
-#include <XmI/MacrosI.h>
 #include <Xm/XmP.h>
 #include <Xm/List.h>
 #include <Xm/SelectioBP.h>
@@ -53,6 +51,9 @@ static const char rcsid[] = "$Header: /cvsroot/lesstif/lesstif/lib/Xm/FileSB.c,v
 #include <Xm/DialogS.h>
 #include <Xm/TransltnsP.h>
 
+#include <XmI/LTmisc.h>
+#include <XmI/MacrosI.h>
+
 #include <XmI/DebugUtil.h>
 
 
@@ -433,12 +434,14 @@ class_initialize(void)
 #endif
 }
 
+
 static void
 class_part_initialize(WidgetClass widget_class)
 {
     _XmFastSubclassInit(widget_class, XmFILE_SELECTION_BOX_BIT);
 }
 
+
 static void
 initialize(Widget request, Widget new_w,
 	   ArgList args, Cardinal *num_args)
@@ -449,7 +452,7 @@ initialize(Widget request, Widget new_w,
     XtTranslations save_acc;
     int dir_set_flag;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, new_w,
+    DEBUGOUT(_LtDebug(__FILE__, new_w,
 		      "initialize: %i args\n"
 		      "\trequest X %5i Y %5i W %5i H %5i\n"
 		      "\t  new_w X %5i Y %5i W %5i H %5i\n",
@@ -734,10 +737,11 @@ initialize(Widget request, Widget new_w,
     FS_DirSpec(new_w) = XmStringCopy(FS_Directory(new_w));
 }
 
+
 static void
 destroy(Widget w)
 {
-    DEBUGOUT(_LtDebugDebug("RWS", w,"%s:destroy(%d)\n",
+    DEBUGOUT(_LtDebug("RWS", w,"%s:destroy(%d)\n",
     	__FILE__, __LINE__
     	));
 
@@ -751,6 +755,7 @@ destroy(Widget w)
     XmStringFree(FS_Directory(w));
 }
 
+
 static Boolean
 set_values(Widget old, Widget request, Widget new_w,
 	   ArgList args, Cardinal *num_args)
@@ -760,7 +765,7 @@ set_values(Widget old, Widget request, Widget new_w,
     Boolean refresh = False;
     Boolean reSearch;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, new_w,
+    DEBUGOUT(_LtDebug(__FILE__, new_w,
 		      "set_values: %i args\n"
 		      "\t    old X %5i Y %5i W %5i H %5i\n"
 		      "\trequest X %5i Y %5i W %5i H %5i\n"
@@ -838,13 +843,13 @@ set_values(Widget old, Widget request, Widget new_w,
 
 	/* T. Straumann: this is a little weird:
 	 *
-	 * 				 FS_FileLabelString() is actually SB_ListLabelString().
+	 * FS_FileLabelString() is actually SB_ListLabelString().
 	 *
-	 *				 NOTE: I don't like this; set_values on FS_FileLabelString
-	 *					   is done by the SB widget.
-	 *					   However we, i.e. FSB does the initialization and
-	 *					   the destruction.
-	 *					   IMHO this is quite confusing and inelegant.
+	 * NOTE: I don't like this; set_values on FS_FileLabelString
+	 *	is done by the SB widget.
+	 *	However we, i.e. FSB does the initialization and
+	 *	the destruction.
+	 *	IMHO this is quite confusing and inelegant.
 	 */
 
     /* label string */
@@ -892,62 +897,63 @@ set_values(Widget old, Widget request, Widget new_w,
 		FS_Directory(new_w) = FS_Directory(old);
 	}
 
-	if (!XmStringCompare(FS_DirMask(new_w), FS_DirMask(old)))
-	{
+	if (!XmStringCompare(FS_DirMask(new_w), FS_DirMask(old))) {
 		XmStringFree(FS_DirMask(old));
 		FS_DirMask(new_w) = XmStringCopy(FS_DirMask(new_w));
+#if 1
+	/* This hopefully fixes bug #470233. */
+		XmStringFree(FS_Pattern(old));
+		FS_Pattern(new_w) = XmStringCopy(FS_DirMask(new_w));
+
+#endif
 		reSearch = True;
-	}
-	else
-	{
+	} else {
 		FS_DirMask(new_w) = FS_DirMask(old);
 	}
 
-	if (!XmStringCompare(FS_Pattern(new_w), FS_Pattern(old)))
-	{
+	if (!XmStringCompare(FS_Pattern(new_w), FS_Pattern(old))) {
 		XmStringFree(FS_Pattern(old));
 		FS_Pattern(new_w) = XmStringCopy(FS_Pattern(new_w));
 		reSearch = True;
-	}
-	else
-	{
+	} else {
 		FS_Pattern(new_w) = FS_Pattern(old);
 	}
 
-	if (!XmStringCompare(FS_NoMatchString(new_w), FS_NoMatchString(old)))
-	{
+	if (!XmStringCompare(FS_NoMatchString(new_w), FS_NoMatchString(old))) {
 		XmStringFree(FS_NoMatchString(old));
 		FS_NoMatchString(new_w) = XmStringCopy(FS_NoMatchString(new_w));
 		reSearch = True;
-	}
-	else
-	{
+	} else {
 		FS_NoMatchString(new_w) = FS_NoMatchString(old);
 	}
 
-	if ( reSearch || (FS_FileTypeMask(new_w) != FS_FileTypeMask(old)))
-    {
-	_XmFileSelectionSearch(new_w);
-    }
+	if (FS_FileSearchProc(new_w) != FS_FileSearchProc(old))
+		reSearch = True;
 
-    /* the next 8 lines are required for every BB subclass that uses
-       the GeoMatrix */
-    BB_InSetValues(new_w) = False;
+	if (FS_DirSearchProc(new_w) != FS_DirSearchProc(old))
+		reSearch = True;
 
-    if (refresh && (XtClass(new_w) == xmFileSelectionBoxWidgetClass))
-    {
-	_XmBulletinBoardSizeUpdate(new_w);
-	return False;
-    }
+	if ( reSearch || (FS_FileTypeMask(new_w) != FS_FileTypeMask(old))) {
+		_XmFileSelectionSearch(new_w);
+	}
 
-    return refresh;
+	/* the next 8 lines are required for every BB subclass that uses
+	 * the GeoMatrix */
+	BB_InSetValues(new_w) = False;
+
+	if (refresh && (XtClass(new_w) == xmFileSelectionBoxWidgetClass)) {
+		_XmBulletinBoardSizeUpdate(new_w);
+		return False;
+	}
+
+	return refresh;
 }
 
 #if 0
 /* Motif has one of these */
 static void get_values_hook(Widget w, ArgList args, Cardinal *num_args)
 {
-    DEBUGOUT(_LtDebugDebug(__FILE__, w,
+    DEBUGOUT(_LtDebug(__FILE__, w,
 		      "%s:get_values_hook() - %i args\n",
 		      __FILE__,
 		      *num_args));
@@ -956,6 +962,7 @@ static void get_values_hook(Widget w, ArgList args, Cardinal *num_args)
 }
 #endif
 
+
 static Dimension
 GetPreferredListWidth(Widget w)
 {
@@ -1033,6 +1040,7 @@ GetPreferredListWidth(Widget w)
     return (Width);
 }
 
+
 /*
  * XmGeoSegmentFixUpProc
  */
@@ -1062,7 +1070,7 @@ _XmTextFix(XmGeoMatrix geoSpec,
     default:
 	break;
     }
-    DEBUGOUT(_LtDebugDebug2(__FILE__, XtParent(rowPtr->kid), rowPtr->kid, "_XmTextFix() - %s %dx%d%+d%+d\n",
+    DEBUGOUT(_LtDebug2(__FILE__, XtParent(rowPtr->kid), rowPtr->kid, "_XmTextFix() - %s %dx%d%+d%+d\n",
     		_LtDebugGeoAction2String(action),
     		rowPtr->box.width,
     		rowPtr->box.height,
@@ -1070,6 +1078,7 @@ _XmTextFix(XmGeoMatrix geoSpec,
     		rowPtr->box.y ));
 }
 
+
 /*
  * XmGeoSegmentFixUpProc
  */
@@ -1079,7 +1088,7 @@ _XmDirListFix(XmGeoMatrix geoSpec,
 	      XmGeoMajorLayout layoutPtr,
 	      XmKidGeometry rowPtr)
 {
-    DEBUGOUT(_LtDebugDebug2(__FILE__, XtParent(rowPtr->kid), rowPtr->kid, "_XmDirListFix() - %s\n",
+    DEBUGOUT(_LtDebug2(__FILE__, XtParent(rowPtr->kid), rowPtr->kid, "_XmDirListFix() - %s\n",
     		_LtDebugGeoAction2String(action)));
 
     switch (action)
@@ -1106,7 +1115,7 @@ _XmDirListFix(XmGeoMatrix geoSpec,
 		    rowPtr->box.width = (&rowPtr[-3])->box.width;
 		}
 		}
-    DEBUGOUT(_LtDebugDebug2(__FILE__, XtParent(rowPtr->kid), rowPtr->kid, "_XmDirListFix() - %s %dx%d%+d%+d\n",
+    DEBUGOUT(_LtDebug2(__FILE__, XtParent(rowPtr->kid), rowPtr->kid, "_XmDirListFix() - %s %dx%d%+d%+d\n",
     		_LtDebugGeoAction2String(action),
     		rowPtr->box.width,
     		rowPtr->box.height,
@@ -1135,7 +1144,7 @@ _XmDirListFix(XmGeoMatrix geoSpec,
 			    GetPreferredListWidth(SW_WorkWindow(rowPtr->kid)) +
 				      rowPtr->box.width);
 		}
-    DEBUGOUT(_LtDebugDebug2(__FILE__, XtParent(rowPtr->kid), rowPtr->kid, "_XmDirListFix() - %s %dx%d%+d%+d\n",
+    DEBUGOUT(_LtDebug2(__FILE__, XtParent(rowPtr->kid), rowPtr->kid, "_XmDirListFix() - %s %dx%d%+d%+d\n",
     		_LtDebugGeoAction2String(action),
     		rowPtr->box.width,
     		rowPtr->box.height,
@@ -1210,13 +1219,13 @@ _XmDirListFix(XmGeoMatrix geoSpec,
 		- geoSpec->margin_w
 		- layoutPtr->row.space_between
 		- 2 * dirList->box.border_width;
-    DEBUGOUT(_LtDebugDebug2(__FILE__, XtParent(rowPtr->kid), rowPtr->kid, "_XmDirListFix() - %s %dx%d%+d%+d\n",
+    DEBUGOUT(_LtDebug2(__FILE__, XtParent(rowPtr->kid), rowPtr->kid, "_XmDirListFix() - %s %dx%d%+d%+d\n",
     		_LtDebugGeoAction2String(action),
     		rowPtr->box.width,
     		rowPtr->box.height,
     		rowPtr->box.x,
     		rowPtr->box.y ));
-    DEBUGOUT(_LtDebugDebug2(__FILE__, XtParent(rowPtr->kid), fileList->kid, "_XmDirListFix() - %s %dx%d%+d%+d\n",
+    DEBUGOUT(_LtDebug2(__FILE__, XtParent(rowPtr->kid), fileList->kid, "_XmDirListFix() - %s %dx%d%+d%+d\n",
     		_LtDebugGeoAction2String(action),
     		fileList->box.width,
     		fileList->box.height,
@@ -1244,6 +1253,7 @@ _XmDirListFix(XmGeoMatrix geoSpec,
     }
 }
 
+
 static XmGeoMatrix
 geoMatrixCreate(Widget _w, Widget _from, XtWidgetGeometry *_pref)
 {
@@ -1741,13 +1751,14 @@ geoMatrixCreate(Widget _w, Widget _from, XtWidgetGeometry *_pref)
     return (geoSpec);
 }
 
+
 static void 
 focus_moved_proc(Widget wid, XtPointer client_data, XtPointer data)
 {
     XmFocusMovedCallback cbs = (XmFocusMovedCallback)data;
     Widget bb = (Widget)client_data;
 
-    DEBUGOUT(_LtDebugDebug2(__FILE__, wid, bb, "%s:focus_moved_proc() - %s -> %s\n",
+    DEBUGOUT(_LtDebug2(__FILE__, wid, bb, "%s:focus_moved_proc() - %s -> %s\n",
     	__FILE__,
     	cbs->old_focus ? XtName(cbs->old_focus) : "NULL",
     	cbs->new_focus ? XtName(cbs->new_focus) : "NULL"));
@@ -1770,13 +1781,14 @@ focus_moved_proc(Widget wid, XtPointer client_data, XtPointer data)
     _XmBulletinBoardFocusMoved(wid, client_data, data);
 }
 
+
 static Boolean
 noGeoRequest(XmGeoMatrix _geoSpec)
 {
 	/*
 	return True;
 	*/
-    DEBUGOUT(_LtDebugDebug("FSB", _geoSpec->composite, "%s:noGeoRequest(%d) - instigator %s\n",
+    DEBUGOUT(_LtDebug("FSB", _geoSpec->composite, "%s:noGeoRequest(%d) - instigator %s\n",
     	__FILE__, __LINE__,
     	_geoSpec->instigator ? XtName(_geoSpec->instigator) : "NULL"));
 
@@ -1919,6 +1931,7 @@ defaultDirSearchProc(Widget widget,
     FS_ListUpdated(widget) = True;
 }
 
+
 static void
 defaultFileSearchProc(Widget widget, XtPointer data)
 {
@@ -1929,29 +1942,29 @@ defaultFileSearchProc(Widget widget, XtPointer data)
     Arg argl[3];
     XmString *table;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, widget, "defaultFileSearchProc\n"));
+    DEBUGOUT(_LtDebug(__FILE__, widget, "defaultFileSearchProc\n"));
 
     if (!XmStringGetLtoR(cbs->dir, XmFONTLIST_DEFAULT_TAG, &dir))
     {
 	dir = XtNewString("");
-	DEBUGOUT(_LtDebugDebug(__FILE__, widget,
+	DEBUGOUT(_LtDebug(__FILE__, widget,
 			  "defaultFileSearchProc: empty directory\n"));
     }
     else
     {
-	DEBUGOUT(_LtDebugDebug(__FILE__, widget,
+	DEBUGOUT(_LtDebug(__FILE__, widget,
 			  "defaultFileSearchProc: directory '%s'\n", dir));
     }
 
     if (!XmStringGetLtoR(cbs->pattern, XmFONTLIST_DEFAULT_TAG, &pat))
     {
 	pat = XtNewString("*");
-	DEBUGOUT(_LtDebugDebug(__FILE__, widget,
+	DEBUGOUT(_LtDebug(__FILE__, widget,
 			  "defaultFileSearchProc: default pattern '*'\n"));
     }
     else
     {
-	DEBUGOUT(_LtDebugDebug(__FILE__, widget,
+	DEBUGOUT(_LtDebug(__FILE__, widget,
 			  "defaultFileSearchProc: pattern '%s'\n", pat));
     }
 
@@ -2028,6 +2041,7 @@ defaultFileSearchProc(Widget widget, XtPointer data)
     FS_ListUpdated(widget) = True;
 }
 
+
 static void
 defaultQualifySearchDataProc(Widget w,
 			     XtPointer input_data,
@@ -2046,7 +2060,7 @@ defaultQualifySearchDataProc(Widget w,
     String mask = NULL;
     String pdir, ppat;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "defaultQualifySearchDataProc\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "defaultQualifySearchDataProc\n"));
 
     if (in->dir)
     {
@@ -2185,7 +2199,7 @@ _XmFileSelectionSearch(Widget w)
     int argc;
     char *value;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "_XmFileSelectionSearch()\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "_XmFileSelectionSearch()\n"));
 
     /*
      * setup the callback structures
@@ -2205,7 +2219,7 @@ _XmFileSelectionSearch(Widget w)
 	in.mask = FS_DirMask(w);
     }
     in.mask_length = XmStringLength(in.mask);
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "\tdirMask %s (%i)\n", 
+    DEBUGOUT(_LtDebug(__FILE__, w, "\tdirMask %s (%i)\n", 
     		_LtDebugXmString2String(FS_DirMask(w)),in.mask_length));
 
     in.dir = FS_Directory(w);
@@ -2215,7 +2229,7 @@ _XmFileSelectionSearch(Widget w)
 	in.dir = FS_Directory(w);
     }
     in.dir_length = XmStringLength(in.dir);
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "\tdirectory %s (%i)\n", 
+    DEBUGOUT(_LtDebug(__FILE__, w, "\tdirectory %s (%i)\n", 
     		_LtDebugXmString2String(FS_Directory(w)),in.dir_length));
 
     in.pattern = FS_Pattern(w);
@@ -2225,13 +2239,13 @@ _XmFileSelectionSearch(Widget w)
 	in.pattern = FS_Pattern(w);
     }
     in.pattern_length = XmStringLength(in.pattern);
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "\tpattern %s (%i)\n", 
+    DEBUGOUT(_LtDebug(__FILE__, w, "\tpattern %s (%i)\n", 
     		_LtDebugXmString2String(FS_Pattern(w)),in.pattern_length));
 
     /*
      * qualification
      */
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "_XmFileSelectionSearch() - Calling Qualify\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "_XmFileSelectionSearch() - Calling Qualify\n"));
     (*FS_QualifySearchDataProc(w)) (w, (XtPointer)&in, (XtPointer)&out);
 
 #ifdef MOZILLA
@@ -2240,11 +2254,11 @@ _XmFileSelectionSearch(Widget w)
        to get the XmNdirectory and compare this to the last time it was 
        called.  If it is the same, the search is not done.
      */
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "_XmFileSelectionSearch()\n\tdirectory %s\n",
+    DEBUGOUT(_LtDebug(__FILE__, w, "_XmFileSelectionSearch()\n\tdirectory %s\n",
 		      _LtDebugXmString2String(FS_Directory(w))));
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "_XmFileSelectionSearch()\n\tin.dir %s\n",
+    DEBUGOUT(_LtDebug(__FILE__, w, "_XmFileSelectionSearch()\n\tin.dir %s\n",
 		      _LtDebugXmString2String(in.dir)));
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "_XmFileSelectionSearch()\n\tout.dir %s\n",
+    DEBUGOUT(_LtDebug(__FILE__, w, "_XmFileSelectionSearch()\n\tout.dir %s\n",
 		      _LtDebugXmString2String(out.dir)));
     if (FS_Directory(w))
     {
@@ -2266,7 +2280,7 @@ _XmFileSelectionSearch(Widget w)
     if ((FS_StateFlags(w) & XmFS_DIR_SEARCH_PROC) == 0)
     {
 	FS_StateFlags(w) |= XmFS_DIR_SEARCH_PROC;
-	DEBUGOUT(_LtDebugDebug(__FILE__, w, "_XmFileSelectionSearch() - Calling DirSearch\n"));
+	DEBUGOUT(_LtDebug(__FILE__, w, "_XmFileSelectionSearch() - Calling DirSearch\n"));
 	(*FS_DirSearchProc(w)) (w, (XtPointer)&out);
 	if (FS_ListUpdated(w))
 	{
@@ -2285,7 +2299,7 @@ _XmFileSelectionSearch(Widget w)
 	if ((FS_StateFlags(w) & XmFS_IN_FILE_SEARCH) == 0)
 	{
 	    FS_StateFlags(w) |= XmFS_IN_FILE_SEARCH;
-	    DEBUGOUT(_LtDebugDebug(__FILE__, w, "_XmFileSelectionSearch() - Calling FileSearch\n"));
+	    DEBUGOUT(_LtDebug(__FILE__, w, "_XmFileSelectionSearch() - Calling FileSearch\n"));
 	    (*FS_FileSearchProc(w)) (w, (XtPointer)&out);
 	    if (FS_ListUpdated(w) && SB_ListItemCount(w) == 0)
 	    {
@@ -2396,6 +2410,7 @@ XmCreateFileSelectionBox(Widget parent,
 			  argcount);
 }
 
+
 Widget
 XmCreateFileSelectionDialog(Widget parent,
 			    char *name,
@@ -2434,20 +2449,31 @@ XmCreateFileSelectionDialog(Widget parent,
     return ret;
 }
 
+/* This routine is marked as obsolete as of Motif 2.1 */
 Widget
 XmFileSelectionBoxGetChild(Widget w,
 			   unsigned char child)
 {
     switch (child)
     {
+
     case XmDIALOG_APPLY_BUTTON:
 	return SB_ApplyButton(w);
 
     case XmDIALOG_CANCEL_BUTTON:
 	return SB_CancelButton(w);
+    
+    case XmDIALOG_DEFAULT_BUTTON:
+	return BB_DefaultButton(w);
 
-    case XmDIALOG_OK_BUTTON:
-	return SB_OkButton(w);
+    case XmDIALOG_DIR_LIST:
+	return FS_DirList(w);
+
+    case XmDIALOG_DIR_LIST_LABEL:
+	return FS_DirListLabel(w);
+
+    case XmDIALOG_FILTER_LABEL:
+	return FS_FilterLabel(w);
 
     case XmDIALOG_FILTER_TEXT:
 	return FS_FilterText(w);
@@ -2458,44 +2484,46 @@ XmFileSelectionBoxGetChild(Widget w,
     case XmDIALOG_LIST:
 	return SB_List(w);
 
+    case XmDIALOG_LIST_LABEL:
+	return SB_ListLabel(w);
+
+    case XmDIALOG_OK_BUTTON:
+	return SB_OkButton(w);
+
+    case XmDIALOG_SELECTION_LABEL:
+	return SB_SelectionLabel(w);
+
     case XmDIALOG_SEPARATOR:
 	return SB_Separator(w);
 
     case XmDIALOG_TEXT:
 	return SB_Text(w);
 
-    case XmDIALOG_LIST_LABEL:
-	return SB_ListLabel(w);
+    case XmDIALOG_WORK_AREA:
+	return SB_WorkArea(w);
 
-    case XmDIALOG_SELECTION_LABEL:
-	return SB_SelectionLabel(w);
-
-    case XmDIALOG_FILTER_LABEL:
-	return FS_FilterLabel(w);
-
-    case XmDIALOG_DIR_LIST:
-	return FS_DirList(w);
-
-    case XmDIALOG_DIR_LIST_LABEL:
-	return FS_DirListLabel(w);
-
-    /* Still have to treat these */
+    /* Still have to treat these.
+       amai: dumb question - why? Motif manpage doesn't show them!? */
+#if 0
     case XmDIALOG_MESSAGE_LABEL:
     case XmDIALOG_DEFAULT_BUTTON:
     case XmDIALOG_SYMBOL_LABEL:
 	return BB_DefaultButton(w);
-    }
+#endif
 
-    return NULL;
+    default:
+      return NULL;
+    }
 }
 
+
 void
 XmFileSelectionDoSearch(Widget w, XmString dirmask)
 {
-       	XmFileSelectionBoxCallbackStruct in, out;
-       	String mask;
+     	XmFileSelectionBoxCallbackStruct in, out;
+     	String mask;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "XmFileSelectionDoSearch() - %s\n",
+    DEBUGOUT(_LtDebug(__FILE__, w, "XmFileSelectionDoSearch() - %s\n",
     		_LtDebugXmString2String(dirmask)));
 
 	in.reason = 0;
@@ -2510,7 +2538,7 @@ XmFileSelectionDoSearch(Widget w, XmString dirmask)
 	in.pattern_length = 0;
 	if (dirmask != (XmString)NULL)
 	{
-		in.mask = dirmask;
+		in.mask = XmStringCopy(dirmask);
 		in.mask_length = XmStringLength(in.mask);
 	}
 	else
@@ -2560,6 +2588,7 @@ XmFileSelectionDoSearch(Widget w, XmString dirmask)
 	_XmFileSelectionSearch((Widget)w);
 }
 
+
 /*
  * Stolen from SelectionBox.c
  *
@@ -2606,7 +2635,7 @@ _XmFsbButton(Widget w, XtPointer client, XtPointer call)
 	{
 	    char *s = XmTextFieldGetString(SB_Text(sb));
 
-	    DEBUGOUT(_LtDebugDebug(__FILE__, w, "_XmFsbButton OK '%s'\n", s));
+	    DEBUGOUT(_LtDebug(__FILE__, w, "_XmFsbButton OK '%s'\n", s));
 
 	    cbs.value = XmStringCreateSimple(s);
 
@@ -2624,7 +2653,7 @@ _XmFsbButton(Widget w, XtPointer client, XtPointer call)
 
 	    cbs.value = XmStringCopy(ls->item);
 
-	    DEBUGOUT(_LtDebugDebug(__FILE__, w, "_XmFsbButton LIST '%s'\n",
+	    DEBUGOUT(_LtDebug(__FILE__, w, "_XmFsbButton LIST '%s'\n",
 			      _LtDebugXmString2String(cbs.value)));
 	}
 
@@ -2660,7 +2689,7 @@ _XmFsbButton(Widget w, XtPointer client, XtPointer call)
     {
 	cbs.reason = XmCR_CANCEL;
 
-	DEBUGOUT(_LtDebugDebug(__FILE__, w, "_XmFsbButton CANCEL\n"));
+	DEBUGOUT(_LtDebug(__FILE__, w, "_XmFsbButton CANCEL\n"));
 
 	XtCallCallbackList((Widget)sb, SB_CancelCallback(sb), &cbs);
     }
@@ -2669,7 +2698,7 @@ _XmFsbButton(Widget w, XtPointer client, XtPointer call)
        	XmFileSelectionBoxCallbackStruct in, out;
        	String mask;
 
-	DEBUGOUT(_LtDebugDebug(__FILE__, w, "_XmFsbButton FILTER\n"));
+	DEBUGOUT(_LtDebug(__FILE__, w, "_XmFsbButton FILTER\n"));
 
 	in.reason = a->reason;
 	in.event = a->event;
@@ -2703,7 +2732,7 @@ _XmFsbButton(Widget w, XtPointer client, XtPointer call)
     else if (w == SB_HelpButton(sb))
     {
 	cbs.reason = XmCR_HELP;
-	DEBUGOUT(_LtDebugDebug(__FILE__, w, "_XmFsbButton HELP\n"));
+	DEBUGOUT(_LtDebug(__FILE__, w, "_XmFsbButton HELP\n"));
 	XtCallCallbackList((Widget)sb, sb->manager.help_callback, &cbs);
     }
     else if (w == FS_DirList(sb))
@@ -2713,7 +2742,7 @@ _XmFsbButton(Widget w, XtPointer client, XtPointer call)
        	XmFileSelectionBoxCallbackStruct in, out;
        	String mask;
 
-	DEBUGOUT(_LtDebugDebug(__FILE__, w, "_XmFsbButton DirList\n"));
+	DEBUGOUT(_LtDebug(__FILE__, w, "_XmFsbButton DirList\n"));
 
 	in.reason = ls->reason;
 	in.event = ls->event;
@@ -2766,7 +2795,7 @@ _XmFsbButton(Widget w, XtPointer client, XtPointer call)
     }
     else
     {
-	DEBUGOUT(_LtDebugDebug(__FILE__, w, "_XmFsbButton : untreated case !!\n"));
+	DEBUGOUT(_LtDebug(__FILE__, w, "_XmFsbButton : untreated case !!\n"));
     }
 
     /* AutoUnmanage */
@@ -2782,7 +2811,7 @@ _XmFsbButton(Widget w, XtPointer client, XtPointer call)
 		!CoreBeingDestroyed(sb))
 	    {
 		XtUnmanageChild((Widget)sb);
-		DEBUGOUT(_LtDebugDebug(__FILE__, (Widget)sb, "FSB AutoUnmanage\n"));
+		DEBUGOUT(_LtDebug(__FILE__, (Widget)sb, "FSB AutoUnmanage\n"));
 
 		XtCallCallbackList(shell,
 				   Shell_PopdownCallback(shell),
@@ -2827,7 +2856,7 @@ _XmFsbFileSelect(Widget w, XtPointer client, XtPointer call)
      */
     if (FS_StateFlags(fsb) & XmFS_NO_MATCH)
     {
-	DEBUGOUT(_LtDebugDebug(__FILE__, w,
+	DEBUGOUT(_LtDebug(__FILE__, w,
 			  "_XmFsbFileSelect (Selection with XmFS_NO_MATCH)\n"));
 
         /*
@@ -2840,26 +2869,26 @@ _XmFsbFileSelect(Widget w, XtPointer client, XtPointer call)
 
     if (SB_Text(fsb) == NULL)
     {
-	DEBUGOUT(_LtDebugDebug(__FILE__, w,
+	DEBUGOUT(_LtDebug(__FILE__, w,
 			  "_XmFsbFileSelect (No TextField)\n"));
 	return;
     }
 
     if (lp == NULL || lp->item == NULL)
     {
-	DEBUGOUT(_LtDebugDebug(__FILE__, w,
+	DEBUGOUT(_LtDebug(__FILE__, w,
 			  "_XmFsbFileSelect (NULL)\n"));
 	return;
     }
 
     if (!XmStringGetLtoR(lp->item, XmFONTLIST_DEFAULT_TAG, &s))
     {
-	DEBUGOUT(_LtDebugDebug(__FILE__, w,
+	DEBUGOUT(_LtDebug(__FILE__, w,
 			  "_XmFsbFileSelect (Couldn't convert to string)\n"));
 	return;
     }
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, w,
+    DEBUGOUT(_LtDebug(__FILE__, w,
 		      "_XmFsbFileSelect '%s'\n", s));
     XmTextFieldSetString(SB_Text(fsb), s);
     XmTextFieldSetInsertionPosition(SB_Text(fsb),
@@ -2877,6 +2906,7 @@ _XmFsbFileSelect(Widget w, XtPointer client, XtPointer call)
     FS_DirMask(fsb) = XmStringCopy(lp->item);
 }
 
+
 /*
  * I assume that the following can be used in synthetic resources :
  *      FSBGetDirListItemCount
@@ -2897,7 +2927,7 @@ _XmFsbFileSelect(Widget w, XtPointer client, XtPointer call)
  * Other articles by Ken are available at http://www.rahul.net/kenton/bib.html
  * or http://www.rahul.net/kenton/index.shtml .
  */
-void 
+static void 
 FSBGetDirListItemCount(Widget wid, int resource_offset, XtArgVal *value)
 {
     /* rws 20 Jun 1998
@@ -2907,7 +2937,7 @@ FSBGetDirListItemCount(Widget wid, int resource_offset, XtArgVal *value)
     *value = List_ItemCount(FS_DirList(wid));
 }
 
-void 
+static void 
 FSBGetDirListItems(Widget wid, int resource_offset, XtArgVal *value)
 {
     /* According to Ken this is copied in SetValues, but not in GetValues */
@@ -2918,42 +2948,42 @@ FSBGetDirListItems(Widget wid, int resource_offset, XtArgVal *value)
     *value = (XtArgVal)List_Items(FS_DirList(wid));
 }
 
-void 
+static void 
 FSBGetDirListLabelString(Widget wid, int resource_offset, XtArgVal *value)
 {
     /* According to Ken this is always a copy */
     *value = (XtArgVal)XmStringCopy(FS_DirListLabelString(wid));
 }
 
-void 
+static void 
 FSBGetDirMask(Widget wid, int resource_offset, XtArgVal *value)
 {
     /* According to Ken this is always a copy */
     *value = (XtArgVal)XmStringCopy(FS_DirMask(wid));
 }
 
-void 
+static void 
 FSBGetDirectory(Widget wid, int resource_offset, XtArgVal *value)
 {
     /* According to Ken this is always a copy */
-    DEBUGOUT(_LtDebugDebug(__FILE__, wid, "FSBGetDirectory()\n"));
+    DEBUGOUT(_LtDebug(__FILE__, wid, "FSBGetDirectory()\n"));
     *value = (XtArgVal)XmStringCopy(FS_Directory(wid));
 }
 
-void 
+static void 
 FSBGetFilterLabelString(Widget wid, int resource_offset, XtArgVal *value)
 {
     /* According to Ken this is always a copy */
     *value = (XtArgVal)XmStringCopy(FS_FilterLabelString(wid));
 }
 
-void 
+static void 
 FSBGetListItemCount(Widget wid, int resource_offset, XtArgVal *value)
 {
     *value = (XtArgVal)SB_ListItemCount(wid);
 }
 
-void 
+static void 
 FSBGetListItems(Widget wid, int resource_offset, XtArgVal *value)
 {
     /* According to Ken this is copied in SetValues, but not in GetValues */
@@ -2963,7 +2993,7 @@ FSBGetListItems(Widget wid, int resource_offset, XtArgVal *value)
     _XmSelectionBoxGetListItems(wid, resource_offset, value);
 }
 
-void 
+static void 
 FSBGetNoMatchString(Widget wid, int resource_offset, XtArgVal *value)
 {
     /* Return a copy of the internal string because the */
@@ -2971,7 +3001,7 @@ FSBGetNoMatchString(Widget wid, int resource_offset, XtArgVal *value)
     *value = (XtArgVal)XmStringCopy(FS_NoMatchString(wid));
 }
 
-void 
+static void 
 FSBGetPattern(Widget wid, int resource_offset, XtArgVal *value)
 {
     /* Return a copy of the internal string because the */
@@ -2979,8 +3009,10 @@ FSBGetPattern(Widget wid, int resource_offset, XtArgVal *value)
     *value = (XtArgVal)XmStringCopy(FS_Pattern(wid));
 }
 
+
 static void
-FileSelectionBoxUpOrDown(Widget w, XEvent *event, String *params, Cardinal *num_params)
+FileSelectionBoxUpOrDown(Widget w, XEvent *event,
+                         String *params, Cardinal *num_params)
 {
     Arg args[4];
     Widget text, list, focus;
@@ -2989,7 +3021,7 @@ FileSelectionBoxUpOrDown(Widget w, XEvent *event, String *params, Cardinal *num_
     int *position_list, position_count, new_position, old_position;
     /* char *selected_text; */
     /* XmFileSelectionBoxCallbackStruct in, out; */
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "FileSelectionBoxUpOrDown %s\n",
+    DEBUGOUT(_LtDebug(__FILE__, w, "FileSelectionBoxUpOrDown %s\n",
 		      params ? *params: "NULL"));
 
     if (*num_params != 1)
@@ -3091,9 +3123,9 @@ FileSelectionBoxUpOrDown(Widget w, XEvent *event, String *params, Cardinal *num_
 }
 
 
-
 static void
-FileSelectionBoxRestore(Widget w, XEvent *event, String *params, Cardinal *num_params)
+FileSelectionBoxRestore(Widget w, XEvent *event,
+                        String *params, Cardinal *num_params)
 {
     Widget text, list, focus;
     /* XmStringTable items; */
@@ -3101,7 +3133,7 @@ FileSelectionBoxRestore(Widget w, XEvent *event, String *params, Cardinal *num_p
     char *selected_text;
     /* XmAnyCallbackStruct in; */
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "FileSelectionBoxRestore\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "FileSelectionBoxRestore\n"));
 
     focus = XmGetFocusWidget(w);
     if (focus == FS_FilterText(w))
