@@ -1,6 +1,6 @@
 /**
  *
- * $Id: Form.c,v 1.172 2001/05/14 19:46:08 amai Exp $
+ * $Id: Form.c,v 1.175 2001/12/04 22:35:18 dannybackx Exp $
  *
  * Copyright (C) 1996 Free Software Foundation, Inc.
  * Copyright (C) 1996-2000 LessTif Development Team
@@ -23,7 +23,7 @@
  *
  **/
 
-static const char rcsid[] = "$Id: Form.c,v 1.172 2001/05/14 19:46:08 amai Exp $";
+static const char rcsid[] = "$Id: Form.c,v 1.175 2001/12/04 22:35:18 dannybackx Exp $";
 
 #include <LTconfig.h>
 #include <XmI/XmI.h>
@@ -91,12 +91,12 @@ static XtGeometryResult _XmFormGeomRequest(Widget f,
 
 static void _XmFormConfigureChildren(Widget f, Widget cw, XtWidgetGeometry *cg);
 
-static void XmFormFindPreferred(Widget f, Widget cw, XtWidgetGeometry *cg);
+static void _XmFormFindPreferred(Widget f, Widget cw, XtWidgetGeometry *cg);
 
-void XmFormPrintAttachmentReport(Widget f);
+static void _XmFormPrintAttachmentReport(Widget f);
 static void _XmCheckAttachedWidget(Widget f, int i, XmFormConstraints con);
 
-static void XmFormAllPaths(Widget f, Dimension *ww, Dimension *hh);
+static void _XmFormAllPaths(Widget f, Dimension *ww, Dimension *hh);
 
 /*
  * Resources for the Form class
@@ -392,7 +392,7 @@ static void
 initialize(Widget request, Widget new_w,
 	   ArgList args, Cardinal *num_args)
 {
-    DEBUGOUT(_LtDebugDebug(__FILE__, new_w,
+    DEBUGOUT(_LtDebug(__FILE__, new_w,
 		      "%s:initialize(%d) - %i args\n"
 		      "\trequest X %5i Y %5i W %5i H %5i\n"
 		      "\t  new_w X %5i Y %5i W %5i H %5i\n",
@@ -433,7 +433,7 @@ realize(Widget w,
    of -2, because of the topOffset, and BulletinBoard was then enforcing
    a margin of 0.
  */
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "%s:realize(%d) - %dx%d\n",
+    DEBUGOUT(_LtDebug(__FILE__, w, "%s:realize(%d) - %dx%d\n",
 		      __FILE__, __LINE__,
 		      XtWidth(w), XtHeight(w)));
 
@@ -449,7 +449,7 @@ set_values(Widget old, Widget request, Widget new_w,
 {
     Boolean relayout = False, refresh = False;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, new_w,
+    DEBUGOUT(_LtDebug(__FILE__, new_w,
 		      "%s:set_values(%d) - %i args\n"
 		      "\t    old X %5i Y %5i W %5i H %5i\n"
 		      "\trequest X %5i Y %5i W %5i H %5i\n"
@@ -518,7 +518,7 @@ resize(Widget w)
 {
     Dimension wd, ht;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "%s:resize(%d) - %dx%d\n",
+    DEBUGOUT(_LtDebug(__FILE__, w, "%s:resize(%d) - %dx%d\n",
 		      __FILE__, __LINE__,
 		      XtWidth(w), XtHeight(w)));
 
@@ -551,7 +551,7 @@ query_geometry(Widget w, XtWidgetGeometry *proposed, XtWidgetGeometry *desired)
     Dimension wd, ht;
     XtWidgetGeometry pp;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "%s:query_geometry(%d) - proposed %s\n",
+    DEBUGOUT(_LtDebug(__FILE__, w, "%s:query_geometry(%d) - proposed %s\n",
 		      __FILE__, __LINE__,
 		      _LtDebugWidgetGeometry2String(proposed)));
 
@@ -588,7 +588,7 @@ query_geometry(Widget w, XtWidgetGeometry *proposed, XtWidgetGeometry *desired)
     desired->width = wd == 0 ? 1 : wd;
     desired->height = ht == 0 ? 1 : ht;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "%s:query_geometry(%d) - desired %s\n",
+    DEBUGOUT(_LtDebug(__FILE__, w, "%s:query_geometry(%d) - desired %s\n",
 		      __FILE__, __LINE__,
 		      _LtDebugWidgetGeometry2String(desired)));
     return _XmGMReplyToQueryGeometry(w, &pp, desired);
@@ -625,7 +625,7 @@ geometry_manager(Widget w, XtWidgetGeometry *request, XtWidgetGeometry *reply)
 
 #define       Wants(x)        (request->request_mode & x)
 
-    DEBUGOUT(_LtDebugDebug2("GM", f, w, "%s:geometry_manager(%d) - request %s\n",
+    DEBUGOUT(_LtDebug2("GM", f, w, "%s:geometry_manager(%d) - request %s\n",
 		       __FILE__, __LINE__,
 		       _LtDebugWidgetGeometry2String(request)));
     if ((request->request_mode & (CWX | CWY | CWWidth | CWHeight)) == 0)
@@ -634,10 +634,10 @@ geometry_manager(Widget w, XtWidgetGeometry *request, XtWidgetGeometry *reply)
 	*reply = *request;
 	return XtGeometryYes;
     }
-    DEBUGOUT(_LtDebugDebug2(__FILE__, f, w, "%s:geometry_manager(%d) - request %s\n",
+    DEBUGOUT(_LtDebug2(__FILE__, f, w, "%s:geometry_manager(%d) - request %s\n",
 		       __FILE__, __LINE__,
 		       _LtDebugWidgetGeometry2String(request)));
-    DEBUGOUT(_LtDebugDebug2("GM", f, w, "%s:geometry_manager(%d) - request %s\n",
+    DEBUGOUT(_LtDebug2("GM", f, w, "%s:geometry_manager(%d) - request %s\n",
 		       __FILE__, __LINE__,
 		       _LtDebugWidgetGeometry2String(request)));
 
@@ -676,11 +676,11 @@ geometry_manager(Widget w, XtWidgetGeometry *request, XtWidgetGeometry *reply)
     /* Ask form's layout algorithm what it thinks about this */
     _XmFormLayout(f, w, &mr, &wd, &ht);
 
-    DEBUGOUT(_LtDebugDebug2(__FILE__, f, w,
+    DEBUGOUT(_LtDebug2(__FILE__, f, w,
 		       "GeometryManager: Form Layout makes child geo"
 		       " %dx%d form %dx%d\n",
 		       mr.width, mr.height, wd, ht));
-    DEBUGOUT(_LtDebugDebug2("GM", f, w,
+    DEBUGOUT(_LtDebug2("GM", f, w,
 		       "GeometryManager: Form Layout makes child geo"
 		       " %dx%d%+i%+i form %dx%d %dx%d\n",
 		       mr.width, mr.height, mr.x, mr.y, wd, ht,
@@ -694,7 +694,7 @@ geometry_manager(Widget w, XtWidgetGeometry *request, XtWidgetGeometry *reply)
 	 */
 	_XmFormLayout(f, w, &mr, &wd, &ht);
 
-	DEBUGOUT(_LtDebugDebug2(__FILE__, (Widget)f, w,
+	DEBUGOUT(_LtDebug2(__FILE__, (Widget)f, w,
 			   "GeometryManager: Form Second Layout makes child geo"
 			   " %dx%d form %dx%d\n",
 			   mr.width, mr.height, wd, ht));
@@ -705,7 +705,7 @@ geometry_manager(Widget w, XtWidgetGeometry *request, XtWidgetGeometry *reply)
 	wd = XtWidth(f);
 	ht = XtHeight(f);
 	_XmFormLayout(f, w, &mr, &wd, &ht);
-	DEBUGOUT(_LtDebugDebug2("GM", f, w,
+	DEBUGOUT(_LtDebug2("GM", f, w,
 			   "GeometryManager: Form Layout 2 makes child geo"
 			   " %dx%d form %dx%d %dx%d\n",
 			   mr.width, mr.height, wd, ht,
@@ -777,7 +777,7 @@ geometry_manager(Widget w, XtWidgetGeometry *request, XtWidgetGeometry *reply)
     }
     else
     {
-	DEBUGOUT(_LtDebugDebug2("GM", f, w,
+	DEBUGOUT(_LtDebug2("GM", f, w,
 			   "GeometryManager: "
 			   " %dx%d %dx%d form %dx%d\n",
 			   wd, ht,
@@ -814,10 +814,10 @@ change_managed(Widget w)
 {
     Dimension wd, ht;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "change_managed %s %s\n",
+    DEBUGOUT(_LtDebug(__FILE__, w, "change_managed %s %s\n",
 		      Form_InitialWidth(w) ? "InitialWidth" : " ",
 		      Form_InitialHeight(w) ? "InitialHeight" : ""));
-    DEBUGOUT(_LtDebugDebug("GM", w, "change_managed %s %s %dx%d %s\n",
+    DEBUGOUT(_LtDebug("GM", w, "change_managed %s %s %dx%d %s\n",
 		      Form_InitialWidth(w) ? "InitialWidth" : " ",
 		      Form_InitialHeight(w) ? "InitialHeight" : "",
 		      XtWidth(w), XtHeight(w),
@@ -854,7 +854,7 @@ change_managed(Widget w)
 
     if (_XmFormGeomRequest(w, &wd, &ht) == XtGeometryYes)
     {
-	DEBUGOUT(_LtDebugDebug("DX", w, "change_managed Got yes %dx%d\n",
+	DEBUGOUT(_LtDebug("DX", w, "change_managed Got yes %dx%d\n",
 		      XtWidth(w), XtHeight(w)));
 	/* Why layout again?  Cause we might have gotten a compromise */
 	_XmFormLayout(w, NULL, NULL, &wd, &ht);
@@ -863,7 +863,7 @@ change_managed(Widget w)
     }
     else
     {
-	DEBUGOUT(_LtDebugDebug("DX", w, "change_managed Got no  %dx%d\n",
+	DEBUGOUT(_LtDebug("DX", w, "change_managed Got no  %dx%d\n",
 		      XtWidth(w), XtHeight(w)));
 	/*
 	 * MLM: I kept adding this, and then taking it out.
@@ -884,7 +884,7 @@ change_managed(Widget w)
     }
 
     _XmNavigChangeManaged(w);
-    DEBUGOUT(_LtDebugDebug("DX", w, "change_managed %dx%d\n",
+    DEBUGOUT(_LtDebug("DX", w, "change_managed %dx%d\n",
 		      XtWidth(w), XtHeight(w)));
 
     return;
@@ -934,7 +934,7 @@ constraint_initialize(Widget request, Widget new_w,
     Widget f = XtParent(new_w);
     int i;
 
-    DEBUGOUT(_LtDebugDebug2(__FILE__, f, new_w,
+    DEBUGOUT(_LtDebug2(__FILE__, f, new_w,
 		       "%s:constraint_initialize(%d) - %i args\n"
 		       "\trequest X %5i Y %5i W %5i H %5i\n"
 		       "\t  new_w X %5i Y %5i W %5i H %5i\n"
@@ -997,7 +997,7 @@ constraint_set_values(Widget current, Widget request, Widget new_w,
     Boolean changed = False;
     int i;
 
-    DEBUGOUT(_LtDebugDebug2(__FILE__, (Widget)f, new_w,
+    DEBUGOUT(_LtDebug2(__FILE__, (Widget)f, new_w,
 		       "%s:constraint_set_values(%d) - %i args\n"
 		       "\tcurrent X %5i Y %5i W %5i H %5i\n"
 		       "\trequest X %5i Y %5i W %5i H %5i\n"
@@ -1013,7 +1013,7 @@ constraint_set_values(Widget current, Widget request, Widget new_w,
 		       XtWidth(new_w), XtHeight(new_w),
 		       XtWidth(XtParent(new_w)), XtHeight(XtParent(new_w))));
     DEBUGOUT(_LtDebugPrintArgList(__FILE__, new_w, args, *num_args, False));
-    DEBUGOUT(_LtDebugDebug2("DX", (Widget)f, new_w,
+    DEBUGOUT(_LtDebug2("DX", (Widget)f, new_w,
 		       "%s:constraint_set_values(%d) - %i args\n"
 		       "\tcurrent X %5i Y %5i W %5i H %5i\n"
 		       "\trequest X %5i Y %5i W %5i H %5i\n"
@@ -1096,7 +1096,7 @@ constraint_set_values(Widget current, Widget request, Widget new_w,
 
 	changed = False;
 
-	DEBUGOUT(_LtDebugDebug2(__FILE__, (Widget)f, new_w,
+	DEBUGOUT(_LtDebug2(__FILE__, (Widget)f, new_w,
 			   "constraint_set_values - refused resize\n"));
     }
 
@@ -1104,7 +1104,7 @@ constraint_set_values(Widget current, Widget request, Widget new_w,
     /* scrolledwindow/test13 */
     /* form/test15 */
     /* Xinvest when centering in the frame */
-    DEBUGOUT(_LtDebugDebug2("DX", (Widget)f, new_w,"%s %s %s %s\n",
+    DEBUGOUT(_LtDebug2("DX", (Widget)f, new_w,"%s %s %s %s\n",
     	changed ? "True" : "False",
     	XtIsRealized(f) ? "True" : "False",
     	XtIsManaged(f) ? "True" : "False",
@@ -1123,7 +1123,7 @@ constraint_set_values(Widget current, Widget request, Widget new_w,
 	Dimension wd, ht;
 	XtWidgetGeometry cg;
 
-	DEBUGOUT(_LtDebugDebug(__FILE__, f,
+	DEBUGOUT(_LtDebug(__FILE__, f,
 			  "GeomRequest in constraint_set_values\n"));
 
 	if (XtWidth(f) == 0 && XtHeight(f) == 0)
@@ -1240,10 +1240,10 @@ SetW(Widget f, Widget child, int p, int line)
 
 #ifdef	PRINT_ASSIGNMENTS
 #ifdef	PRINT_LINENO
-    DEBUGOUT(_LtDebugDebug2(__FILE__, (Widget)f, child,
+    DEBUGOUT(_LtDebug2(__FILE__, (Widget)f, child,
 		       "set width to %d (line %d)\n", p, line));
 #else
-    DEBUGOUT(_LtDebugDebug2(__FILE__, (Widget)f, child, "set width to %d\n", p));
+    DEBUGOUT(_LtDebug2(__FILE__, (Widget)f, child, "set width to %d\n", p));
 #endif
 #endif
     FCP_W(con) = p;
@@ -1256,10 +1256,10 @@ SetH(Widget f, Widget child, int p, int line)
 
 #ifdef	PRINT_ASSIGNMENTS
 #ifdef	PRINT_LINENO
-    DEBUGOUT(_LtDebugDebug2(__FILE__, (Widget)f, child,
+    DEBUGOUT(_LtDebug2(__FILE__, (Widget)f, child,
 		       "set height to %d (line %d)\n", p, line));
 #else
-    DEBUGOUT(_LtDebugDebug2(__FILE__, (Widget)f, child, "set height to %d\n", p));
+    DEBUGOUT(_LtDebug2(__FILE__, (Widget)f, child, "set height to %d\n", p));
 #endif
 #endif
     FCP_H(con) = p;
@@ -1273,10 +1273,10 @@ SetX(Widget f, Widget child, int p, int line)
 
 #ifdef	PRINT_ASSIGNMENTS
 #ifdef	PRINT_LINENO
-    DEBUGOUT(_LtDebugDebug2(__FILE__, (Widget)f, child,
+    DEBUGOUT(_LtDebug2(__FILE__, (Widget)f, child,
 		       "set x to %d (line %d)\n", p, line));
 #else
-    DEBUGOUT(_LtDebugDebug2(__FILE__, (Widget)f, child, "set x to %d\n", p));
+    DEBUGOUT(_LtDebug2(__FILE__, (Widget)f, child, "set x to %d\n", p));
 #endif
 #endif
     FCP_X(con) = p;
@@ -1290,10 +1290,10 @@ SetY(Widget f, Widget child, int p, int line)
 
 #ifdef	PRINT_ASSIGNMENTS
 #ifdef	PRINT_LINENO
-    DEBUGOUT(_LtDebugDebug2(__FILE__, (Widget)f, child,
+    DEBUGOUT(_LtDebug2(__FILE__, (Widget)f, child,
 		       "set y to %d (line %d)\n", p, line));
 #else
-    DEBUGOUT(_LtDebugDebug2(__FILE__, (Widget)f, child, "set y to %d\n", p));
+    DEBUGOUT(_LtDebug2(__FILE__, (Widget)f, child, "set y to %d\n", p));
 #endif
 #endif
     FCP_Y(con) = p;
@@ -1305,10 +1305,10 @@ SetFW(Widget f, Widget child, int p, int line)
 {
 #ifdef	PRINT_ASSIGNMENTS
 #ifdef	PRINT_LINENO
-    DEBUGOUT(_LtDebugDebug2(__FILE__, (Widget)f, child,
+    DEBUGOUT(_LtDebug2(__FILE__, (Widget)f, child,
 		       "set form width to %d (line %d)\n", p, line));
 #else
-    DEBUGOUT(_LtDebugDebug2(__FILE__, (Widget)f, child,
+    DEBUGOUT(_LtDebug2(__FILE__, (Widget)f, child,
 		       "set form width to %d\n", p));
 #endif
 #endif
@@ -1320,10 +1320,10 @@ SetFH(Widget f, Widget child, int p, int line)
 {
 #ifdef	PRINT_ASSIGNMENTS
 #ifdef	PRINT_LINENO
-    _LtDebugDebug2(__FILE__, (Widget)f, child,
+    _LtDebug2(__FILE__, (Widget)f, child,
 	      "set form height to %d (line %d)\n", p, line);
 #else
-    DEBUGOUT(_LtDebugDebug2(__FILE__, (Widget)f, child,
+    DEBUGOUT(_LtDebug2(__FILE__, (Widget)f, child,
 		       "set form height to %d\n", p));
 #endif
 #endif
@@ -1350,7 +1350,7 @@ _XmCheckAttachedWidget(Widget f, int i, XmFormConstraints con)
 	{
 	    if (XtParent(w) == (Widget)f)
 	    {
-		DEBUGOUT(_LtDebugDebug2(__FILE__, (Widget)f,
+		DEBUGOUT(_LtDebug2(__FILE__, (Widget)f,
 				   FCP_Atta(con, i).w,
 				   "Replace child by %s\n", XtName(w)));
 #ifdef	LESSTIF_VERBOSE
@@ -1438,13 +1438,13 @@ _XmCheckAttachedWidget(Widget f, int i, XmFormConstraints con)
  *  set call XtQueryGeomtry()" (Bottom Pg 388)
  */
 static void
-XmFormFindPreferred(Widget f, Widget cw, XtWidgetGeometry *cg)
+_XmFormFindPreferred(Widget f, Widget cw, XtWidgetGeometry *cg)
 {
     Cardinal i;
     Boolean changed;		/* is needed because of SETX macros */
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, (Widget)f, "XmFormFindPreferred() - start\n"));
-    DEBUGOUT(_LtDebugDebug2(__FILE__, (Widget)f, cw, "XmFormFindPreferred() - request %s\n",
+    DEBUGOUT(_LtDebug(__FILE__, (Widget)f, "_XmFormFindPreferred() - start\n"));
+    DEBUGOUT(_LtDebug2(__FILE__, (Widget)f, cw, "_XmFormFindPreferred() - request %s\n",
 		       _LtDebugWidgetGeometry2String(cg)));
     for (i = 0; i < MGR_NumChildren(f); i++)
     {
@@ -1536,7 +1536,7 @@ XmFormFindPreferred(Widget f, Widget cw, XtWidgetGeometry *cg)
 	}
     }
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, (Widget)f, "XmFormFindPreferred() - end\n"));
+    DEBUGOUT(_LtDebug(__FILE__, (Widget)f, "_XmFormFindPreferred() - end\n"));
 }
 
 /*
@@ -1548,13 +1548,13 @@ XmFormFindPreferred(Widget f, Widget cw, XtWidgetGeometry *cg)
     {									\
 	if (FCP_Atta(con, x).w == NULL)					\
 	{								\
-	    DEBUGOUT(_LtDebugDebug0(__FILE__, (Widget)f,  "%s(%s)\t",	\
+	    DEBUGOUT(_LtDebug0(__FILE__, (Widget)f,  "%s(%s)\t",	\
 			       _LtDebugAttachment2String(FCP_Atta(con, x).type),	\
 			       "(null)"));				\
 	}								\
 	else								\
 	{								\
-	    DEBUGOUT(_LtDebugDebug0(__FILE__, (Widget)f,  "%s(%s,%d)\t",	\
+	    DEBUGOUT(_LtDebug0(__FILE__, (Widget)f,  "%s(%s,%d)\t",	\
 			       _LtDebugAttachment2String(FCP_Atta(con, x).type),	\
 			       XtName(FCP_Atta(con, x).w),		\
 			       FCP_Atta(con, x).offset));		\
@@ -1562,25 +1562,25 @@ XmFormFindPreferred(Widget f, Widget cw, XtWidgetGeometry *cg)
     }									\
     else if (FCP_Atta(con, x).type == XmATTACH_POSITION)		\
     {									\
-	DEBUGOUT(_LtDebugDebug0(__FILE__, (Widget)f, "%s(%d/%d,%d)\t",	\
+	DEBUGOUT(_LtDebug0(__FILE__, (Widget)f, "%s(%d/%d,%d)\t",	\
 		 _LtDebugAttachment2String(FCP_Atta(con, x).type),		\
 		 FCP_Atta(con, x).percent, Form_FractionBase(f),		\
 		 FCP_Atta(con, x).offset));				\
     }									\
     else								\
     {									\
-	DEBUGOUT(_LtDebugDebug0(__FILE__, (Widget)f,  "%s(%d)\t",		\
+	DEBUGOUT(_LtDebug0(__FILE__, (Widget)f,  "%s(%d)\t",		\
 		 _LtDebugAttachment2String(FCP_Atta(con, x).type),		\
 		 FCP_Atta(con, x).offset));				\
     }
 
 
 extern void
-XmFormPrintAttachmentReport(Widget f)
+_XmFormPrintAttachmentReport(Widget f)
 {
     Cardinal i;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, (Widget)f,
+    DEBUGOUT(_LtDebug(__FILE__, (Widget)f,
 		      "Attachment Report : (Top,Bottom,Left,Right)\n"));
 
     for (i = 0; i < MGR_NumChildren(f); i++)
@@ -1588,16 +1588,16 @@ XmFormPrintAttachmentReport(Widget f)
 	Widget child = MGR_Children(f)[i];
 	XmFormConstraints con = (XmFormConstraints)CoreConstraints(child);
 
-	DEBUGOUT(_LtDebugDebug0(__FILE__, (Widget)f,
+	DEBUGOUT(_LtDebug0(__FILE__, (Widget)f,
 			   "child %s\t\t", XtName(child)));
 
 	PRINTIT(TOP);
 	PRINTIT(BOTTOM);
-	DEBUGOUT(_LtDebugDebug0(__FILE__, (Widget)f, "\n\t\t\t\t"));
+	DEBUGOUT(_LtDebug0(__FILE__, (Widget)f, "\n\t\t\t\t"));
 	PRINTIT(LEFT);
 	PRINTIT(RIGHT);
 
-	DEBUGOUT(_LtDebugDebug0(__FILE__, (Widget)f, "\n"));
+	DEBUGOUT(_LtDebug0(__FILE__, (Widget)f, "\n"));
     }
 }
 #undef	PRINTIT
@@ -1731,7 +1731,7 @@ XmFormPath(Widget f, Widget c, int dir, XmFormAttachment atta)
 
 
 static void
-XmFormAllPaths(Widget f, Dimension *ww, Dimension *hh)
+_XmFormAllPaths(Widget f, Dimension *ww, Dimension *hh)
 {
     int y;
     Cardinal i;
@@ -1797,8 +1797,8 @@ XmFormAllPaths(Widget f, Dimension *ww, Dimension *hh)
 	    {
 		y += atta[TOP].tempValue;
 	    }
-	    DEBUGOUT(_LtDebugDebug2(__FILE__, (Widget)f, child,
-			       "XmFormAllPaths H %5i %i %i\n", y, atta[TOP].tempValue, atta[BOTTOM].tempValue));
+	    DEBUGOUT(_LtDebug2(__FILE__, (Widget)f, child,
+			       "_XmFormAllPaths H %5i %i %i\n", y, atta[TOP].tempValue, atta[BOTTOM].tempValue));
 	    if (y > *hh)
 	    {
 		*hh = y;
@@ -1865,8 +1865,8 @@ XmFormAllPaths(Widget f, Dimension *ww, Dimension *hh)
 	    {
 		y += atta[LEFT].tempValue;
 	    }
-	    DEBUGOUT(_LtDebugDebug2(__FILE__, (Widget)f, child,
-			       "XmFormAllPaths W %5i %i %i\n", y, atta[LEFT].tempValue, atta[RIGHT].tempValue));
+	    DEBUGOUT(_LtDebug2(__FILE__, (Widget)f, child,
+			       "_XmFormAllPaths W %5i %i %i\n", y, atta[LEFT].tempValue, atta[RIGHT].tempValue));
 	    if (y > *ww)
 	    {
 		*ww = y;
@@ -1874,8 +1874,8 @@ XmFormAllPaths(Widget f, Dimension *ww, Dimension *hh)
 	}
     }
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, (Widget)f,
-		      "XmFormAllPaths returning %d %d\n", *ww, *hh));
+    DEBUGOUT(_LtDebug(__FILE__, (Widget)f,
+		      "_XmFormAllPaths returning %d %d\n", *ww, *hh));
 }
 
 
@@ -1937,10 +1937,10 @@ _XmFormLayout(Widget f, Widget cw, XtWidgetGeometry *cg,
 
 #define	Wants(x)	(cg->request_mode & x)
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, (Widget)f,
+    DEBUGOUT(_LtDebug(__FILE__, (Widget)f,
 		      "_XmFormLayout with width %d height %d\n",
 		      XtWidth(f), XtHeight(f)));
-    DEBUGOUT(_LtDebugDebug2(__FILE__, (Widget)f, cw,
+    DEBUGOUT(_LtDebug2(__FILE__, (Widget)f, cw,
 		       "_XmFormLayout request %s\n",
 		       _LtDebugWidgetGeometry2String(cg)));
 
@@ -1951,7 +1951,7 @@ _XmFormLayout(Widget f, Widget cw, XtWidgetGeometry *cg,
      */
     if (_XmGeoCount_kids((CompositeRec *)f) == 0)
     {
-	DEBUGOUT(_LtDebugDebug(__FILE__, (Widget)f,
+	DEBUGOUT(_LtDebug(__FILE__, (Widget)f,
 			  "_XmFormLayout: Form has no managed kids!\n"));
 
 	*width = XtWidth(f);
@@ -1965,7 +1965,7 @@ _XmFormLayout(Widget f, Widget cw, XtWidgetGeometry *cg,
     fh = *height;
 
     /* Find all preferred sizes */
-    XmFormFindPreferred(f, cw, cg);
+    _XmFormFindPreferred(f, cw, cg);
 
     if (fw > 1)
     {
@@ -1990,7 +1990,7 @@ _XmFormLayout(Widget f, Widget cw, XtWidgetGeometry *cg,
 	ParentChangeMode = False;
     }
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, (Widget)f,
+    DEBUGOUT(_LtDebug(__FILE__, (Widget)f,
 		      "XmFormLayout\n\tWidthChangeMode  %s\n"
 		      "\tHeightChangeMode %s\n\tParentChangeMode %s\n",
 		      _LtDebugBoolean2String(WidthChangeMode),
@@ -2041,7 +2041,7 @@ _XmFormLayout(Widget f, Widget cw, XtWidgetGeometry *cg,
 	if (FCP_Atta(con, LEFT).type == XmATTACH_NONE &&
 	    FCP_Atta(con, RIGHT).type == XmATTACH_NONE)
 	{
-	    DEBUGOUT(_LtDebugDebug2(__FILE__, (Widget)f, child,
+	    DEBUGOUT(_LtDebug2(__FILE__, (Widget)f, child,
 			       "left & right were NONE\n"));
 
 	    if (Form_RubberPos(f) == True)
@@ -2053,7 +2053,7 @@ _XmFormLayout(Widget f, Widget cw, XtWidgetGeometry *cg,
 		    (FCP_Atta(con, LEFT).value / Form_FractionBase(f));
 		    */
 
-		DEBUGOUT(_LtDebugDebug2(__FILE__, (Widget)f, child,
+		DEBUGOUT(_LtDebug2(__FILE__, (Widget)f, child,
 				   "Left set to ATTACH_POSITION %d\n",
 				   FCP_Atta(con, LEFT).percent));
 	    }
@@ -2065,7 +2065,7 @@ _XmFormLayout(Widget f, Widget cw, XtWidgetGeometry *cg,
 		 */
 		FCP_Atta(con, LEFT).offset = XtX(child) - BB_MarginWidth(f);
 
-		DEBUGOUT(_LtDebugDebug2(__FILE__, (Widget)f, child,
+		DEBUGOUT(_LtDebug2(__FILE__, (Widget)f, child,
 				   "Left set to ATTACH_FORM %d\n",
 				   FCP_Atta(con, LEFT).offset));
 	    }
@@ -2078,7 +2078,7 @@ _XmFormLayout(Widget f, Widget cw, XtWidgetGeometry *cg,
 	if (FCP_Atta(con, TOP).type == XmATTACH_NONE &&
 	    FCP_Atta(con, BOTTOM).type == XmATTACH_NONE)
 	{
-	    DEBUGOUT(_LtDebugDebug2(__FILE__, (Widget)f, child,
+	    DEBUGOUT(_LtDebug2(__FILE__, (Widget)f, child,
 			       "top & bottom were NONE\n"));
 
 	    if (Form_RubberPos(f) == True)
@@ -2090,7 +2090,7 @@ _XmFormLayout(Widget f, Widget cw, XtWidgetGeometry *cg,
 		    (FCP_Atta(con, TOP).value / Form_FractionBase(f));
 		    */
 
-		DEBUGOUT(_LtDebugDebug2(__FILE__, (Widget)f, child,
+		DEBUGOUT(_LtDebug2(__FILE__, (Widget)f, child,
 				   "Top set to ATTACH_POSITION %d\n",
 				   FCP_Atta(con, TOP).percent));
 	    }
@@ -2099,7 +2099,7 @@ _XmFormLayout(Widget f, Widget cw, XtWidgetGeometry *cg,
 		FCP_Atta(con, TOP).type = XmATTACH_FORM;
 		FCP_Atta(con, TOP).offset = XtY(child) - BB_MarginHeight(f);
 
-		DEBUGOUT(_LtDebugDebug2(__FILE__, (Widget)f, child,
+		DEBUGOUT(_LtDebug2(__FILE__, (Widget)f, child,
 				   "Top set to ATTACH_FORM %d\n",
 				   FCP_Atta(con, TOP).offset));
 	    }
@@ -2108,20 +2108,20 @@ _XmFormLayout(Widget f, Widget cw, XtWidgetGeometry *cg,
     }
 
 #ifdef	PRINT_ATTACHMENT_REPORT
-    XmFormPrintAttachmentReport(f);
+    _XmFormPrintAttachmentReport(f);
 #endif
 
 #ifdef PRINT_REPORT
-    DEBUGOUT(_LtDebugDebug(__FILE__, (Widget)f,
+    DEBUGOUT(_LtDebug(__FILE__, (Widget)f,
 		      "Initial geometry : %d %d\n", fw, fh));
-    DEBUGOUT(_LtDebugDebug0(__FILE__, (Widget)f, "Initial child geometry :\n"));
+    DEBUGOUT(_LtDebug0(__FILE__, (Widget)f, "Initial child geometry :\n"));
 
     for (i = 0; i < MGR_NumChildren(f); i++)
     {
 	Widget child = MGR_Children(f)[i];
 	XmFormConstraints con = (XmFormConstraints)CoreConstraints(child);
 
-	DEBUGOUT(_LtDebugDebug0(__FILE__, (Widget)f,
+	DEBUGOUT(_LtDebug0(__FILE__, (Widget)f,
 			   "Child #%d (%s)\tx %d y %d w %d h %d\n",
 			   i, XtName(child),
 			   FCP_X(con), FCP_Y(con),
@@ -2140,7 +2140,7 @@ _XmFormLayout(Widget f, Widget cw, XtWidgetGeometry *cg,
      */
     do
     {
-	DEBUGOUT(_LtDebugDebug(__FILE__, (Widget)f,
+	DEBUGOUT(_LtDebug(__FILE__, (Widget)f,
 			  "Layout iteration %d\n", number_of_iterations));
 
 	changed = False;
@@ -2161,7 +2161,7 @@ _XmFormLayout(Widget f, Widget cw, XtWidgetGeometry *cg,
 	     * have their sizes changed due to the constraints, if this
 	     * is the case we need this call.
 	     */
-	    XmFormAllPaths(f, &ww, &hh);
+	    _XmFormAllPaths(f, &ww, &hh);
 
 	    if (number_of_iterations / 2 * 2 == number_of_iterations)
 	    {
@@ -2322,7 +2322,7 @@ _XmFormLayout(Widget f, Widget cw, XtWidgetGeometry *cg,
 
 		    if (FCP_Y(con) != pos)
 		    {
-			DEBUGOUT(_LtDebugDebug(__FILE__, (Widget)f,
+			DEBUGOUT(_LtDebug(__FILE__, (Widget)f,
 					  "Computed pos as %d\n", pos));
 
 			if (!HeightChangeMode && FCP_Atta(con, BOTTOM).type != XmATTACH_NONE)
@@ -2525,9 +2525,11 @@ _XmFormLayout(Widget f, Widget cw, XtWidgetGeometry *cg,
 
 		/* BOTTOM */
 	    case XmATTACH_SELF:
+#if 0
+		/* Meditres has this */
 		_XmWarning(child, "bottom ATTACH_SELF %s %d"
 			   " no test coverage", __FILE__, __LINE__);
-
+#endif
 		FCP_Atta(con, BOTTOM).percent = (FCP_Y(con) + FCP_H(con) +
 					       _XmGetOffset(child, BOTTOM)) *
 		    Form_FractionBase(f) / fh;
@@ -2881,7 +2883,7 @@ _XmFormLayout(Widget f, Widget cw, XtWidgetGeometry *cg,
 	_XmWarning((Widget)f,
 		   "Layout algorithm bailing out after %d iterations",
 		   MAX_ITERATIONS);
-	DEBUGOUT(_LtDebugDebug(__FILE__, (Widget)f,
+	DEBUGOUT(_LtDebug(__FILE__, (Widget)f,
 			  "Bailing out after %d iterations",
 			  MAX_ITERATIONS));
     }
@@ -2890,14 +2892,14 @@ _XmFormLayout(Widget f, Widget cw, XtWidgetGeometry *cg,
      * handy/dandy debug data.
      */
 #ifdef	PRINT_REPORT
-    DEBUGOUT(_LtDebugDebug(__FILE__, (Widget)f,
+    DEBUGOUT(_LtDebug(__FILE__, (Widget)f,
 		      "XmFormLayout results : form size %d %d\n", fw, fh));
     for (i = 0; i < MGR_NumChildren(f); i++)
     {
 	Widget child = MGR_Children(f)[i];
 	XmFormConstraints con = (XmFormConstraints)CoreConstraints(child);
 
-	DEBUGOUT(_LtDebugDebug0(__FILE__, (Widget)f,
+	DEBUGOUT(_LtDebug0(__FILE__, (Widget)f,
 			   "\tChild #%d (%s)\tx %d y %d w %d h %d %s\n",
 			   i, XtName(child), FCP_X(con),
 			   FCP_Y(con), FCP_W(con), FCP_H(con),
@@ -2943,7 +2945,7 @@ _XmFormGeomRequest(Widget f, Dimension *width, Dimension *height)
     request.height = *height;
     request.border_width = XtBorderWidth(f);
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, (Widget)f,
+    DEBUGOUT(_LtDebug(__FILE__, (Widget)f,
 		      "Form is making a GeometryRequest to %s!!!!!!!!!\n",
 		      XtName(XtParent(f))));
 
@@ -2968,11 +2970,11 @@ _XmFormGeomRequest(Widget f, Dimension *width, Dimension *height)
     {
 	result = _XmMakeGeometryRequest((Widget)f, &request);
 
-	DEBUGOUT(_LtDebugDebug(__FILE__, (Widget)f,
+	DEBUGOUT(_LtDebug(__FILE__, (Widget)f,
 			  "_XmMakeGeometryRequest (w %d h %d) => %s\n",
 			  request.width, request.height,
 			  _LtDebugGeometryResult2String(result)));
-	DEBUGOUT(_LtDebugDebug("GM", (Widget)f,
+	DEBUGOUT(_LtDebug("GM", (Widget)f,
 			  "_XmMakeGeometryRequest (w %d h %d) => %s\n",
 			  request.width, request.height,
 			  _LtDebugGeometryResult2String(result)));
@@ -2982,10 +2984,10 @@ _XmFormGeomRequest(Widget f, Dimension *width, Dimension *height)
 	    *width = request.width;
 	    *height = request.height;
 
-	    DEBUGOUT(_LtDebugDebug(__FILE__, (Widget)f,
+	    DEBUGOUT(_LtDebug(__FILE__, (Widget)f,
 			      "Got Yes for _XmMakeGeometryRequest: %d %d\n",
 			      *width, *height));
-	    DEBUGOUT(_LtDebugDebug("GM", (Widget)f,
+	    DEBUGOUT(_LtDebug("GM", (Widget)f,
 			      "Got Yes for _XmMakeGeometryRequest: %d %d\n",
 			      *width, *height));
 	}
@@ -3010,7 +3012,7 @@ _XmFormConfigureChildren(Widget f, Widget cw, XtWidgetGeometry *cg)
 {
     Cardinal i;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, (Widget)f,
+    DEBUGOUT(_LtDebug(__FILE__, (Widget)f,
 		      "_XmFormConfigureChildren:  Child is %s\n",
 		      cw ? XtName(cw) : "(null)"));
 
@@ -3024,7 +3026,7 @@ _XmFormConfigureChildren(Widget f, Widget cw, XtWidgetGeometry *cg)
 	    continue;
 	if (cw && cw == child)
 	{
-	    DEBUGOUT(_LtDebugDebug(__FILE__, (Widget)f,
+	    DEBUGOUT(_LtDebug(__FILE__, (Widget)f,
 			      "_XmFormConfigureChildren:  Child is %s\n",
 			      cw ? XtName(cw) : "(null)"));
 
