@@ -1,9 +1,9 @@
 /**
  *
- * $Id: ImageCache.c,v 1.25 2001/05/14 19:46:09 amai Exp $
+ * $Header: /cvsroot/lesstif/lesstif/lib/Xm/ImageCache.c,v 1.27 2002/02/20 21:39:16 dannybackx Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
- * Copyright (C) 1995-2001 LessTif Development Team
+ * Copyright  1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -23,7 +23,7 @@
  *
  **/
 
-static const char rcsid[] = "$Id: ImageCache.c,v 1.25 2001/05/14 19:46:09 amai Exp $";
+static const char rcsid[] = "$Header: /cvsroot/lesstif/lesstif/lib/Xm/ImageCache.c,v 1.27 2002/02/20 21:39:16 dannybackx Exp $";
 
 /*
  * --aldi 97/01/11: changed to use the generic hashtable module.
@@ -251,7 +251,7 @@ XmGetPixmap(Screen *screen, char *image_name,
     p = XmGetPixmapByDepth(screen, image_name, foreground, background,
 			   DefaultDepthOfScreen(screen));
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, NULL,
+    DEBUGOUT(_LtDebug(__FILE__, NULL,
 		      "XmGetPixmap(%s, %d, %d) => 0x%x (depth %d)\n",
 		      image_name, foreground, background, p,
 		      DefaultDepthOfScreen(screen)));
@@ -445,7 +445,7 @@ XmGetPixmapByDepth(Screen *screen, char *image_name,
 	return XmUNSPECIFIED_PIXMAP;
     }
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, NULL,
+    DEBUGOUT(_LtDebug(__FILE__, NULL,
 		      "pathname found is %s\n", pathname_to_pixmap));
 
 
@@ -1096,7 +1096,7 @@ _LTCreateSearchPath(void)
 		HOME, HOME, HOME, HOME, HOME, HOME, HOME);
     }
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, NULL,
+    DEBUGOUT(_LtDebug(__FILE__, NULL,
 		      "Using %s for search path\n", _search_path));
 }
 
