@@ -1,5 +1,5 @@
 /**
- * $Id: LTglob.c,v 1.26 2001/05/14 19:46:09 amai Exp $
+ * $Id: LTglob.c,v 1.29 2002/04/12 23:38:44 amai Exp $
  *
  * derived from GNU libc glob.c
  *
@@ -25,7 +25,7 @@
  *
  **/
 
-static const char rcsid[] = "$Id: LTglob.c,v 1.26 2001/05/14 19:46:09 amai Exp $";
+static const char rcsid[] = "$Id: LTglob.c,v 1.29 2002/04/12 23:38:44 amai Exp $";
 
 #include <LTconfig.h>
 
@@ -81,7 +81,7 @@ static const char rcsid[] = "$Id: LTglob.c,v 1.26 2001/05/14 19:46:09 amai Exp $
 #define REAL_DIR_ENTRY(dp) (dp->d_ino != 0)
 #endif /* POSIX */
 
-#include "LTglob.h"
+#include <XmI/LTglob.h>
 
 #include <XmI/DebugUtil.h>
 
@@ -316,7 +316,7 @@ _Lesstif_glob(const char *pattern, int flags,
 	return -1;
     }
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, NULL,
+    DEBUGOUT(_LtDebug(__FILE__, NULL,
 		      "_Lesstif_glob(%s, %i)\n", pattern, flags));
 
     /* Find the filename.  */
@@ -372,7 +372,7 @@ _Lesstif_glob(const char *pattern, int flags,
 	glob_t dirs;
 	register int i;
 
-        DEBUGOUT(_LtDebugDebug(__FILE__, NULL,
+        DEBUGOUT(_LtDebug(__FILE__, NULL,
 		      "glob_pattern(%s, !(flags & GLOB_NOESCAPE))!=NULL\n", dirname));
 	status = _Lesstif_glob(dirname,
 			 ((flags & (GLOB_ERR | GLOB_NOCHECK | GLOB_NOESCAPE)) |
@@ -463,7 +463,7 @@ _Lesstif_glob(const char *pattern, int flags,
     } /* if (glob_pattern_p(dirname, !(flags & GLOB_NOESCAPE))) */
     else
     {
-        DEBUGOUT(_LtDebugDebug(__FILE__, NULL,
+        DEBUGOUT(_LtDebug(__FILE__, NULL,
 		      "glob_pattern(%s, !(flags & GLOB_NOESCAPE))=NULL\n", dirname));
 
 	status = glob_in_dir(filename, dirname, flags, errfunc, pglob);
@@ -502,7 +502,7 @@ _Lesstif_glob(const char *pattern, int flags,
 	int i;
 	struct stat st;
 
-        DEBUGOUT(_LtDebugDebug(__FILE__, NULL,
+        DEBUGOUT(_LtDebug(__FILE__, NULL,
 		      "_Lesstif_glob(): GLOB_NOSORT\n"));
 	for (i = oldcount; i < pglob->gl_pathc; ++i)
 	    if (LTstat(pglob->gl_pathv[i], &st) == 0 &&
@@ -598,7 +598,7 @@ glob_pattern_p(const char *pattern, int quote)
     register const char *p;
     int open = 0;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, NULL,
+    DEBUGOUT(_LtDebug(__FILE__, NULL,
 		      "glob_pattern_p(%s, %i)\n", pattern, quote));
     for (p = pattern; *p != '\0'; ++p)
 	switch (*p)
@@ -645,7 +645,7 @@ glob_in_dir(const char *pattern, const char *directory, int flags,
     size_t nfound = 0;
 
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, NULL,
+    DEBUGOUT(_LtDebug(__FILE__, NULL,
 		      "glob_in_dir(%s, %s, %i,)\n",
 		      pattern, directory, flags));    
     if (!glob_pattern_p(pattern, !(flags & GLOB_NOESCAPE)))
@@ -741,8 +741,12 @@ glob_in_dir(const char *pattern, const char *directory, int flags,
 	while (pglob->gl_pathc < pglob->gl_offs)
 	    pglob->gl_pathv[pglob->gl_pathc++] = NULL;
 
-    for (; names != NULL; names = names->next)
+    while (names != NULL) {
+	struct globlink *next = names->next;
 	pglob->gl_pathv[pglob->gl_pathc++] = names->name;
+	XtFree((char *)names);
+	names = next;
+    }
     pglob->gl_pathv[pglob->gl_pathc] = NULL;
 
     pglob->gl_flags = flags;
@@ -757,7 +761,7 @@ glob_in_dir(const char *pattern, const char *directory, int flags,
 	    closedir((DIR *) stream);
 	errno = save;
     }
-    if (names) XtFree((char *)names);
+
     return nfound == 0 ? GLOB_NOMATCH : 0;
 
   memory_error:
