@@ -1,9 +1,9 @@
 /**
  *
- * $Header: /cvsroot/lesstif/lesstif/lib/Xm/Label.c,v 1.119 2001/05/14 19:46:09 amai Exp $
+ * $Header: /cvsroot/lesstif/lesstif/lib/Xm/Label.c,v 1.130 2002/04/25 17:40:11 dannybackx Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
- * Copyright (C) 1995-2001 LessTif Development Team
+ * Copyright  1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -23,7 +23,7 @@
  *
  **/
 
-static const char rcsid[] = "$Header: /cvsroot/lesstif/lesstif/lib/Xm/Label.c,v 1.119 2001/05/14 19:46:09 amai Exp $";
+static const char rcsid[] = "$Header: /cvsroot/lesstif/lesstif/lib/Xm/Label.c,v 1.130 2002/04/25 17:40:11 dannybackx Exp $";
 
 #include <LTconfig.h>
 
@@ -96,7 +96,7 @@ static void drag_drop_finish(Widget w,
 			     XtPointer call_data);
 
 static void preferred_size(Widget w, Dimension *width, Dimension *height);
-
+static void _XmLabelSetRenderTable(Widget, int, XrmValue *);
 /*
  * Resources for the label class
  */
@@ -148,18 +148,38 @@ static XtResource resources[] =
 	sizeof(Dimension), Offset(margin_bottom),
 	XmRImmediate, (XtPointer)0
     },
+#if (XmVERSION > 1)
+    {
+	/*
+	 * Note !!
+	 * Order is important. This resource must be specified before the
+	 * XmNfontList and XmNrenderTable, otherwise the check_set_render_table
+	 * flag is not initialised before use in _XmLabelSetRenderTable().
+	 */
+	"keep.off", "Keep.off", XmRBoolean,
+	sizeof(Boolean), Offset(check_set_render_table),
+	XmRImmediate, (XtPointer)NULL
+    },
+#endif
     {
 	XmNfontList, XmCFontList, XmRFontList,
 	sizeof(XmFontList), Offset(font),
-	XmRImmediate, (XtPointer)NULL
+	XmRCallProc, (XtPointer)_XmLabelSetRenderTable
     },
+#if (XmVERSION > 1)
+    {
+	XmNrenderTable, XmCRenderTable, XmRRenderTable,
+	sizeof(XmFontList), Offset(font),
+	XmRCallProc, (XtPointer)_XmLabelSetRenderTable
+    },
+#endif
     {
 	XmNlabelPixmap, XmCLabelPixmap, XmRPrimForegroundPixmap,
 	sizeof(Pixmap), Offset(pixmap),
 	XmRImmediate, (XtPointer)XmUNSPECIFIED_PIXMAP
     },
     {
- XmNlabelInsensitivePixmap, XmCLabelInsensitivePixmap, XmRPrimForegroundPixmap,
+	XmNlabelInsensitivePixmap, XmCLabelInsensitivePixmap, XmRPrimForegroundPixmap,
 	sizeof(Pixmap), Offset(pixmap_insen),
 	XmRImmediate, (XtPointer)XmUNSPECIFIED_PIXMAP
     },
@@ -206,9 +226,9 @@ static XtResource resources[] =
     },
     {
 	XmNhighlightThickness, XmCHighlightThickness, XmRHorizontalDimension,
-      sizeof(Dimension), XtOffsetOf(XmLabelRec, primitive.highlight_thickness),
+	sizeof(Dimension), XtOffsetOf(XmLabelRec, primitive.highlight_thickness),
 	XmRImmediate, (XtPointer)0
-    }
+    },
 };
 
 /* Synthetic Resources for the Label Widget */
@@ -281,7 +301,6 @@ static XtActionsRec actions[] =
     {"ProcessDrag", ProcessDrag},
 };
 
-/* *INDENT-OFF* */
 static XmBaseClassExtRec _XmLabelCoreClassExtRec = {
     /* next_extension            */ NULL,
     /* record_type               */ NULLQUARK,
@@ -372,11 +391,9 @@ XmLabelClassRec xmLabelClassRec = {
 	/* extension           */ NULL
     }
 };
-/* *INDENT-ON* */
 
 WidgetClass xmLabelWidgetClass = (WidgetClass)&xmLabelClassRec;
 
-extern XmFontList _XmFontListCreateDefault(Display *);
 
 static XtTranslations menu_trans = NULL;
 static XtTranslations default_trans = NULL;
@@ -398,11 +415,11 @@ class_part_initialize(WidgetClass widget_class)
     (XmLabelWidgetClass)(widget_class->core_class.superclass);
     XmPrimitiveClassExt ext, *extptr, *sextptr;
 
-    DEBUGOUT(_LtDebugDebug0(__FILE__, NULL, "%s:class_part_initialize(%d) - %s -> %s\n",
+    DEBUGOUT(_LtDebug0(__FILE__, NULL, "%s:class_part_initialize(%d) - %s -> %s\n",
 		__FILE__, __LINE__,
 		swc->core_class.class_name,
 		widget_class->core_class.class_name));
-    DEBUGOUT(_LtDebugDebug0("MENUT", NULL, "%s:class_part_initialize(%d) - %s -> %s\n",
+    DEBUGOUT(_LtDebug0("MENUT", NULL, "%s:class_part_initialize(%d) - %s -> %s\n",
 		__FILE__, __LINE__,
 		swc->core_class.class_name,
 		widget_class->core_class.class_name));
@@ -410,34 +427,34 @@ class_part_initialize(WidgetClass widget_class)
 
     if (lwc->label_class.menuProcs == XmInheritMenuProc)
     {
-	DEBUGOUT(_LtDebugDebug(__FILE__, NULL, "    XmInheritMenuProc\n"));
+	DEBUGOUT(_LtDebug(__FILE__, NULL, "    XmInheritMenuProc\n"));
 	lwc->label_class.menuProcs =
 	    swc->label_class.menuProcs;
     }
     if (lwc->label_class.setOverrideCallback == XmInheritSetOverrideCallback)
     {
-	DEBUGOUT(_LtDebugDebug(__FILE__, NULL, "    XmInheritSetOverrideCallback\n"));
+	DEBUGOUT(_LtDebug(__FILE__, NULL, "    XmInheritSetOverrideCallback\n"));
 	lwc->label_class.setOverrideCallback =
 	    swc->label_class.setOverrideCallback;
     }
     if (lwc->label_class.translations == XtInheritTranslations)
     {
-	DEBUGOUT(_LtDebugDebug(__FILE__, NULL, "    XtInheritTranslations\n"));
-	DEBUGOUT(_LtDebugDebug0("MENUT", NULL, "    XtInheritTranslations\n"));
+	DEBUGOUT(_LtDebug(__FILE__, NULL, "    XtInheritTranslations\n"));
+	DEBUGOUT(_LtDebug0("MENUT", NULL, "    XtInheritTranslations\n"));
 	lwc->label_class.translations =
 	    swc->label_class.translations;
     }
     else if (lwc->label_class.translations != NULL)
     {
-	DEBUGOUT(_LtDebugDebug(__FILE__, NULL, "    supplied by subclass\n"));
-	DEBUGOUT(_LtDebugDebug0("MENUT", NULL, "    supplied by subclass\n"));
+	DEBUGOUT(_LtDebug(__FILE__, NULL, "    supplied by subclass\n"));
+	DEBUGOUT(_LtDebug0("MENUT", NULL, "    supplied by subclass\n"));
 	lwc->label_class.translations =
 	    (String)XtParseTranslationTable(lwc->label_class.translations);
     }
     else
     {
-	DEBUGOUT(_LtDebugDebug(__FILE__, NULL, "    Use menu traversal translations\n"));
-	DEBUGOUT(_LtDebugDebug0("MENUT", NULL, "    Use menu traversal translations\n"));
+	DEBUGOUT(_LtDebug(__FILE__, NULL, "    Use menu traversal translations\n"));
+	DEBUGOUT(_LtDebug0("MENUT", NULL, "    Use menu traversal translations\n"));
 	lwc->label_class.translations =
 	    (String)XtParseTranslationTable(_XmLabel_menu_traversal_events);
     }
@@ -532,7 +549,7 @@ initialize_prehook(Widget request,
 		   ArgList args,
 		   Cardinal *num_args)
 {
-    DEBUGOUT(_LtDebugDebug(__FILE__, new_w, "Initialize Prehook\n"));
+    DEBUGOUT(_LtDebug(__FILE__, new_w, "Initialize Prehook\n"));
 
     _XmSaveCoreClassTranslations(new_w);
 
@@ -553,7 +570,7 @@ static void
 initialize_posthook(Widget request, Widget new_w,
 		    ArgList args, Cardinal *num_args)
 {
-    DEBUGOUT(_LtDebugDebug(__FILE__, new_w, "Initialize Posthook\n"));
+    DEBUGOUT(_LtDebug(__FILE__, new_w, "Initialize Posthook\n"));
 
     _XmRestoreCoreClassTranslations(new_w);
 }
@@ -562,17 +579,27 @@ static void
 initialize(Widget request, Widget new_w,
 	   ArgList args, Cardinal *num_args)
 {
-    DEBUGOUT(_LtDebugDebug(__FILE__, new_w,
-		      "%s:initialize(%d) - %i args\n"
-		      "\trequest X %5i Y %5i W %5i H %5i\n"
-		      "\t  new_w X %5i Y %5i W %5i H %5i\n",
-		      __FILE__, __LINE__,
-		      *num_args,
-		      XtX(request), XtY(request),
-		      XtWidth(request), XtHeight(request),
-		      XtX(new_w), XtY(new_w),
-		      XtWidth(new_w), XtHeight(new_w)));
-    DEBUGOUT(_LtDebugPrintArgList(__FILE__, new_w, args, *num_args, False));
+	DEBUGOUT(_LtDebug(__FILE__, new_w,
+		"%s:initialize(%d) - %i args\n"
+		"\trequest X %5i Y %5i W %5i H %5i\n"
+		"\t  new_w X %5i Y %5i W %5i H %5i\n",
+		__FILE__, __LINE__,
+		*num_args,
+		XtX(request), XtY(request),
+		XtWidth(request), XtHeight(request),
+		XtX(new_w), XtY(new_w),
+		XtWidth(new_w), XtHeight(new_w)));
+	DEBUGOUT(_LtDebugPrintArgList(__FILE__, new_w, args, *num_args, False));
+
+	if (Lab_Font(new_w) == NULL || Lab_Font(new_w) == (XmFontList)XmUNSPECIFIED) {
+#if (XmVERSION > 1)
+		/* Use the trait to find a default renderTable */
+		/* FIX ME currently same as 1.2 */
+		Lab_Font(new_w) = _XmGetDefaultFontList(new_w, XmTEXT_FONTLIST);
+#else
+		Lab_Font(new_w) = _XmGetDefaultFontList(new_w, XmTEXT_FONTLIST);
+#endif
+	}
 
     Lab_SkipCallback(new_w) = False;
 
@@ -595,14 +622,14 @@ initialize(Widget request, Widget new_w,
     /* Force the traversal and highlight on enter resources if in a menu */
     if (Lab_MenuType(new_w) != XmWORK_AREA)
     {
-	DEBUGOUT(_LtDebugDebug(__FILE__, new_w, "    merge in Label Class Translations\n"));
+	DEBUGOUT(_LtDebug(__FILE__, new_w, "    merge in Label Class Translations\n"));
 #if 0
 MLM: WHY TRAVERSAL?
 	Prim_TraversalOn(new_w) = False;
 #endif
 	Prim_HighlightOnEnter(new_w) = False;
 
-	DEBUGOUT(_LtDebugDebug("MENUT", new_w, "%s:initialize(%d) - Override translations\n",
+	DEBUGOUT(_LtDebug("MENUT", new_w, "%s:initialize(%d) - Override translations\n",
 	    __FILE__, __LINE__
 	    ));
 	XtOverrideTranslations(new_w,
@@ -771,7 +798,7 @@ set_values(Widget old, Widget request, Widget new_w,
     Boolean refresh_needed = False, relayout_needed = False,
 	recalc_needed = False;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, new_w,
+    DEBUGOUT(_LtDebug(__FILE__, new_w,
 		      "%s(%d):set_values: %i args\n"
 		      "\t    old X %5i Y %5i W %5i H %5i\n"
 		      "\trequest X %5i Y %5i W %5i H %5i\n"
@@ -1038,7 +1065,7 @@ expose(Widget w, XEvent *event, Region region)
     GC myGC;
     Pixmap mypm;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "Expose\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "Expose\n"));
 
     /*
      * I'm becoming paranoid - Danny - see testXm/filesb/test3
@@ -1088,7 +1115,7 @@ expose(Widget w, XEvent *event, Region region)
     /* Draw the accelerator without clipping */
     if (Lab_AcceleratorText(w))
     {
-	DEBUGOUT(_LtDebugDebug(__FILE__, w,
+	DEBUGOUT(_LtDebug(__FILE__, w,
 			  "Expose: acctextrect %d %d %dx%d\n",
 			  Lab_AccTextRect(w).x, Lab_AccTextRect(w).y,
 			  Lab_AccTextRect(w).width, Lab_AccTextRect(w).height));
@@ -1129,7 +1156,7 @@ expose(Widget w, XEvent *event, Region region)
 	- ((Prim_ShadowThickness(w) + Prim_HighlightThickness(w)) << 1)
 	- Lab_MarginTop(w) - Lab_MarginBottom(w);
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, w,
+    DEBUGOUT(_LtDebug(__FILE__, w,
 		      "Expose: cliprect %d %d %dx%d\n",
 		      cliprect.x, cliprect.y,
 		      cliprect.width, cliprect.height));
@@ -1402,7 +1429,7 @@ resize(Widget w)
 				 - Lab_AccTextRect(w).height) >> 1)
 	    + Lab_MarginTop(w);
 #if 0
-	DEBUGOUT(_LtDebugDebug(__FILE__, w,
+	DEBUGOUT(_LtDebug(__FILE__, w,
 			  "Accelerator @ %d %d (x = %d - %d - %d - %d)\n",
 			  Lab_AccTextRect(w).x, Lab_AccTextRect(w).y,
 			  XtWidth(w), Lab_Shadow(w), Lab_Highlight(w),
@@ -1418,7 +1445,7 @@ query_geometry(Widget w, XtWidgetGeometry *proposed, XtWidgetGeometry *answer)
     XtWidgetGeometry a;
     Dimension wd, ht;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "query_geometry\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "query_geometry\n"));
 
     wd = XtWidth(w);
     ht = XtHeight(w);
@@ -1491,7 +1518,7 @@ query_geometry(Widget w, XtWidgetGeometry *proposed, XtWidgetGeometry *answer)
 	*answer = a;
     }
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "query_geometry => %s\n",
+    DEBUGOUT(_LtDebug(__FILE__, w, "query_geometry => %s\n",
 		      _LtDebugWidgetGeometry2String(answer)));
 
     if ((proposed->request_mode & (CWWidth | CWHeight)) ==
@@ -1649,7 +1676,7 @@ drag_convert_proc(Widget w, Atom *selection,
 	return False;
     }
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "We're dealing with a motif drop\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "We're dealing with a motif drop\n"));
 
     XtVaGetValues(w,
     	XmNsourceWidget, &source,
@@ -1708,7 +1735,7 @@ drag_convert_proc(Widget w, Atom *selection,
 static void
 drag_drop_finish(Widget w, XtPointer client_data, XtPointer call_data)
 {
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "%s:drag_drop_finish(%d)\n",
+    DEBUGOUT(_LtDebug(__FILE__, w, "%s:drag_drop_finish(%d)\n",
     	__FILE__, __LINE__));
 }
 
@@ -1721,7 +1748,7 @@ ProcessDrag(Widget w, XEvent *event, String *params, Cardinal *num_params)
     Widget dc;
 
     _XmObjectLock(w);
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "Processing a drag-drop request\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "Processing a drag-drop request\n"));
 
     if (Lab_IsPixmap(w))
     {
@@ -1796,8 +1823,12 @@ void
 _XmCalcLabelDimensions(Widget w)
 {
     _XmObjectLock(w);
+
     if (Lab_IsText(w))
     {
+#if (XmVERSION > 1)
+	__XmRenderTableFinalise(w, Lab_Font(w), Lab_Label(w));
+#endif
 	_XmStringExtent(Lab_Font(w), Lab_Label(w), &Lab_TextRect_width(w),
 			&Lab_TextRect_height(w));
 	if (!Lab_TextRect_width(w))
@@ -1853,3 +1884,43 @@ XmCreateLabel(Widget parent, char *name,
 	return XtCreateWidget(name, xmLabelWidgetClass, parent,
 			  arglist, argcount);
 }
+
+static void
+_XmLabelSetRenderTable(Widget w, int o, XrmValue *v)
+{
+	XmLabelWidget	lw = (XmLabelWidget)w;
+
+#if (XmVERSION > 1)
+	DEBUGOUT(_LtDebug(__FILE__, w, "_XmLabelSetRenderTable (%d)\n",
+		lw->label.check_set_render_table));
+
+	/* HACK
+	 * this should be 0 or 1 (but it isn't).
+	 * Assume that another value is bogus, replace it by 0.
+	 */
+	if ( ! ((lw->label.check_set_render_table == 0) ||
+			(lw->label.check_set_render_table == 1))) {
+		lw->label.check_set_render_table = 0;
+		DEBUGOUT(_LtDebug(__FILE__, w, "_XmLabelSetRenderTable restore bogus\n"));
+		_XmWarning(w, "_XmLabelSetRenderTable restore bogus\n");
+	}
+	if (lw->label.check_set_render_table) {
+		/*
+		 * This is the second time we're getting called.
+		 * Therefore the result is undefined.
+		 */
+		v->addr = NULL;	/* FIX ME or should we pass nothing ? */
+#if 0
+	/* Don't generate a warning here, not even in LESSTIF_VERBOSE.
+	 * - this is really too much */
+		_XmWarning(w, "Shouldn't set both XmNfontList and XmNrenderTable\n");
+#endif
+	} else {
+		v->addr = (char *)&(lw->label.font);
+		lw->label.check_set_render_table = True;
+	}
+#else
+	/* Motif 1.x */
+	v->addr = (char *)&(lw->label.font);
+#endif
+}
