@@ -1,9 +1,9 @@
 /**
  *
- * $Id: LabelG.c,v 1.99 2001/05/14 19:46:09 amai Exp $
+ * $Header: /cvsroot/lesstif/lesstif/lib/Xm/LabelG.c,v 1.114 2002/04/25 17:40:11 dannybackx Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
- * Copyright (C) 1995-2001 LessTif Development Team
+ * Copyright  1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -23,7 +23,7 @@
  *
  **/
 
-static const char rcsid[] = "$Id: LabelG.c,v 1.99 2001/05/14 19:46:09 amai Exp $";
+static const char rcsid[] = "$Header: /cvsroot/lesstif/lesstif/lib/Xm/LabelG.c,v 1.114 2002/04/25 17:40:11 dannybackx Exp $";
 
 #include <LTconfig.h>
 
@@ -47,25 +47,16 @@ static const char rcsid[] = "$Id: LabelG.c,v 1.99 2001/05/14 19:46:09 amai Exp $
 
 #include <XmI/DebugUtil.h>
 
-#ifndef XmUNSPECIFIED
-#define XmUNSPECIFIED (~0)
-#endif
 
 /* Forward Declarations */
 
 static void class_initialize(void);
-
 static void class_part_initialize(WidgetClass w_class);
-
 static void initialize(Widget request, Widget new_w,
 		       ArgList args, Cardinal *num_args);
-
 static void destroy(Widget w);
-
 static void resize(Widget w);
-
 static void expose(Widget w, XEvent *event, Region region);
-
 static XtGeometryResult query_geometry(Widget w,
 				       XtWidgetGeometry *proposed,
 				       XtWidgetGeometry *answer);
@@ -75,10 +66,8 @@ static void get_values_hook(Widget w, ArgList args, Cardinal *num_args);
 #endif
 
 static void input_dispatch(Widget gadget, XEvent *event, Mask event_mask);
-
 static Boolean set_values(Widget current, Widget request, Widget new_w,
 			  ArgList args, Cardinal *num_args);
-
 static void secondary_object_create(Widget request, Widget new_w,
 				    ArgList args, Cardinal *num_args);
 
@@ -89,40 +78,30 @@ static void initialize_prehook(Widget request, Widget new_w,
 
 static void initialize_posthook(Widget request, Widget new_w,
 				ArgList args, Cardinal *num_args);
-
 static Boolean set_values_prehook(Widget old, Widget request, Widget new_w,
 				  ArgList args, Cardinal *num_args);
-
 static Boolean set_values_posthook(Widget old, Widget request, Widget new_w,
 				   ArgList args, Cardinal *num_args);
-
 static void get_values_prehook(Widget new_w, ArgList args, Cardinal *num_args);
-
 static void get_values_posthook(Widget new_w, ArgList args, Cardinal *num_args);
-
 static Cardinal get_sec_res_data(WidgetClass wc,
 				 XmSecondaryResourceData **data);
-
 static Boolean widget_baseline(Widget w, Dimension **baselines,
 			       int *nbaselines);
-
 static Boolean widget_display_rect(Widget w, XRectangle *rect);
-
+static void widget_margins (Widget w, XmBaselineMargins *margins);
 static void set_override_callback(Widget w);
-
 static void export_label_string(Widget w, int offset, XtArgVal *value);
-
 static void drag_drop_finish(Widget w,
 			     XtPointer client_data,
 			     XtPointer call_data);
-
 static Boolean drag_convert_proc(Widget w, Atom *selection,
 				 Atom *target, Atom *type_return,
 				 XtPointer *value_return,
 				 unsigned long *length_return,
 				 int *format_return);
-
 static void preferred_size(Widget w, Dimension *width, Dimension *height);
+static void _XmLabelGSetRenderTable(Widget, int, XrmValue *);
 
 /*
  * resources
@@ -273,7 +252,7 @@ static XtResource resources[] =
 {
     {
 	XmNshadowThickness, XmCShadowThickness, XmRHorizontalDimension,
-      sizeof(Dimension), XtOffsetOf(XmLabelGadgetRec, gadget.shadow_thickness),
+	sizeof(Dimension), XtOffsetOf(XmLabelGadgetRec, gadget.shadow_thickness),
 	XmRImmediate, (XtPointer)0
     },
     {
@@ -291,11 +270,31 @@ static XtResource resources[] =
 	sizeof(XmString), Offset(_label),
 	XmRImmediate, (XtPointer)NULL
     },
+#if (XmVERSION > 1)
+    {
+	/*
+	 * Note !!
+	 * Order is important. This resource must be specified before the
+	 * XmNfontList and XmNrenderTable, otherwise the check_set_render_table
+	 * flag is not initialised before use in _XmLabelGSetRenderTable().
+	 */
+	"keep.off", "Keep.off", XmRBoolean,
+	sizeof(Boolean), Offset(check_set_render_table),
+	XmRImmediate, (XtPointer)NULL
+    },
+#endif
     {
 	XmNfontList, XmCFontList, XmRFontList,
 	sizeof(XmFontList), Offset(font),
-	XmRImmediate, (XtPointer)NULL
+	XmRCallProc, (XtPointer)_XmLabelGSetRenderTable
     },
+#if (XmVERSION > 1)
+    {
+	XmNrenderTable, XmCRenderTable, XmRRenderTable,
+	sizeof(XmFontList), Offset(font),
+	XmRCallProc, (XtPointer)_XmLabelGSetRenderTable
+    },
+#endif
     {
 	XmNmnemonic, XmCMnemonic, XmRKeySym,
 	sizeof(KeySym), Offset(mnemonic),
@@ -324,9 +323,9 @@ static XtResource resources[] =
     },
     {
 	XmNhighlightThickness, XmCHighlightThickness, XmRHorizontalDimension,
-   sizeof(Dimension), XtOffsetOf(XmLabelGadgetRec, gadget.highlight_thickness),
+	sizeof(Dimension), XtOffsetOf(XmLabelGadgetRec, gadget.highlight_thickness),
 	XmRImmediate, (XtPointer)0
-    }
+    },
 };
 
 static XmSyntheticResource syn_resources[] =
@@ -353,7 +352,6 @@ static XmSyntheticResource syn_resources[] =
     }
 };
 
-/* *INDENT-OFF* */
 static XmBaseClassExtRec _XmLabelGRectClassExtRec = {
     /* next_extension            */ NULL,
     /* record_type               */ NULLQUARK,
@@ -399,6 +397,10 @@ static XmGadgetClassExtRec _XmLabelGadgetClassExtRec = {
     /* size                      */ sizeof(XmGadgetClassExtRec),
     /* widget_baseline           */ widget_baseline,
     /* widget_display_rect       */ widget_display_rect,
+#if XmVERSION >= 2
+    /* margins_proc              */ widget_margins,
+#endif
+
 };
 
 XmLabelGadgetClassRec xmLabelGadgetClassRec = {
@@ -456,12 +458,10 @@ XmLabelGadgetClassRec xmLabelGadgetClassRec = {
 	/* extension           */ NULL
     },
 };
-/* *INDENT-ON* */
 
 
 WidgetClass xmLabelGadgetClass = (WidgetClass)&xmLabelGadgetClassRec;
 
-extern XmFontList _XmFontListCreateDefault(Display *);
 
 /******************************** CACHE PART *********************************/
 static void
@@ -475,7 +475,7 @@ secondary_object_create(Widget request,
     XmWidgetExtData ed;
     Cardinal size;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, new_w,
+    DEBUGOUT(_LtDebug(__FILE__, new_w,
 		      "LabelGCacheRec %s being initialized.\n", XtName(new_w)));
 
     bce = _XmGetBaseClassExtPtr(XtClass(new_w), XmQmotif);
@@ -516,14 +516,16 @@ secondary_object_create(Widget request,
 int
 _XmLabelCacheCompare(XtPointer A, XtPointer B)
 {
-    return !memcmp(((XmLabelGCacheObjPart *)A),
-		 ((XmLabelGCacheObjPart *)B),
-		 sizeof(XmLabelGCacheObjPart));
+	DEBUGOUT(_LtDebug(__FILE__, NULL, "XmLabelGadget CacheCompare()\n"));
+	return !memcmp(((XmLabelGCacheObjPart *)A), ((XmLabelGCacheObjPart *)B),
+		sizeof(XmLabelGCacheObjPart));
 }
 
 void
 _XmCalcLabelGDimensions(Widget w)
 {
+	DEBUGOUT(_LtDebug(__FILE__, w, "_XmCalcLabelGDimensions\n"));
+
     if (LabG_IsText(w))
     {
 	_XmStringExtent(LabG_Font(w), LabG_Label(w), &LabG_TextRect_width(w),
@@ -569,6 +571,7 @@ _XmReCacheLabG(Widget w)
 {
     XmWidgetExtData ext;
 
+	DEBUGOUT(_LtDebug(__FILE__, w, "_XmReCacheLabG\n"));
     _XmPopWidgetExtData(w, &ext, XmCACHE_EXTENSION);
 
     LabG_Cache(w) = (XmLabelGCacheObjPart *)
@@ -589,6 +592,8 @@ _XmAssignLabG_MarginHeight(XmLabelGadget lw, Dimension value)
     Cardinal size;
     XtPointer nsec;
 
+	DEBUGOUT(_LtDebug(__FILE__, (Widget)lw, "_XmAssignLabG_MarginHeight\n"));
+
     if ((ed = _XmGetWidgetExtData((Widget)lw, XmCACHE_EXTENSION)) != NULL)
     {
 	LabG_MarginHeight(lw) = value;
@@ -634,6 +639,8 @@ _XmAssignLabG_MarginWidth(XmLabelGadget lw, Dimension value)
     Cardinal size;
     XtPointer nsec;
 
+	DEBUGOUT(_LtDebug(__FILE__, (Widget)lw, "_XmAssignLabG_MarginWidth\n"));
+
     if ((ed = _XmGetWidgetExtData((Widget)lw, XmCACHE_EXTENSION)) != NULL)
     {
 	LabG_MarginWidth(lw) = value;
@@ -677,6 +684,8 @@ _XmAssignLabG_MarginLeft(XmLabelGadget lw, Dimension value)
     Cardinal size;
     XtPointer nsec;
 
+	DEBUGOUT(_LtDebug(__FILE__, (Widget)lw, "_XmAssignLabG_MarginLeft\n"));
+
     if ((ed = _XmGetWidgetExtData((Widget)lw, XmCACHE_EXTENSION)) != NULL)
     {
 	LabG_MarginLeft(lw) = value;
@@ -720,6 +729,8 @@ _XmAssignLabG_MarginRight(XmLabelGadget lw, Dimension value)
     Cardinal size;
     XtPointer nsec;
 
+	DEBUGOUT(_LtDebug(__FILE__, (Widget)lw, "_XmAssignLabG_MarginRight\n"));
+
     if ((ed = _XmGetWidgetExtData((Widget)lw, XmCACHE_EXTENSION)) != NULL)
     {
 	LabG_MarginRight(lw) = value;
@@ -763,6 +774,8 @@ _XmAssignLabG_MarginTop(XmLabelGadget lw, Dimension value)
     Cardinal size;
     XtPointer nsec;
 
+	DEBUGOUT(_LtDebug(__FILE__, (Widget)lw, "_XmAssignLabG_MarginTop\n"));
+
     if ((ed = _XmGetWidgetExtData((Widget)lw, XmCACHE_EXTENSION)) != NULL)
     {
 	LabG_MarginTop(lw) = value;
@@ -806,6 +819,8 @@ _XmAssignLabG_MarginBottom(XmLabelGadget lw, Dimension value)
     Cardinal size;
     XtPointer nsec;
 
+	DEBUGOUT(_LtDebug(__FILE__, (Widget)lw, "_XmAssignLabG_MarginBottom\n"));
+
     if ((ed = _XmGetWidgetExtData((Widget)lw, XmCACHE_EXTENSION)) != NULL)
     {
 	LabG_MarginBottom(lw) = value;
@@ -856,6 +871,8 @@ drag_convert_proc(Widget w, Atom *selection,
     Atom TEXT;
     int len;
 
+	DEBUGOUT(_LtDebug(__FILE__, w, "drag_convert_proc\n"));
+
     _XmObjectLock(w);
     COMPOUND_TEXT = XmInternAtom(XtDisplay(w), _XA_COMPOUND_TEXT, False);
     MOTIF_DROP = XmInternAtom(XtDisplay(w), _XA_MOTIF_DROP, False);
@@ -867,7 +884,7 @@ drag_convert_proc(Widget w, Atom *selection,
 	return False;
     }
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "We're dealing with a motif drop\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "We're dealing with a motif drop\n"));
 
     XtVaGetValues(w,
     	XmNsourceWidget, &source,
@@ -926,6 +943,7 @@ drag_convert_proc(Widget w, Atom *selection,
 static void
 drag_drop_finish(Widget w, XtPointer client_data, XtPointer call_data)
 {
+	DEBUGOUT(_LtDebug(__FILE__, w, "drag_drop_finish\n"));
 }
 
 void
@@ -937,7 +955,7 @@ _XmProcessDrag(Widget w, XEvent *event,
     int n = 0;
     Widget dc;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "Processing a drag-drop request\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "_XmProcessDrag\n"));
 
     if (LabG_IsPixmap(w))
     {
@@ -974,6 +992,8 @@ _XmProcessDrag(Widget w, XEvent *event,
 static void
 class_initialize(void)
 {
+    DEBUGOUT(_LtDebug(__FILE__, NULL, "XmLabelGadget class_initialize\n"));
+
     /* don't let the nulls fool you.  look at the header file -- the arg
      * isn't used. */
     ClassCacheHead(LabG_ClassCachePart(NULL)).prev =
@@ -992,6 +1012,8 @@ class_part_initialize(WidgetClass widget_class)
     (XmLabelGadgetClass)(widget_class->core_class.superclass);
     XmGadgetClassExt ext, *extptr, *sextptr;
 
+    DEBUGOUT(_LtDebug(__FILE__, NULL, "XmLabelGadget class_part_initialize\n"));
+
     if (lc->label_class.menuProcs == XmInheritMenuProc)
     {
 	lc->label_class.menuProcs =
@@ -1045,6 +1067,8 @@ CreateNormalGC(Widget w)
     XGCValues values;
     XtGCMask mask;
 
+    DEBUGOUT(_LtDebug(__FILE__, w, "CreateNormalGC\n"));
+
     mask = GCForeground | GCBackground | GCFillStyle | GCFunction |
 	GCSubwindowMode | GCGraphicsExposures | GCPlaneMask;
     values.function = GXcopy;
@@ -1064,6 +1088,8 @@ CreateInsensitiveGC(Widget w)
     XGCValues values;
     XtGCMask mask;
 
+    DEBUGOUT(_LtDebug(__FILE__, w, "CreateInsensitiveGC\n"));
+
     mask = GCForeground | GCBackground | GCFillStyle | GCFunction | GCStipple |
 	GCSubwindowMode | GCGraphicsExposures | GCPlaneMask |
 	GCTileStipXOrigin | GCTileStipYOrigin;
@@ -1085,7 +1111,7 @@ static void
 initialize_prehook(Widget request, Widget new_w,
 		   ArgList args, Cardinal *num_args)
 {
-    DEBUGOUT(_LtDebugDebug(__FILE__, new_w, "LabelG InitializePrehook\n"));
+    DEBUGOUT(_LtDebug(__FILE__, new_w, "LabelG InitializePrehook\n"));
 }
 #endif
 
@@ -1097,7 +1123,7 @@ initialize_posthook(Widget request,
 {
     XmWidgetExtData ext;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, new_w, "LabelG InitializePosthook\n"));
+    DEBUGOUT(_LtDebug(__FILE__, new_w, "LabelG InitializePosthook\n"));
 
     /* don't let the null fool you */
     LabG_Cache(new_w) = (XmLabelGCacheObjPart *)
@@ -1115,19 +1141,33 @@ static void
 initialize(Widget request, Widget new_w,
 	   ArgList args, Cardinal *num_args)
 {
-    XmString xmstring;
+	XmString	xmstring;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, new_w,
-		      "%s:initialize(%d) - %i args\n"
-		      "\trequest X %5i Y %5i W %5i H %5i\n"
-		      "\t  new_w X %5i Y %5i W %5i H %5i\n",
-		      __FILE__, __LINE__,
-		      *num_args,
-		      XtX(request), XtY(request),
-		      XtWidth(request), XtHeight(request),
-		      XtX(new_w), XtY(new_w),
-		      XtWidth(new_w), XtHeight(new_w)));
-    DEBUGOUT(_LtDebugPrintArgList(__FILE__, new_w, args, *num_args, False));
+#if 1
+	DEBUGOUT(_LtDebug(__FILE__, new_w, "XmLabelGadget Initialize fontlist %p (%p %p)\n",
+		LabG_Font(new_w)));
+#else
+	DEBUGOUT(_LtDebug(__FILE__, new_w,
+		"%s:initialize(%d) - %i args\n"
+		"\trequest X %5i Y %5i W %5i H %5i\n"
+		"\t  new_w X %5i Y %5i W %5i H %5i\n",
+		__FILE__, __LINE__,
+		*num_args,
+		XtX(request), XtY(request),
+		XtWidth(request), XtHeight(request),
+		XtX(new_w), XtY(new_w),
+		XtWidth(new_w), XtHeight(new_w)));
+	DEBUGOUT(_LtDebugPrintArgList(__FILE__, new_w, args, *num_args, False));
+#endif
+	if (LabG_Font(new_w) == NULL || LabG_Font(new_w) == (XmFontList)XmUNSPECIFIED) {
+#if (XmVERSION > 1)
+		/* Use the trait to find a default renderTable */
+		/* FIX ME currently same as 1.2 */
+		LabG_Font(new_w) = _XmGetDefaultFontList(new_w, XmTEXT_FONTLIST);
+#else
+		LabG_Font(new_w) = _XmGetDefaultFontList(new_w, XmTEXT_FONTLIST);
+#endif
+	}
 
     LabG_SkipCallback(new_w) = False;
 
@@ -1274,6 +1314,8 @@ MLM: WHY TRAVERSAL?
 static void
 destroy(Widget w)
 {
+    DEBUGOUT(_LtDebug(__FILE__, w, "XmLabelGadget destroy\n"));
+
     XmFontListFree(LabG_Font(w));
     _XmStringFree(LabG_Label(w));
     _XmStringFree(LabG_AcceleratorText(w));
@@ -1289,6 +1331,8 @@ destroy(Widget w)
 static void
 resize(Widget w)
 {
+    DEBUGOUT(_LtDebug(__FILE__, w, "XmLabelGadget resize\n"));
+
     /* NB. For gadgets, the TextRect is relative to the XtX and XtY
      * positions, as the Xt[X|Y] are added onto them before the text is drawn.
      */
@@ -1310,7 +1354,7 @@ resize(Widget w)
 	    {
 		_XmAssignLabG_MarginRight((XmLabelGadget)w,
 		    LABEL_ACC_PAD + LabG_AccTextRect(w).width);
-		DEBUGOUT(_LtDebugDebug(__FILE__, w,
+		DEBUGOUT(_LtDebug(__FILE__, w,
 				  "resize: set right margin to %d\n",
 				  LabG_MarginRight(w)));
 		_XmReCacheLabG(w);
@@ -1323,7 +1367,7 @@ resize(Widget w)
 	    {
 		_XmAssignLabG_MarginLeft((XmLabelGadget)w,
 		    LABEL_ACC_PAD + LabG_AccTextRect(w).width);
-		DEBUGOUT(_LtDebugDebug(__FILE__, w,
+		DEBUGOUT(_LtDebug(__FILE__, w,
 				  "resize: set left margin to %d\n",
 				  LabG_MarginLeft(w)));
 		_XmReCacheLabG(w);
@@ -1410,6 +1454,8 @@ set_values_prehook(Widget old, Widget request, Widget new_w,
     Cardinal size;
     XtPointer nsec, rsec;
 
+	DEBUGOUT(_LtDebug(__FILE__, new_w, "XmLabelGadget set_values_prehook\n"));
+
     bce = _XmGetBaseClassExtPtr(XtClass(new_w), XmQmotif);
     size = (*bce)->secondaryObjectClass->core_class.widget_size;
 
@@ -1461,6 +1507,8 @@ set_values_posthook(Widget old, Widget request, Widget new_w,
 {
     XmWidgetExtData ext;
 
+	DEBUGOUT(_LtDebug(__FILE__, new_w, "XmLabelGadget set_values_posthook\n"));
+
     if (!_XmLabelCacheCompare((XtPointer)LabG_Cache(new_w),
 			      (XtPointer)LabG_Cache(old)))
     {
@@ -1498,7 +1546,7 @@ set_values(Widget old, Widget request, Widget new_w,
     Boolean refresh_needed = False, relayout_needed = False,
 	recalc_needed = False;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, new_w, "LabelGadget SetValues %d %d\n",
+    DEBUGOUT(_LtDebug(__FILE__, new_w, "LabelGadget SetValues %d %d\n",
 		      LabG_MarginRight(new_w), LabG_MarginRight(old)));
 
     /* Silently discard accelerator for non-menu labels and cascades */
@@ -1762,6 +1810,8 @@ get_values_prehook(Widget new_w, ArgList args, Cardinal *num_args)
     Cardinal size;
     XtPointer nsec;
 
+	DEBUGOUT(_LtDebug(__FILE__, new_w, "XmLabelGadget get_values_prehook\n"));
+
     bce = _XmGetBaseClassExtPtr(XtClass(new_w), XmQmotif);
     size = (*bce)->secondaryObjectClass->core_class.widget_size;
 
@@ -1803,6 +1853,8 @@ get_values_posthook(Widget new_w, ArgList args, Cardinal *num_args)
 {
     XmWidgetExtData ext;
 
+	DEBUGOUT(_LtDebug(__FILE__, new_w, "XmLabelGadget get_values_posthook\n"));
+
     _XmPopWidgetExtData(new_w, &ext, XmCACHE_EXTENSION);
 
     _XmExtObjFree((XtPointer)ext->widget);
@@ -1814,7 +1866,7 @@ get_values_posthook(Widget new_w, ArgList args, Cardinal *num_args)
 static void
 get_values_hook(Widget w, ArgList args, Cardinal *num_args)
 {
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "LabelG: GetValuesHook\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "LabelG: GetValuesHook\n"));
 }
 #endif
 
@@ -1827,6 +1879,8 @@ expose(Widget w,
     GC myGC;
     Pixmap mypm;
 
+	DEBUGOUT(_LtDebug(__FILE__, w, "XmLabelGadget expose\n"));
+
     /*
      * I'm getting paranoid - Danny - see testXm/filesb/test3
      */
@@ -1895,11 +1949,11 @@ expose(Widget w,
 	- ((G_ShadowThickness(w) + G_HighlightThickness(w)) << 1)
 	- LabG_MarginTop(w) - LabG_MarginBottom(w);
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, w,
+    DEBUGOUT(_LtDebug(__FILE__, w,
              "Expose: cliprect %d %d %dx%d\n",
             cliprect.x, cliprect.y,
              cliprect.width, cliprect.height));
-    DEBUGOUT(_LtDebugDebug(__FILE__, w,
+    DEBUGOUT(_LtDebug(__FILE__, w,
              "Expose: acctextrect %d %d %dx%d\n",
             LabG_AccTextRect(w).x, LabG_AccTextRect(w).y,
              LabG_AccTextRect(w).width, LabG_AccTextRect(w).height));
@@ -2060,6 +2114,8 @@ query_geometry(Widget w, XtWidgetGeometry *proposed, XtWidgetGeometry *answer)
     XtWidgetGeometry a;		/* Standin for answer if NULL parameter */
     Dimension wd, ht;
 
+	DEBUGOUT(_LtDebug(__FILE__, w, "XmLabelGadget query_geometry\n"));
+
     wd = XtWidth(w);
     ht = XtHeight(w);
     /* rws 28 Feb 1997
@@ -2120,7 +2176,7 @@ query_geometry(Widget w, XtWidgetGeometry *proposed, XtWidgetGeometry *answer)
     a.width = XtWidth(w);
     a.height = XtHeight(w);
     a.request_mode = CWWidth | CWHeight;
-    DEBUGOUT(_LtDebugDebug(__FILE__, w,
+    DEBUGOUT(_LtDebug(__FILE__, w,
 		      "LabelGadget queried for size: reporting %d %d %08x\n",
 		      XtWidth(w), XtHeight(w), answer));
 
@@ -2149,6 +2205,8 @@ query_geometry(Widget w, XtWidgetGeometry *proposed, XtWidgetGeometry *answer)
 #else
     XtWidgetGeometry pc;
 
+	DEBUGOUT(_LtDebug(__FILE__, w, "XmLabelGadget query_geometry\n"));
+
 	pc = *proposed;
 	/* rws 27 Sep 1998
 	   label/test8 should prove whether this IsRealized should be here
@@ -2190,15 +2248,19 @@ query_geometry(Widget w, XtWidgetGeometry *proposed, XtWidgetGeometry *answer)
 static Cardinal
 get_sec_res_data(WidgetClass wc, XmSecondaryResourceData **data)
 {
-    /* FIX ME */
+	DEBUGOUT(_LtDebug(__FILE__, NULL, "XmLabelGadget get_sec_res_data\n"));
 
-    return _XmSecondaryResourceData(&_XmLabelGRectClassExtRec,
-				    data, NULL, NULL, NULL, NULL);
+	/* FIX ME */
+
+	return _XmSecondaryResourceData(&_XmLabelGRectClassExtRec,
+		data, NULL, NULL, NULL, NULL);
 }
 
 static Boolean
 widget_baseline(Widget w, Dimension **baselines, int *nbaselines)
 {
+	DEBUGOUT(_LtDebug(__FILE__, w, "XmLabelGadget widget_baseline\n"));
+
     if (!LabG_IsText(w))
 	return False;
 
@@ -2212,10 +2274,21 @@ widget_baseline(Widget w, Dimension **baselines, int *nbaselines)
 static Boolean
 widget_display_rect(Widget w, XRectangle *rect)
 {
-    *rect = ((XmLabelGadget)w)->label.TextRect;
-    return True;
+	DEBUGOUT(_LtDebug(__FILE__, w, "XmLabelGadget widget_display_rect\n"));
+	*rect = ((XmLabelGadget)w)->label.TextRect;
+	return True;
 }
 
+
+#if XmVERSION >= 2
+static void
+widget_margins (Widget w, XmBaselineMargins *margins)
+{
+	DEBUGOUT(_LtDebug(__FILE__, w, "XmLabelGadget widget_margins\n"));
+ /* FIX ME */
+}
+#endif
+
 /* FIX ME: there has to be more to this, doesn't there? */
 static void
 set_override_callback(Widget w)
@@ -2228,32 +2301,38 @@ export_label_string(Widget w, int offset, XtArgVal *value)
 {
     _XmString str = *(_XmString *)(((char *)w) + offset);
 
+	DEBUGOUT(_LtDebug(__FILE__, w, "XmLabelGadget export_label_string\n"));
+
     *value = str
 	? (XtArgVal)_XmStringCreateExternal(LabG_Font(w), str)
 	: (XtArgVal)NULL;
 }
 
 static void
-input_dispatch(Widget gadget,
-	       XEvent *event,
-	       Mask event_mask)
+input_dispatch(Widget gadget, XEvent *event, Mask event_mask)
 {
     switch (event_mask)
     {
     case XmHELP_EVENT:
-	DEBUGOUT(_LtDebugDebug(__FILE__, gadget, "LabelGadget got help event\n"));
+	DEBUGOUT(_LtDebug(__FILE__, gadget, "LabelGadget got help event\n"));
 	break;
 
     case XmBDRAG_EVENT:
-	DEBUGOUT(_LtDebugDebug(__FILE__, gadget, "LabelGadget got bdrag event\n"));
+	DEBUGOUT(_LtDebug(__FILE__, gadget, "LabelGadget got bdrag event\n"));
 	_XmProcessDrag(gadget, event, NULL, NULL);
 	break;
+    default:
+	/* Should this happen ? */
+	DEBUGOUT(_LtDebug(__FILE__, gadget, "XmLabelGadget input_dispatch\n"));
+	break;
     }
 }
 
 static void
 preferred_size(Widget w, Dimension *width, Dimension *height)
 {
+	DEBUGOUT(_LtDebug(__FILE__, w, "XmLabelGadget preferred_size\n"));
+
     if (width)
     {
 	*width =
@@ -2288,9 +2367,56 @@ XmCreateLabelGadget(Widget parent, char *name,
 {
 	Widget	w;
 
+	DEBUGOUT(_LtDebug(__FILE__, parent, "XmCreateLabelGadget(%s)\n", name));
+
 	_XmObjectLock(parent);
 	w =  XtCreateWidget(name, xmLabelGadgetClass, parent,
 			  arglist, argcount);
+
+	DEBUGOUT(_LtDebug2(__FILE__, parent, w, "XmCreateLabelGadget => %p\n", w));
+
 	_XmObjectUnlock(parent);
 	return w;
 }
+
+static void
+_XmLabelGSetRenderTable(Widget w, int o, XrmValue *v)
+{
+	XmLabelGadget	lw = (XmLabelGadget)w;
+
+#if (XmVERSION > 1)
+	DEBUGOUT(_LtDebug(__FILE__, w, "_XmLabelGSetRenderTable (%d) Font was %p\n",
+		lw->label.check_set_render_table, lw->label.font));
+
+	/* HACK
+	 * this should be 0 or 1 (but it isn't).
+	 * Assume that another value is bogus, replace it by 0.
+	 */
+	if ( ! ((lw->label.check_set_render_table == 0) ||
+			(lw->label.check_set_render_table == 1))) {
+		lw->label.check_set_render_table = 0;
+		DEBUGOUT(_LtDebug(__FILE__, w, "_XmLabelGSetRenderTable restore bogus\n"));
+		_XmWarning(w, "_XmLabelGSetRenderTable restore bogus\n");
+	}
+	if (lw->label.check_set_render_table) {
+		/*
+		 * This is the second time we're getting called.
+		 * Therefore the result is undefined.
+		 */
+#if 0
+		v->addr = NULL;	/* FIX ME or should we pass nothing ? */
+#endif
+#if 0
+	/* Don't generate a warning here, not even in LESSTIF_VERBOSE.
+	 * - this is really too much */
+		_XmWarning(w, "Shouldn't set both XmNfontList and XmNrenderTable\n");
+#endif
+	} else {
+		v->addr = (char *)&(lw->label.font);
+		lw->label.check_set_render_table = True;
+	}
+#else
+	/* Motif 1.x */
+	v->addr = (char *)&(lw->label.font);
+#endif
+}
