@@ -1,6 +1,6 @@
 /**
  *
- * $Id: MainW.c,v 1.61 2001/05/20 17:49:38 amai Exp $
+ * $Id: MainW.c,v 1.63 2001/09/03 21:33:06 amai Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
  * Copyright (C) 1995-2001 LessTif Development Team
@@ -23,7 +23,7 @@
  *
  **/
 
-static const char rcsid[] = "$Id: MainW.c,v 1.61 2001/05/20 17:49:38 amai Exp $";
+static const char rcsid[] = "$Id: MainW.c,v 1.63 2001/09/03 21:33:06 amai Exp $";
 
 #include <LTconfig.h>
 
@@ -386,7 +386,7 @@ set_values(Widget old, Widget request, Widget new_w,
     Boolean relayout = False;
 #define NE(x)	(x(old) != x(new_w))
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, new_w,
+    DEBUGOUT(_LtDebug(__FILE__, new_w,
 		      "%s:set_values(%d) - %i args\n"
 		      "\t    old X %5i Y %5i W %5i H %5i\n"
 		      "\trequest X %5i Y %5i W %5i H %5i\n"
@@ -410,7 +410,7 @@ set_values(Widget old, Widget request, Widget new_w,
 
     if (NE(SW_WorkWindow))
     {
-	DEBUGOUT(_LtDebugDebug(__FILE__, new_w,
+	DEBUGOUT(_LtDebug(__FILE__, new_w,
 			  "SetValues: Changed the work window !\n"));
 
 	if (SW_ClipWindow(new_w))
@@ -440,7 +440,7 @@ set_values(Widget old, Widget request, Widget new_w,
 
     if (NE(MW_CommandWindow))
     {
-	DEBUGOUT(_LtDebugDebug(__FILE__, new_w,
+	DEBUGOUT(_LtDebug(__FILE__, new_w,
 			  "SetValues: Changed the command window !\n"));
 
 	if (SW_VisualPolicy(new_w) == XmCONSTANT &&
@@ -468,7 +468,7 @@ set_values(Widget old, Widget request, Widget new_w,
 
     if (NE(MW_MessageWindow))
     {
-	DEBUGOUT(_LtDebugDebug(__FILE__, new_w,
+	DEBUGOUT(_LtDebug(__FILE__, new_w,
 			  "SetValues: Changed the message window !\n"));
 
 	if (SW_VisualPolicy(new_w) == XmCONSTANT &&
@@ -496,7 +496,7 @@ set_values(Widget old, Widget request, Widget new_w,
 
     if (NE(MW_MenuBar))
     {
-	DEBUGOUT(_LtDebugDebug(__FILE__, new_w,
+	DEBUGOUT(_LtDebug(__FILE__, new_w,
 			  "SetValues: Changed the menu bar !\n"));
 
 	if (SW_VisualPolicy(new_w) == XmCONSTANT &&
@@ -590,7 +590,7 @@ resize(Widget w)
 {
     XmMWValues vals;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "%s:resize(%d) (%dx%d)\n",
+    DEBUGOUT(_LtDebug(__FILE__, w, "%s:resize(%d) (%dx%d)\n",
 		      __FILE__, __LINE__,
 		      XtWidth(w), XtHeight(w)));
 
@@ -619,7 +619,7 @@ realize(Widget w, Mask *value_mask, XSetWindowAttributes *attributes)
        XmMWValues vals;
      */
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "Realize ...\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "Realize ...\n"));
 
 #define superclass (&xmManagerClassRec)
     (*superclass->core_class.realize) (w, value_mask, attributes);
@@ -647,7 +647,7 @@ realize(Widget w, Mask *value_mask, XSetWindowAttributes *attributes)
 
     _XmMainWindowConfigureChildren(w, NULL, NULL, &vals);
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "Realize => size %d %d\n",
+    DEBUGOUT(_LtDebug(__FILE__, w, "Realize => size %d %d\n",
 		      XtWidth(w), XtHeight(w)));
 #endif
 }
@@ -793,7 +793,7 @@ ReparentChild(Widget w, Widget child)
     {
 	XtRealizeWidget(child);
     }
-    for (j = 0; j < num_managed; j++)
+    for (j = 0; j < (int)num_managed; j++)
     {
 	XtManageChild(managed[j]);
     }
@@ -814,7 +814,7 @@ change_managed(Widget w)
 {
     XmMWValues vals;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "ChangeManaged\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "ChangeManaged\n"));
     /*
      * It is possible that some of the MainWindows children is made children
      * of ClipWindow by the ScrolledWindow. Steal them back.
@@ -1062,7 +1062,7 @@ _XmMainWindowPreferredSize(Widget w, Widget child, XtWidgetGeometry *cg,
      */
 
     /* Talk */
-    DEBUGOUT(_LtDebugDebug2(__FILE__, w, child, "_XmMainWindowPreferredSize request %s\n",
+    DEBUGOUT(_LtDebug2(__FILE__, w, child, "_XmMainWindowPreferredSize request %s\n",
 		       _LtDebugWidgetGeometry2String(cg)));
 
     /* T. Straumann: do querying the kids using a loop (I'm lazy) */
@@ -1152,7 +1152,7 @@ _XmMainWindowPreferredSize(Widget w, Widget child, XtWidgetGeometry *cg,
 		Dimension bw = XtBorderWidth(chld[i]);
 		XtWidgetGeometry rcg, rcg_r;
 
-		DEBUGOUT(_LtDebugDebug2(__FILE__, w, chld[i],
+		DEBUGOUT(_LtDebug2(__FILE__, w, chld[i],
 		       "_XmMainWindowPreferredSize: %s current wid %d ht %d\n",
 			 chldwh[i].name, XtWidth(chld[i]), XtHeight(chld[i])));
 
@@ -1186,14 +1186,14 @@ _XmMainWindowPreferredSize(Widget w, Widget child, XtWidgetGeometry *cg,
 		    {
 			chldwh[i].w = cg->width;
 			childNotHappy = True;
-			DEBUGOUT(_LtDebugDebug0(__FILE__, w, "\tbut it wants width %d\n",
+			DEBUGOUT(_LtDebug0(__FILE__, w, "\tbut it wants width %d\n",
 					   cg->width));
 		    }
 		    if (Wants(CWHeight) && chldwh[i].h != cg->height)
 		    {
 			chldwh[i].h = cg->height;
 			childNotHappy = True;
-			DEBUGOUT(_LtDebugDebug0(__FILE__, w, "\tbut it wants height %d\n",
+			DEBUGOUT(_LtDebug0(__FILE__, w, "\tbut it wants height %d\n",
 					   cg->height));
 		    }
 		    /* T. Straumann: allow changes of border width */
@@ -1207,7 +1207,7 @@ _XmMainWindowPreferredSize(Widget w, Widget child, XtWidgetGeometry *cg,
 		chldwh[i].w += 2 * bw;
 		chldwh[i].h += 2 * bw;
 
-		DEBUGOUT(_LtDebugDebug2(__FILE__, w, chld[i],
+		DEBUGOUT(_LtDebug2(__FILE__, w, chld[i],
 				   "%s w %d h %d\n",
 				   chldwh[i].name, chldwh[i].w, chldwh[i].h));
 
@@ -1369,7 +1369,7 @@ _XmMainWindowGeomRequest(Widget w, XmMWValues * vals)
     geo.height = vals->MwH;
     geo.request_mode = CWWidth | CWHeight;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, w,
+    DEBUGOUT(_LtDebug(__FILE__, w,
 		      "_XmMainWindowGeomRequests: request geo %s: "
 		      "am %d %d given: %d %d\n",
 		      _LtDebugWidgetGeometry2String(&geo),
@@ -1386,7 +1386,7 @@ _XmMainWindowGeomRequest(Widget w, XmMWValues * vals)
 	vals->MwW = XtWidth(w);
 	vals->MwH = XtHeight(w);
 
-	DEBUGOUT(_LtDebugDebug(__FILE__, w,
+	DEBUGOUT(_LtDebug(__FILE__, w,
 			  "_XmMainWindowGeomRequests CONF got %s\n",
 			  _LtDebugWidgetGeometry2String(&geo)));
     }
@@ -1430,7 +1430,7 @@ _XmMainWindowLayout(Widget w, Widget child, XtWidgetGeometry *cg,
 
     if (MW_CommandLoc(w) == XmCOMMAND_ABOVE_WORKSPACE)
     {
-	DEBUGOUT(_LtDebugDebug(__FILE__, w,
+	DEBUGOUT(_LtDebug(__FILE__, w,
 			  "_XmMainWindowLayout COMMAND_ABOVE_WORKSPACE\n"));
 	if (VALID(MW_CommandWindow(w)))
 	{
@@ -1483,7 +1483,7 @@ _XmMainWindowLayout(Widget w, Widget child, XtWidgetGeometry *cg,
     }
     else
     {				/* XmCOMMAND_BELOW_WORKSPACE */
-	DEBUGOUT(_LtDebugDebug(__FILE__, w,
+	DEBUGOUT(_LtDebug(__FILE__, w,
 			  "_XmMainWindowLayout COMMAND_BELOW_WORKSPACE\n"));
 	/*
 	 * Start working from the bottom immediately, eventually getting
@@ -1596,7 +1596,7 @@ _XmMainWindowLayout(Widget w, Widget child, XtWidgetGeometry *cg,
 	    cg->request_mode = CWWidth | CWHeight | CWX | CWY;
 	}
 
-	DEBUGOUT(_LtDebugDebug2(__FILE__, w, child, "feedback => %s\n",
+	DEBUGOUT(_LtDebug2(__FILE__, w, child, "feedback => %s\n",
 			   _LtDebugWidgetGeometry2String(cg)));
     }
 }
@@ -1615,7 +1615,7 @@ _XmMainWindowLayout(Widget w, Widget child, XtWidgetGeometry *cg,
  */
 #define	CONF(wid, xx, yy, ww, hh, child, cg)				\
     {								\
-	DEBUGOUT(_LtDebugDebug2(__FILE__, w, wid,                    \
+	DEBUGOUT(_LtDebug2(__FILE__, w, wid,                    \
                            "CONF: x %d y %d w %d h %d\n",   \
 			   xx, yy, ww, hh));	\
 	if (child && wid == child)		\
@@ -1685,7 +1685,7 @@ geometry_manager(Widget w,
     XtWidgetGeometry wants;
     XtGeometryResult rval;
 
-    DEBUGOUT(_LtDebugDebug2(__FILE__, XtParent(w), w,
+    DEBUGOUT(_LtDebug2(__FILE__, XtParent(w), w,
 		       "geometry_manager request %s\n",
 		       _LtDebugWidgetGeometry2String(desired)));
 
@@ -1695,7 +1695,7 @@ geometry_manager(Widget w,
 
     if (Wants(XtCWQueryOnly))
     {
-	DEBUGOUT(_LtDebugDebug(__FILE__, w,
+	DEBUGOUT(_LtDebug(__FILE__, w,
 			  "Geometry Mgr Query Only Unimplemented\n"));
 	return XtGeometryYes;
     }
@@ -1708,17 +1708,17 @@ geometry_manager(Widget w,
      */
     if (SW_ScrollPolicy(mw) == XmAUTOMATIC && w == (Widget)SW_ClipWindow(mw))
     {
-	DEBUGOUT(_LtDebugDebug2(__FILE__, mw, w,
+	DEBUGOUT(_LtDebug2(__FILE__, mw, w,
 			   "BEGIN AUTOMATIC FAKE\n\n"));
 
-	DEBUGOUT(_LtDebugDebug2(__FILE__, mw, w,
+	DEBUGOUT(_LtDebug2(__FILE__, mw, w,
 			   "geometry_manager: resize WorkWindow: %d %d\n",
 			   wants.width, wants.height));
 	/* bypass the clipwindow; the _real_ instigator is the work window */
 	_XmMainWindowPreferredSize(mw, SW_WorkWindow(mw), &wants, &vals);
 	_XmMainWindowLayout(mw, SW_WorkWindow(mw), &wants, &vals);
 	_XmMainWindowConfigureChildren(mw, SW_WorkWindow(mw), &wants, &vals);
-	DEBUGOUT(_LtDebugDebug2(__FILE__, mw, w, "END AUTOMATIC FAKE\n"));
+	DEBUGOUT(_LtDebug2(__FILE__, mw, w, "END AUTOMATIC FAKE\n"));
 	/* consult ScrolledW.c about this return value */
 	return XtGeometryNo;
     }
@@ -1807,7 +1807,7 @@ geometry_manager(Widget w,
     }
     else if (rval == XtGeometryAlmost)
     {
-	DEBUGOUT(_LtDebugDebug2(__FILE__, mw, w,
+	DEBUGOUT(_LtDebug2(__FILE__, mw, w,
 		       "geometry_manager : child wants %s gets %s => Almost\n",
 			   _LtDebugWidgetGeometry2String(&wants),
 			   _LtDebugWidgetGeometry2String(desired)));
@@ -1879,20 +1879,20 @@ XmMainWindowSetAreas(Widget widget,
     Arg args[5];
     int n = 0;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, widget, "XmMainWindowSetAreas ["));
+    DEBUGOUT(_LtDebug(__FILE__, widget, "XmMainWindowSetAreas ["));
 
 #define	P(cw, t)						\
     if (cw)							\
-	{ DEBUGOUT(_LtDebugDebug0(__FILE__, widget, t, XtName(cw))); }\
+	{ DEBUGOUT(_LtDebug0(__FILE__, widget, t, XtName(cw))); }\
     else							\
-	{ DEBUGOUT(_LtDebugDebug0(__FILE__, widget, t, ": NULL")); }
+	{ DEBUGOUT(_LtDebug0(__FILE__, widget, t, ": NULL")); }
 
     P(menu_bar, " MenuBar %s");
     P(command_window, " CommandWindow %s");
     P(horizontal_scrollbar, " Hor.Scrollbar %s");
     P(vertical_scrollbar, " Vert.Scrollbar %s");
     P(work_region, " WorkRegion %s");
-    DEBUGOUT(_LtDebugDebug0(__FILE__, widget, "]\n"));
+    DEBUGOUT(_LtDebug0(__FILE__, widget, "]\n"));
 
 #if 1
     if (menu_bar)
@@ -2027,13 +2027,13 @@ insert_child(Widget w)
 
 	if (XmIsRowColumn(w) && RC_Type(w) == XmMENU_BAR)
 	{
-	    DEBUGOUT(_LtDebugDebug2(__FILE__, p, w,
+	    DEBUGOUT(_LtDebug2(__FILE__, p, w,
 			       "insert_child : this is the menu bar\n"));
 	    MW_MenuBar(p) = w;
 	}
 	else if (XmIsSeparator(w) || XmIsSeparatorGadget(w))
 	{
-	    DEBUGOUT(_LtDebugDebug2(__FILE__, p, w,
+	    DEBUGOUT(_LtDebug2(__FILE__, p, w,
 			       "insert_child : this is a separator\n"));
 	}
 	else if (MW_MessageWindow(p) == NULL &&
@@ -2044,7 +2044,7 @@ insert_child(Widget w)
 		 w != (Widget)SW_HSB(p) &&
 		 w != (Widget)SW_VSB(p))
 	{
-	    DEBUGOUT(_LtDebugDebug2(__FILE__, p, w,
+	    DEBUGOUT(_LtDebug2(__FILE__, p, w,
 			       "insert_child : this is the message window\n"));
 	    MW_MessageWindow(p) = w;
 	}
@@ -2067,7 +2067,7 @@ insert_child(Widget w)
 	    w != (Widget)SW_HSB(p) &&
 	    w != (Widget)SW_VSB(p))
 	{
-	    DEBUGOUT(_LtDebugDebug2(__FILE__, p, w,
+	    DEBUGOUT(_LtDebug2(__FILE__, p, w,
 			       "insert_child : this is the message window\n"));
 	    MW_MessageWindow(p) = w;
 	}
