@@ -1,9 +1,9 @@
 /**
  *
- * $Id: Manager.c,v 1.95 2001/05/20 17:49:38 amai Exp $
+ * $Id: Manager.c,v 1.108 2002/04/12 21:07:02 amai Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
- * Copyright (C) 1995-2001 LessTif Development Team
+ * Copyright  1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -23,7 +23,7 @@
  *
  **/
 
-static const char rcsid[] = "$Id: Manager.c,v 1.95 2001/05/20 17:49:38 amai Exp $";
+static const char rcsid[] = "$Id: Manager.c,v 1.108 2002/04/12 21:07:02 amai Exp $";
 
 #include <LTconfig.h>
 
@@ -55,13 +55,20 @@ static const char rcsid[] = "$Id: Manager.c,v 1.95 2001/05/20 17:49:38 amai Exp
 #include <Xm/DialogS.h>
 
 #if XmVERSION > 1
+#include <XmI/ManagerI.h>
 /* 
  * Traits  
  */
 #include <Xm/TraitP.h>
 #include <Xm/LayoutT.h>
 #include <XmI/DirectionI.h>
+#include <Xm/CareVisualT.h>
+#endif
 
+#include <XmI/DebugUtil.h>
+
+
+#if XmVERSION > 1
 static XmDirection get_direction(Widget w);
 
 static XmSpecifyLayoutDirectionTraitRec _XmManagerLayoutTraitRec =
@@ -69,26 +76,17 @@ static XmSpecifyLayoutDirectionTraitRec _XmManagerLayoutTraitRec =
     0,				/* version */
     get_direction		/* getValue */
 };
-
 #endif
 
-#include <XmI/DebugUtil.h>
-
 
 /* Forward Declarations */
-
 static void class_initialize(void);
-
 static void class_part_initialize(WidgetClass w_class);
-
 static void initialize(Widget request, Widget new_w,
 		       ArgList args, Cardinal *num_args);
-
 static void realize(Widget w, XtValueMask *value_mask,
 		    XSetWindowAttributes *attributes);
-
 static void destroy(Widget w);
-
 static Boolean set_values(Widget current, Widget request, Widget new_w,
 			  ArgList args, Cardinal *num_args);
 
@@ -102,76 +100,52 @@ static Boolean set_values(Widget current, Widget request, Widget new_w,
 
 static void constraint_initialize(Widget request, Widget new_w,
 				  ArgList args, Cardinal *num_args);
-
 static XmNavigability widget_navigable(Widget w);
-
 void _XmManagerInstallAccelerator(Widget m, Widget w, String s);
-
 static void _XmManagerExportX(Widget w, int offset, XtArgVal *value);
-
 static void _XmManagerExportY(Widget w, int offset, XtArgVal *value);
 
 /* action routine prototypes */
 void _XmGadgetButtonMotion(Widget w, XEvent *event,
 			   String *params, Cardinal *num_params);
-
 void _XmGadgetArm(Widget w, XEvent *event,
 		  String *params, Cardinal *num_params);
-
 void _XmGadgetActivate(Widget w, XEvent *event,
 		       String *params, Cardinal *num_params);
-
 void _XmGadgetMultiArm(Widget w, XEvent *event,
 		       String *params, Cardinal *num_params);
-
 void _XmGadgetMultiActivate(Widget w, XEvent *event,
 			    String *params, Cardinal *num_params);
-
 void _XmGadgetDrag(Widget w, XEvent *event,
 		   String *params, Cardinal *num_params);
-
 void _XmGadgetSelect(Widget w, XEvent *event,
 		     String *params, Cardinal *num_params);
-
 void _XmManagerParentActivate(Widget w, XEvent *event,
 			      String *params, Cardinal *num_params);
-
 void _XmManagerParentCancel(Widget w, XEvent *event,
 			    String *params, Cardinal *num_params);
-
 void _XmGadgetTraversePrevTabGroup(Widget w, XEvent *event,
 				   String *params, Cardinal *num_params);
-
 void _XmGadgetTraverseNextTabGroup(Widget w, XEvent *event,
 				   String *params, Cardinal *num_params);
-
 void _XmGadgetTraversePrev(Widget w, XEvent *event,
 			   String *params, Cardinal *num_params);
-
 void _XmGadgetTraverseNext(Widget w, XEvent *event,
 			   String *params, Cardinal *num_params);
-
 void _XmGadgetTraverseUp(Widget w, XEvent *event,
 			 String *params, Cardinal *num_params);
-
 void _XmGadgetTraverseDown(Widget w, XEvent *event,
 			   String *params, Cardinal *num_params);
-
 void _XmGadgetTraverseLeft(Widget w, XEvent *event,
 			   String *params, Cardinal *num_params);
-
 void _XmGadgetTraverseRight(Widget w, XEvent *event,
 			    String *params, Cardinal *num_params);
-
 void _XmGadgetTraverseHome(Widget w, XEvent *event,
 			   String *params, Cardinal *num_params);
-
 void _XmGadgetHelp(Widget w, XEvent *event,
 		   String *params, Cardinal *num_params);
-
 void _XmGadgetKeyInput(Widget w, XEvent *event,
 		       String *params, Cardinal *num_params);
-
 void _XmGadgetHelp(Widget w, XEvent *event,
 		   String *params, Cardinal *num_params);
 
@@ -849,7 +823,7 @@ initialize(Widget request,
 static void
 destroy(Widget w)
 {
-    DEBUGOUT(_LtDebugDebug("RWS", w, "%s:destroy(%d)\n",
+    DEBUGOUT(_LtDebug("RWS", w, "%s:destroy(%d)\n",
 		      __FILE__, __LINE__
 	     ));
     XtReleaseGC(w, MGR_TopShadowGC(w));
@@ -879,7 +853,7 @@ realize(Widget w, XtValueMask *value_mask, XSetWindowAttributes *attributes)
        This causes a parse error with gcc on AIX???
        Boolean wz = False, hz = False; */
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "%s:realize(%d) - %dx%d\n",
+    DEBUGOUT(_LtDebug(__FILE__, w, "%s:realize(%d) - %dx%d\n",
 		      __FILE__, __LINE__,
 		      XtWidth(w), XtHeight(w)));
 
@@ -926,9 +900,13 @@ set_values(Widget old,
 	   ArgList args,
 	   Cardinal *num_args)
 {
-    Boolean need_refresh = False;
+	Boolean need_refresh = False;
+#if	XmVERSION > 1
+	/* A variable to hold the trait flags */
+	Mask	msk = 0;
+#endif
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, new_w, "SetValues()\n"));
+    DEBUGOUT(_LtDebug(__FILE__, new_w, "SetValues()\n"));
 
 #if 0
     if (XtWidth(new_w) != XtWidth(old) && XtWidth(new_w) == 0)
@@ -986,44 +964,80 @@ set_values(Widget old,
     {
 	need_refresh = True;
     }
+#if XmVERSION > 1
+	if (MGR_Foreground(old) != MGR_Foreground(new_w))
+		msk |= VisualForeground;
+#endif
 
-    if (MGR_HighlightColor(old) != MGR_HighlightColor(new_w)
-	|| MGR_HighlightPixmap(old) != MGR_HighlightPixmap(new_w))
-    {
-	XtReleaseGC(new_w, MGR_HighlightGC(new_w));
-	CreateHighlightGC(new_w);
-	need_refresh = True;
-    }
+	if (MGR_HighlightColor(old) != MGR_HighlightColor(new_w)
+			|| MGR_HighlightPixmap(old) != MGR_HighlightPixmap(new_w)) {
+		XtReleaseGC(new_w, MGR_HighlightGC(new_w));
+		CreateHighlightGC(new_w);
+		need_refresh = True;
+#if XmVERSION > 1
+		if (MGR_HighlightColor(old) != MGR_HighlightColor(new_w))
+			msk |= VisualHighlightColor;
+		if (MGR_HighlightPixmap(old) != MGR_HighlightPixmap(new_w))
+			msk |= VisualHighlightPixmap;
+#endif
+	}
 
-    if (MGR_BottomShadowColor(old) != MGR_BottomShadowColor(new_w)
-	|| MGR_BottomShadowPixmap(old) != MGR_BottomShadowPixmap(new_w))
-    {
-	XtReleaseGC(new_w, MGR_BottomShadowGC(new_w));
-	CreateBottomShadowGC(new_w);
+	if (MGR_BottomShadowColor(old) != MGR_BottomShadowColor(new_w)
+			|| MGR_BottomShadowPixmap(old) != MGR_BottomShadowPixmap(new_w)) {
+		XtReleaseGC(new_w, MGR_BottomShadowGC(new_w));
+		CreateBottomShadowGC(new_w);
+		need_refresh = True;
+#if XmVERSION > 1
+		if (MGR_BottomShadowColor(old) != MGR_BottomShadowColor(new_w))
+			msk |= VisualBottomShadowColor;
+		if (MGR_BottomShadowPixmap(old) != MGR_BottomShadowPixmap(new_w))
+			msk |= VisualBottomShadowPixmap;
+#endif
+	}
 
-	need_refresh = True;
-    }
+	if (MGR_TopShadowColor(old) != MGR_TopShadowColor(new_w)
+			|| MGR_TopShadowPixmap(old) != MGR_TopShadowPixmap(new_w)) {
+		XtReleaseGC(new_w, MGR_TopShadowGC(new_w));
+		CreateTopShadowGC(new_w);
+		need_refresh = True;
+#if XmVERSION > 1
+		if (MGR_TopShadowColor(old) != MGR_TopShadowColor(new_w))
+			msk |= VisualTopShadowColor;
+		if (MGR_TopShadowPixmap(old) != MGR_TopShadowPixmap(new_w))
+			msk |= VisualTopShadowPixmap;
+#endif
+	}
 
-    if (MGR_TopShadowColor(old) != MGR_TopShadowColor(new_w)
-	|| MGR_TopShadowPixmap(old) != MGR_TopShadowPixmap(new_w))
-    {
-	XtReleaseGC(new_w, MGR_TopShadowGC(new_w));
-	CreateTopShadowGC(new_w);
+	if (XtBackground(old) != XtBackground(new_w)) {
+		XtReleaseGC(new_w, MGR_BackgroundGC(new_w));
+		CreateBackgroundGC(new_w);
+		need_refresh = True;
+#if XmVERSION > 1
+		if (XtBackground(old) != XtBackground(new_w))
+			msk |= VisualBackgroundPixel;
+#endif
+	}
 
-	need_refresh = True;
-    }
+	_XmManagerImportArgs(new_w, args, num_args);
 
-    if (XtBackground(old) != XtBackground(new_w))
-    {
-	XtReleaseGC(new_w, MGR_BackgroundGC(new_w));
-	CreateBackgroundGC(new_w);
+#if XmVERSION > 1
+	if (msk) {
+		XmCareVisualTrait	t;
+		int			i;
 
-	need_refresh = True;
-    }
+		for (i=0; i<MGR_NumChildren(new_w); i++) {
+			Widget	child = MGR_Children(new_w)[i];
 
-    _XmManagerImportArgs(new_w, args, num_args);
-
-    return need_refresh;
+			t = (XmCareVisualTrait) XmeTraitGet((XtPointer)XtClass(child),
+				XmQTcareParentVisual);
+			if (t && t->redraw(child, old, new_w, msk)) {
+				/* FIX ME this doesn't look like the right action, does it ? */
+				need_refresh = True;
+			}
+		}
+	}
+#endif
+	return need_refresh;
 }
 
 #if 0
@@ -1033,7 +1047,7 @@ geometry_manager(Widget w,
 		 XtWidgetGeometry *reply)
 {
     /* Motif does not have this method */
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "geometry_manager()\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "geometry_manager()\n"));
 
     if (reply)
     {
@@ -1069,7 +1083,7 @@ changed_managed(Widget w)
 {
     /* Motif does not have this method */
     /* FIX ME */
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "ChangeManaged()\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "ChangeManaged()\n"));
 
 
     _XmNavigChangeManaged(w);
@@ -1097,7 +1111,7 @@ constraint_initialize(Widget request,
 		|| G_EventMask(new_w) & XmENTER_EVENT
 		|| G_EventMask(new_w) & XmLEAVE_EVENT)
 	    {
-		DEBUGOUT(_LtDebugDebug(__FILE__, manager, "adding event handler\n"));
+		DEBUGOUT(_LtDebug(__FILE__, manager, "adding event handler\n"));
 
 		XtAddEventHandler(manager,
 				  PointerMotionMask | EnterWindowMask |
@@ -1120,7 +1134,7 @@ _XmGadgetArm(Widget w,
     XButtonEvent *ev = (XButtonEvent *)event;
     Widget g = (Widget)_XmInputForGadget(w, ev->x, ev->y);
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "Inside _XmGadgetArm()\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "Inside _XmGadgetArm()\n"));
 
     if (g)
     {
@@ -1149,7 +1163,7 @@ _XmGadgetActivate(Widget w,
 {
     Widget g = (Widget)MGR_SelectedGadget(w);
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "Inside _XmGadgetActivate()\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "Inside _XmGadgetActivate()\n"));
 
     if (g)
     {
@@ -1170,7 +1184,7 @@ _XmGadgetMultiArm(Widget w,
     XButtonEvent *ev = (XButtonEvent *)event;
     Widget g = (Widget)_XmInputForGadget(w, ev->x, ev->y);
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "Inside _XmGadgetMultiArm()\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "Inside _XmGadgetMultiArm()\n"));
 
     if (g)
     {
@@ -1212,7 +1226,7 @@ _XmGadgetMultiActivate(Widget w,
 {
     Widget g = (Widget)MGR_SelectedGadget(w);
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "Inside _XmGadgetMultiActivate()\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "Inside _XmGadgetMultiActivate()\n"));
 
     if (g)
     {
@@ -1247,7 +1261,7 @@ _XmGadgetDrag(Widget w,
     XButtonEvent *ev = (XButtonEvent *)event;
     Widget g = (Widget)_XmInputForGadget(w, ev->x, ev->y);
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "Inside _XmGadgetDrag()\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "Inside _XmGadgetDrag()\n"));
 
     if (g)
     {
@@ -1265,7 +1279,7 @@ _XmGadgetSelect(Widget w,
 {
     Widget g = MGR_ActiveChild(w);
 
-    DEBUGOUT(_LtDebugDebug2(__FILE__, w, g, "Inside _XmGadgetSelect()\n"));
+    DEBUGOUT(_LtDebug2(__FILE__, w, g, "Inside _XmGadgetSelect()\n"));
 
     if (g && XmIsGadget(g))
     {
@@ -1287,7 +1301,7 @@ _XmManagerParentActivate(Widget w,
     XmParentProcessDataRec data;
     XmManagerWidgetClass mwc = (XmManagerWidgetClass)w->core.widget_class;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "Inside ManagerParentActivate()\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "Inside ManagerParentActivate()\n"));
 
     data.input_action.process_type = XmINPUT_ACTION;
     data.input_action.event = event;
@@ -1367,7 +1381,7 @@ _XmGadgetTraverseRight(Widget w,
 {
     Widget g = MGR_ActiveChild(w);
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, g,
+    DEBUGOUT(_LtDebug(__FILE__, g,
 		      "Manager XmProcessTraversal(TRAVERSE_RIGHT)\n"));
 
     XmProcessTraversal(g, XmTRAVERSE_RIGHT);
@@ -1394,7 +1408,7 @@ _XmGadgetHelp(Widget w,
     Widget cur;
     XmAnyCallbackStruct cbs;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "Inside _XmGadgetHelp()\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "Inside _XmGadgetHelp()\n"));
 
     if (g)
     {
@@ -1439,8 +1453,8 @@ _XmGadgetKeyInput(Widget w,
 {
     Widget g = MGR_ActiveChild(w);
 
-    DEBUGOUT(_LtDebugDebug2(__FILE__, w, g, "Inside _XmGadgetKeyInput()\n"));
-    DEBUGOUT(_LtDebugDebug2(__FILE__, w, g,
+    DEBUGOUT(_LtDebug2(__FILE__, w, g, "Inside _XmGadgetKeyInput()\n"));
+    DEBUGOUT(_LtDebug2(__FILE__, w, g,
 		       "event type: %d code %08x\n",
 		       event->type, event->xkey.keycode));
 
@@ -1460,7 +1474,7 @@ _XmGadgetButtonMotion(Widget w,
 {
     Widget g = MGR_ActiveChild(w);
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, w,
+    DEBUGOUT(_LtDebug(__FILE__, w,
 		      "Inside _XmGadgetButtonMotion(), gadget %s\n",
 		      g ? XtName(g) : "(null)"));
 
@@ -1481,7 +1495,7 @@ _XmManagerParentCancel(Widget w,
     XmParentProcessDataRec data;
     XmManagerWidgetClass mwc = (XmManagerWidgetClass)w->core.widget_class;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "ManagerParentCancel\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "ManagerParentCancel\n"));
 
     data.input_action.process_type = XmINPUT_ACTION;
     data.input_action.event = event;
@@ -1526,7 +1540,7 @@ _XmSocorro(Widget w, XEvent *event, String *params, Cardinal *num_params)
 {
     XmAnyCallbackStruct cbs;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "Inside _XmSocorro()\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "Inside _XmSocorro()\n"));
 
     cbs.reason = XmCR_HELP;
     cbs.event = event;
@@ -1575,12 +1589,12 @@ _XmManagerEventHandler(Widget w,
     g = _XmInputForGadget(w, event->xmotion.x, event->xmotion.y);
     if (g == NULL)
     {
-	DEBUGOUT(_LtDebugDebug(__FILE__, w,
+	DEBUGOUT(_LtDebug(__FILE__, w,
 			  "### _XmManagerEventHandler(gadget NULL)\n"));
     }
     else
     {
-	DEBUGOUT(_LtDebugDebug2(__FILE__, w,
+	DEBUGOUT(_LtDebug2(__FILE__, w,
 			   (Widget)g, "### _XmManagerEventHandler()\n"));
     }
 
@@ -1620,7 +1634,7 @@ _XmManagerEventHandler(Widget w,
 
 	if (MGR_HighlightedWidget(w) != NULL)
 	{
-	    DEBUGOUT(_LtDebugDebug(__FILE__, w, "Sending LEAVE event to gadget\n"));
+	    DEBUGOUT(_LtDebug(__FILE__, w, "Sending LEAVE event to gadget\n"));
 	    _XmDispatchGadgetInput(MGR_HighlightedWidget(w),
 				   event,
 				   XmLEAVE_EVENT);
@@ -1643,7 +1657,7 @@ _XmManagerEventHandler(Widget w,
 
 	if (MGR_HighlightedWidget(w) == NULL)
 	{
-	    DEBUGOUT(_LtDebugDebug(__FILE__, w, "Sending ENTER event to gadget\n"));
+	    DEBUGOUT(_LtDebug(__FILE__, w, "Sending ENTER event to gadget\n"));
 
 	    _XmDispatchGadgetInput((Widget)g,
 				   event,
@@ -1656,14 +1670,14 @@ _XmManagerEventHandler(Widget w,
 	    if (MGR_HighlightedWidget(w) != (Widget)g)
 	    {
 
-		DEBUGOUT(_LtDebugDebug(__FILE__, w,
+		DEBUGOUT(_LtDebug(__FILE__, w,
 				  "Sending LEAVE event to old gadget\n"));
 
 		_XmDispatchGadgetInput(MGR_HighlightedWidget(w),
 				       event,
 				       XmLEAVE_EVENT);
 
-		DEBUGOUT(_LtDebugDebug(__FILE__, w,
+		DEBUGOUT(_LtDebug(__FILE__, w,
 				  "Sending ENTER event to new gadget\n"));
 
 		_XmDispatchGadgetInput((Widget)g,
@@ -1679,7 +1693,7 @@ _XmManagerEventHandler(Widget w,
 void
 _XmDestroyParentCallback(Widget w, XtPointer client, XtPointer call)
 {
-    DEBUGOUT(_LtDebugDebug2("NEDIT", XtParent(w), w,
+    DEBUGOUT(_LtDebug2("NEDIT", XtParent(w), w,
 		       "%s:_XmDestroyParentCallback(%d)\n",
 		       __FILE__, __LINE__));
     XtDestroyWidget(XtParent(w));
@@ -1747,12 +1761,12 @@ _XmAcceleratorHandler(Widget w, XtPointer client_data,
     XtActionProc act = NULL;
     Widget comp = (Widget)client_data;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, w,
+    DEBUGOUT(_LtDebug(__FILE__, w,
 		      "Got Accelerator key: type %d code %04x "
 		      "state %08x data %08x\n",
 		      event->type, event->xkey.keycode, event->xkey.state,
 		      client_data));
-    DEBUGOUT(_LtDebugDebug("NMEM", w,
+    DEBUGOUT(_LtDebug("NMEM", w,
 		      "Got Accelerator key: type %d code %04x "
 		      "state %08x data %08x\n",
 		      event->type, event->xkey.keycode, event->xkey.state,
@@ -1761,16 +1775,16 @@ _XmAcceleratorHandler(Widget w, XtPointer client_data,
     if (!XmIsManager(w) ||
 	(event->type != KeyPress && event->type != KeyRelease))
     {
-	DEBUGOUT(_LtDebugDebug(__FILE__, w,
+	DEBUGOUT(_LtDebug(__FILE__, w,
 			  "Bad match for event.  Not manager or bad event.\n"));
 	return;
     }
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, w,
+    DEBUGOUT(_LtDebug(__FILE__, w,
 		    "Got Accelerator key: code: %08x state: %08x cd %08x %s\n",
 		      event->xkey.keycode, event->xkey.state, comp,
 		      XtName(comp)));
-    DEBUGOUT(_LtDebugDebug("NMEM", w,
+    DEBUGOUT(_LtDebug("NMEM", w,
 		    "Got Accelerator key: code: %08x state: %08x cd %08x %s\n",
 		      event->xkey.keycode, event->xkey.state, comp,
 		      XtName(comp)));
@@ -1800,13 +1814,19 @@ _XmAcceleratorHandler(Widget w, XtPointer client_data,
     if (!comp->core.widget_class)
     {
 	_XmWarning(NULL, "XmManager _XmAcceleratorHandler: bad news!!!\n");
-	DEBUGOUT(_LtDebugDebug(__FILE__, w,
+	DEBUGOUT(_LtDebug(__FILE__, w,
 			  "_XmAcceleratorHandler: called for w=%s"
 			  " with invalid comp, ignoring\n",
 			  XtName(w)));
 	return;
 
     }
+    /* Another one of these. Danny 21/10/2001 */
+    if (comp->core.being_destroyed) {
+	_XmWarning(NULL, "XmManager _XmAcceleratorHandler: being destroyed, bad news!!!\n");
+	return;
+    }
+
 
     /*
      * Insensitive widgets shouldn't be activated by accelerators or
@@ -1819,7 +1839,7 @@ _XmAcceleratorHandler(Widget w, XtPointer client_data,
      * --mu@trends.net, 1998.09.06 */
     if (!XtIsSensitive(comp))
     {
-	DEBUGOUT(_LtDebugDebug(__FILE__, w,
+	DEBUGOUT(_LtDebug(__FILE__, w,
 			"_XmAcceleratorHandler: %s is insensitive, ignoring\n",
 			  XtName(comp)));
 	return;
@@ -1835,7 +1855,7 @@ _XmAcceleratorHandler(Widget w, XtPointer client_data,
 	{
 	    Cardinal num_params = 0;
 
-	    DEBUGOUT(_LtDebugDebug(__FILE__, w,
+	    DEBUGOUT(_LtDebug(__FILE__, w,
 			      "MATCH!!!! "
 			      "code %08x state %08x name: %s:%s mnem: %d\n",
 			      event->xkey.keycode, event->xkey.state,
@@ -1844,7 +1864,7 @@ _XmAcceleratorHandler(Widget w, XtPointer client_data,
 			      : "(nil)",
 			      comp ? XtName(comp) : "(nil)",
 			      MGR_KeyboardList(w)[i].isMnemonic));
-	    DEBUGOUT(_LtDebugDebug("NMEM", w,
+	    DEBUGOUT(_LtDebug("NMEM", w,
 			      "MATCH!!!! "
 			      "code %08x state %08x name: %s:%s mnem: %d\n",
 			      event->xkey.keycode, event->xkey.state,
@@ -1870,9 +1890,9 @@ _XmAcceleratorHandler(Widget w, XtPointer client_data,
 		(MGR_KeyboardList(w)[i].isMnemonic && XtParent(comp) == RC_PopupPosted(w))
 		)
 	    {
-		DEBUGOUT(_LtDebugDebug2(__FILE__, w, MGR_KeyboardList(w)[i].component,
+		DEBUGOUT(_LtDebug2(__FILE__, w, MGR_KeyboardList(w)[i].component,
 				   "menu showing\n"));
-		DEBUGOUT(_LtDebugDebug2("NMEM", w, MGR_KeyboardList(w)[i].component,
+		DEBUGOUT(_LtDebug2("NMEM", w, MGR_KeyboardList(w)[i].component,
 				   "menu showing\n"));
 		if (XmIsPrimitive(MGR_KeyboardList(w)[i].component))
 		{
@@ -1906,7 +1926,7 @@ _XmAcceleratorHandler(Widget w, XtPointer client_data,
 		}
 		else
 		{
-		    DEBUGOUT(_LtDebugDebug(__FILE__, MGR_KeyboardList(w)[i].component,
+		    DEBUGOUT(_LtDebug(__FILE__, MGR_KeyboardList(w)[i].component,
 				      "Not a widget/gadget\n"));
 
 		    XtCallActionProc(comp, "Activate", event, NULL, 0);
@@ -1916,9 +1936,9 @@ _XmAcceleratorHandler(Widget w, XtPointer client_data,
 	    }
 	    else
 	    {
-		DEBUGOUT(_LtDebugDebug2(__FILE__, w, MGR_KeyboardList(w)[i].component,
+		DEBUGOUT(_LtDebug2(__FILE__, w, MGR_KeyboardList(w)[i].component,
 				   "menu is not showing\n"));
-		DEBUGOUT(_LtDebugDebug2("NMEM", w, MGR_KeyboardList(w)[i].component,
+		DEBUGOUT(_LtDebug2("NMEM", w, MGR_KeyboardList(w)[i].component,
 				   "menu is not showing\n"));
 	    }
 
@@ -1934,6 +1954,7 @@ static void
 AddKeyboardEntry(Widget m, Widget w, XmKeyboardData *item)
 {
     int i;
+    unsigned long mask;
 
     /* Register with the manager widget */
     if (MGR_SizeKeyboardList(m) == 0 ||
@@ -1977,18 +1998,39 @@ AddKeyboardEntry(Widget m, Widget w, XmKeyboardData *item)
 
     MGR_NumKeyboardEntries(m)++;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, m,
+    DEBUGOUT(_LtDebug(__FILE__, m,
 		      "GrabKey: key %04x Sym: %04x modifiers %08x %s %s\n",
 		      item->key, item->keysym, item->modifiers,
 		      item->needGrab ? "Grabbing" : "Not Grabbing",
 		      item->isMnemonic ? "mnemonic" : "not mnemonic"));
-    DEBUGOUT(_LtDebugDebug("NMEM", m,
+    DEBUGOUT(_LtDebug("NMEM", m,
 		      "GrabKey: key %04x Sym: %04x modifiers %08x %s %s\n",
 		      item->key, item->keysym, item->modifiers,
 		      item->needGrab ? "Grabbing" : "Not Grabbing",
 		      item->isMnemonic ? "mnemonic" : "not mnemonic"));
-
-    XtInsertEventHandler(m, item->eventType /*KeyPressMask|KeyReleaseMask */ ,
+#if 1
+	switch (item->eventType) {
+	case KeyPress:
+		mask = KeyPressMask;
+		break;
+	case KeyRelease:
+		mask = KeyReleaseMask;
+		break;
+	case ButtonPress:
+		mask = ButtonPressMask;
+		break;
+	case ButtonRelease:
+		mask = ButtonReleaseMask;
+		break;
+	default:
+		_XmWarning(m, "AddKeyboardEntry: can't map event %d\n", item->eventType);
+		mask = 0;
+	}
+#else
+	mask = KeyPressMask;
+	mask = item->eventType;	/* This must be wrong but the alternatives crash nedit. FIX ME */
+#endif
+    XtInsertEventHandler(m, mask,
 			 False, _XmAcceleratorHandler,
 			 (XtPointer)w, XtListHead);
 
@@ -2058,9 +2100,9 @@ _XmManagerInstallAccelerator(Widget m, Widget w, String s)
     unsigned int modifiers = 0;
     XmKeyboardData data;
 
-    DEBUGOUT(_LtDebugDebug2(__FILE__, m, w,
+    DEBUGOUT(_LtDebug2(__FILE__, m, w,
 		       "_XmManagerInstallAccelerator(%s)\n", s));
-    DEBUGOUT(_LtDebugDebug2("NMEM", m, w,
+    DEBUGOUT(_LtDebug2("NMEM", m, w,
 		       "_XmManagerInstallAccelerator(%s)\n", s));
 
     /* Do we really have an accelerator ? */
@@ -2099,7 +2141,7 @@ _XmManagerInstallAccelerator(Widget m, Widget w, String s)
     }
 
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, w,
+    DEBUGOUT(_LtDebug(__FILE__, w,
 		      "_XmManagerInstallAccelerator found manager %s\n",
 		      XtName(mw)));
 
@@ -2181,8 +2223,8 @@ _XmManagerInstallMnemonic(Widget m, Widget w, KeySym mn)
 	return;
     }
 
-    DEBUGOUT(_LtDebugDebug2(__FILE__, m, w, "_XmManagerInstallMnemonic(%c)\n", mn));
-    DEBUGOUT(_LtDebugDebug2("NMEM", m, w, "_XmManagerInstallMnemonic(%c)\n", mn));
+    DEBUGOUT(_LtDebug2(__FILE__, m, w, "_XmManagerInstallMnemonic(%c)\n", mn));
+    DEBUGOUT(_LtDebug2("NMEM", m, w, "_XmManagerInstallMnemonic(%c)\n", mn));
 
     /* If we're dealing with the menu bar, store the stuff in the highest
      * manager widget that you can find (with all the accelerators) */
@@ -2214,8 +2256,8 @@ _XmManagerInstallMnemonic(Widget m, Widget w, KeySym mn)
 	    }
 	}
 
-	DEBUGOUT(_LtDebugDebug2(__FILE__, mw, w, "Store mnemonic info\n"));
-	DEBUGOUT(_LtDebugDebug2("NMEM", mw, w, "Store mnemonic info\n"));
+	DEBUGOUT(_LtDebug2(__FILE__, mw, w, "Store mnemonic info\n"));
+	DEBUGOUT(_LtDebug2("NMEM", mw, w, "Store mnemonic info\n"));
 	m = mw;
     }
 
@@ -2277,28 +2319,29 @@ widget_navigable(Widget w)
 	    MGR_NavigationType(w) == XmEXCLUSIVE_TAB_GROUP ||
 	    (MGR_NavigationType(w) == XmTAB_GROUP && !_XmShellIsExclusive(w)))
 	{
-	    DEBUGOUT(_LtDebugDebug(__FILE__, w,
+	    DEBUGOUT(_LtDebug(__FILE__, w,
 			  "WidgetNavigable => XmDESCENDANTS_TAB_NAVIGABLE\n"));
 
 	    return XmDESCENDANTS_TAB_NAVIGABLE;
 	}
-	DEBUGOUT(_LtDebugDebug(__FILE__, w,
+	DEBUGOUT(_LtDebug(__FILE__, w,
 			  "WidgetNavigable => XmDESCENDANTS_NAVIGABLE\n"));
 
 	return XmDESCENDANTS_NAVIGABLE;
     }
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "WidgetNavigable => XmNOT_NAVIGABLE\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "WidgetNavigable => XmNOT_NAVIGABLE\n"));
 
     return XmNOT_NAVIGABLE;
 }
 
+
 void
 _XmManagerHighlightPixmapDefault(Widget w, int offset, XrmValue *value)
 {
     static Pixmap pixmap;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "_XmManagerHighlightPixmapDefault\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "_XmManagerHighlightPixmapDefault\n"));
 
     pixmap = XmUNSPECIFIED_PIXMAP;
 
@@ -2312,12 +2355,13 @@ _XmManagerHighlightPixmapDefault(Widget w, int offset, XrmValue *value)
 				    CoreDepth(w));
 }
 
+
 void
 _XmManagerTopShadowPixmapDefault(Widget w, int offset, XrmValue *value)
 {
     static Pixmap pixmap;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "_XmManagerTopShadowPixmapDefault\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "_XmManagerTopShadowPixmapDefault\n"));
 
     pixmap = XmUNSPECIFIED_PIXMAP;
 
@@ -2336,6 +2380,7 @@ _XmManagerTopShadowPixmapDefault(Widget w, int offset, XrmValue *value)
 				    CoreDepth(w));
 }
 
+
 static void
 _XmManagerExportX(Widget widget, int offset, XtArgVal *value)
 {
@@ -2374,6 +2419,7 @@ _XmManagerExportY(Widget widget, int offset, XtArgVal *value)
     *value = converted_value;
 }
 
+
 #if XmVERSION > 1
 static XmDirection 
 get_direction(Widget w)
@@ -2387,4 +2433,35 @@ get_direction(Widget w)
      */
     return MGR_StringDirection(w);
 }
-#endif
+
+
+extern Widget
+XmObjectAtPoint(Widget w, Position x, Position y)
+{
+
+   /* FIX ME */
+   /* Used to be in GadgetUtil.c, but didn't do 
+      exactly what it is supposed to ... */
+
+    int i;
+    
+    DEBUGOUT(_LtDebug(__FILE__, w, "XmObjectAtPoint()\n"));
+    for (i = 0; i < (int)MGR_NumChildren(w); i++)
+    {
+	Widget g = MGR_Children(w)[i];
+
+	if (!XtIsManaged(g))
+	{
+	    continue;
+	}
+
+	if ((x >= XtX(g) && x < XtX(g) + XtWidth(g)) &&
+	    (y >= XtY(g) && y < XtY(g) + XtHeight(g)))
+	{
+	    return g;
+	}
+    }
+    /* Northing found */
+    return NULL;
+}
+#endif /* XmVERSION > 1 */
