@@ -1,9 +1,9 @@
 /**
  *
- * $Id: Primitive.c,v 1.46 2001/05/14 19:46:09 amai Exp $
+ * $Id: Primitive.c,v 1.50 2001/12/29 15:11:38 dannybackx Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
- * Copyright (C) 1995-2001 LessTif Development Team
+ * Copyright  1995, 1996, 1997, 1998, 1999, 2000, 2001 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -23,7 +23,7 @@
  *
  **/
 
-static const char rcsid[] = "$Id: Primitive.c,v 1.46 2001/05/14 19:46:09 amai Exp $";
+static const char rcsid[] = "$Id: Primitive.c,v 1.50 2001/12/29 15:11:38 dannybackx Exp $";
 
 #include <LTconfig.h>
 
@@ -39,38 +39,27 @@ static const char rcsid[] = "$Id: Primitive.c,v 1.46 2001/05/14 19:46:09 amai Ex
 #if XmVERSION > 1
 /* Includes for 2.0 features */
 #include <XmI/DirectionI.h>
+#include <Xm/CareVisualT.h>
 #endif
 
 #include <XmI/DebugUtil.h>
 
 
 /* Forward Declarations */
-
 static void class_initialize(void);
-
 static void class_part_initialize(WidgetClass w_class);
-
 static void initialize(Widget request, Widget new_w,
 		       ArgList args, Cardinal *num_args);
-
 static void realize(Widget w, XtValueMask *value_mask,
 		    XSetWindowAttributes *attributes);
-
 static void destroy(Widget w);
-
 static Boolean set_values(Widget current, Widget request, Widget new_w,
 			  ArgList args, Cardinal *num_args);
-
 static void focus_change(Widget w, XmFocusChange fevent);
-
 static XmNavigability widget_navigable(Widget w);
-
 static void primitive_border_unhighlight(Widget w);
-
 static void primitive_border_highlight(Widget w);
-
 static void _XmPrimitiveExportY(Widget widget, int offset, XtArgVal *value);
-
 static void _XmPrimitiveExportX(Widget widget, int offset, XtArgVal *value);
 
 /*
@@ -369,13 +358,30 @@ XmPrimitiveClassRec xmPrimitiveClassRec = {
 
 WidgetClass xmPrimitiveWidgetClass = (WidgetClass)&xmPrimitiveClassRec;
 
+#if XmVERSION > 1
+/* Trait record */
+static Boolean _PrimitiveTrait_Redraw(Widget, Widget, Widget, Mask);
+
+static XmCareVisualTraitRec _XmPrimitiveTraitRec = {
+	/* version */		0,
+	/* redraw */		_PrimitiveTrait_Redraw
+};
+#endif
+
 static void
 class_initialize(void)
 {
-    _XmRegisterConverters();
-    _XmRegisterPixmapConverters();
-    _XmInitializeExtensions();
-    _XmPrimitiveCoreClassExtRec.record_type = XmQmotif;
+	_XmRegisterConverters();
+	_XmRegisterPixmapConverters();
+	_XmInitializeExtensions();
+	_XmPrimitiveCoreClassExtRec.record_type = XmQmotif;
+
+#if XmVERSION > 1
+	if (! XmeTraitSet((XtPointer)xmPrimitiveWidgetClass, XmQTcareParentVisual,
+			(XtPointer)&_XmPrimitiveTraitRec)) {
+		_XmWarning(NULL, "XmPrimitive ClassInitialize: XmeTraitSet failed\n");
+	}
+#endif
 }
 
 static void
@@ -651,7 +657,7 @@ realize(Widget w,
 {
     int i;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, w,
+    DEBUGOUT(_LtDebug(__FILE__, w,
 		      "Realize wid before create %d ht %d bw %d\n",
 		      XtWidth(w), XtHeight(w), XtBorderWidth(w)));
 
@@ -682,7 +688,7 @@ realize(Widget w,
 	XtRealizeWidget(w->core.popup_list[i]);
     }
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "Realize wid %d ht %d bw %d\n",
+    DEBUGOUT(_LtDebug(__FILE__, w, "Realize wid %d ht %d bw %d\n",
 		      XtWidth(w), XtHeight(w), XtBorderWidth(w)));
 }
 
@@ -736,7 +742,7 @@ set_values(Widget old, Widget request, Widget new_w,
     /* Debug print */
     if (Prim_Foreground(old) != Prim_Foreground(new_w))
     {
-	DEBUGOUT(_LtDebugDebug(__FILE__, new_w,
+	DEBUGOUT(_LtDebug(__FILE__, new_w,
 			  "Primitive SetValues: Foreground changed\n"));
 	need_refresh = True;
     }
@@ -809,7 +815,7 @@ focus_change(Widget w, XmFocusChange change)
 {
     XmPrimitiveWidgetClass pc = (XmPrimitiveWidgetClass)XtClass(w);
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "Primitive Focus Change (%s)\n",
+    DEBUGOUT(_LtDebug(__FILE__, w, "Primitive Focus Change (%s)\n",
 		      (change == XmENTER) ? "XmENTER" :
 		      (change == XmFOCUS_IN) ? "XmFOCUS_IN" :
 		      (change == XmLEAVE) ? "XmLEAVE" :
@@ -866,19 +872,19 @@ widget_navigable(Widget w)
 	    Prim_NavigationType(w) == XmEXCLUSIVE_TAB_GROUP ||
 	    (Prim_NavigationType(w) == XmTAB_GROUP && !_XmShellIsExclusive(w)))
 	{
-	    DEBUGOUT(_LtDebugDebug(__FILE__, w,
+	    DEBUGOUT(_LtDebug(__FILE__, w,
 			      "PrimitiveWidgetNavigable => XmTAB_NAVIGABLE\n"));
 
 	    return XmTAB_NAVIGABLE;
 	}
 
-	DEBUGOUT(_LtDebugDebug(__FILE__, w,
+	DEBUGOUT(_LtDebug(__FILE__, w,
 			  "PrimitiveWidgetNavigable => XmCONTROL_NAVIGABLE\n"));
 
 	return XmCONTROL_NAVIGABLE;
     }
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, w,
+    DEBUGOUT(_LtDebug(__FILE__, w,
 	   "PrimitiveWidgetNavigable (sens %s TravOn %s) => XmNOT_NAVIGABLE\n",
 		      _LtDebugBoolean2String(XtSensitive(w)),
 		      _LtDebugBoolean2String(Prim_TraversalOn(w))));
@@ -889,7 +895,7 @@ widget_navigable(Widget w)
 static void
 primitive_border_unhighlight(Widget w)
 {
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "PrimitiveBorderUnhighlight\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "PrimitiveBorderUnhighlight\n"));
 
     if (!XtIsRealized(w))
     {
@@ -925,7 +931,7 @@ primitive_border_unhighlight(Widget w)
 static void
 primitive_border_highlight(Widget w)
 {
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "PrimitiveBorderHighlight\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "PrimitiveBorderHighlight\n"));
 
     if (!XtIsRealized(w))
     {
@@ -957,8 +963,8 @@ _XmTraverseLeft(Widget w, XEvent *event, String *params, Cardinal *num_params)
 void
 _XmTraverseRight(Widget w, XEvent *event, String *params, Cardinal *num_params)
 {
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "XmProcessTraversal(TRAVERSE_RIGHT)\n"));
-    DEBUGOUT(_LtDebugDebug(__FILE__, w,
+    DEBUGOUT(_LtDebug(__FILE__, w, "XmProcessTraversal(TRAVERSE_RIGHT)\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w,
 		       "event type: %d code %08x\n",
 		       event->type, event->xkey.keycode));
 
@@ -968,7 +974,7 @@ _XmTraverseRight(Widget w, XEvent *event, String *params, Cardinal *num_params)
 void
 _XmTraverseNext(Widget w, XEvent *event, String *params, Cardinal *num_params)
 {
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "XmProcessTraversal(TRAVERSE_NEXT)\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "XmProcessTraversal(TRAVERSE_NEXT)\n"));
 
     XmProcessTraversal(w, XmTRAVERSE_NEXT);
 }
@@ -976,7 +982,7 @@ _XmTraverseNext(Widget w, XEvent *event, String *params, Cardinal *num_params)
 void
 _XmTraversePrev(Widget w, XEvent *event, String *params, Cardinal *num_params)
 {
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "XmProcessTraversal(TRAVERSE_PREV)\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "XmProcessTraversal(TRAVERSE_PREV)\n"));
 
     XmProcessTraversal(w, XmTRAVERSE_PREV);
 }
@@ -1060,7 +1066,7 @@ _XmPrimitiveHelp(Widget w, XEvent *event,
     Widget cur = w;
     XmAnyCallbackStruct cbs;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "_XmPrimitiveHelp\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "_XmPrimitiveHelp\n"));
 
     cbs.reason = XmCR_HELP;
     cbs.event = event;
@@ -1069,7 +1075,7 @@ _XmPrimitiveHelp(Widget w, XEvent *event,
     {
 	if (XtHasCallbacks(cur, XmNhelpCallback) == XtCallbackHasSome)
 	{
-	    DEBUGOUT(_LtDebugDebug(__FILE__, cur,
+	    DEBUGOUT(_LtDebug(__FILE__, cur,
 			      "_XmPrimitiveHelp ... calling !!\n"));
 
 	    XtCallCallbacks(cur, XmNhelpCallback, (XtPointer)&cbs);
@@ -1077,7 +1083,7 @@ _XmPrimitiveHelp(Widget w, XEvent *event,
 	    return;
 	}
 
-	DEBUGOUT(_LtDebugDebug(__FILE__, cur, "_XmPrimitiveHelp ... no luck\n"));
+	DEBUGOUT(_LtDebug(__FILE__, cur, "_XmPrimitiveHelp ... no luck\n"));
 	cur = XtParent(cur);
     }
 }
@@ -1105,7 +1111,7 @@ _XmPrimitiveHighlightPixmapDefault(Widget w, int offset, XrmValue *value)
 {
     static Pixmap pixmap;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "_XmPrimitiveHighlightPixmapDefault\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "_XmPrimitiveHighlightPixmapDefault\n"));
 
     pixmap = XmUNSPECIFIED_PIXMAP;
 
@@ -1126,7 +1132,7 @@ _XmPrimitiveTopShadowPixmapDefault(Widget w, int offset, XrmValue *value)
 {
     static Pixmap pixmap;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "_XmPrimitiveTopShadowPixmapDefault\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "_XmPrimitiveTopShadowPixmapDefault\n"));
 
     pixmap = XmUNSPECIFIED_PIXMAP;
 
@@ -1200,7 +1206,7 @@ XmResolveAllPartOffsets( WidgetClass w_class,
     Cardinal			num_resources;
     ConstraintWidgetClass	superclass, thisclass, tmp;
 
-    DEBUGOUT(_LtDebugDebug0(__FILE__, NULL,
+    DEBUGOUT(_LtDebug0(__FILE__, NULL,
 		       "\nXmResolveAllPartOffsets(`%s')\n",
 		       w_class->core_class.class_name));
 
@@ -1248,7 +1254,7 @@ XmResolveAllPartOffsets( WidgetClass w_class,
 	bfIsConstraint = False;
     }
 
-    DEBUGOUT(_LtDebugDebug0(__FILE__, NULL,
+    DEBUGOUT(_LtDebug0(__FILE__, NULL,
 		       "\twidget class:`%s' is %s a Constraint type.\n",
 		       thisclass->core_class.class_name,
 		       (bfIsConstraint ? "" : "NOT" )));
@@ -1279,7 +1285,7 @@ XmResolveAllPartOffsets( WidgetClass w_class,
 	array_size++;
     }
 
-    DEBUGOUT(_LtDebugDebug0(__FILE__, NULL, "\tarray size:%d\n", array_size));
+    DEBUGOUT(_LtDebug0(__FILE__, NULL, "\tarray size:%d\n", array_size));
 
     /*
      * Allocate an array based upon the number of superclass
@@ -1318,7 +1324,7 @@ XmResolveAllPartOffsets( WidgetClass w_class,
      */
 
 
-    DEBUGOUT(_LtDebugDebug0(__FILE__, NULL, "\n\t--- Calculate Core offsets ---\n"));
+    DEBUGOUT(_LtDebug0(__FILE__, NULL, "\n\t--- Calculate Core offsets ---\n"));
 
     for ( tmp = (ConstraintWidgetClass)thisclass->core_class.superclass,
 	      k = array_size - 1;
@@ -1327,7 +1333,7 @@ XmResolveAllPartOffsets( WidgetClass w_class,
     {
 	offset[k] = tmp->core_class.widget_size;
 
-	DEBUGOUT(_LtDebugDebug0(__FILE__, NULL, "\t  offset[%2d] = %-6d `%s'\n",
+	DEBUGOUT(_LtDebug0(__FILE__, NULL, "\t  offset[%2d] = %-6d `%s'\n",
 			   k, offset[k], tmp->core_class.class_name));
     }
 
@@ -1348,7 +1354,7 @@ XmResolveAllPartOffsets( WidgetClass w_class,
 	 *    xmBulletinBoardClass->constraint_class.constraint_size'
 	 */
 
-	DEBUGOUT(_LtDebugDebug0(__FILE__, NULL,
+	DEBUGOUT(_LtDebug0(__FILE__, NULL,
 			   "\n\t--- Calculate Constraint offsets ---\n"));
 
 	for ( tmp = (ConstraintWidgetClass)thisclass->core_class.superclass,
@@ -1358,7 +1364,7 @@ XmResolveAllPartOffsets( WidgetClass w_class,
 	{
 	    constraint_offset[k] = tmp->constraint_class.constraint_size;
 
-	    DEBUGOUT(_LtDebugDebug0(__FILE__, NULL, "\t  offset[%2d] = %-6d `%s'\n",
+	    DEBUGOUT(_LtDebug0(__FILE__, NULL, "\t  offset[%2d] = %-6d `%s'\n",
 			       k, constraint_offset[k],
 			       tmp->core_class.class_name));
 	}
@@ -1369,7 +1375,7 @@ XmResolveAllPartOffsets( WidgetClass w_class,
      * list to be real offsets.
      */
 
-    DEBUGOUT(_LtDebugDebug0(__FILE__, NULL, "\n\t--- Core Final ---\n"));
+    DEBUGOUT(_LtDebug0(__FILE__, NULL, "\n\t--- Core Final ---\n"));
 
     resources = (XmPartResource*)thisclass->core_class.resources;
     num_resources = thisclass->core_class.num_resources;
@@ -1379,7 +1385,7 @@ XmResolveAllPartOffsets( WidgetClass w_class,
 	int	true_offset =  resources[j].resource_offset &  XmOFFSETMASK;
 	resources[j].resource_offset = offset[widget_index] + true_offset;
 
-	DEBUGOUT(_LtDebugDebug0(__FILE__, NULL,
+	DEBUGOUT(_LtDebug0(__FILE__, NULL,
 			   "\t  [%2d] windex:%-3d true_offset:%-3d"
 			   " real_offset: %-3d\n",
 			   j, widget_index, true_offset,
@@ -1393,7 +1399,7 @@ XmResolveAllPartOffsets( WidgetClass w_class,
 	 * constraint resource list to be real offsets.
 	 */
 
-	DEBUGOUT(_LtDebugDebug0(__FILE__, NULL, "\n\t--- Constraint Final ---\n"));
+	DEBUGOUT(_LtDebug0(__FILE__, NULL, "\n\t--- Constraint Final ---\n"));
 
 	resources = (XmPartResource*)thisclass->constraint_class.resources;
 	num_resources = thisclass->constraint_class.num_resources;
@@ -1406,7 +1412,7 @@ XmResolveAllPartOffsets( WidgetClass w_class,
 	    resources[j].resource_offset = constraint_offset[widget_index] +
 						true_offset;
 
-	    DEBUGOUT(_LtDebugDebug0(__FILE__, NULL,
+	    DEBUGOUT(_LtDebug0(__FILE__, NULL,
 			       "\t  [%2d] windex:%-3d true_offset:%-3d "
 			       "real_offset: %-3d\n",
 			       j, widget_index, true_offset,
@@ -1430,7 +1436,7 @@ XmResolveAllPartOffsets( WidgetClass w_class,
 	XtFree((char *)offset);
     }
 
-    DEBUGOUT(_LtDebugDebug0(__FILE__, NULL,
+    DEBUGOUT(_LtDebug0(__FILE__, NULL,
 		       "END OF XmResolveAllPartOffsets(`%s')\n\n",
 		       w_class->core_class.class_name));
 }
@@ -1517,19 +1523,69 @@ _XmPrimitiveExportX(Widget widget, int offset, XtArgVal *value)
 static void
 _XmPrimitiveExportY(Widget widget, int offset, XtArgVal *value)
 {
-    unsigned char unitType = _XmGetUnitType(widget);
-    int converted_value;
+	unsigned char unitType = _XmGetUnitType(widget);
+	int converted_value;
 
-    if (XtIsManaged(widget) && XtParent(widget) && XmIsVendorShell(XtParent(widget)))
-    {
-    	*value = XtY(XtParent(widget));
-    }
-    converted_value = XmConvertUnits(widget,
-				     XmVERTICAL,
-				     XmPIXELS,
-				     *value,
-				     unitType);
+	if (XtIsManaged(widget) && XtParent(widget) && XmIsVendorShell(XtParent(widget))) {
+		*value = XtY(XtParent(widget));
+	}
+	converted_value = XmConvertUnits(widget, XmVERTICAL, XmPIXELS, *value, unitType);
 
-    *value = converted_value;
+	*value = converted_value;
 }
 
+#if XmVERSION > 1
+/*
+ * Motif widgets that depend on their parent's appearance are alerted of an appearance
+ * change in the parent by the XmQTcareParentVisual trait.
+ * All Manager widgets must notify their children (holding this trait) when the visual
+ * appearance of the manager parent changes.
+ * Subclasses of XmManager need not implement this as they inherit this behaviour.
+ *
+ * A return value of True means that the child needs to be redrawn.
+ *
+ * Note that this does NOT work for XmNselectColor.
+ */
+static Boolean
+_PrimitiveTrait_Redraw(Widget child, Widget newp, Widget curp, Mask flag)
+{
+	XtExposeProc	e;
+	Boolean		r = False;
+
+	e = ((XmPrimitiveClassRec *)XtClass(child))->core_class.expose;
+
+	DEBUGOUT(_LtDebug2(__FILE__, newp, child, "Primitive CareParentVisualRedraw()\n"));
+
+	if (flag & VisualForeground) {
+	}
+	if (flag & VisualHighlightPixmap) {
+	}
+	if (flag & VisualHighlightColor) {
+	}
+	if (flag & VisualBottomShadowPixmap) {
+	}
+	if (flag & VisualBottomShadowColor) {
+	}
+	if (flag & VisualSelectColor) {	/* Note XmManager doesn't do this */
+	}
+	if (flag & VisualTopShadowPixmap) {
+	}
+	if (flag & VisualTopShadowColor) {
+	}
+	if (flag & VisualBackgroundPixel) {
+		/* FIX ME do we need to get info from MGR_* here ? */
+		r = True;
+	}
+	if (flag & VisualBackgroundPixmap) {
+		/* FIX ME do we need to get info from MGR_* here ? */
+		r = True;
+	}
+
+	if (r && e) {
+		(*e)(child, NULL, NULL);
+		return False;
+	} else {
+		return r;
+	}
+}
+#endif
