@@ -1,9 +1,9 @@
 /**
  *
- * $Id: PushBG.c,v 1.86 2001/05/20 17:49:38 amai Exp $
+ * $Id: PushBG.c,v 1.94 2002/04/24 19:54:46 dannybackx Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
- * Copyright (C) 1995-2001 LessTif Development Team
+ * Copyright  1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -23,7 +23,7 @@
  *
  **/
 
-static const char rcsid[] = "$Id: PushBG.c,v 1.86 2001/05/20 17:49:38 amai Exp $";
+static const char rcsid[] = "$Id: PushBG.c,v 1.94 2002/04/24 19:54:46 dannybackx Exp $";
 
 #include <LTconfig.h>
 
@@ -45,6 +45,12 @@ static const char rcsid[] = "$Id: PushBG.c,v 1.86 2001/05/20 17:49:38 amai Exp $
 #include <Xm/LabelP.h>
 #include <X11/ShellP.h>
 
+#if XmVERSION > 1
+#include <Xm/TraitP.h>
+#include <Xm/ActivatableT.h>
+#include <Xm/ContItemT.h>
+#endif
+
 #include <XmI/DebugUtil.h>
 
 /*
@@ -53,20 +59,23 @@ static const char rcsid[] = "$Id: PushBG.c,v 1.86 2001/05/20 17:49:38 amai Exp $
  * Try to add trait stuff by #ifdeffing it.
  */
 #if XmVERSION > 1
-#include <Xm/TraitP.h>
-#include <Xm/ActivatableT.h>
-
 void _XmPushBG_TraitAddCallback(Widget, XtCallbackProc, XtPointer, Boolean);
 
 static XmActivatableTraitRec _XmPushBGTraitRec = {
 	/* version	*/	0,
 	/* cb		*/	_XmPushBG_TraitAddCallback
 };
+
+static void _XmPushBG_ContainerItemGetValues(Widget w, XmContainerItemData d);
+static void _XmPushBG_ContainerItemSetValues(Widget w, XmContainerItemData d);
+
+static XmContainerItemTraitRec _XmPushBG_ContainerItemTrait = {
+        /* version */           0,
+        /* setvalues */         _XmPushBG_ContainerItemGetValues,
+        /* getvalues */         _XmPushBG_ContainerItemSetValues
+};
 #endif
 
-#ifndef XmUNSPECIFIED
-#define XmUNSPECIFIED (~0)
-#endif
 
 /* Forward Declarations */
 
@@ -347,6 +356,9 @@ static XmGadgetClassExtRec _XmPushBGadgetClassExtRec = {
     /* size                      */ sizeof(XmGadgetClassExtRec),
     /* widget_baseline_proc      */ XmInheritBaselineProc,
     /* display_rect_proc         */ XmInheritDisplayRectProc,
+#if XmVERSION >= 2
+    /* margins_proc              */ XmInheritMarginsProc,
+#endif
 };
 
 XmPushButtonGadgetClassRec xmPushButtonGadgetClassRec = {
@@ -428,7 +440,7 @@ secondary_object_create(Widget request, Widget new_w,
     XmWidgetExtData ed;
     Cardinal size;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, new_w,
+    DEBUGOUT(_LtDebug(__FILE__, new_w,
 		      "PushBGCacheRec %s being initialized.\n",
 		      XtName(new_w)));
 
@@ -473,9 +485,10 @@ secondary_object_create(Widget request, Widget new_w,
 int
 _XmPushBCacheCompare(XtPointer A, XtPointer B)
 {
-    return !memcmp(((XmPushButtonGCacheObjPart *)A),
-		 ((XmPushButtonGCacheObjPart *)B),
-		 sizeof(XmPushButtonGCacheObjPart));
+	DEBUGOUT(_LtDebug(__FILE__, NULL, "_XmPushBCacheCompare\n"));
+
+	return !memcmp(((XmPushButtonGCacheObjPart *)A), ((XmPushButtonGCacheObjPart *)B),
+		sizeof(XmPushButtonGCacheObjPart));
 }
 
 /******************************* GADGET PART *********************************/
@@ -486,6 +499,8 @@ class_initialize(void)
     int ncom;
     Cardinal nlabels;
 
+	DEBUGOUT(_LtDebug(__FILE__, NULL, "XmPushButtonGadget class_initialize\n"));
+
     /* don't let the nulls fool you.  look at the header file -- the arg
      * isn't used. */
     ClassCacheHead(PBG_ClassCachePart(NULL)).prev =
@@ -521,18 +536,24 @@ class_initialize(void)
     xmPushButtonGCacheObjClassRec.object_class.num_resources = ncom;
 
 #if XmVERSION > 1
-    if (! XmeTraitSet((XtPointer)xmPushButtonGadgetClass, XmQTactivatable,
-		(XtPointer)&_XmPushBGTraitRec)) {
-	_XmWarning(NULL,
-	    "XmPushButtonGadget ClassInitialize: XmeTraitSet failed\n");
-    }
+	if (! XmeTraitSet((XtPointer)xmPushButtonGadgetClass, XmQTactivatable,
+			(XtPointer)&_XmPushBGTraitRec)) {
+		_XmWarning(NULL, "XmPushButtonGadget ClassInitialize: XmeTraitSet failed\n");
+	}
+	if (! XmeTraitSet((XtPointer)xmPushButtonGadgetClass, XmQTcontainerItem,
+			(XtPointer)&_XmPushBG_ContainerItemTrait)) {
+		_XmWarning(NULL, "XmPushButtonGadget ClassInitialize: XmeTraitSet failed\n");
+	}
+
 #endif
 }
 
 static void
 class_part_initialize(WidgetClass widget_class)
 {
-    _XmFastSubclassInit(widget_class, XmPUSH_BUTTON_GADGET_BIT);
+	DEBUGOUT(_LtDebug(__FILE__, NULL, "XmPushButtonGadget class_part_initialize\n"));
+
+	_XmFastSubclassInit(widget_class, XmPUSH_BUTTON_GADGET_BIT);
 }
 
 static void
@@ -541,6 +562,8 @@ CreateFillGC(Widget w)
     XGCValues values;
     XtGCMask mask;
 
+	DEBUGOUT(_LtDebug(__FILE__, w, "XmPushButtonGadget CreateFillGC\n"));
+
     mask = GCForeground | GCBackground | GCFillStyle | GCFunction |
 	GCSubwindowMode | GCGraphicsExposures | GCPlaneMask;
 
@@ -561,6 +584,8 @@ CreateBackgroundGC(Widget w)
     XGCValues values;
     XtGCMask mask;
 
+	DEBUGOUT(_LtDebug(__FILE__, w, "XmPushButtonGadget CreateBackgroundGC\n"));
+
     mask = GCForeground | GCBackground | GCFillStyle | GCFunction |
 	GCSubwindowMode | GCGraphicsExposures | GCPlaneMask;
 
@@ -593,7 +618,7 @@ static void
 initialize_prehook(Widget request, Widget new_w,
 		   ArgList args, Cardinal *num_args)
 {
-    DEBUGOUT(_LtDebugDebug(__FILE__, new_w, "PushBG InitializePrehook\n"));
+    DEBUGOUT(_LtDebug(__FILE__, new_w, "PushBG InitializePrehook\n"));
 }
 #endif
 
@@ -603,7 +628,7 @@ initialize_posthook(Widget request, Widget new_w,
 {
     XmWidgetExtData ext;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, new_w, "PushBG InitializePosthook\n"));
+    DEBUGOUT(_LtDebug(__FILE__, new_w, "PushBG InitializePosthook\n"));
 
     /* don't let the null fool you */
     LabG_Cache(new_w) = (XmLabelGCacheObjPart *)
@@ -627,6 +652,8 @@ initialize(Widget request, Widget new_w,
 {
     Dimension margin, width, height;
 
+    DEBUGOUT(_LtDebug(__FILE__, new_w, "PushBG Initialize\n"));
+
     if (!XtIsSubclass(XtParent(new_w), xmManagerWidgetClass))
     {
 	_XmError(new_w, "parent should be manager.");
@@ -743,6 +770,8 @@ initialize(Widget request, Widget new_w,
 static void
 destroy(Widget w)
 {
+    DEBUGOUT(_LtDebug(__FILE__, w, "PushBG Destroy\n"));
+
     if (PBG_Timer(w) != 0)
     {
 	XtRemoveTimeOut(PBG_Timer(w));
@@ -763,6 +792,8 @@ set_values_prehook(Widget old, Widget request, Widget new_w,
     Cardinal size;
     XtPointer nsec, rsec;
 
+    DEBUGOUT(_LtDebug(__FILE__, new_w, "PushBG set_values_prehook\n"));
+
     bce = _XmGetBaseClassExtPtr(XtClass(new_w), XmQmotif);
     size = (*bce)->secondaryObjectClass->core_class.widget_size;
 
@@ -818,6 +849,8 @@ set_values_posthook(Widget old, Widget request, Widget new_w,
 {
     XmWidgetExtData ext;
 
+    DEBUGOUT(_LtDebug(__FILE__, new_w, "PushBG set_values_posthook\n"));
+
     /* Gaaaa.  Forgot the CachePart copy!!! */
     if (!_XmLabelCacheCompare((XtPointer)LabG_Cache(new_w),
 			      (XtPointer)LabG_Cache(old)))
@@ -868,7 +901,7 @@ set_values(Widget old, Widget request, Widget new_w,
     Boolean refresh_needed = False;
     Dimension margin, width, height;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, new_w,
+    DEBUGOUT(_LtDebug(__FILE__, new_w,
 		      "set_values: %i args\n"
 		      "\t    old X %5i Y %5i W %5i H %5i\n"
 		      "\trequest X %5i Y %5i W %5i H %5i\n"
@@ -1074,6 +1107,8 @@ get_values_prehook(Widget new_w, ArgList args, Cardinal *num_args)
     Cardinal size;
     XtPointer nsec;
 
+    DEBUGOUT(_LtDebug(__FILE__, new_w, "PushBG get_values_prehook\n"));
+
     bce = _XmGetBaseClassExtPtr(XtClass(new_w), XmQmotif);
     size = (*bce)->secondaryObjectClass->core_class.widget_size;
 
@@ -1118,6 +1153,8 @@ get_values_posthook(Widget new_w, ArgList args, Cardinal *num_args)
 {
     XmWidgetExtData ext;
 
+    DEBUGOUT(_LtDebug(__FILE__, new_w, "PushBG get_values_posthook\n"));
+
     _XmPopWidgetExtData(new_w, &ext, XmCACHE_EXTENSION);
 
     _XmExtObjFree((XtPointer)ext->widget);
@@ -1129,7 +1166,7 @@ get_values_posthook(Widget new_w, ArgList args, Cardinal *num_args)
 static void
 get_values_hook(Widget w, ArgList args, Cardinal *num_args)
 {
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "GetValuesHook\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "GetValuesHook\n"));
 }
 #endif
 
@@ -1138,8 +1175,7 @@ expose(Widget w, XEvent *event, Region region)
 {
     Dimension inset;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "PBG expose: XY %d %d\n",
-		      XtX(w), XtY(w)));
+    DEBUGOUT(_LtDebug(__FILE__, w, "PBG expose: XY %d %d\n", XtX(w), XtY(w)));
 
     if (!IN_MENU(w))
     {
@@ -1148,7 +1184,7 @@ expose(Widget w, XEvent *event, Region region)
 	    inset += Xm3D_ENHANCE_PIXEL + LabG_Shadow(w)
 		+ (PBG_DefaultButtonShadow(w) << 1);
 
-	DEBUGOUT(_LtDebugDebug(__FILE__, w,
+	DEBUGOUT(_LtDebug(__FILE__, w,
 			  "x %d y %d w %d h %d b %d\n",
 			  inset, inset,
 			  (XtWidth(w) - (inset << 1)),
@@ -1335,8 +1371,8 @@ Activate(Widget w, XEvent *event, String *params, Cardinal *num_params)
     XmPushButtonCallbackStruct cbs;
     XButtonEvent *ev = (XButtonEvent *)event;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "Activate\n"));
-    DEBUGOUT(_LtDebugDebug("MENU", w, "%s:Activate(%d)\n",
+    DEBUGOUT(_LtDebug(__FILE__, w, "Activate\n"));
+    DEBUGOUT(_LtDebug("MENU", w, "%s:Activate(%d)\n",
     	__FILE__, __LINE__
     	));
 
@@ -1391,7 +1427,7 @@ ArmTimeout(XtPointer data, XtIntervalId *id)
 {
     Widget w = (Widget)data;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "ArmTimeout\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "ArmTimeout\n"));
 
     PBG_Timer(w) = 0;
 
@@ -1408,8 +1444,8 @@ ArmAndActivate(Widget w, XEvent *event, String *params, Cardinal *num_params)
     XmPushButtonCallbackStruct cbs;
     Boolean poppedUp;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "ArmAndActivate\n"));
-    DEBUGOUT(_LtDebugDebug("MENU", w, "%s:ArmAndActivate(%d)\n",
+    DEBUGOUT(_LtDebug(__FILE__, w, "ArmAndActivate\n"));
+    DEBUGOUT(_LtDebug("MENU", w, "%s:ArmAndActivate(%d)\n",
     	__FILE__, __LINE__
     	));
 
@@ -1472,8 +1508,8 @@ EnterWindow(Widget w,
 {
     XmPushButtonCallbackStruct cbs;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "EnterWindow()\n"));
-    DEBUGOUT(_LtDebugDebug("MENU", w, "%s:EnterWindow(%d)\n",
+    DEBUGOUT(_LtDebug(__FILE__, w, "EnterWindow()\n"));
+    DEBUGOUT(_LtDebug("MENU", w, "%s:EnterWindow(%d)\n",
     	__FILE__, __LINE__
     	));
 
@@ -1517,7 +1553,7 @@ LeaveWindow(Widget w, XEvent *event, String *params, Cardinal *num_params)
 {
     XmPushButtonCallbackStruct cbs;
 
-    DEBUGOUT(_LtDebugDebug("MENU", w, "%s:LeaveWindow(%d) - %s %s %s\n",
+    DEBUGOUT(_LtDebug("MENU", w, "%s:LeaveWindow(%d) - %s %s %s\n",
     	__FILE__, __LINE__,
     	IN_MENU(w) ? "menu" : "no-menu",
     	IN_MENU(w) && _XmGetInDragMode(w) ? "dragging" : "not-dragging",
@@ -1568,9 +1604,9 @@ ButtonUp(Widget w, XEvent *event, String *params, Cardinal *num_params)
     Boolean validButton, poppedUp;
     XmPushButtonCallbackStruct cbs;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "ButtonUp()\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "ButtonUp()\n"));
 
-    DEBUGOUT(_LtDebugDebug("MENU", w, "%s:ButtonUp(%d)\n",
+    DEBUGOUT(_LtDebug("MENU", w, "%s:ButtonUp(%d)\n",
     	__FILE__, __LINE__
     	));
     /* queue events until the next button event */
@@ -1646,7 +1682,7 @@ ButtonDown(Widget w, XEvent *event, String *params, Cardinal *num_params)
     XmPushButtonCallbackStruct cbs;
     Boolean poppedUp;
 
-    DEBUGOUT(_LtDebugDebug("MENU", w, "%s:ButtonDown(%d)\n",
+    DEBUGOUT(_LtDebug("MENU", w, "%s:ButtonDown(%d)\n",
     	__FILE__, __LINE__
     	));
     /* queue events until the next button event */
@@ -1734,7 +1770,7 @@ input_dispatch(Widget gadget, XEvent *event, Mask event_mask)
     switch (event_mask)
     {
     case XmARM_EVENT:
-	DEBUGOUT(_LtDebugDebug(__FILE__, gadget, "got arm event\n"));
+	DEBUGOUT(_LtDebug(__FILE__, gadget, "got arm event\n"));
 	if (IN_MENU(gadget))
 	{
 	    ButtonDown(gadget, event, NULL, &num_params);
@@ -1760,7 +1796,7 @@ input_dispatch(Widget gadget, XEvent *event, Mask event_mask)
 	break;
 
     case XmACTIVATE_EVENT:
-	DEBUGOUT(_LtDebugDebug(__FILE__, gadget, "got activate event\n"));
+	DEBUGOUT(_LtDebug(__FILE__, gadget, "got activate event\n"));
 	/*
 	 * The test below is expanded so it also checks for the Shell.
 	 * In tearoff menus, the shell will be a TransientShell, thus we'll
@@ -1796,17 +1832,17 @@ input_dispatch(Widget gadget, XEvent *event, Mask event_mask)
 	break;
 
     case XmENTER_EVENT:
-	DEBUGOUT(_LtDebugDebug(__FILE__, gadget, "got an enter window\n"));
+	DEBUGOUT(_LtDebug(__FILE__, gadget, "got an enter window\n"));
 	EnterWindow(gadget, event, NULL, &num_params);
 	break;
 
     case XmLEAVE_EVENT:
-	DEBUGOUT(_LtDebugDebug(__FILE__, gadget, "got a leave window\n"));
+	DEBUGOUT(_LtDebug(__FILE__, gadget, "got a leave window\n"));
 	LeaveWindow(gadget, event, NULL, &num_params);
 	break;
 
     case XmMOTION_EVENT:
-	DEBUGOUT(_LtDebugDebug(__FILE__, gadget, "got a motion event\n"));
+	DEBUGOUT(_LtDebug(__FILE__, gadget, "got a motion event\n"));
 	break;
 
     case XmFOCUS_IN_EVENT:
@@ -1869,8 +1905,10 @@ XmCreatePushButtonGadget(Widget parent, char *name,
 {
 	Widget	r;
 	_XmObjectLock(parent);
+	DEBUGOUT(_LtDebug(__FILE__, parent, "XmCreatePushButtonGadget(%s)\n", name));
 	r = XtCreateWidget(name, xmPushButtonGadgetClass, parent,
 			  arglist, argcount);
+	DEBUGOUT(_LtDebug2(__FILE__, parent, r, "XmCreatePushButtonGadget => %p\n", r));
 	_XmObjectUnlock(parent);
 	return r;
 }
@@ -1886,4 +1924,17 @@ void _XmPushBG_TraitAddCallback(Widget w,
     else
 	XtRemoveCallback(w, XmNactivateCallback, cb, cbp);
 }
+
+/*
+ * Trait functions for ContainerItem
+ */
+static void _XmPushBG_ContainerItemGetValues(Widget w, XmContainerItemData d)
+{
+	DEBUGOUT(_LtDebug(__FILE__, w, "_XmPushBG_ContainerItemGetValues()\n"));
+}
+
+static void _XmPushBG_ContainerItemSetValues(Widget w, XmContainerItemData d)
+{       
+	DEBUGOUT(_LtDebug(__FILE__, w, "_XmPushBG_ContainerItemSetValues()\n"));
+}
 #endif
