@@ -1,9 +1,9 @@
 /**
  *
- * $Id: ResConvert.c,v 1.75 2001/05/29 12:51:02 amai Exp $
+ * $Id: ResConvert.c,v 1.85 2002/04/12 23:38:44 amai Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
- * Copyright (C) 1995-2001 LessTif Development Team
+ * Copyright  1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -23,7 +23,7 @@
  *
  **/
 
-static const char rcsid[] = "$Id: ResConvert.c,v 1.75 2001/05/29 12:51:02 amai Exp $";
+static const char rcsid[] = "$Id: ResConvert.c,v 1.85 2002/04/12 23:38:44 amai Exp $";
 
 #include <LTconfig.h>
 
@@ -42,8 +42,7 @@ static const char rcsid[] = "$Id: ResConvert.c,v 1.75 2001/05/29 12:51:02 amai E
 #include <Xm/VendorSEP.h>
 #include <Xm/ExtObjectP.h>
 #include <Xm/XmosP.h>
-
-#include "LTmisc.h"
+#include <XmI/LTmisc.h>
 
 #include <XmI/DebugUtil.h>
 
@@ -104,11 +103,25 @@ static Boolean _XmCvtStringToTabList(Display *display, XrmValue *args,
 static Boolean _XmCvtStringToRenderTable(Display *display, XrmValue *args,
 		       Cardinal *num_args, XrmValue *from, XrmValue *to,
 		       XtPointer *converter_data);
+#endif /* XmVERSION > 1 */
+
+
+/*
+   xmUseVersion is used for a sanity check by developers.  It is used within
+   a M*tif applications to ensure the version of the (shared) M*tif library
+   being used corresponds to the M*tif toolkit header the application was
+   compiled against.  8/3/98, pgw@ma.ultranet.com
+   amai: it seems that at least OM 2.1 initializes this number
+         immediately, instead of waiting for XmRegisterConverters()
+	 to be called. We try to stay as compatible as possible here ...
+ */
+#if XmVersion < 2001
+int xmUseVersion = 0;
+#else
+int xmUseVersion = XmVersion;
 #endif
 
 
-int xmUseVersion = 0;
-
 /* please be careful if you're editting these arrays, as
  * the strings have to be in the _same_ order as the
  * enumerated constants in the include files.  Failure to comply
@@ -349,7 +362,6 @@ static char *row_column_types[] =
     "menu_popup",
     "menu_option"
 };
-
 static unsigned char row_column_type_values[] =
 {
     XmWORK_AREA,
@@ -368,7 +380,6 @@ static char *indicator_types[] =
     "one_of_many_diamond"
 #endif
 };
-
 static unsigned char indicator_type_values[] =
 {
     XmN_OF_MANY,
@@ -519,6 +530,21 @@ static char *toggle_mode[] =
     "toggle_indeterminate"
 };
 
+/* ComboBox */
+
+static char *combobox_type[] =
+{
+   "combo_box",
+   "drop_down_combo_box",
+   "drop_down_list",
+};
+static unsigned char combobox_type_values[] =
+{
+   XmCOMBO_BOX,
+   XmDROP_DOWN_COMBO_BOX,
+   XmDROP_DOWN_LIST,
+};
+
 /* Spinbox */
 static char *spb_child_types[] =
 {
@@ -541,9 +567,11 @@ static char *spb_arrow_layouts[] =
 
 static unsigned char spb_arrow_layout_values[] =
 {
-    XmARROWS_BEGINNING,
     XmARROWS_END,
-    XmARROWS_SPLIT
+    XmARROWS_BEGINNING,
+    XmARROWS_SPLIT,
+    XmARROWS_FLAT_END,
+    XmARROWS_FLAT_BEGINNING
 };
 
 /* Notebook */
@@ -663,13 +691,10 @@ _XmRegisterConverters(void)
 	return;
     }
 
-    /*
-       xmUseVersion is used for a santity check by developers.  It is used within
-       a M*tif applications to ensure the version of the (shared) M*tif library
-       being used corresponds to the M*tif toolkit header the application was
-       compiled against.  8/3/98, pgw@ma.ultranet.com
-     */
+/* See comment at declaration at beginning of this file */
+#if XmVersion < 2001
     xmUseVersion = XmVersion;
+#endif
 
 #define REPTYPE_REGISTER(reptype,array) \
     XmRepTypeRegister((reptype), \
@@ -733,7 +758,7 @@ _XmRegisterConverters(void)
                                 indicator_type_values);
 
 #if XmVERSION > 1
-/* Motif 2.0 */
+/* Motif 2.x */
     REPTYPE_REGISTER(XmRToggleMode, toggle_mode);
     REPTYPE_REGISTER_WITH_VALUES(XmRArrowLayout,
                 spb_arrow_layouts, spb_arrow_layout_values);
@@ -743,7 +768,11 @@ _XmRegisterConverters(void)
                 indicator_on, indicator_on_values);
     REPTYPE_REGISTER_WITH_VALUES(XmRNotebookChildType,
                 nb_child_types, nb_child_type_values);
-#endif
+    REPTYPE_REGISTER_WITH_VALUES(XmRComboBoxType,
+                combobox_type, combobox_type_values);
+
+    XmRepTypeInstallTearOffModelConverter();
+#endif /* XmVERSION > 1 */
 
 #undef REPTYPE_REGISTER
 #undef REPTYPE_REGISTER_WITH_VALUES
@@ -757,15 +786,24 @@ _XmRegisterConverters(void)
 		       0,	/* number of args to converter routine */
 		       XtCacheAll,	/* caching instructions */
 		       NULL);	/* destructor function */
-
-    XtSetTypeConverter(XtRString,	/* source type */
-		       XmRFontList,	/* target type */
-		       _XmCvtStringToXmFontList,	/* converter routine */
-		       NULL,	/* args for converter routine */
-		       0,	/* number of args to converter routine */
-		       XtCacheByDisplay,	/* caching instructions */
-		       destroy_font_list);	/* destructor function */
-
+#if 1
+	/* Don't cache */
+	XtSetTypeConverter(XtRString,		/* source type */
+		XmRFontList,			/* target type */
+		_XmCvtStringToXmFontList,	/* converter routine */
+		NULL,				/* args for converter routine */
+		0,				/* number of args to converter routine */
+		XtCacheNone,			/* caching instructions */
+		NULL);				/* destructor function */
+#else
+    XtSetTypeConverter(XtRString,		/* source type */
+		XmRFontList,			/* target type */
+		_XmCvtStringToXmFontList,	/* converter routine */
+		NULL,				/* args for converter routine */
+		0,				/* number of args to converter routine */
+		XtCacheByDisplay,	/* caching instructions */
+		destroy_font_list);	/* destructor function */
+#endif
     XtSetTypeConverter(XtRString,	/* source type */
 		       XmRHorizontalDimension,	/* target type */
 		       _XmCvtStringToResIndDimension,	/* converter routine */
@@ -1031,9 +1069,9 @@ _XmError(Widget w, const char *fmt, ...)
 /*
  * Warning convenience
  *
- * Added _LtDebugDebug stuff here to be able to avoid infinite loops in applications
+ * Added _LtDebug stuff here to be able to avoid infinite loops in applications
  * that redirect stderr to a scrolledText. ML suffers from this, due to LessTif
- * bugs of cource :-(
+ * bugs of course :-(
  */
 static void
 _LtWarning(Widget w, const char *fmt, va_list arg_list)
@@ -1114,16 +1152,18 @@ _LtWarning(Widget w, const char *fmt, va_list arg_list)
 /*
  * Warning convenience
  *
- * Added _LtDebugDebug stuff here to be able to avoid infinite loops in applications
+ * Added _LtDebug stuff here to be able to avoid infinite loops in applications
  * that redirect stderr to a scrolledText. ML suffers from this, due to LessTif
  * bugs of course :-(
  */
 
-/* unshadow for the Motif 2.x build */
+/* unshadow for the Motif 2.x build and give prototype */
 #if XmVERSION >= 2
 #ifdef _XmWarning
 #undef _XmWarning
 #endif
+extern void
+_XmWarning(Widget w, const char *fmt, ...);
 #endif
 
 extern void
@@ -1190,7 +1230,7 @@ XmCvtXmStringToCT(XmString string)
     XmStringDirection direction;
     Boolean separator;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, NULL, "XmCvtXmStringToCT\n"));
+    DEBUGOUT(_LtDebug(__FILE__, NULL, "XmCvtXmStringToCT\n"));
 
     if (XmStringInitContext(&context, string) == True)
     {
@@ -1294,7 +1334,7 @@ XmCvtXmStringToText(Display *display, XrmValuePtr args,
     to_val->addr = value;
     to_val->size = strlen(value);  /* FIXME: should this be sizeof(value)? */
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, NULL,
+    DEBUGOUT(_LtDebug(__FILE__, NULL,
 		      "XmCvtXmStringToText(%p) => %s\n",
 		      from_val->addr, to_val->addr));
 
@@ -1334,21 +1374,14 @@ _XmStringsAreEqual(char *in_str,
  * Fixed this thing to make a COPY of the fontlist it returns.
  * Danny 16/4/1996
  */
-extern XmFontList
-_XmGetDefaultFontList(Widget w,
-		      unsigned char fontListType)
+extern XmFontList _XmGetDefaultFontList(Widget w, unsigned char fontListType)
 {
-#if 1
     XmFontList labelFontList = NULL;
     XmFontList buttonFontList = NULL;
     XmFontList textFontList = NULL;
-#else
-    static XmFontList labelFontList = NULL;
-    static XmFontList buttonFontList = NULL;
-    static XmFontList textFontList = NULL;
-#endif
+
     Widget par = w;
-    XmFontList fontlist;
+    XmFontList fontlist, r;
     XmVendorShellExtObject ve = NULL;
 
     fontlist = NULL;
@@ -1380,7 +1413,9 @@ _XmGetDefaultFontList(Widget w,
 	}
 	if (fontlist)
 	{
-	    return XmFontListCopy(fontlist);
+		XmFontList	r = XmFontListCopy(fontlist);
+		DEBUGOUT(_LtDebug(__FILE__, w, "_XmGetDefaultFontList(XmTEXT_FONTLIST) -> %p\n", r));
+		return r;
 	}
 
 	if (!textFontList)
@@ -1394,10 +1429,12 @@ _XmGetDefaultFontList(Widget w,
 	}
 
 	if (textFontList == NULL) {
-		_XmWarning(w, "_XmGetDefaultFontList: returning NULL\n");
+		_XmWarning(w, "_XmGetDefaultFontList: textFontList NULL\n");
 	}
 
-	return XmFontListCopy(textFontList);
+	r = XmFontListCopy(textFontList);
+	DEBUGOUT(_LtDebug(__FILE__, w, "_XmGetDefaultFontList(textFontList) -> %p\n", r));
+	return r;
 
     case XmBUTTON_FONTLIST:
 	while ((par = XtParent(par)) != NULL)
@@ -1423,7 +1460,9 @@ _XmGetDefaultFontList(Widget w,
 	    }
 	}
 	if (fontlist) {
-		return XmFontListCopy(fontlist);
+		r = XmFontListCopy(fontlist);
+		DEBUGOUT(_LtDebug(__FILE__, w, "_XmGetDefaultFontList(XmBUTTON_FONTLIST) -> %p\n", r));
+		return r;
 	}
 
 	if (!buttonFontList)
@@ -1437,10 +1476,12 @@ _XmGetDefaultFontList(Widget w,
 	}
 
 	if (buttonFontList == NULL) {
-		_XmWarning(w, "_XmGetDefaultFontList: returning NULL\n");
+		_XmWarning(w, "_XmGetDefaultFontList: buttonFontlist NULL\n");
 	}
 
-	return XmFontListCopy(buttonFontList);
+	r = XmFontListCopy(buttonFontList);
+	DEBUGOUT(_LtDebug(__FILE__, w, "_XmGetDefaultFontList(buttonFontList) -> %p\n", r));
+	return r;
 
     default:
     case XmLABEL_FONTLIST:
@@ -1469,7 +1510,9 @@ _XmGetDefaultFontList(Widget w,
 
 	if (fontlist)
 	{
-	    return XmFontListCopy(fontlist);
+		r = XmFontListCopy(fontlist);
+		DEBUGOUT(_LtDebug(__FILE__, w, "_XmGetDefaultFontList(XmLABEL_FONTLIST) -> %p\n", r));
+		return r;
 	}
 
 	if (!labelFontList)
@@ -1483,11 +1526,12 @@ _XmGetDefaultFontList(Widget w,
 	}
 
 	if (labelFontList == NULL) {
-		_XmWarning(w, "_XmGetDefaultFontList: returning NULL\n");
+		_XmWarning(w, "_XmGetDefaultFontList: labelFontList NULL\n");
 	}
 
-	return XmFontListCopy(labelFontList);
-
+	r = XmFontListCopy(labelFontList);
+	DEBUGOUT(_LtDebug(__FILE__, w, "_XmGetDefaultFontList(labelFontList) -> %p\n", r));
+	return r;
     }
 }
 
@@ -1556,7 +1600,7 @@ _XmCvtStringToXmString(Display *display,
 					 XmRXmString);
     }
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, NULL,
+    DEBUGOUT(_LtDebug(__FILE__, NULL,
 		      "_XmCvtStringToXmString(%s) => %p\n",
 		      from->addr, to->addr));
 
@@ -1584,7 +1628,7 @@ __XmFontListResourceAddEntry(Display *display,
     XmFontListEntry newEntry;
     char *eq, *end, *fn, *ft, *tag, *font, *semi, *colon;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, NULL,
+    DEBUGOUT(_LtDebug(__FILE__, NULL,
 		      "__XmFontListResourceAddEntry(%s)\n", full_entry));
 
     eq = strchr(full_entry, (int)'=');
@@ -1739,16 +1783,15 @@ _XmCvtStringToXmFontList(Display *display,
 			 XrmValue *to,
 			 XtPointer *converter_data)
 {
-    XmFontList newFontList = NULL;
-    char *p, *end, *font, *fn, *buf;
+	XmFontList newFontList = NULL;
+	char *p, *end, *font, *fn, *buf;
 
-    if (*num_args != 0)
-    {
-	XtWarningMsg("wrongParameters", "cvtStringToFontlist",
-		     "XtToolkitError",
-		     "String to Fontlist conversion needs no extra arguments",
-		     (String *)NULL, (Cardinal *)NULL);
-    }
+	if (*num_args != 0) {
+		XtWarningMsg("wrongParameters", "cvtStringToFontlist",
+			"XtToolkitError",
+			"String to Fontlist conversion needs no extra arguments",
+			(String *)NULL, (Cardinal *)NULL);
+	}
 
     /* there is an implicit rule here.  strtok() modifies the passed in buffer
      * at least on Linux, so if a comma is found, a \0 is put there.  This is
@@ -1843,6 +1886,9 @@ _XmCvtStringToXmFontList(Display *display,
 					 XmRFontList);
     }
 
+	DEBUGOUT(_LtDebug(__FILE__, NULL, "_XmCvtStringToXmFontList(%s) -> %p\n",
+		from->addr, *((XmFontList *)to->addr)));
+
     return True;
 }
 
@@ -1998,7 +2044,7 @@ _XmCvtStringToKeySym(Display *d, XrmValue *args, Cardinal *nargs,
 	    {
 		XtDisplayStringConversionWarning(d, (char *)from->addr,
 						 XmRKeySym);
-		DEBUGOUT(_LtDebugDebug(__FILE__, NULL,
+		DEBUGOUT(_LtDebug(__FILE__, NULL,
 				  "_XmCvtStringToKeySym fail at line %d\n",
 				  __LINE__));
 		return False;
@@ -2008,7 +2054,7 @@ _XmCvtStringToKeySym(Display *d, XrmValue *args, Cardinal *nargs,
 
     XtDisplayStringConversionWarning(d, (char *)from->addr, XmRKeySym);
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, NULL,
+    DEBUGOUT(_LtDebug(__FILE__, NULL,
 		      "_XmCvtStringToKeySym fail at line %d\n", __LINE__));
     return False;
 }
@@ -2640,6 +2686,7 @@ get_unit_type(Widget w, Cardinal *size, XrmValue *val)
     ut = _XmGetUnitType(w);
 }
 
+
 #if XmVERSION > 1
 /*
  * XmConvertStringToUnits converts a string specification value and returns
