@@ -1,6 +1,6 @@
 /**
  *
- * $Id: Screen.c,v 1.25 2001/05/31 19:25:08 amai Exp $
+ * $Id: Screen.c,v 1.30 2002/03/21 22:25:51 amai Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
  * Copyright (C) 1995-2001 LessTif Development Team 
@@ -23,7 +23,7 @@
  *
  **/
 
-static const char rcsid[] = "$Id: Screen.c,v 1.25 2001/05/31 19:25:08 amai Exp $";
+static const char rcsid[] = "$Id: Screen.c,v 1.30 2002/03/21 22:25:51 amai Exp $";
 
 #include <LTconfig.h>
 
@@ -271,65 +271,64 @@ static void
 initialize(Widget request, Widget new_w,
 	   ArgList args, Cardinal *num_args)
 {
-    XtPointer FirstScreenWidget;
+	XtPointer FirstScreenWidget;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, new_w, "%s:initialize(%d)\n", 
-    			__FILE__, __LINE__));
+	DEBUGOUT(_LtDebug(__FILE__, new_w, "%s:initialize(%d)\n", 
+		__FILE__, __LINE__));
 
-    /*
-     * This is due to the %&"% children management mechanism needed for the
-     * shell "shadow hierarchy". See Desktop.c for more details on this.
-     */
-    Screen_NumChildren(new_w) = 0;
-    Screen_NumSlots(new_w) = 0;
-    Screen_Children(new_w) = NULL;
+	/*
+	 * This is due to the %&"% children management mechanism needed for the
+	 * shell "shadow hierarchy". See Desktop.c for more details on this.
+	 */
+	Screen_NumChildren(new_w) = 0;
+	Screen_NumSlots(new_w) = 0;
+	Screen_Children(new_w) = NULL;
 
-    /*
-     * If haven't yet allocated the context with all kind of information
-     * about LessTif goodies we'll do it right now. This context contains
-     * LessTif goodies on a per display basis.
-     */
-    if (PerScreenWidgetContext == PSWC_None)
-    {
-	PerScreenWidgetContext = XUniqueContext();
-    }
+	/*
+	 * If haven't yet allocated the context with all kind of information
+	 * about LessTif goodies we'll do it right now. This context contains
+	 * LessTif goodies on a per display basis.
+	 */
+	if (PerScreenWidgetContext == PSWC_None)
+	{
+		PerScreenWidgetContext = XUniqueContext();
+	}
 
-    /*
-     * Make sure that there hasn't already allocated another XmScreen
-     * widget. Then register this widget as the XmScreen widget for the
-     * appropiate screen.
-     */
-    if (XFindContext(XtDisplay(new_w), RootWindowOfScreen(XtScreen(new_w)),
-		     PerScreenWidgetContext, (XPointer *)&FirstScreenWidget)
-	== XCSUCCESS)
-    {
-	_XmError(new_w, "Attempt to create a second XmScreen widget.");
-    }
-    else
-    {
-	XSaveContext(XtDisplay(new_w), RootWindowOfScreen(XtScreen(new_w)),
-		     PerScreenWidgetContext, (XPointer)new_w);
-    }
+	/*
+	 * Make sure that there hasn't already allocated another XmScreen
+	 * widget. Then register this widget as the XmScreen widget for the
+	 * appropiate screen.
+	 */
+	if (XFindContext(XtDisplay(new_w), RootWindowOfScreen(XtScreen(new_w)),
+		PerScreenWidgetContext, (XPointer *)&FirstScreenWidget)
+		== XCSUCCESS) {
+		_XmError(new_w, "Attempt to create a second XmScreen widget.");
+	} else {
+		XSaveContext(XtDisplay(new_w), RootWindowOfScreen(XtScreen(new_w)),
+			PerScreenWidgetContext, (XPointer)new_w);
+	}
 
-    Screen_MwmPresent(new_w) = XmIsMotifWMRunning(new_w);
+	Screen_MwmPresent(new_w) = XmIsMotifWMRunning(new_w);
 
-    Screen_ScratchPixmaps(new_w) = NULL;
-    Screen_ScreenInfo(new_w) = NULL;
-    Screen_CursorCache(new_w) = NULL;
+	Screen_ScratchPixmaps(new_w) = NULL;
+	Screen_ScreenInfo(new_w) = NULL;
+	Screen_CursorCache(new_w) = NULL;
 
-    Screen_MoveCursorIcon(new_w) = NULL;
-    Screen_CopyCursorIcon(new_w) = NULL;
-    Screen_LinkCursorIcon(new_w) = NULL;
-    Screen_StateCursorIcon(new_w) = NULL;
-    Screen_StateCursorIcon(new_w) = NULL;
-    Screen_SourceCursorIcon(new_w) = NULL;
+	Screen_MoveCursorIcon(new_w) = NULL;
+	Screen_CopyCursorIcon(new_w) = NULL;
+	Screen_LinkCursorIcon(new_w) = NULL;
+	Screen_StateCursorIcon(new_w) = NULL;
+	Screen_StateCursorIcon(new_w) = NULL;
+	Screen_SourceCursorIcon(new_w) = NULL;
 
-    XQueryBestCursor(XtDisplay(new_w), RootWindowOfScreen(XtScreen(new_w)),
-		     32, 32,
-		     &Screen_MaxCursorWidth(new_w),
-		     &Screen_MaxCursorHeight(new_w));
+	XQueryBestCursor(XtDisplay(new_w), RootWindowOfScreen(XtScreen(new_w)),
+		32, 32,
+		&Screen_MaxCursorWidth(new_w),
+		&Screen_MaxCursorHeight(new_w));
 
-    Screen_NullCursor(new_w) = None;
+	Screen_NullCursor(new_w) = None;
+
+	_XmPickupUnspecifiedPixmaps(XtDisplay(new_w));
 }
 
 
@@ -420,7 +419,7 @@ realize(Widget w,
 	XtValueMask *value_mask,
 	XSetWindowAttributes *attributes)
 {
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "%s:realize(%d)\n", 
+    DEBUGOUT(_LtDebug(__FILE__, w, "%s:realize(%d)\n", 
     			__FILE__, __LINE__));
 
 }
@@ -670,7 +669,7 @@ _XmAllocScratchPixmap(XmScreen xmScreen,
 {
     XmScratchPixmap pix = NULL;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, (Widget)xmScreen, "%s:_XmAllocScratchPixmap(%d) - %dx%dx%d\n", 
+    DEBUGOUT(_LtDebug(__FILE__, (Widget)xmScreen, "%s:_XmAllocScratchPixmap(%d) - %dx%dx%d\n", 
     			__FILE__, __LINE__,
     			width, height, depth));
 
@@ -680,7 +679,7 @@ _XmAllocScratchPixmap(XmScreen xmScreen,
 	    pix->width == width && pix->height == height)
 	{
 	    pix->inUse = True;
-	    DEBUGOUT(_LtDebugDebug(__FILE__, (Widget)xmScreen, "\tfrom cache %p\n", 
+	    DEBUGOUT(_LtDebug(__FILE__, (Widget)xmScreen, "\tfrom cache %p\n", 
     			pix->pixmap));
 	    break;
 	}
@@ -699,7 +698,7 @@ _XmAllocScratchPixmap(XmScreen xmScreen,
 	pix->next = Screen_ScratchPixmaps(xmScreen);
 	Screen_ScratchPixmaps(xmScreen) = pix;
 
-	DEBUGOUT(_LtDebugDebug(__FILE__, (Widget)xmScreen, "\tnew %p\n", 
+	DEBUGOUT(_LtDebug(__FILE__, (Widget)xmScreen, "\tnew %p\n", 
 			    pix->pixmap));
     }
     return pix->pixmap;
@@ -711,7 +710,7 @@ _XmFreeScratchPixmap(XmScreen xmScreen, Pixmap pixmap)
 {
     XmScratchPixmap pix;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, (Widget)xmScreen, "%s:_XmFreeScratchPixmap(%d) - %p\n", 
+    DEBUGOUT(_LtDebug(__FILE__, (Widget)xmScreen, "%s:_XmFreeScratchPixmap(%d) - %p\n", 
     			__FILE__, __LINE__,
     			pixmap));
     for (pix = Screen_ScratchPixmaps(xmScreen); pix != NULL; pix = pix->next)
@@ -835,8 +834,7 @@ _XmScreenRemoveFromCursorCache(XmDragIconObject icon)
     XmDragCursorCache *ptr, tmp;
     static XmDragIconRec nullIcon =
     {
-	{0},
-	{0}};
+	{0},{0}, {0}};
     Boolean match;
 
     scr = (XmScreen)XmGetXmScreen(XtScreen(icon));
@@ -921,7 +919,7 @@ XmGetXmScreen(Screen *scr)
     char name[128];
     int screen_no, max_screens;
 
-    DEBUGOUT(_LtDebugDebug0(__FILE__, (Widget)NULL, "%s:XmGetXmScreen(%d)\n", 
+    DEBUGOUT(_LtDebug0(__FILE__, (Widget)NULL, "%s:XmGetXmScreen(%d)\n", 
     			__FILE__, __LINE__));
 
     disp = XmGetXmDisplay(DisplayOfScreen(scr));
@@ -948,8 +946,7 @@ XmGetXmScreen(Screen *scr)
 	}
 	sprintf(name, "screen%d", screen_no);
 
-	screen = XtCreateWidget(name, xmScreenClass, disp,
-				       args, argc);
+	screen = XtCreateWidget(name, xmScreenClass, disp, args, argc);
     }
 
     return screen;
