@@ -1,6 +1,6 @@
 /**
  *
- * $Id: ScrollBar.c,v 1.60 2001/05/14 19:46:10 amai Exp $
+ * $Id: ScrollBar.c,v 1.61 2001/07/27 18:51:57 dannybackx Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
  * Copyright (C) 1995-2001 LessTif Development Team
@@ -23,7 +23,7 @@
  *
  **/
 
-static const char rcsid[] = "$Id: ScrollBar.c,v 1.60 2001/05/14 19:46:10 amai Exp $";
+static const char rcsid[] = "$Id: ScrollBar.c,v 1.61 2001/07/27 18:51:57 dannybackx Exp $";
 
 #include <LTconfig.h>
 
@@ -598,7 +598,7 @@ CreateUnavailableGC(Widget w)
 static void
 initialize(Widget request, Widget new_w, ArgList args, Cardinal *num_args)
 {
-    DEBUGOUT(_LtDebugDebug(__FILE__, new_w,
+    DEBUGOUT(_LtDebug(__FILE__, new_w,
 		      "%s(%i) - initialize: %i args\n"
 		      "\trequest X %5i Y %5i W %5i H %5i\n"
 		      "\t  new_w X %5i Y %5i W %5i H %5i\n",
@@ -683,7 +683,7 @@ initialize(Widget request, Widget new_w, ArgList args, Cardinal *num_args)
 static void
 check_constraints(Widget sw, Widget current)
 {
-    DEBUGOUT(_LtDebugDebug(__FILE__, sw,
+    DEBUGOUT(_LtDebug(__FILE__, sw,
 	     "Specified scrollbar values: min=%d, max=%d, val=%d, sl_size=%d\n"
 		      " inc=%d, p_inc=%d, p_dir=%d\n",
 		      SCB_Minimum(sw), SCB_Maximum(sw), SCB_Value(sw),
@@ -811,7 +811,7 @@ check_constraints(Widget sw, Widget current)
 	/* Yes, 75 is not equal to the default. */
     }
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, sw,
+    DEBUGOUT(_LtDebug(__FILE__, sw,
 		   "Got scrollbar values: min=%d, max=%d, val=%d, sl_size=%d\n"
 		      " inc=%d, p_inc=%d, p_dir=%d\n",
 		      SCB_Minimum(sw), SCB_Maximum(sw), SCB_Value(sw),
@@ -853,7 +853,7 @@ set_values(Widget current, Widget request, Widget new_w,
 	Boolean redrawSlider = CNE(Prim_Foreground) || CNE(Prim_TopShadowColor) ||
 		CNE(Prim_BottomShadowColor);
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, new_w,
+    DEBUGOUT(_LtDebug(__FILE__, new_w,
 		      "%s(%d) - set_values: %i args\n"
 		      "\t    old X %5i Y %5i W %5i H %5i\n"
 		      "\trequest X %5i Y %5i W %5i H %5i\n"
@@ -1250,7 +1250,7 @@ resize(Widget sw)
 static void
 realize(Widget w, XtValueMask *values, XSetWindowAttributes *attributes)
 {
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "%s:realize(%d) %dx%d\n",
+    DEBUGOUT(_LtDebug(__FILE__, w, "%s:realize(%d) %dx%d\n",
     	__FILE__, __LINE__,
     	XtWidth(w), XtHeight(w)));
 
@@ -1318,7 +1318,7 @@ query_geometry(Widget w,
 static void
 scrollbar_unhighlight(Widget w)
 {
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "ScrollBarUnHighlight\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "ScrollBarUnHighlight\n"));
 
 #define superclass (&xmPrimitiveClassRec)
     (*superclass->primitive_class.border_unhighlight) (w);
@@ -1328,7 +1328,7 @@ scrollbar_unhighlight(Widget w)
 static void
 scrollbar_highlight(Widget w)
 {
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "ScrollBarHighlight\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "ScrollBarHighlight\n"));
 
 #define superclass (&xmPrimitiveClassRec)
     (*superclass->primitive_class.border_highlight) (w);
@@ -1599,7 +1599,7 @@ Select(Widget sw,
     int eventPos;
     int change_type;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, sw, "Select\n"));
+    DEBUGOUT(_LtDebug(__FILE__, sw, "Select\n"));
 
     if (ev->button == Button1 && !XmIsScrolledWindow(XtParent(sw)))
     {
@@ -1724,7 +1724,7 @@ Release(Widget sw,
     int arrow1, arrow2;
     XmScrollBarCallbackStruct cbs;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, sw, "Release\n"));
+    DEBUGOUT(_LtDebug(__FILE__, sw, "Release\n"));
 
     SCB_Flags(sw) &= ~FLG_DRAG;
 
@@ -1752,7 +1752,7 @@ Release(Widget sw,
 	cbs.value = EXPORTED_VALUE(sw);
 	cbs.pixel = (SCB_Orientation(sw) == XmHORIZONTAL ? ev->x : ev->y);
 
-	DEBUGOUT(_LtDebugDebug(__FILE__, sw, "Release: ValueChangedCallback\n"));
+	DEBUGOUT(_LtDebug(__FILE__, sw, "Release: ValueChangedCallback\n"));
 
 	XFlush(XtDisplay(sw));
 	XtCallCallbackList(sw, SCB_ValueChangedCallback(sw), &cbs);
@@ -1777,7 +1777,7 @@ Moved(Widget sw,
 
     old_value = SCB_Value(sw);
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, sw, "Moved\n"));
+    DEBUGOUT(_LtDebug(__FILE__, sw, "Moved\n"));
 
     if (SCB_Orientation(sw) == XmHORIZONTAL)
     {
@@ -1865,7 +1865,7 @@ Moved(Widget sw,
     /* only call dragcallback if value really changed */
     if (SCB_Value(sw) != old_value)
     {
-	DEBUGOUT(_LtDebugDebug(__FILE__, sw, "Moved: DragCallback\n"));
+	DEBUGOUT(_LtDebug(__FILE__, sw, "Moved: DragCallback\n"));
 
 	cbs.event = event;
 	cbs.value = EXPORTED_VALUE(sw);
@@ -1884,7 +1884,7 @@ TopOrBottom(Widget sw,
 {
     int change_type;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, sw, "TopOrBottom\n"));
+    DEBUGOUT(_LtDebug(__FILE__, sw, "TopOrBottom\n"));
 
     if (event->type == KeyPress)
     {
@@ -2070,7 +2070,7 @@ IncrementDownOrRight(Widget w,
 {
     int which;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "IncrementDownOrRight\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "IncrementDownOrRight\n"));
 
     if (*num_params != 1)
     {
@@ -2094,7 +2094,7 @@ IncrementUpOrLeft(Widget w,
 {
     int which;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "IncrementUpOrLeft\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "IncrementUpOrLeft\n"));
 
     if (*num_params != 1)
     {
