@@ -1,9 +1,9 @@
 /*
  *
- * $Id: ScrolledW.c,v 1.125 2001/05/14 20:54:10 amai Exp $
+ * $Header: /cvsroot/lesstif/lesstif/lib/Xm/ScrolledW.c,v 1.128 2002/05/02 17:25:03 dannybackx Exp $
  *
  * Copyright (C) 1996 Free Software Foundation, Inc.
- * Copyright (C) 1996-2000 LessTif Development Team
+ * Copyright  1996, 1997, 1998, 1999, 2000, 2001, 2002 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -23,7 +23,7 @@
  *
  **/
 
-static const char rcsid[] = "$Id: ScrolledW.c,v 1.125 2001/05/14 20:54:10 amai Exp $";
+static const char rcsid[] = "$Header: /cvsroot/lesstif/lesstif/lib/Xm/ScrolledW.c,v 1.128 2002/05/02 17:25:03 dannybackx Exp $";
 
 /*
  * Current status of changes in layout (Danny 18/4/1997) :
@@ -51,10 +51,6 @@ static const char rcsid[] = "$Id: ScrolledW.c,v 1.125 2001/05/14 20:54:10 amai E
 
 #include <XmI/DebugUtil.h>
 
-#ifndef XmUNSPECIFIED
-#define XmUNSPECIFIED (~0)
-#endif
-
 /* rws 25 Mar 1998
    With this undefined the page list of mgv and mfm work correctly. The mfm
    problem can be seen if you start it and then select a directory from the
@@ -462,7 +458,7 @@ static void
 initialize(Widget request, Widget new_w,
 	   ArgList args, Cardinal *num_args)
 {
-    DEBUGOUT(_LtDebugDebug(__FILE__, new_w,
+    DEBUGOUT(_LtDebug(__FILE__, new_w,
 		      "%s:initialize: %i args\n"
 		      "\trequest X %5i Y %5i W %5i H %5i\n"
 		      "\t  new_w X %5i Y %5i W %5i H %5i\n",
@@ -737,7 +733,7 @@ set_values(Widget old, Widget request, Widget new_w,
 {
     Boolean r = False;		/* Must I be redisplayed ? */
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, new_w,
+    DEBUGOUT(_LtDebug(__FILE__, new_w,
 		      "set_values: %i args\n"
 		      "\t    old X %5i Y %5i W %5i H %5i\n"
 		      "\trequest X %5i Y %5i W %5i H %5i\n"
@@ -814,7 +810,7 @@ set_values(Widget old, Widget request, Widget new_w,
 
     if (NE(SW_WorkWindow))
     {
-	DEBUGOUT(_LtDebugDebug0(__FILE__, new_w,
+	DEBUGOUT(_LtDebug0(__FILE__, new_w,
 			   "Work Window changed: from %s to %s.\n",
 			   SW_WorkWindow(old) != NULL
 				? XtName(SW_WorkWindow(old))
@@ -822,7 +818,7 @@ set_values(Widget old, Widget request, Widget new_w,
 			   SW_WorkWindow(new_w) != NULL
 				? XtName(SW_WorkWindow(new_w))
 				: "(null)"));
-	DEBUGOUT(_LtDebugDebug0(__FILE__, new_w,
+	DEBUGOUT(_LtDebug0(__FILE__, new_w,
 			   "Work Window was: %dx%d now %dx%d.\n",
 			   SW_WorkWindow(old) != NULL
 				? XtWidth(SW_WorkWindow(old))
@@ -836,7 +832,7 @@ set_values(Widget old, Widget request, Widget new_w,
 			   SW_WorkWindow(new_w) != NULL
 				? XtHeight(SW_WorkWindow(new_w))
 				: 0));
-	DEBUGOUT(_LtDebugDebug0(__FILE__, new_w, "... SW_VisualPolicy %s",
+	DEBUGOUT(_LtDebug0(__FILE__, new_w, "... SW_VisualPolicy %s",
 			   (SW_VisualPolicy(new_w) == XmCONSTANT)
 				? "XmCONSTANT"
 				: (SW_VisualPolicy(new_w) == XmVARIABLE)
@@ -845,13 +841,13 @@ set_values(Widget old, Widget request, Widget new_w,
 					   XmRESIZE_IF_POSSIBLE)
 						? "XmRESIZE_IF_POSSIBLE"
 						: "???"));
-	DEBUGOUT(_LtDebugDebug0(__FILE__, new_w, " SW_ScrollBarPolicy %s",
+	DEBUGOUT(_LtDebug0(__FILE__, new_w, " SW_ScrollBarPolicy %s",
 			   (SW_ScrollBarPolicy(new_w) == XmSTATIC)
 			   ? "XmSTATIC"
 			   : (SW_ScrollBarPolicy(new_w) == XmAS_NEEDED)
 			   ? "XmAS_NEEDED"
 			   : "???"));
-	DEBUGOUT(_LtDebugDebug0(__FILE__, new_w, " SW_ScrollPolicy %s\n",
+	DEBUGOUT(_LtDebug0(__FILE__, new_w, " SW_ScrollPolicy %s\n",
 			   (SW_ScrollPolicy(new_w) == XmAPPLICATION_DEFINED)
 			   ? "XmAPPLICATION_DEFINED"
 			   : (SW_ScrollPolicy(new_w) == XmAUTOMATIC)
@@ -912,7 +908,7 @@ resize(Widget w)
 {
     XmSWValues vals;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "Resize: x %d y %d w %d h %d\n",
+    DEBUGOUT(_LtDebug(__FILE__, w, "Resize: x %d y %d w %d h %d\n",
 		      XtX(w), XtY(w), XtWidth(w), XtHeight(w)));
 
     SW_FromResize(w) = True;
@@ -987,7 +983,7 @@ realize(Widget w, Mask *value_mask, XSetWindowAttributes *attributes)
     XmSWValues vals;
     */
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "%s:realize(%d) - %dx%d\n",
+    DEBUGOUT(_LtDebug(__FILE__, w, "%s:realize(%d) - %dx%d\n",
     	__FILE__, __LINE__,
     	XtWidth(w), XtHeight(w)));
 
@@ -1044,7 +1040,7 @@ query_geometry(Widget w,
     XtWidgetGeometry wants;
 
 #if 0
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "query_geometry(%s)\n",
+    DEBUGOUT(_LtDebug(__FILE__, w, "query_geometry(%s)\n",
 		      _LtDebugWidgetGeometry2String(intended)));
 
     wants = *intended;
@@ -1059,7 +1055,7 @@ query_geometry(Widget w,
 	preferred->height = vals.SwH;
     }
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "query_geometry: I want %s\n",
+    DEBUGOUT(_LtDebug(__FILE__, w, "query_geometry: I want %s\n",
 		      _LtDebugWidgetGeometry2String(preferred)));
 
     if (((wants.request_mode & CWWidth) &&
@@ -1067,7 +1063,7 @@ query_geometry(Widget w,
         ((intended->request_mode & CWHeight) &&
 	wants.height == preferred->height))
     {
-	DEBUGOUT(_LtDebugDebug(__FILE__, w, "query_geometry => NO (w %d)\n",
+	DEBUGOUT(_LtDebug(__FILE__, w, "query_geometry => NO (w %d)\n",
 			  preferred->width));
 
 	return XtGeometryNo;	/* Something's different */
@@ -1076,7 +1072,7 @@ query_geometry(Widget w,
     if ((wants.request_mode & CWWidth) &&
 	wants.width != preferred->width)
     {
-	DEBUGOUT(_LtDebugDebug(__FILE__, w, "query_geometry => ALMOST (w %d)\n",
+	DEBUGOUT(_LtDebug(__FILE__, w, "query_geometry => ALMOST (w %d)\n",
 			  preferred->width));
 
 	return XtGeometryAlmost;	/* Something's different */
@@ -1085,17 +1081,17 @@ query_geometry(Widget w,
     if ((wants.request_mode & CWHeight) &&
 	wants.height != preferred->height)
     {
-	DEBUGOUT(_LtDebugDebug(__FILE__, w, "query_geometry => ALMOST (h %d)\n",
+	DEBUGOUT(_LtDebug(__FILE__, w, "query_geometry => ALMOST (h %d)\n",
 			  preferred->height));
 
 	return XtGeometryAlmost;	/* Something's different */
     }
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "query_geometry => YES\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "query_geometry => YES\n"));
 
     return XtGeometryYes;	/* I'm happy */
 #else
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "query_geometry(%s)\n",
+    DEBUGOUT(_LtDebug(__FILE__, w, "query_geometry(%s)\n",
 		      _LtDebugWidgetGeometry2String(intended)));
 
     wants = *intended;
@@ -1126,7 +1122,7 @@ geometry_manager(Widget w, XtWidgetGeometry *desired, XtWidgetGeometry *allowed)
     XmSWValues vals;
 	XtGeometryResult rval;
 
-    DEBUGOUT(_LtDebugDebug2(__FILE__, sw, w, "geometry_manager (request %s)\n",
+    DEBUGOUT(_LtDebug2(__FILE__, sw, w, "geometry_manager (request %s)\n",
 		       _LtDebugWidgetGeometry2String(desired)));
 
     /* Whoa, nelly.  Not if we control what you do. */
@@ -1148,10 +1144,10 @@ geometry_manager(Widget w, XtWidgetGeometry *desired, XtWidgetGeometry *allowed)
      */
     if (SW_ScrollPolicy(sw) == XmAUTOMATIC && w == (Widget)SW_ClipWindow(sw))
     {
-	DEBUGOUT(_LtDebugDebug2(__FILE__, sw, w,
+	DEBUGOUT(_LtDebug2(__FILE__, sw, w,
 			   "BEGIN AUTOMATIC FAKE\n\n"));
 
-	DEBUGOUT(_LtDebugDebug2(__FILE__, sw, w,
+	DEBUGOUT(_LtDebug2(__FILE__, sw, w,
 			   "geometry_manager: resize WorkWindow: %d %d\n",
 			   wants.width, wants.height));
 
@@ -1190,7 +1186,7 @@ geometry_manager(Widget w, XtWidgetGeometry *desired, XtWidgetGeometry *allowed)
 	_XmRepositionScrolledWindow(w, NULL, NULL);
 #endif
 
-	DEBUGOUT(_LtDebugDebug2(__FILE__, sw, w, "END AUTOMATIC FAKE\n"));
+	DEBUGOUT(_LtDebug2(__FILE__, sw, w, "END AUTOMATIC FAKE\n"));
 
 	return XtGeometryNo;
     }
@@ -1227,7 +1223,7 @@ geometry_manager(Widget w, XtWidgetGeometry *desired, XtWidgetGeometry *allowed)
 		   "not implemented (child %s, class %s)",
 		   XtName(w), XtClass(w)->core_class.class_name);
 
-	DEBUGOUT(_LtDebugDebug2(__FILE__, sw, w,
+	DEBUGOUT(_LtDebug2(__FILE__, sw, w,
 		   "geometry_manager QueryOnly not implemented ! (=> YES)\n"));
 
 	return XtGeometryYes;
@@ -1239,7 +1235,7 @@ geometry_manager(Widget w, XtWidgetGeometry *desired, XtWidgetGeometry *allowed)
 	 */
     if ( (Wants(CWX) || Wants(CWY)) && !(Wants(CWWidth) || Wants(CWHeight) || Wants(CWBorderWidth)))
     {
-	DEBUGOUT(_LtDebugDebug2(__FILE__, sw, w, "GeometryManager => No 2\n"));
+	DEBUGOUT(_LtDebug2(__FILE__, sw, w, "GeometryManager => No 2\n"));
 	return XtGeometryNo;
     }
 
@@ -1248,32 +1244,32 @@ geometry_manager(Widget w, XtWidgetGeometry *desired, XtWidgetGeometry *allowed)
     {
 	wants.request_mode &= ~CWWidth;
 	wants.request_mode &= ~CWHeight;
-	DEBUGOUT(_LtDebugDebug2(__FILE__, sw, w, "GeometryManager => Yes-1 %s\n",
+	DEBUGOUT(_LtDebug2(__FILE__, sw, w, "GeometryManager => Yes-1 %s\n",
 		_LtDebugWidgetGeometry2String(allowed)));
     }
     else if (Wants((CWWidth|CWHeight)) == CWWidth &&
 	wants.width == desired->width)
     {
 	wants.request_mode &= ~CWWidth;
-	DEBUGOUT(_LtDebugDebug2(__FILE__, sw, w, "GeometryManager => Yes-2 %s\n",
+	DEBUGOUT(_LtDebug2(__FILE__, sw, w, "GeometryManager => Yes-2 %s\n",
 		_LtDebugWidgetGeometry2String(allowed)));
     }
     else if (Wants((CWWidth|CWHeight)) == CWHeight &&
 	wants.height == desired->height)
     {
 	wants.request_mode &= ~CWHeight;
-	DEBUGOUT(_LtDebugDebug2(__FILE__, sw, w, "GeometryManager => Yes-3 %s\n",
+	DEBUGOUT(_LtDebug2(__FILE__, sw, w, "GeometryManager => Yes-3 %s\n",
 		_LtDebugWidgetGeometry2String(allowed)));
     }
 	else if (rval == XtGeometryYes)
 	{
 	/* T. Straumann: change in border width only */
-	DEBUGOUT(_LtDebugDebug2(__FILE__, sw, w, "GeometryManager => Yes-4 %s\n",
+	DEBUGOUT(_LtDebug2(__FILE__, sw, w, "GeometryManager => Yes-4 %s\n",
 		_LtDebugWidgetGeometry2String(allowed)));
 	}
 	else
 	{
-    DEBUGOUT(_LtDebugDebug2(__FILE__, sw, w, "GeometryManager -> Almost %s\n",
+    DEBUGOUT(_LtDebug2(__FILE__, sw, w, "GeometryManager -> Almost %s\n",
 		_LtDebugWidgetGeometry2String(allowed)));
 	}
 
@@ -1297,7 +1293,7 @@ geometry_manager(Widget w, XtWidgetGeometry *desired, XtWidgetGeometry *allowed)
     }
     else
     {
-	DEBUGOUT(_LtDebugDebug2(__FILE__, sw, w, "GeometryManager => No 1\n"));
+	DEBUGOUT(_LtDebug2(__FILE__, sw, w, "GeometryManager => No 1\n"));
 	return XtGeometryNo;
     }
 	}
@@ -1308,41 +1304,55 @@ geometry_manager(Widget w, XtWidgetGeometry *desired, XtWidgetGeometry *allowed)
 static void
 change_managed(Widget w)
 {
-    XmSWValues vals;
+	XmSWValues vals;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "%s:change_managed(%d)\n",
-			  __FILE__, __LINE__));
-    if (True || XtIsManaged(w))
-    {
-	_XmScrolledWPreferredSize(w, NULL, NULL, &vals);
+	DEBUGOUT(_LtDebug(__FILE__, w, "change_managed()\n"));
+	/*
+	 * SW_ScrollPolicy
+	 */
+	if (SW_ScrollPolicy(w) == XmAPPLICATION_DEFINED) {
+		Widget	child;
+		int	i;
 
-	if (_XmScrolledWGeomRequest(w, &vals) == XtGeometryYes)
-	{
+		for (i=0, child=0; i<MGR_NumChildren(w) && child == NULL; i++)
+			if (! XmIsScrollBar(MGR_Children(w)[i]))
+				child = MGR_Children(w)[i];
 
-	    _XmScrolledWLayout(w, NULL, NULL, &vals);
-
-	    _XmScrolledWConfigureChildren(w, NULL, NULL, &vals);
+		DEBUGOUT(_LtDebug2(__FILE__, w, child, "CM %d %d\n",
+			XtIsManaged(w), XtIsManaged(child)));
+#if 1
+		if (child && XtIsManaged(w) && !XtIsManaged(child)) {
+			DEBUGOUT(_LtDebug2(__FILE__, w, child, "Unmanage SW\n"));
+			XtUnmanageChild(w);
+		} else if (child && XtIsManaged(child) && !XtIsManaged(w)) {
+			DEBUGOUT(_LtDebug2(__FILE__, w, child, "Manage SW\n"));
+			XtManageChild(w);
+		}
+#endif
 	}
+	if (True || XtIsManaged(w)) {
+		_XmScrolledWPreferredSize(w, NULL, NULL, &vals);
 
-	DEBUGOUT(_LtDebugDebug(__FILE__, w, "change_managed: size %d %d\n",
+		if (_XmScrolledWGeomRequest(w, &vals) == XtGeometryYes) {
+			_XmScrolledWLayout(w, NULL, NULL, &vals);
+			_XmScrolledWConfigureChildren(w, NULL, NULL, &vals);
+		}
+
+		DEBUGOUT(_LtDebug(__FILE__, w, "change_managed: size %d %d\n",
 			  XtWidth(w), XtHeight(w)));
-    }
-    else
-    {
-	if (SW_ScrollBarPolicy(w) != XmSTATIC)
-	{
-	    DEBUGOUT(_LtDebugDebug(__FILE__, w, "change_managed: unmanaging sb's\n"));
+	} else {
+		if (SW_ScrollBarPolicy(w) != XmSTATIC) {
+			DEBUGOUT(_LtDebug(__FILE__, w,
+				"change_managed: unmanaging sb's\n"));
 
-	    if (SW_HSB(w) && XtIsManaged((Widget)SW_HSB(w)))
-	    {
-		XtUnmanageChild((Widget)SW_HSB(w));
-	    }
-	    if (SW_VSB(w) && XtIsManaged((Widget)SW_VSB(w)))
-	    {
-		XtUnmanageChild((Widget)SW_VSB(w));
-	    }
+			if (SW_HSB(w) && XtIsManaged((Widget)SW_HSB(w))) {
+				XtUnmanageChild((Widget)SW_HSB(w));
+			}
+			if (SW_VSB(w) && XtIsManaged((Widget)SW_VSB(w))) {
+				XtUnmanageChild((Widget)SW_VSB(w));
+			}
+		}
 	}
-    }
 }
 
 /*
@@ -1450,7 +1460,7 @@ insert_child(Widget w)
      */
     else if (SW_VisualPolicy(sw) == XmCONSTANT)
     {
-	DEBUGOUT(_LtDebugDebug2(__FILE__, (Widget)sw, (Widget)w, "Reparented to %s\n",
+	DEBUGOUT(_LtDebug2(__FILE__, (Widget)sw, (Widget)w, "Reparented to %s\n",
 			   XtName(SW_ClipWindow(sw))));
 
 	XtParent(w) = (Widget)SW_ClipWindow(sw);
@@ -1465,7 +1475,7 @@ insert_child(Widget w)
     }
     else if (SW_WorkWindow(sw) == NULL)
     {
-	DEBUGOUT(_LtDebugDebug2(__FILE__, (Widget)sw, w, "Child is Work Window\n"));
+	DEBUGOUT(_LtDebug2(__FILE__, (Widget)sw, w, "Child is Work Window\n"));
 
 	(*superclass->composite_class.insert_child) (w);
 
@@ -1473,7 +1483,7 @@ insert_child(Widget w)
     }
     else
     {
-	DEBUGOUT(_LtDebugDebug2(__FILE__, (Widget)sw, w, "Child is goofy\n"));
+	DEBUGOUT(_LtDebug2(__FILE__, (Widget)sw, w, "Child is goofy\n"));
 
 	(*superclass->composite_class.insert_child) (w);
     }
@@ -1548,7 +1558,7 @@ _XmRepositionScrolledWindow(Widget w, XtPointer client, XtPointer call)
 	SW_HSBValue(sw) = 0;
     }
 
-    DEBUGOUT(_LtDebugDebug2(__FILE__, sw, w, "Hor %d Vert %d\n", h, v));
+    DEBUGOUT(_LtDebug2(__FILE__, sw, w, "Hor %d Vert %d\n", h, v));
 
     /*
      * Position the work window
@@ -1611,10 +1621,10 @@ _XmFixupScrollBars(Widget w, Dimension ww, Dimension wh)
     /*
      * otherwise, fixup the scrollbars.
      */
-    DEBUGOUT(_LtDebugDebug(__FILE__, w,
+    DEBUGOUT(_LtDebug(__FILE__, w,
 		      "FixupScrollBars Widths : Work %d Clip %d\n",
 		      ww, SW_CWWidth(w)));
-    DEBUGOUT(_LtDebugDebug(__FILE__, w,
+    DEBUGOUT(_LtDebug(__FILE__, w,
 		      "FixupScrollBars Heights : Work %d Clip %d\n",
 		      wh, SW_CWHeight(w)));
 
@@ -1665,7 +1675,7 @@ _XmFixupScrollBars(Widget w, Dimension ww, Dimension wh)
 	SW_HSBMaximum(w) = max;
 	SW_HSBSliderSize(w) = percent;
 
-	DEBUGOUT(_LtDebugDebug(__FILE__, w,
+	DEBUGOUT(_LtDebug(__FILE__, w,
 			  "FixupScrollBars HSB min %d max %d percent %d\n",
 			  min, max, percent));
     }
@@ -1716,7 +1726,7 @@ _XmFixupScrollBars(Widget w, Dimension ww, Dimension wh)
 	SW_VSBMaximum(w) = max;
 	SW_VSBSliderSize(w) = percent;
 
-	DEBUGOUT(_LtDebugDebug(__FILE__, w,
+	DEBUGOUT(_LtDebug(__FILE__, w,
 			  "FixupScrollBars VSB min %d max %d percent %d value %d\n",
 			  min, max, percent, value));
     }
@@ -1810,21 +1820,21 @@ _XmScrolledWPreferredSize(Widget w, Widget child, XtWidgetGeometry *childgeom,
 			  XmSWValues *vals)
 {
     /* Print out how we're called */
-	DEBUGOUT(_LtDebugDebug(__FILE__, w,
+	DEBUGOUT(_LtDebug(__FILE__, w,
 			  "XmScrolledWPreferredSize [size %d %d]\n",
 			  XtWidth(w), XtHeight(w)));
-	DEBUGOUT(_LtDebugDebug0(__FILE__, w, "... SW_VisualPolicy %s",
+	DEBUGOUT(_LtDebug0(__FILE__, w, "... SW_VisualPolicy %s",
 			   (SW_VisualPolicy(w) == XmCONSTANT) ? "XmCONSTANT" :
 			   (SW_VisualPolicy(w) == XmVARIABLE) ? "XmVARIABLE" :
 			   (SW_VisualPolicy(w) == XmRESIZE_IF_POSSIBLE)
 			   ? "XmRESIZE_IF_POSSIBLE" : "???"));
-	DEBUGOUT(_LtDebugDebug0(__FILE__, w, " SW_ScrollBarPolicy %s",
+	DEBUGOUT(_LtDebug0(__FILE__, w, " SW_ScrollBarPolicy %s",
 			   (SW_ScrollBarPolicy(w) == XmSTATIC)
 			   ? "XmSTATIC"
 			   : (SW_ScrollBarPolicy(w) == XmAS_NEEDED)
 			   ? "XmAS_NEEDED"
 			   : "???"));
-	DEBUGOUT(_LtDebugDebug0(__FILE__, w, " SW_ScrollPolicy %s\n",
+	DEBUGOUT(_LtDebug0(__FILE__, w, " SW_ScrollPolicy %s\n",
 			   (SW_ScrollPolicy(w) == XmAPPLICATION_DEFINED)
 			   ? "XmAPPLICATION_DEFINED"
 			   : (SW_ScrollPolicy(w) == XmAUTOMATIC)
@@ -1896,7 +1906,7 @@ _XmScrolledWPreferredSize(Widget w, Widget child, XtWidgetGeometry *childgeom,
 	    vals->WorkH = XtHeight(SW_WorkWindow(w)) + 2 * XtBorderWidth(SW_WorkWindow(w));
 	}
 
-	DEBUGOUT(_LtDebugDebug2(__FILE__, w, (Widget)SW_WorkWindow(w),
+	DEBUGOUT(_LtDebug2(__FILE__, w, (Widget)SW_WorkWindow(w),
 			   "WorkWindow queried geo is W %d H %d X %d Y %d\n",
 			   vals->WorkW, vals->WorkH, vals->WorkX, vals->WorkY));
     }
@@ -2043,7 +2053,7 @@ _XmScrolledWPreferredSize(Widget w, Widget child, XtWidgetGeometry *childgeom,
 					? (SW_Spacing(w) + vals->VsbW)
 					: 0);
 
-	    DEBUGOUT(_LtDebugDebug2(__FILE__, w, SW_WorkWindow(w),
+	    DEBUGOUT(_LtDebug2(__FILE__, w, SW_WorkWindow(w),
 			       "Grow WorkW %d -> %d\n",
 			       xx, vals->WorkW));
 	}
@@ -2058,7 +2068,7 @@ _XmScrolledWPreferredSize(Widget w, Widget child, XtWidgetGeometry *childgeom,
 					? (SW_Spacing(w) + vals->HsbH)
 					: 0);
 
-	    DEBUGOUT(_LtDebugDebug2(__FILE__, w, SW_WorkWindow(w),
+	    DEBUGOUT(_LtDebug2(__FILE__, w, SW_WorkWindow(w),
 			       "Grow WorkH %d -> %d\n",
 			       xx, vals->WorkH));
 	}
@@ -2090,7 +2100,7 @@ _XmScrolledWPreferredSize(Widget w, Widget child, XtWidgetGeometry *childgeom,
 			2 * (SW_MarginWidth(w) + MGR_ShadowThickness(w)) +
 			(vals->ShowVSB ? (SW_Spacing(w) + vals->VsbW) : 0);
 
-		DEBUGOUT(_LtDebugDebug2(__FILE__, w, SW_WorkWindow(w),
+		DEBUGOUT(_LtDebug2(__FILE__, w, SW_WorkWindow(w),
 				   "Grow SwW %d -> %d\n",
 				   xx, vals->SwW));
 	    }
@@ -2109,7 +2119,7 @@ _XmScrolledWPreferredSize(Widget w, Widget child, XtWidgetGeometry *childgeom,
 			2 * (SW_MarginHeight(w) + MGR_ShadowThickness(w)) +
 			(vals->ShowHSB ? (SW_Spacing(w) + vals->HsbH) : 0);
 
-		DEBUGOUT(_LtDebugDebug2(__FILE__, w, SW_WorkWindow(w),
+		DEBUGOUT(_LtDebug2(__FILE__, w, SW_WorkWindow(w),
 				   "Grow SwH %d -> %d\n",
 				   xx, vals->SwH));
 	    }
@@ -2218,14 +2228,14 @@ _XmScrolledWGeomRequest(Widget w, XmSWValues *vals)
     }
 #endif
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "Request geo %s from parent %s %s\n",
+    DEBUGOUT(_LtDebug(__FILE__, w, "Request geo %s from parent %s %s\n",
 		      _LtDebugWidgetGeometry2String(&request),
 		      XtName(XtParent(w)),
 		      XtClass(XtParent(w))->core_class.class_name));
 
     res = _XmMakeGeometryRequest(w, &request);
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "==> Got %s %s\n",
+    DEBUGOUT(_LtDebug(__FILE__, w, "==> Got %s %s\n",
 		      _LtDebugGeometryResult2String(res),
 		      _LtDebugWidgetGeometry2String(&request)));
 
@@ -2448,29 +2458,29 @@ _XmScrolledWLayout(Widget w, Widget child, XtWidgetGeometry *childgeom,
 	SetMinimum((Widget)SW_VSB(w));
     }
 
-    DEBUGOUT(_LtDebugDebug0(__FILE__, w, "##############################\n"));
-    DEBUGOUT(_LtDebugDebug2(__FILE__, w, (Widget)SW_ClipWindow(w),
+    DEBUGOUT(_LtDebug0(__FILE__, w, "##############################\n"));
+    DEBUGOUT(_LtDebug2(__FILE__, w, (Widget)SW_ClipWindow(w),
 		       "Clip @ x %d y %d w %d h %d\n",
 		       vals->ClipX, vals->ClipY, vals->ClipW, vals->ClipH));
-    DEBUGOUT(_LtDebugDebug0(__FILE__, w,
+    DEBUGOUT(_LtDebug0(__FILE__, w,
 		       "HSB @ x %d y %d w %d h %d\n",
 		       vals->HsbX, vals->HsbY, vals->HsbW, vals->HsbH));
-    DEBUGOUT(_LtDebugDebug0(__FILE__, w,
+    DEBUGOUT(_LtDebug0(__FILE__, w,
 		       "VSB @ x %d y %d w %d h %d\n",
 		       vals->VsbX, vals->VsbY, vals->VsbW, vals->VsbH));
-    DEBUGOUT(_LtDebugDebug0(__FILE__, w,
+    DEBUGOUT(_LtDebug0(__FILE__, w,
 		       "HasHSB %s ShowHSB %s HasVSB %s ShowVSB %s\n",
 		       vals->HasHSB ? "True" : "False",
 		       vals->ShowHSB ? "True" : "False",
 		       vals->HasVSB ? "True" : "False",
 		       vals->ShowVSB ? "True" : "False"));
-    DEBUGOUT(_LtDebugDebug0(__FILE__, w,
+    DEBUGOUT(_LtDebug0(__FILE__, w,
 	      "MarginWidth %d MarginHeight %d ShadowThickness %d Spacing %d\n",
 		       SW_MarginWidth(w), SW_MarginHeight(w),
 		       MGR_ShadowThickness(w), SW_Spacing(w)));
-    DEBUGOUT(_LtDebugDebug0(__FILE__, w,
+    DEBUGOUT(_LtDebug0(__FILE__, w,
 		       "SwW %d SwH %d\n", vals->SwW, vals->SwH));
-    DEBUGOUT(_LtDebugDebug0(__FILE__, w, "##############################\n"));
+    DEBUGOUT(_LtDebug0(__FILE__, w, "##############################\n"));
 
     if (SW_ScrollPolicy(w) == XmAPPLICATION_DEFINED)
     {
@@ -2561,7 +2571,7 @@ _XmScrolledWLayout(Widget w, Widget child, XtWidgetGeometry *childgeom,
 	    childgeom->height = vals->VsbH;
 	}
 
-	DEBUGOUT(_LtDebugDebug2(__FILE__, w, child, "feedback => %s\n",
+	DEBUGOUT(_LtDebug2(__FILE__, w, child, "feedback => %s\n",
 			   _LtDebugWidgetGeometry2String(childgeom)));
     }
 }
@@ -2570,7 +2580,7 @@ void
 _XmConfigureScrollBars(Widget w, Widget child, XtWidgetGeometry *childgeom,
 		    XmSWValues *vals)
 {
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "%s:_XmConfigureScrollBars(%d)\n",
+    DEBUGOUT(_LtDebug(__FILE__, w, "%s:_XmConfigureScrollBars(%d)\n",
     	__FILE__, __LINE__));
     /* Don't display scrollbars unless the child is managed */
     if (SW_WorkWindow(w) && ! XtIsManaged(SW_WorkWindow(w)))
@@ -2619,7 +2629,7 @@ _XmConfigureScrollBars(Widget w, Widget child, XtWidgetGeometry *childgeom,
 	{
 	    if (XtIsManaged(SW_VSB(w)) && !vals->ShowVSB)
 	    {
-		DEBUGOUT(_LtDebugDebug2(__FILE__, w, (Widget)SW_VSB(w),
+		DEBUGOUT(_LtDebug2(__FILE__, w, (Widget)SW_VSB(w),
 				   "Unmanaging VSB\n"));
 
 		vals->VsbX = vals->SwW;
@@ -2658,7 +2668,7 @@ _XmConfigureScrollBars(Widget w, Widget child, XtWidgetGeometry *childgeom,
 	{
 	    if (vals->ShowVSB && !XtIsManaged(SW_VSB(w)))
 	    {
-		DEBUGOUT(_LtDebugDebug2(__FILE__, w, (Widget)SW_VSB(w),
+		DEBUGOUT(_LtDebug2(__FILE__, w, (Widget)SW_VSB(w),
 				   "Managing VSB\n"));
 
 		if (True || XtIsRealized(w))
@@ -2680,7 +2690,7 @@ _XmConfigureScrollBars(Widget w, Widget child, XtWidgetGeometry *childgeom,
 	{
 	    if (XtIsManaged(SW_HSB(w)) && !vals->ShowHSB)
 	    {
-		DEBUGOUT(_LtDebugDebug2(__FILE__, w, (Widget)SW_HSB(w),
+		DEBUGOUT(_LtDebug2(__FILE__, w, (Widget)SW_HSB(w),
 				   "Unmanaging HSB\n"));
 
 		vals->HsbY = vals->SwH;
@@ -2719,7 +2729,7 @@ _XmConfigureScrollBars(Widget w, Widget child, XtWidgetGeometry *childgeom,
 	{
 	    if (vals->ShowHSB && !XtIsManaged(SW_HSB(w)))
 	    {
-		DEBUGOUT(_LtDebugDebug2(__FILE__, w, (Widget)SW_HSB(w),
+		DEBUGOUT(_LtDebug2(__FILE__, w, (Widget)SW_HSB(w),
 				   "Managing HSB\n"));
 
 		if (True || XtIsRealized(w))
@@ -2743,20 +2753,20 @@ _XmScrolledWConfigureChildren(Widget w, Widget child,
 {
     if (_LtDebugInDebug(__FILE__, w))
     {
-	DEBUGOUT(_LtDebugDebug(__FILE__, w,
+	DEBUGOUT(_LtDebug(__FILE__, w,
 			  "_XmScrolledWConfigureChildren: Sw %dx%d\n",
 			  vals->SwW, vals->SwH));
-	DEBUGOUT(_LtDebugDebug0(__FILE__, w,
+	DEBUGOUT(_LtDebug0(__FILE__, w,
 			   "\t\tX\tY\tW\tH\n\tWork\t%d\t%d\t%d\t%d\n",
 			   vals->WorkX, vals->WorkY, vals->WorkW, vals->WorkH));
-	DEBUGOUT(_LtDebugDebug0(__FILE__, w,
+	DEBUGOUT(_LtDebug0(__FILE__, w,
 			   "\tClip\t%d\t%d\t%d\t%d\n",
 			   vals->ClipX, vals->ClipY, vals->ClipW, vals->ClipH));
-	DEBUGOUT(_LtDebugDebug0(__FILE__, w,
+	DEBUGOUT(_LtDebug0(__FILE__, w,
 			   "\tHsb\t%d\t%d\t%d\t%d\t%3s managed\n",
 			   vals->HsbX, vals->HsbY, vals->HsbW, vals->HsbH,
 			   (vals->ShowHSB && vals->HasHSB) ? "" : "not"));
-	DEBUGOUT(_LtDebugDebug0(__FILE__, w,
+	DEBUGOUT(_LtDebug0(__FILE__, w,
 			   "\tVsb\t%d\t%d\t%d\t%d\t%3s managed\n",
 			   vals->VsbX, vals->VsbY, vals->VsbW, vals->VsbH,
 			   (vals->ShowVSB && vals->HasVSB) ? "" : "not"));
@@ -3107,7 +3117,7 @@ XmScrolledWindowSetAreas(Widget widget,
 			 Widget v_scrollbar,
 			 Widget work_region)
 {
-    DEBUGOUT(_LtDebugDebug(__FILE__, widget, "XmScrolledWindowSetAreas() - %s %s %s\n",
+    DEBUGOUT(_LtDebug(__FILE__, widget, "XmScrolledWindowSetAreas() - %s %s %s\n",
 		      h_scrollbar ? XtName(h_scrollbar) : "NULL",
 		      v_scrollbar ? XtName(v_scrollbar) : "NULL",
 		      work_region ? XtName(work_region) : "NULL"));
