@@ -1,6 +1,6 @@
 /**
  *
- * $Id: SeparatoG.c,v 1.19 2001/05/14 22:23:34 dannybackx Exp $
+ * $Id: SeparatoG.c,v 1.21 2001/09/13 13:34:13 amai Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
  * Copyright (C) 1995-2001 LessTif Development Team
@@ -23,7 +23,7 @@
  *
  **/
 
-static const char rcsid[] = "$Id: SeparatoG.c,v 1.19 2001/05/14 22:23:34 dannybackx Exp $";
+static const char rcsid[] = "$Id: SeparatoG.c,v 1.21 2001/09/13 13:34:13 amai Exp $";
 
 #include <LTconfig.h>
 
@@ -118,7 +118,7 @@ static XmSyntheticResource cache_syn_resources[] =
 	_XmFromHorizontalPixels, _XmToHorizontalPixels
     }
 };
-/* *INDENT-OFF* */
+
 XmSeparatorGCacheObjClassRec xmSeparatorGCacheObjClassRec = {
     /* Object class part */
     {
@@ -228,6 +228,9 @@ static XmGadgetClassExtRec SeparatorGadgetClassExtRec = {
     /* size                      */ sizeof(XmGadgetClassExtRec),
     /* widget_baseline_proc      */ NULL, /* FIX ME */
     /* display_rect_proc         */ NULL, /* FIX ME */
+#if XmVERSION >= 2
+    /* margins_proc              */ NULL, /* FIX ME */
+#endif
 };
 #endif
 
@@ -284,7 +287,6 @@ XmSeparatorGadgetClassRec xmSeparatorGadgetClassRec = {
 	/* extension */ NULL
     },
 };
-/* *INDENT-ON* */
 
 
 WidgetClass xmSeparatorGadgetClass = (WidgetClass)&xmSeparatorGadgetClassRec;
@@ -303,7 +305,7 @@ secondary_object_create(Widget request,
     XmWidgetExtData ed;
     Cardinal size;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, new_w,
+    DEBUGOUT(_LtDebug(__FILE__, new_w,
 		      "SeparatorGCacheRec %s being initialized.\n",
 		      XtName(new_w)));
 
@@ -376,7 +378,7 @@ static void
 initialize_prehook(Widget request, Widget new_w,
 		   ArgList args, Cardinal *num_args)
 {
-    DEBUGOUT(_LtDebugDebug(__FILE__, new_w, "SeparatoG InitializePrehook\n"));
+    DEBUGOUT(_LtDebug(__FILE__, new_w, "SeparatoG InitializePrehook\n"));
 
     /*
      * We should allocate secondary object here, using _XmExtObjAlloc (to create
@@ -400,7 +402,7 @@ initialize_posthook(Widget request, Widget new_w,
 {
     XmWidgetExtData ext;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, new_w, "SeparatoG InitializePosthook\n"));
+    DEBUGOUT(_LtDebug(__FILE__, new_w, "SeparatoG InitializePosthook\n"));
 
     /* don't let the null fool you */
     SEPG_Cache(new_w) = (XmSeparatorGCacheObjPart *)
@@ -763,7 +765,7 @@ get_values_posthook(Widget new_w, ArgList args, Cardinal *num_args)
 static void
 expose(Widget w, XEvent *event, Region region)
 {
-    DEBUGOUT(_LtDebugDebug(__FILE__, w,
+    DEBUGOUT(_LtDebug(__FILE__, w,
 		      "XmSeparatorGadget %s Expose (shadowThickness %d)\n",
 		      XtName(w), G_ShadowThickness(w)));
 
