@@ -1,9 +1,9 @@
 /**
  *
- * $Header: /cvsroot/lesstif/lesstif/lib/Xm/Text.c,v 1.149 2001/05/21 08:36:52 amai Exp $
+ * $Header: /cvsroot/lesstif/lesstif/lib/Xm/Text.c,v 1.161 2002/05/11 17:58:04 dannybackx Exp $
  *
  * Copyright (C) 1997 Free Software Foundation, Inc.
- * Copyright (C) 1997-2001 LessTif Development Team
+ * Copyright  1997, 1998, 1999, 2000, 2001, 2002 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -23,16 +23,20 @@
  *
  **/
 
-static const char rcsid[] = "$Id: Text.c,v 1.149 2001/05/21 08:36:52 amai Exp $";
+static const char rcsid[] = "$Id: Text.c,v 1.161 2002/05/11 17:58:04 dannybackx Exp $";
 
 #undef VERBOSE
 
 #include <LTconfig.h>
 
+#include <stdio.h>
 #include <string.h>
 #include <stdlib.h>
 #include <stddef.h>    /* for  wchar_t */
 #include <limits.h>    /* for INT_MAX */
+#ifdef HAVE_WCHAR_H
+#include <wchar.h>
+#endif
 
 #include <Xm/XmP.h>
 #include <Xm/TextP.h>
@@ -61,47 +65,29 @@ static const char rcsid[] = "$Id: Text.c,v 1.149 2001/05/21 08:36:52 amai Exp $"
 #include <XmI/DebugUtil.h>
 
 
-#define _XmMin(a,b)  ((a) < (b)) ? (a) : (b)
-#define _XmMax(a,b)  ((a) > (b)) ? (a) : (b)
-
 /* Forward Declarations */
 
 static void ClassInitialize(void);
-
 static void ClassPartInitialize(WidgetClass widget_class);
-
 static void Initialize(Widget request, Widget new_w,
 		       ArgList args, Cardinal *num_args);
-
 static void Destroy(Widget w);
-
 static void Resize(Widget w);
-
 static void Realize(Widget w, XtValueMask *value_mask,
 		    XSetWindowAttributes *attributes);
-
 static void DoExpose(Widget w, XEvent *event, Region region);
-
 static XtGeometryResult query_geometry(Widget w,
 				      XtWidgetGeometry *proposed,
 				      XtWidgetGeometry *answer);
-
 static void _XmTextSetEditable(Widget w, Boolean e);
-
 static Boolean SetValues(Widget current, Widget request, Widget new_w,
 			 ArgList args, Cardinal *num_args);
-
 static void RefigureLines(XmTextWidget w);
-
 static void InitializeLineTable(XmTextWidget w);
-
 static Cardinal GetSecResData(WidgetClass wc,
 			      XmSecondaryResourceData **resdata);
-
 static OutputCreateProc output_create = _XmTextOutputCreate;
-
 static InputCreateProc input_create = _XmTextInputCreate;
-
 void _XmTextInvalidate(XmTextWidget w, XmTextPosition position,
 		       XmTextPosition topos, long delta);
 void _XmTextExportValue(Widget w, int offset, XtArgVal *value);
@@ -180,7 +166,7 @@ static XtResource resources[] =
     {
 	XmNvalue, XmCValue, XmRString,
 	sizeof(String), Offset(value),
-	XmRString, (XtPointer)"" /*NULL*/
+	XmRString, (XtPointer)NULL
     },
     {
 	XmNvalueWcs, XmCValueWcs, XmRValueWcs,
@@ -372,7 +358,7 @@ WidgetClass xmTextWidgetClass = (WidgetClass)&xmTextClassRec;
 static void
 InnerInitialize(Widget request, Widget new_w, ArgList args, Cardinal *num_args)
 {
-    DEBUGOUT(_LtDebugDebug(__FILE__, new_w,
+    DEBUGOUT(_LtDebug(__FILE__, new_w,
 		      "InnerInitialize: %i args\n"
 		      "\trequest X %5i Y %5i W %5i H %5i\n"
 		      "\t  new_w X %5i Y %5i W %5i H %5i\n",
@@ -393,7 +379,7 @@ InnerDestroy(Widget w)
 {
     /* Destroy Output and Input */
     /* Nah - already done in XmText's destroy method (Destroy). */
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "InnerDestroy\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "InnerDestroy\n"));
 }
 
 /*
@@ -405,7 +391,7 @@ InnerSetValues(Widget old, Widget request, Widget new_w,
 {
     Boolean refresh_needed = False;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, new_w,
+    DEBUGOUT(_LtDebug(__FILE__, new_w,
 		      "InnerSetValues: %i args\n"
 		      "\t    old X %5i Y %5i W %5i H %5i\n"
 		      "\trequest X %5i Y %5i W %5i H %5i\n"
@@ -478,13 +464,7 @@ WidgetClass xmTextInnerObjectClass = (WidgetClass)&xmTextInnerClassRec;
 static void
 ClassInitialize(void)
 {
-    int len1 = strlen(_XmTextIn_XmTextEventBindings1);
-    int len2 = strlen(_XmTextIn_XmTextEventBindings2);
-    int len3 = strlen(_XmTextIn_XmTextEventBindings3);
-    char *buf = XtMalloc((unsigned)(len1 + len2 + len3 + 1));
-    char *cp = buf;
-
-    DEBUGOUT(_LtDebugDebug(__FILE__, NULL, "ClassInitialize\n"));
+    DEBUGOUT(_LtDebug(__FILE__, NULL, "ClassInitialize\n"));
 
     textBaseClassExtRec.record_type = XmQmotif;
     xmTextClassRec.core_class.actions =
@@ -492,20 +472,10 @@ ClassInitialize(void)
 
     xmTextClassRec.core_class.num_actions = _XmdefaultTextActionsTableSize;
 
-    (void)strcpy(cp, _XmTextIn_XmTextEventBindings1);
-    cp += len1;
-
-    (void)strcpy(cp, _XmTextIn_XmTextEventBindings2);
-    cp += len2;
-
-    (void)strcpy(cp, _XmTextIn_XmTextEventBindings3);
-
-    xmTextClassRec.core_class.tm_table = buf;
-
 #if XmVERSION > 1
     if (!XmeTraitSet((XtPointer)xmTextWidgetClass, XmQTaccessTextual,
                      (XtPointer) &_XmTextTraitRec)) {
-	DEBUGOUT(_LtDebugDebug(__FILE__, NULL,
+	DEBUGOUT(_LtDebug(__FILE__, NULL,
 		"ClassInitialize: XmeTraitSet failed\n"));
     }
 #endif
@@ -515,7 +485,29 @@ ClassInitialize(void)
 static void
 ClassPartInitialize(WidgetClass widget_class)
 {
-    DEBUGOUT(_LtDebugDebug(__FILE__, NULL, "ClassPartInitialize\n"));
+    int len1 = strlen(_XmTextIn_XmTextEventBindings1);
+    int len2 = strlen(_XmTextIn_XmTextEventBindings2);
+    int len3 = strlen(_XmTextIn_XmTextEventBindings3);
+    char *buf = XtMalloc((unsigned)(len1 + len2 + len3 + 1));
+    char *cp = buf;
+
+    DEBUGOUT(_LtDebug(__FILE__, NULL, "ClassPartInitialize\n"));
+
+    /* Moved from ClassInitialize because the Xt routine
+     * CoreClassPartInitialize (Xt/Core.c) will overwrite
+     * the original core_class.tm_table, thus leaking any
+     * malloc'd buffer assigned to tm_table.
+     */
+    (void)strcpy(cp, _XmTextIn_XmTextEventBindings1);
+    cp += len1;
+    (void)strcpy(cp, _XmTextIn_XmTextEventBindings2);
+    cp += len2;
+    (void)strcpy(cp, _XmTextIn_XmTextEventBindings3);
+
+    xmTextClassRec.core_class.tm_table = (String)XtParseTranslationTable(buf);
+
+    XtFree(buf);
+
     _XmFastSubclassInit(widget_class, XmTEXT_BIT);
 }
 
@@ -530,7 +522,7 @@ Initialize(Widget request, Widget new_w,
     Arg ds_args[6];
     int n = 0;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, new_w,
+    DEBUGOUT(_LtDebug(__FILE__, new_w,
 		      "initialize: %i args\n"
 		      "\trequest X %5i Y %5i W %5i H %5i\n"
 		      "\t  new   X %5i Y %5i W %5i H %5i\n",
@@ -638,20 +630,16 @@ Initialize(Widget request, Widget new_w,
 	if ( vendor )
 	    Text_VerifyBell(w) = _XmGetAudibleWarning(vendor);
 	}
-    if ( strlen ( Text_Value(w) ) != 0 || passedSourceAsArg )
+
+    if ( (Text_Value(w) && strlen(Text_Value(w))> 0) || passedSourceAsArg )
 	{
 	_XmTextUpdateLineTable( (Widget)w, 0, strlen( Text_Value(w) ),
 		       NULL, True /* it is unused */ );
 	Text_BottomPos(w) = Text_LineTable(w)[Text_LineCount(w)].start_pos;
 	Text_Repaint(w).range[0].to = Text_BottomPos(w);
-
-	/*CP: but the value attribute is a hangover of M*tif 1.1
-		and seems to be unused in 1.2. SO free it. */
-	if (strlen(Text_Value(w)) == 0)
-		XtFree ( (char*) Text_Value(w) );
-
-	Text_Value(w) = NULL;
 	}
+     Text_Value(w) = NULL; /* amai: FIX ME! We should check for value! */
+     Text_WcsValue(w) = NULL; /* amai: FIX ME! We should check for value! */
 
     /* initialize default DropSite */
     import_target[0] = XmInternAtom(XtDisplay(new_w), _XA_COMPOUND_TEXT, False);
@@ -669,7 +657,7 @@ Initialize(Widget request, Widget new_w,
 static void
 Destroy(Widget w)
 {
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "Destroy\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "Destroy\n"));
 
 #if XmVERSION > 1
     XmImCloseXIM(w);
@@ -709,7 +697,7 @@ SetValues(Widget old, Widget request, Widget new_w,
     XmTextWidget nw = (XmTextWidget)new_w;
     XmTextWidget ow = (XmTextWidget)old;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, new_w,
+    DEBUGOUT(_LtDebug(__FILE__, new_w,
 		      "set_values: %i args\n"
 		      "\t    old X %5i Y %5i W %5i H %5i\n"
 		      "\trequest X %5i Y %5i W %5i H %5i\n"
@@ -725,24 +713,41 @@ SetValues(Widget old, Widget request, Widget new_w,
 
     Text_InSetValues(nw) = True;
 
-    if (Text_Value(nw) != Text_Value(ow))
-    {
-	XmTextSetString(new_w, Text_Value(new_w));
+	if (nw->core.sensitive != ow->core.sensitive) {
+		OutputData o = Text_OutputData(new_w);
+		XGCValues	v;
+		int		m;
 
-	refresh_needed = True;
-    }
+		if (! nw->core.sensitive) {
+			m = GCFillStyle | GCStipple;
+			v.fill_style = FillStippled;
+			v.stipple = XmGetPixmapByDepth(XtScreen(new_w), "50_foreground", 1, 0, 1);
+		} else {
+			m = GCFillStyle;
+			v.fill_style = FillSolid;
+		}
 
-    if (Text_WcsValue(nw) != Text_WcsValue(ow))
+		if (XtIsRealized(new_w))
+			XChangeGC(XtDisplay(new_w), Out_DrawGC(o), m, &v);
+		refresh_needed = True;
+	}
+
+    if (Text_WcsValue(nw))
     {
 	XmTextSetStringWcs(new_w, Text_WcsValue(new_w));
-
+	Text_WcsValue(nw) = NULL;
+	refresh_needed = True;
+    } else if (Text_Value(nw))
+    {
+	XmTextSetString(new_w, Text_Value(new_w));
+	Text_Value(nw) = NULL;
 	refresh_needed = True;
     }
 
+
     if (Text_Editable(nw) != Text_Editable(ow))
     {
 	_XmTextSetEditable(new_w, Text_Editable(nw));
-
 	refresh_needed = True;
     }
 
@@ -820,7 +825,7 @@ Realize(Widget aw, XtValueMask *value_mask, XSetWindowAttributes *attributes)
 {
     XmTextWidget w = (XmTextWidget)aw;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, aw, "%s:Realize(%d) - valuemask 0x%X - %dx%d\n",
+    DEBUGOUT(_LtDebug(__FILE__, aw, "%s:Realize(%d) - valuemask 0x%X - %dx%d\n",
     		__FILE__, __LINE__, *value_mask,
     		XtWidth(aw), XtHeight(aw)));
 
@@ -852,7 +857,7 @@ DoExpose(Widget aw, XEvent *event, Region region)
 	return;
     }
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, aw, "DoExpose\n"));
+    DEBUGOUT(_LtDebug(__FILE__, aw, "DoExpose\n"));
     if (Text_DisableDepth(w) != 0)
 	return;		/* Should we be doing this ? FIX ME */
 
@@ -881,7 +886,7 @@ Resize(Widget aw)
 {
     XmTextWidget w = (XmTextWidget)aw;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, aw, "%s:resize(%d) - %dx%d\n",
+    DEBUGOUT(_LtDebug(__FILE__, aw, "%s:resize(%d) - %dx%d\n",
     		__FILE__, __LINE__,
     		XtWidth(aw), XtHeight(aw)));
 
@@ -916,7 +921,7 @@ query_geometry(Widget w, XtWidgetGeometry *proposed, XtWidgetGeometry *answer)
     XtWidgetGeometry a;
 
 #define Wants(x)   (proposed->request_mode & x)
-    DEBUGOUT(_LtDebugDebug(__FILE__, w,
+    DEBUGOUT(_LtDebug(__FILE__, w,
 		      "query_geometry proposed width=%d height=%d mode=%X\n",
 		   proposed->width, proposed->height, proposed->request_mode));
 
@@ -967,7 +972,7 @@ query_geometry(Widget w, XtWidgetGeometry *proposed, XtWidgetGeometry *answer)
 	return XtGeometryAlmost;
     }
 #else
-    DEBUGOUT(_LtDebugDebug(__FILE__, w,
+    DEBUGOUT(_LtDebug(__FILE__, w,
 		      "query_geometry proposed width=%d height=%d mode=%X\n",
 		   proposed->width, proposed->height, proposed->request_mode));
 
@@ -984,7 +989,7 @@ query_geometry(Widget w, XtWidgetGeometry *proposed, XtWidgetGeometry *answer)
 static void
 Redisplay(XmTextWidget w)
 {
-    DEBUGOUT(_LtDebugDebug(__FILE__, (Widget)w, "Redisplay\n"));
+    DEBUGOUT(_LtDebug(__FILE__, (Widget)w, "Redisplay\n"));
 
     if (Text_DisableDepth(w) != 0)
 	return;
@@ -1030,7 +1035,7 @@ GetSecResData(WidgetClass wc, XmSecondaryResourceData **resdata)
 static void
 LineIncrease(XmTextWidget w, LineNum num)
 {
-    DEBUGOUT(_LtDebugDebug(__FILE__, (Widget)w, "LineIncrease %d\n",num));
+    DEBUGOUT(_LtDebug(__FILE__, (Widget)w, "LineIncrease %d\n",num));
     if (num > Text_LineMax(w))
     {
 	LineNum start = Text_LineMax(w);
@@ -1076,7 +1081,7 @@ RefigureLines(XmTextWidget w)
     LineTableExtra extra;
     Boolean more;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, (Widget)w, "RefigureLines\n"));
+    DEBUGOUT(_LtDebug(__FILE__, (Widget)w, "RefigureLines\n"));
 /*
  * DisableDepth is meant to optimize frequent updates to XmText.
  * This probably means we shouldn't do anything here ...
@@ -1099,7 +1104,7 @@ RefigureLines(XmTextWidget w)
 				   Text_LineTable(w)[i].start_pos != 0);
 	 i++)
     {
-	DEBUGOUT(_LtDebugDebug(__FILE__, w,
+	DEBUGOUT(_LtDebug(__FILE__, (Widget)w,
 			  "RefigureLines: [%d] start_pos %d virt %d\n",
 			  i, Text_LineTable(w)[i].start_pos,
 			  Text_LineTable(w)[i].virt_line));
@@ -1200,21 +1205,21 @@ RefigureLines(XmTextWidget w)
 
 	    if (line->extra)
 	    {
-		DEBUGOUT(_LtDebugDebug(__FILE__, (Widget)w,
+		DEBUGOUT(_LtDebug(__FILE__, (Widget)w,
 				"RefigureLines: line[%d]: start=%d width=%d\n",
 				  i, line->start, line->extra->width));
 	    }
 	    else
 	    {
-		DEBUGOUT(_LtDebugDebug(__FILE__, (Widget)w,
+		DEBUGOUT(_LtDebug(__FILE__, (Widget)w,
 				"RefigureLines: line[%d]: start=%d width=NA\n",
 				  i, line->start));
 	    }
 	}
     }
 
-#if VERBOSE
-    DEBUGOUT(_LtDebugDebug(__FILE__, (Widget)w,
+#ifdef VERBOSE
+    DEBUGOUT(_LtDebug(__FILE__, (Widget)w,
 		      "RefigureLines: top on line %d, bottompos %d\n",
 		      i, Text_BottomPos(w)));
 #endif
@@ -1288,7 +1293,7 @@ _XmTextUpdateLineTable(Widget w,
     unsigned int index;
     Boolean wrap = _XmTextShouldWordWrap(tw), next_is_virtual;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "_XmTextUpdateLineTable start %d end %d\n",
+    DEBUGOUT(_LtDebug(__FILE__, w, "_XmTextUpdateLineTable start %d end %d\n",
     		start, end));
     Text_NeedsRefigureLines(w) = True;
     Text_NeedsRedisplay(w) = True;
@@ -1317,7 +1322,7 @@ _XmTextUpdateLineTable(Widget w,
 
     end = Text_LastPos(w);
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, (Widget)w,
+    DEBUGOUT(_LtDebug(__FILE__, (Widget)w,
 		      "_XmTextUpdateLineTable(start %d end %d update %s) %s\n",
 		      start, end, _LtDebugBoolean2String(update),
 		      wrap ? "wrap" : ""));
@@ -1371,7 +1376,7 @@ _XmTextUpdateLineTable(Widget w,
 	max_cols = max_cols < Out_ColumnsSet(od) ? Out_ColumnsSet(od) : max_cols;
 	max_lines = max_lines < Out_RowsSet(od) ? Out_RowsSet(od) : max_lines;
 
-	DEBUGOUT(_LtDebugDebug(__FILE__, (Widget)w,
+	DEBUGOUT(_LtDebug(__FILE__, (Widget)w,
 		      "_XmTextUpdateLineTable - %d %d %d %d\n",
 		      max_lines, max_cols, Out_Rows(od), Out_Columns(od)));
     	XtFree(value);
@@ -1440,7 +1445,7 @@ _XmTextUpdateLineTable(Widget w,
 		    line->start_pos = start;
 		    line->virt_line = next_is_virtual;
 
-		    DEBUGOUT(_LtDebugDebug(__FILE__, (Widget)w,
+		    DEBUGOUT(_LtDebug(__FILE__, (Widget)w,
 		       "_XmTextUpdateLineTable: line %d start %d virtual %d\n",
 				      index, line->start_pos, line->virt_line));
 
@@ -1551,8 +1556,8 @@ _XmTextGetTableIndex(XmTextWidget w, XmTextPosition pos)
 
     for (; current->start_pos > pos; current--, i--);
 
-#if VERBOSE
-    DEBUGOUT(_LtDebugDebug(__FILE__, (Widget)w,
+#ifdef VERBOSE
+    DEBUGOUT(_LtDebug(__FILE__, (Widget)w,
 		      "XmTextGetTableIndex Pos %d Index %d\n", pos, i));
 #endif
 
@@ -1603,7 +1608,7 @@ _XmTextInsert(Widget w, XmTextPosition position, char *string, XEvent *evp)
     XmTextBlockRec block;
     XmTextPosition startret, endret;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "_XmTextInsert\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "_XmTextInsert\n"));
 
     if (XtIsSubclass(w, xmTextFieldWidgetClass))
     {
@@ -1652,7 +1657,7 @@ _XmTextSetCursorPosition(Widget w, XmTextPosition position)
     cbs.doit = True;
     cbs.newInsert = position;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, (Widget)w,
+    DEBUGOUT(_LtDebug(__FILE__, (Widget)w,
 		      "_XmTextSetCursorPosition Pos %d \n",
 		      position));
 
@@ -1677,8 +1682,8 @@ _XmTextSetCursorPosition(Widget w, XmTextPosition position)
 
     if (cbs.doit)
     {
-#if VERBOSE
-	DEBUGOUT(_LtDebugDebug(__FILE__, (Widget)w,
+#ifdef VERBOSE
+	DEBUGOUT(_LtDebug(__FILE__, (Widget)w,
 			  "Text_CursorPos before draw: %08x\n",
 			  Text_CursorPos(w)));
 #endif
@@ -1694,8 +1699,8 @@ _XmTextSetCursorPosition(Widget w, XmTextPosition position)
 	Text_CursorPos(w) = position;
 #endif
 
-#if VERBOSE
-	DEBUGOUT(_LtDebugDebug(__FILE__, (Widget)w,
+#ifdef VERBOSE
+	DEBUGOUT(_LtDebug(__FILE__, (Widget)w,
 			  "Text_CursorPos after draw: %08x\n",
 			  Text_CursorPos(w)));
 #endif
@@ -1722,7 +1727,7 @@ _XmTextSetCursorPosition(Widget w, XmTextPosition position)
 static void
 _XmTextSetEditable(Widget w, Boolean e)
 {
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "_XmTextSetEditable()\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "_XmTextSetEditable()\n"));
 
     if (!XtIsRealized(w))
     {
@@ -2436,7 +2441,7 @@ XmTextPaste(Widget w)
 	    XtFree(buf);
 	    return False;
 	}
-	DEBUGOUT(_LtDebugDebug(__FILE__, w,
+	DEBUGOUT(_LtDebug(__FILE__, w,
 	    "XmTextPaste: should be getting %ld bytes\n", nbytes));
 
 	while ((r = XmClipboardEndRetrieve(dpy, win)) == XmClipboardLocked)
@@ -2535,7 +2540,7 @@ XmTextReplace(Widget w, XmTextPosition from_pos, XmTextPosition to_pos, char *va
 	return;
     }
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "XmTextReplace(from %d to %d '%s'\n",
+    DEBUGOUT(_LtDebug(__FILE__, w, "XmTextReplace(from %d to %d '%s'\n",
 		      from_pos, to_pos, value));
 
     block.ptr = value;
@@ -2649,7 +2654,7 @@ XmTextSetHighlight(Widget w, XmTextPosition left, XmTextPosition right, XmHighli
     if (left >= right || left < 0 )
     {
 	/* FIX ME */
-	DEBUGOUT(_LtDebugDebug(__FILE__, w,
+	DEBUGOUT(_LtDebug(__FILE__, w,
 			  "XmTextSetHighlight %d >= %d, not sure what to do.\n",
 			  left, right));
 
@@ -2666,7 +2671,7 @@ XmTextSetHighlight(Widget w, XmTextPosition left, XmTextPosition right, XmHighli
 			  "XmTextSetHighlight(%d,%d,%s)\n",
 			  left, right, _LtDebugHighlightMode2String(mode));
 #endif
-	DEBUGOUT(_LtDebugDebug(__FILE__, w,
+	DEBUGOUT(_LtDebug(__FILE__, w,
 			  "XmTextSetHighlight(%d,%d,%s)\n",
 			  left, right, _LtDebugHighlightMode2String(mode)));
 
@@ -2838,7 +2843,7 @@ extern void
 XmTextSetSelection(Widget w, XmTextPosition first, XmTextPosition last,
 		   Time time)
 {
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "XmTextSetSelection(%d,%d)\n", first, last));
+    DEBUGOUT(_LtDebug(__FILE__, w, "XmTextSetSelection(%d,%d)\n", first, last));
 
     if (XtIsSubclass(w, xmTextWidgetClass))
     {
@@ -2885,7 +2890,7 @@ XmTextSetString(Widget w, char *value)
 #endif
 	Text_CursorPos(w) = 0;
 
-	DEBUGOUT(_LtDebugDebug(__FILE__, w, "XmTextSetString(%s), lastpos %d\n",
+	DEBUGOUT(_LtDebug(__FILE__, w, "XmTextSetString(%s), lastpos %d\n",
 		value, Text_LastPos(w)));
 
 	_XmTextUpdateLineTable(w, 0, 0, NULL, False);
@@ -2952,7 +2957,7 @@ XmTextSetSource(Widget w, XmTextSource s,
 {
     XmTextWidget tw = (XmTextWidget)w;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "XmTextSetSource\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "XmTextSetSource\n"));
 
     if (s == NULL)
     {
@@ -3002,7 +3007,7 @@ XmTextScroll(Widget aw, int n)
    we would rather like to be able to scroll down to the last line */
 		       Text_TotalLines(w) ) - Text_LineCount(w) + 1;
     }
-    DEBUGOUT(_LtDebugDebug(__FILE__, aw, "XmTextScroll index=%d n=%d\n", index, n));
+    DEBUGOUT(_LtDebug(__FILE__, aw, "XmTextScroll index=%d n=%d\n", index, n));
 
     Text_TableIndex(w) = index;
     XmTextSetTopCharacter(aw, Text_LineTable(w)[index].start_pos);
@@ -3019,7 +3024,7 @@ XmTextSetTopCharacter(Widget w, XmTextPosition top_character)
 	return;
     }
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "XmTextSetTopCharacter top_character=%d\n",
+    DEBUGOUT(_LtDebug(__FILE__, w, "XmTextSetTopCharacter top_character=%d\n",
 		      top_character));
 
     if (Text_EditMode(w) == XmSINGLE_LINE_EDIT)
@@ -3055,7 +3060,7 @@ XmTextShowPosition(Widget aw, XmTextPosition position)
     XmTextWidget w = (XmTextWidget)aw;
     unsigned int top_index, index, bottom_index;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, aw, "XmTextShowPosition pos=%d\n", position));
+    DEBUGOUT(_LtDebug(__FILE__, aw, "XmTextShowPosition pos=%d\n", position));
 
     if (XtIsSubclass(aw, xmTextFieldWidgetClass))
     {
@@ -3105,7 +3110,7 @@ XmTextShowPosition(Widget aw, XmTextPosition position)
 extern XmTextPosition
 XmTextXYToPos(Widget w, Position x, Position y)
 {
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "XmTextXYToPos x=%d y=%d\n", x, y));
+    DEBUGOUT(_LtDebug(__FILE__, w, "XmTextXYToPos x=%d y=%d\n", x, y));
 
     if (XtIsSubclass(w, xmTextFieldWidgetClass))
     {
@@ -3127,7 +3132,7 @@ _XmTextExportValue(Widget w, int offset, XtArgVal *value)
 {
     *value = (XtArgVal)XmTextGetString(w);
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, w,
+    DEBUGOUT(_LtDebug(__FILE__, w,
 		      "_XmTextExportValue: value '%s'\n",
 		      (char *)*value));
 }
@@ -3162,7 +3167,7 @@ TextGetValues(Widget w, ArgList args, Cardinal *num_args)
     }
 
     /* Be verbose about what they're trying to find out */
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "TextGetValues :\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "TextGetValues :\n"));
     DEBUGOUT(_LtDebugPrintArgList(__FILE__, w, args, *num_args, True));
 }
 
@@ -3218,7 +3223,7 @@ _XmTextNumLines(XmTextWidget widget)
 static XtPointer
 _XmText_TraitGetValue(Widget w, int format)
 {
-	DEBUGOUT(_LtDebugDebug(__FILE__, w, "_XmText_TraitGetValue(%s)\n",
+	DEBUGOUT(_LtDebug(__FILE__, w, "_XmText_TraitGetValue(%s)\n",
 		(format == XmFORMAT_XmSTRING) ? "XmFORMAT_XmSTRING" :
 		(format == XmFORMAT_MBYTE) ? "XmFORMAT_MBYTE" :
 		(format == XmFORMAT_WCS) ? "XmFORMAT_WCS" : "??"));
@@ -3241,7 +3246,7 @@ _XmText_TraitSetValue(Widget w, XtPointer value, int format)
 {
 	char    *s;
 
-	DEBUGOUT(_LtDebugDebug(__FILE__, w, "_XmText_TraitSetValue(%s)\n",
+	DEBUGOUT(_LtDebug(__FILE__, w, "_XmText_TraitSetValue(%s)\n",
 		(format == XmFORMAT_XmSTRING) ? "XmFORMAT_XmSTRING" :
 		(format == XmFORMAT_MBYTE) ? "XmFORMAT_MBYTE" :
 		(format == XmFORMAT_WCS) ? "XmFORMAT_WCS" : "??"));
@@ -3269,7 +3274,7 @@ _XmText_TraitSetValue(Widget w, XtPointer value, int format)
 static int
 _XmText_TraitPreferredFormat(Widget w)
 {
-	DEBUGOUT(_LtDebugDebug(__FILE__, w, "_XmText_TraitPreferredFormat\n"));
+	DEBUGOUT(_LtDebug(__FILE__, w, "_XmText_TraitPreferredFormat\n"));
 
 	return XmFORMAT_WCS;
 }
