@@ -1,9 +1,9 @@
 /**
  *
- * $Header: /cvsroot/lesstif/lesstif/lib/Xm/TextIn.c,v 1.71 2001/05/28 15:05:30 amai Exp $
+ * $Header: /cvsroot/lesstif/lesstif/lib/Xm/TextIn.c,v 1.75 2001/11/26 19:40:24 dannybackx Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
- * Copyright (C) 1995-2001 LessTif Development Team
+ * Copyright  1995, 1996, 1997, 1998, 1999, 2000, 2001 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -23,7 +23,7 @@
  *
  **/
 
-static const char rcsid[] = "$Header: /cvsroot/lesstif/lesstif/lib/Xm/TextIn.c,v 1.71 2001/05/28 15:05:30 amai Exp $";
+static const char rcsid[] = "$Header: /cvsroot/lesstif/lesstif/lib/Xm/TextIn.c,v 1.75 2001/11/26 19:40:24 dannybackx Exp $";
 
 #include <LTconfig.h>
 
@@ -233,8 +233,6 @@ static void VoidAction(Widget w, XEvent *ev, String *params,
 static void UnKill(Widget w, XEvent *ev, String *params,
 		   Cardinal *num_params);
 
-extern void LineTable(XmTextWidget w);
-
 static Boolean drag_convert_proc(Widget w, Atom *selection,
 				 Atom *target, Atom *type_return,
 				 XtPointer *value_return,
@@ -249,8 +247,8 @@ static void drag_drop_finish(Widget w,
 			     XtPointer client_data,
 			     XtPointer call_data);
 
-
-extern void _XmImSendSpot(Widget w);
+static void _KeySelection(Widget w, XEvent *ev, int flag,
+                          String *params, Cardinal *np);
 
 #define Offset(field) XtOffsetOf(XmTextInnerRec, inner.in.field)
 
@@ -407,7 +405,7 @@ InputGetValues(Widget w, ArgList args, Cardinal num_args)
 		   input_resources, XtNumber(input_resources),
 		   args, num_args);
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "InputGetValues :\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "InputGetValues :\n"));
 
     _LtDebugPrintArgList(__FILE__, w, args, num_args, True);
 }
@@ -424,7 +422,7 @@ static void
 InputSetValues(Widget old, Widget request, Widget new_w,
 	       ArgList args, Cardinal *num_args)
 {
-    DEBUGOUT(_LtDebugDebug(__FILE__, new_w, "InputSetValues :\n"));
+    DEBUGOUT(_LtDebug(__FILE__, new_w, "InputSetValues :\n"));
 
     DEBUGOUT(_LtDebugPrintArgList(__FILE__, new_w, args, *num_args, False));
 
@@ -441,7 +439,7 @@ InputDestroy(Widget aw)
 {
     XmTextWidget w = (XmTextWidget)aw;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, aw, "InputDestroy\n"));
+    DEBUGOUT(_LtDebug(__FILE__, aw, "InputDestroy\n"));
 
     (*Text_Source(w)->RemoveWidget) (Text_Source(w), w);
 
@@ -508,7 +506,7 @@ _XmTextInputCreate(Widget aw, ArgList args, Cardinal num_args)
     i->extendDir = XmsdRight;
     i->cancel = True;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, aw,
+    DEBUGOUT(_LtDebug(__FILE__, aw,
 		      "_XmTextInputCreate (selectionArrayCount %d)\n",
 		      In_SelArrayCount(i)));
 
@@ -557,7 +555,7 @@ ScanType(XmTextWidget w)
 	}
     }
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, (Widget)w,
+    DEBUGOUT(_LtDebug(__FILE__, (Widget)w,
 		      "ScanType(%d) -> %s\n", In_SelArray(i),
 		      (type == XmSELECT_WORD) ? "XmSELECT_WORD" :
 		      (type == XmSELECT_LINE) ? "XmSELECT_LINE" :
@@ -779,7 +777,7 @@ DoInsert(XmTextWidget w, XEvent *ev, char *buf, int len)
         cbs.newInsert = cbs.currInsert;
     }
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, (Widget)w,
+    DEBUGOUT(_LtDebug(__FILE__, (Widget)w,
 		      "DoInsert before CB: CursorPos %08x len %08x\n",
 		      Text_CursorPos(w), len));
 
@@ -803,7 +801,7 @@ DoInsert(XmTextWidget w, XEvent *ev, char *buf, int len)
 
 	start = cbs.startPos;
 	end = cbs.endPos;
-	DEBUGOUT(_LtDebugDebug(__FILE__, (Widget)w,
+	DEBUGOUT(_LtDebug(__FILE__, (Widget)w,
 			  "DoInsert: start %08x:%08x end %08x:%08x\n",
 			  start, cbs.startPos, end, cbs.endPos));
 	status = (*Text_Source(w)->Replace) (w, ev, &start,
@@ -839,7 +837,7 @@ DoScanType(XmTextWidget w, XEvent *ev, XmTextPosition pos)
     switch (st)
     {
     case XmSELECT_POSITION:
-	DEBUGOUT(_LtDebugDebug(__FILE__, (Widget)w,
+	DEBUGOUT(_LtDebug(__FILE__, (Widget)w,
 			  "DoScanType: XmSELECT_POSITION\n"));
 
 	_XmTextSetCursorPosition((Widget)w, pos);
@@ -857,7 +855,7 @@ DoScanType(XmTextWidget w, XEvent *ev, XmTextPosition pos)
 					XmsdLeft, 1, False);
         In_HighlightPivot(i) = left;
 
-	DEBUGOUT(_LtDebugDebug(__FILE__, (Widget)w,
+	DEBUGOUT(_LtDebug(__FILE__, (Widget)w,
 		       "DoScanType: XmSELECT_WORD (left %d pos %d right %d)\n",
 			  left, pos, right));
 
@@ -872,7 +870,7 @@ DoScanType(XmTextWidget w, XEvent *ev, XmTextPosition pos)
 					XmsdLeft, 1, False);
         In_HighlightPivot(i) = left;
 
-	DEBUGOUT(_LtDebugDebug(__FILE__, (Widget)w,
+	DEBUGOUT(_LtDebug(__FILE__, (Widget)w,
 		       "DoScanType: XmSELECT_LINE (left %d pos %d right %d)\n",
 			  left, pos, right));
 
@@ -881,7 +879,7 @@ DoScanType(XmTextWidget w, XEvent *ev, XmTextPosition pos)
 
 #if	XmVERSION > 1
     case XmSELECT_OUT_LINE:	/* Motif 2.* feature - unimplemented here */
-	DEBUGOUT(_LtDebugDebug(__FILE__, (Widget)w,
+	DEBUGOUT(_LtDebug(__FILE__, (Widget)w,
 			  "DoScanType: XmSELECT_OUT_LINE\n"));
 	break;
 #endif
@@ -890,7 +888,7 @@ DoScanType(XmTextWidget w, XEvent *ev, XmTextPosition pos)
 	In_HighlightPivot(i) = left = 0;
 	right = XmTextGetLastPosition((Widget)w);
 
-	DEBUGOUT(_LtDebugDebug(__FILE__, (Widget)w,
+	DEBUGOUT(_LtDebug(__FILE__, (Widget)w,
 			"DoScanType: XmSELECT_ALL (left %d pos %d right %d)\n",
 			  left, pos, right));
  
@@ -899,7 +897,7 @@ DoScanType(XmTextWidget w, XEvent *ev, XmTextPosition pos)
 	break;
 
     default:
-	DEBUGOUT(_LtDebugDebug(__FILE__, (Widget)w, "DoScanType: ???\n"));
+	DEBUGOUT(_LtDebug(__FILE__, (Widget)w, "DoScanType: ???\n"));
 
 	break;
     }
@@ -926,7 +924,7 @@ Activate(Widget w, XEvent *ev, String *params, Cardinal *num_params)
 	return;
     }
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "Activate\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "Activate\n"));
 
     cb.reason = XmCR_ACTIVATE;
     cb.event = ev;
@@ -950,7 +948,7 @@ Activate(Widget w, XEvent *ev, String *params, Cardinal *num_params)
 static void
 MoveBackwardChar(Widget w, XEvent *ev, String *params, Cardinal *num_params)
 {
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "MoveBackwardChar\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "MoveBackwardChar\n"));
     DoUnselectionBecauseOfKeyNavigation(w,ev);
     if (Text_CursorPos(w) > 0)
     {
@@ -981,7 +979,7 @@ static void
 MoveBackwardParagraph(Widget w, XEvent *ev,
 		      String *params, Cardinal *num_params)
 {
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "MoveBackwardParagraph"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "MoveBackwardParagraph"));
 
     DoUnselectionBecauseOfKeyNavigation(w,ev);
     if (Text_CursorPos(w) > 0)
@@ -1001,7 +999,7 @@ MoveBackwardParagraph(Widget w, XEvent *ev,
 static void
 MoveBackwardWord(Widget w, XEvent *ev, String *params, Cardinal *num_params)
 {
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "MoweBackwardWord"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "MoweBackwardWord"));
 
     DoUnselectionBecauseOfKeyNavigation(w,ev);
     if (Text_CursorPos(w) > 0)
@@ -1028,7 +1026,7 @@ static void
 MoveBeginningOfFile(Widget w, XEvent *ev, String *params,
 		    Cardinal *num_params)
 {
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "MoveBeginningOfFile"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "MoveBeginningOfFile"));
 
     DoUnselectionBecauseOfKeyNavigation(w,ev);
     if (Text_CursorPos(w) > 0)
@@ -1043,32 +1041,36 @@ MoveToLineStart(Widget w, XEvent *ev, String *params,
 {
     XmTextPosition pos;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "MoveToLineStart"));
-
-    DoUnselectionBecauseOfKeyNavigation(w,ev);
-    pos = (*Text_Source(w)->Scan) (Text_Source(w), Text_CursorPos(w),
+    
+    if (*num_params==1 && !strcmp("extend", *params)) {
+       DEBUGOUT(_LtDebug(__FILE__, w, "MoveToLineStart(extend)"));
+       _KeySelection(w, ev, 3, params, num_params);   
+    } else {
+       DEBUGOUT(_LtDebug(__FILE__, w, "MoveToLineStart"));
+       DoUnselectionBecauseOfKeyNavigation(w,ev);
+       pos = (*Text_Source(w)->Scan) (Text_Source(w), Text_CursorPos(w),
 				   XmSELECT_LINE, XmsdLeft, 1, False);
-
-    _XmTextSetCursorPosition(w, pos);
+       _XmTextSetCursorPosition(w, pos);
+    }
 }
 
 static void
 ClearSelection(Widget w, XEvent *ev, String *params, Cardinal *num_params)
 {
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "ClearSelection\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "ClearSelection\n"));
 }
 
 static void
 CopyClipboard(Widget w, XEvent *ev, String *params, Cardinal *num_params)
 {
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "CopyClipboard\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "CopyClipboard\n"));
     XmTextCopy(w, ev->xkey.time);
 }
 
 static void
 CopyPrimary(Widget w, XEvent *ev, String *params, Cardinal *num_params)
 {
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "CopyPrimary\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "CopyPrimary\n"));
 }
 
 /* For Selection */
@@ -1092,7 +1094,7 @@ _XmTextGetSelection(Widget w, XtPointer client, Atom *selection, Atom *type,
     SelectionClientData *client_data = (SelectionClientData*)client;
     XEvent *ev = (XEvent*)client_data->ev;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "_XmTextGetSelection\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "_XmTextGetSelection\n"));
 
     if ((!value) || (*len == 0))
     {
@@ -1211,7 +1213,7 @@ _XmTextGetSelection(Widget w, XtPointer client, Atom *selection, Atom *type,
 static void
 ProcessCopy(Widget w, XEvent *ev, String *params, Cardinal *num_params)
 {
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "ProcessCopy\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "ProcessCopy\n"));
 
     if (Text_Editable(w))
     {
@@ -1234,7 +1236,7 @@ ProcessCopy(Widget w, XEvent *ev, String *params, Cardinal *num_params)
 static void
 ProcessCancel(Widget w, XEvent *ev, String *params, Cardinal *num_params)
 {
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "ProcessCancel\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "ProcessCancel\n"));
     /* rws 15 Jan 2000
        There is more to it than this. It needs to cancel some operations that
        may be in progress, otherwise do this. Look at the man page.
@@ -1248,14 +1250,14 @@ ProcessCancel(Widget w, XEvent *ev, String *params, Cardinal *num_params)
 static void
 CutClipboard(Widget w, XEvent *ev, String *params, Cardinal *num_params)
 {
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "CutClipboard\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "CutClipboard\n"));
     XmTextCut(w, ev->xbutton.time);
 }
 
 static void
 CutPrimary(Widget w, XEvent *ev, String *params, Cardinal *num_params)
 {
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "CutPrimary\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "CutPrimary\n"));
 }
 
 /*
@@ -1275,7 +1277,7 @@ DeleteForwardChar(Widget w, XEvent *ev, String *params,
     Boolean sel;
     XmTextPosition left, right;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "DeleteForwardChar"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "DeleteForwardChar"));
 
     if (!Text_Editable(w))
     {
@@ -1324,7 +1326,7 @@ DeleteBackwardChar(Widget w, XEvent *ev, String *params,
 {
     Boolean sel;
     XmTextPosition left, right;
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "DeleteBackardChar"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "DeleteBackardChar"));
 
     if (!Text_Editable(w))
     {
@@ -1370,7 +1372,7 @@ DeleteForwardWord(Widget w, XEvent *ev, String *params, Cardinal *num_params)
 {
     Boolean sel;
     XmTextPosition left, right;
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "DeleteForwardWord\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "DeleteForwardWord\n"));
 
     if (!Text_Editable(w))
     {
@@ -1403,7 +1405,7 @@ DeleteBackwardWord(Widget w, XEvent *ev, String *params, Cardinal *num_params)
 {
     Boolean sel;
     XmTextPosition left, right;
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "DeleteBackwardWord\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "DeleteBackwardWord\n"));
 
     if (!Text_Editable(w))
     {
@@ -1439,7 +1441,7 @@ DeleteCurrentSelection(Widget w, XEvent *ev,
     Boolean sel;
     XmTextPosition left, right;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "DeleteCurrentSelection\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "DeleteCurrentSelection\n"));
 
     if (!Text_Editable(w))
     {
@@ -1459,7 +1461,7 @@ static void
 DeleteToEndOfLine(Widget w, XEvent *ev, String *params, Cardinal *num_params)
 {
     XmTextPosition pos;
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "DeleteToEndOfLine\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "DeleteToEndOfLine\n"));
 
     if (!Text_Editable(w))
     {
@@ -1476,7 +1478,7 @@ static void
 DeleteToStartOfLine(Widget w, XEvent *ev, String *params, Cardinal *num_params)
 {
     XmTextPosition pos;
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "DeleteToStartOfLine\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "DeleteToStartOfLine\n"));
 
     if (!Text_Editable(w))
     {
@@ -1492,7 +1494,7 @@ DeleteToStartOfLine(Widget w, XEvent *ev, String *params, Cardinal *num_params)
 static void
 DeselectAll(Widget w, XEvent *ev, String *params, Cardinal *num_params)
 {
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "DeselectAll\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "DeselectAll\n"));
     (*Text_Source(w)->SetSelection)(Text_Source(w),1,0,ev->xkey.time);
 }
 
@@ -1502,12 +1504,18 @@ MoveToLineEnd(Widget w, XEvent *ev, String *params, Cardinal *num_params)
 {
     XmTextPosition pos;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "MoveToLineEnd"));
 
-    DoUnselectionBecauseOfKeyNavigation(w,ev);
-    pos = (*Text_Source(w)->Scan) (Text_Source(w), Text_CursorPos(w),
+    if (*num_params==1 && !strcmp("extend", *params)) {
+        DEBUGOUT(_LtDebug(__FILE__, w, "MoveToLineEnd(extend)"));
+        _KeySelection(w, ev, 4, params, num_params);   
+    } else
+    {
+        DEBUGOUT(_LtDebug(__FILE__, w, "MoveToLineEnd"));
+        DoUnselectionBecauseOfKeyNavigation(w,ev);
+        pos = (*Text_Source(w)->Scan) (Text_Source(w), Text_CursorPos(w),
 				   XmSELECT_LINE, XmsdRight, 1, False);
-    _XmTextSetCursorPosition(w, pos);
+        _XmTextSetCursorPosition(w, pos);
+     }
 }
 
 static void
@@ -1515,7 +1523,7 @@ MoveEndOfFile(Widget w, XEvent *ev, String *params, Cardinal *num_params)
 {
     XmTextPosition pos;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "MoveToEndOfFile"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "MoveToEndOfFile"));
 
     DoUnselectionBecauseOfKeyNavigation(w,ev);
     pos = Text_LastPos(w);
@@ -1532,7 +1540,7 @@ DoSelection(Widget w, XEvent *ev, String *params, Cardinal *num_params)
 	return;
     }
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "DoSelection"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "DoSelection"));
 }
 
 /*
@@ -1550,7 +1558,7 @@ ExtendEnd(Widget w, XEvent *ev, String *params, Cardinal *num_params)
 	return;
     }
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "ExtendEnd"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "ExtendEnd"));
 
     /*
      * Set a flag for ExtendSelection() to know that when it happens,
@@ -1581,7 +1589,7 @@ ExtendSelection(Widget w, XEvent *ev, String *params, Cardinal *num_params)
 
     if (sel)
     {
-	DEBUGOUT(_LtDebugDebug(__FILE__, w,
+	DEBUGOUT(_LtDebug(__FILE__, w,
 		 "ExtendSelection (pos %d, origleft %d) existing sel. %d-%d\n",
 			  pos, In_HighlightPivot(i), left, right));
 	if ( pos >= left && pos <= right )
@@ -1591,7 +1599,7 @@ ExtendSelection(Widget w, XEvent *ev, String *params, Cardinal *num_params)
     }
     else
     {
-	DEBUGOUT(_LtDebugDebug(__FILE__, w,
+	DEBUGOUT(_LtDebug(__FILE__, w,
 	    "ExtendSelection (pos %d, origleft %d) (x %d y %d)\n",
 	    pos, In_HighlightPivot(i), ev->xbutton.x, ev->xbutton.y));
     }
@@ -1649,7 +1657,7 @@ FindWord(Widget w, XEvent *ev, String *params, Cardinal *num_params)
 static void
 MoveForwardChar(Widget w, XEvent *ev, String *params, Cardinal *num_params)
 {
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "MoveForwardChar\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "MoveForwardChar\n"));
 
     DoUnselectionBecauseOfKeyNavigation(w,ev);
     if (Text_CursorPos(w) < Text_LastPos(w))
@@ -1679,7 +1687,7 @@ MoveForwardParagraph(Widget w, XEvent *ev, String *params,
 {
     XmTextPosition pos;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "MoveForwardParagraph"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "MoveForwardParagraph"));
 
     DoUnselectionBecauseOfKeyNavigation(w,ev);
     pos = (*Text_Source(w)->Scan) (Text_Source(w), Text_CursorPos(w),
@@ -1698,7 +1706,7 @@ MoveForwardWord(Widget w, XEvent *ev, String *params,
 {
     XmTextPosition pos;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "MoveForwardWord"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "MoveForwardWord"));
 
     DoUnselectionBecauseOfKeyNavigation(w,ev);
     pos = (*Text_Source(w)->Scan) (Text_Source(w), Text_CursorPos(w),
@@ -1716,7 +1724,7 @@ DoGrabFocus(Widget w, XEvent *ev, String *params, Cardinal *num_params)
     InputData i = Text_InputData(w);
     XmTextPosition pos;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "DoGrabFocus"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "DoGrabFocus"));
 
     XmProcessTraversal((Widget)w, XmTRAVERSE_CURRENT);
 
@@ -1742,7 +1750,7 @@ DoGrabFocus(Widget w, XEvent *ev, String *params, Cardinal *num_params)
 static void
 InsertString(Widget w, XEvent *ev, String *params, Cardinal *num_params)
 {
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "InsertString\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "InsertString\n"));
     if ( *num_params == 1 )
            XmTextInsert ( w, XmTextGetCursorPosition(w), params[0] );
 }
@@ -1767,7 +1775,7 @@ _KeySelection(Widget w, XEvent *ev, int flag, String *params, Cardinal *np)
     case 1:			/* left */
 	MoveBackwardChar(w, ev, params, np);
 
-	DEBUGOUT(_LtDebugDebug(__FILE__, w,
+	DEBUGOUT(_LtDebug(__FILE__, w,
 			  "KeySelection old %d new %d left %d right %d\n",
 			  old, Text_CursorPos(w), left, right));
 
@@ -1801,7 +1809,7 @@ _KeySelection(Widget w, XEvent *ev, int flag, String *params, Cardinal *np)
     case 2:			/* right */
 	MoveForwardChar(w, ev, params, np);
 
-	DEBUGOUT(_LtDebugDebug(__FILE__, w,
+	DEBUGOUT(_LtDebug(__FILE__, w,
 			  "KeySelection old %d new %d left %d right %d\n",
 			  old, Text_CursorPos(w), left, right));
 
@@ -1834,7 +1842,7 @@ _KeySelection(Widget w, XEvent *ev, int flag, String *params, Cardinal *np)
     case 3:			/* up */
 	MovePreviousLine(w, ev, params, np);
 
-	DEBUGOUT(_LtDebugDebug(__FILE__, w,
+	DEBUGOUT(_LtDebug(__FILE__, w,
 			  "KeySelection old %d new %d left %d right %d\n",
 			  old, Text_CursorPos(w), left, right));
 
@@ -1867,7 +1875,7 @@ _KeySelection(Widget w, XEvent *ev, int flag, String *params, Cardinal *np)
     case 4:			/* down */
 	MoveNextLine(w, ev, params, np);
 
-	DEBUGOUT(_LtDebugDebug(__FILE__, w,
+	DEBUGOUT(_LtDebug(__FILE__, w,
 			  "KeySelection old %d new %d left %d right %d\n",
 			  old, Text_CursorPos(w), left, right));
 
@@ -1910,11 +1918,11 @@ KeySelection(Widget w, XEvent *ev, String *params, Cardinal *num_params)
 
     if (*num_params == 0)
     {
-	DEBUGOUT(_LtDebugDebug(__FILE__, w, "KeySelection()\n"));
+	DEBUGOUT(_LtDebug(__FILE__, w, "KeySelection()\n"));
     }
     else
     {
-	DEBUGOUT(_LtDebugDebug(__FILE__, w, "KeySelection(%s)\n", params[0]));
+	DEBUGOUT(_LtDebug(__FILE__, w, "KeySelection(%s)\n", params[0]));
     }
 
     if (*num_params == 1)
@@ -1948,7 +1956,7 @@ KeySelection(Widget w, XEvent *ev, String *params, Cardinal *num_params)
 static void
 ProcessShiftDown(Widget w, XEvent *ev, String *params, Cardinal *num_params)
 {
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "ProcessShiftDown\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "ProcessShiftDown\n"));
 
     _KeySelection(w, ev, 4, params, num_params);
 }
@@ -1956,7 +1964,7 @@ ProcessShiftDown(Widget w, XEvent *ev, String *params, Cardinal *num_params)
 static void
 ProcessShiftUp(Widget w, XEvent *ev, String *params, Cardinal *num_params)
 {
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "ProcessShiftUp\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "ProcessShiftUp\n"));
 
     _KeySelection(w, ev, 3, params, num_params);
 }
@@ -1965,7 +1973,7 @@ static void
 KillForwardChar(Widget w, XEvent *ev, String *params,
 		Cardinal *num_params)
 {
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "KillForwardChar\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "KillForwardChar\n"));
 
     DeleteForwardChar(w, ev, params, num_params);
 }
@@ -1974,7 +1982,7 @@ static void
 KillForwardWord(Widget w, XEvent *ev, String *params,
 		Cardinal *num_params)
 {
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "KillForwardWord\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "KillForwardWord\n"));
 
     DeleteForwardWord(w, ev, params, num_params);
 }
@@ -1983,7 +1991,7 @@ static void
 KillBackwardChar(Widget w, XEvent *ev, String *params,
 		 Cardinal *num_params)
 {
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "KillBackwardChar\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "KillBackwardChar\n"));
 
     DeleteBackwardChar(w, ev, params, num_params);
 }
@@ -1992,7 +2000,7 @@ static void
 KillBackwardWord(Widget w, XEvent *ev, String *params,
 		 Cardinal *num_params)
 {
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "KillBackwardWord\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "KillBackwardWord\n"));
 
     DeleteBackwardWord(w, ev, params, num_params);
 }
@@ -2001,14 +2009,14 @@ static void
 KillCurrentSelection(Widget w, XEvent *ev, String *params,
 		     Cardinal *num_params)
 {
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "KillCurrentSelection\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "KillCurrentSelection\n"));
 }
 
 static void
 KillToEndOfLine(Widget w, XEvent *ev, String *params,
 		Cardinal *num_params)
 {
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "KillToEndOfLine\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "KillToEndOfLine\n"));
 
     DeleteToEndOfLine(w, ev, params, num_params);
 }
@@ -2017,7 +2025,7 @@ static void
 KillToStartOfLine(Widget w, XEvent *ev, String *params,
 		  Cardinal *num_params)
 {
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "KillToStartOfLine\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "KillToStartOfLine\n"));
     DeleteToStartOfLine(w, ev, params, num_params);
 }
 
@@ -2025,21 +2033,21 @@ static void
 MoveDestination(Widget w, XEvent *ev, String *params,
 		Cardinal *num_params)
 {
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "MoveDestination\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "MoveDestination\n"));
 }
 
 static void
 ProcessMove(Widget w, XEvent *ev, String *params,
 	    Cardinal *num_params)
 {
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "ProcessMove\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "ProcessMove\n"));
 }
 
 static void
 TraverseNextTabGroup(Widget w, XEvent *ev, String *params,
 		     Cardinal *num_params)
 {
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "TraverseNextTabGroup\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "TraverseNextTabGroup\n"));
 
     XtCallActionProc(w, "PrimitiveNextTabGroup", ev, params, *num_params);
 }
@@ -2055,7 +2063,7 @@ MoveNextLine(Widget aw, XEvent *ev, String *params, Cardinal *num_params)
     int index, maxindex;
     XmTextPosition pos = Text_CursorPos(w);
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, aw, "MoveNextLine\n"));
+    DEBUGOUT(_LtDebug(__FILE__, aw, "MoveNextLine\n"));
     DoUnselectionBecauseOfKeyNavigation(aw,ev);
 
     index = _XmTextGetTableIndex(w, pos);
@@ -2098,7 +2106,7 @@ MoveNextPage(Widget aw, XEvent *ev, String *params, Cardinal *num_params)
     int delta = Text_LineCount(w) - 1;
 #endif
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, aw, "MoveNextPage"));
+    DEBUGOUT(_LtDebug(__FILE__, aw, "MoveNextPage"));
     DoUnselectionBecauseOfKeyNavigation(aw,ev);
 
     index = _XmTextGetTableIndex(w, pos);
@@ -2133,7 +2141,7 @@ MoveNextPage(Widget aw, XEvent *ev, String *params, Cardinal *num_params)
 static void
 InsertNewLine(Widget w, XEvent *ev, String *params, Cardinal *num_params)
 {
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "InsertNewLine\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "InsertNewLine\n"));
 
     if (!Text_Editable(w))
     {
@@ -2151,7 +2159,7 @@ InsertNewLine(Widget w, XEvent *ev, String *params, Cardinal *num_params)
 static void
 InsertNewLineAndBackup(Widget w, XEvent *ev, String *params, Cardinal *num_params)
 {
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "InsertNewLineAndBackup\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "InsertNewLineAndBackup\n"));
 
     if ((!Text_Editable(w)) || (Text_EditMode(w) == XmSINGLE_LINE_EDIT))
     {
@@ -2166,7 +2174,7 @@ static void
 InsertNewLineAndIndent(Widget w, XEvent *ev, String *params,
 		       Cardinal *num_params)
 {
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "InsertNewLineAndIndent\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "InsertNewLineAndIndent\n"));
 
     if ((!Text_Editable(w)) || (Text_EditMode(w) == XmSINGLE_LINE_EDIT))
     {
@@ -2195,28 +2203,28 @@ InsertNewLineAndIndent(Widget w, XEvent *ev, String *params,
 static void
 MovePageLeft(Widget w, XEvent *ev, String *params, Cardinal *num_params)
 {
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "MovePageLeft\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "MovePageLeft\n"));
     DoUnselectionBecauseOfKeyNavigation(w,ev);
 }
 
 static void
 MovePageRight(Widget w, XEvent *ev, String *params, Cardinal *num_params)
 {
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "MovePageRight\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "MovePageRight\n"));
     DoUnselectionBecauseOfKeyNavigation(w,ev);
 }
 
 static void
 PasteClipboard(Widget w, XEvent *ev, String *params, Cardinal *num_params)
 {
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "PasteClipboard\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "PasteClipboard\n"));
     XmTextPaste(w);
 }
 
 static void
 TraversePrevTabGroup(Widget w, XEvent *ev, String *params, Cardinal *num_params)
 {
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "TraversePrevTabGroup\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "TraversePrevTabGroup\n"));
 
     XtCallActionProc(w, "PrimitivePrevTabGroup", ev, params, *num_params);
 }
@@ -2229,7 +2237,7 @@ MovePreviousLine(Widget aw, XEvent *ev, String *params, Cardinal *num_params)
     unsigned int index;
     XmTextPosition pos = Text_CursorPos(w);
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, aw, "MovePreviousLine\n"));
+    DEBUGOUT(_LtDebug(__FILE__, aw, "MovePreviousLine\n"));
 
     DoUnselectionBecauseOfKeyNavigation(aw,ev);
     index = _XmTextGetTableIndex(w, pos);
@@ -2266,7 +2274,7 @@ MovePreviousPage(Widget aw, XEvent *ev, String *params, Cardinal *num_params)
     Cardinal delta = Text_LineCount(w) - 1;
 #endif
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, aw, "MovePreviousPage"));
+    DEBUGOUT(_LtDebug(__FILE__, aw, "MovePreviousPage"));
 
     DoUnselectionBecauseOfKeyNavigation(aw,ev);
     index = _XmTextGetTableIndex(w, pos);
@@ -2301,7 +2309,7 @@ ProcessBDrag(Widget w, XEvent *ev, String *params, Cardinal *num_params)
     XmSourceData d = Text_Source(w)->data;
 
     _XmObjectLock(w);
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "ProcessBDrag\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "ProcessBDrag\n"));
 
     /* If widget has no selection or cursor is not in selection,
        then return. */
@@ -2341,7 +2349,7 @@ ProcessBDrag(Widget w, XEvent *ev, String *params, Cardinal *num_params)
 static void
 drag_drop_finish(Widget w, XtPointer client_data, XtPointer call_data)
 {
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "%s:drag_drop_finish(%d)\n",
+    DEBUGOUT(_LtDebug(__FILE__, w, "%s:drag_drop_finish(%d)\n",
     	__FILE__, __LINE__));
 }
 
@@ -2368,11 +2376,11 @@ drag_convert_proc(Widget w, Atom *selection,
 
     if (*selection != atom_motif_drop)
     {
-    	DEBUGOUT(_LtDebugDebug(__FILE__, w, "selection is not MOTIF_DROP\n"));
+    	DEBUGOUT(_LtDebug(__FILE__, w, "selection is not MOTIF_DROP\n"));
 	return False;
     }
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "We're dealing with MOTIF_DROP\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "We're dealing with MOTIF_DROP\n"));
 
     XtVaGetValues(w, XmNclientData, &src, NULL);
     d = Text_Source(src)->data;
@@ -2457,7 +2465,7 @@ drag_transfer_proc(Widget dw, XtPointer client, Atom *selection, Atom *type,
     	(*type != atom_comp_text && *type != atom_text && *type != XA_STRING)))
     {
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, (Widget)w, "%s\n", 
+    DEBUGOUT(_LtDebug(__FILE__, (Widget)w, "%s\n", 
 	 "drag_transfer_proc: DnD Transfer Failed(Text)"));
 
         XtSetArg(args[0], XmNtransferStatus, XmTRANSFER_FAILURE);
@@ -2598,7 +2606,7 @@ _Lttext_process_drop(Widget w, XtPointer client_data, XtPointer call_data)
 static void
 ProcessDown(Widget w, XEvent *ev, String *params, Cardinal *num_params)
 {
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "ProcessDown\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "ProcessDown\n"));
 
     MoveNextLine(w, ev, params, num_params);
 }
@@ -2608,7 +2616,7 @@ static void
 ProcessHome(Widget w, XEvent *ev, String *params,
 	    Cardinal *num_params)
 {
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "ProcessHome\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "ProcessHome\n"));
 
     MoveToLineStart(w, ev, params, num_params);
 }
@@ -2617,7 +2625,7 @@ ProcessHome(Widget w, XEvent *ev, String *params,
 static void
 ProcessReturn(Widget w, XEvent *ev, String *params, Cardinal *num_params)
 {
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "ProcessReturn\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "ProcessReturn\n"));
 
     InsertNewLine(w, ev, params, num_params);
 }
@@ -2626,7 +2634,7 @@ ProcessReturn(Widget w, XEvent *ev, String *params, Cardinal *num_params)
 static void
 ProcessTab(Widget w, XEvent *ev, String *params, Cardinal *num_params)
 {
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "ProcessTab\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "ProcessTab\n"));
     if (Text_EditMode(w) == XmSINGLE_LINE_EDIT)
     {
     	_XmMgrTraversal(w, XmTRAVERSE_NEXT_TAB_GROUP);
@@ -2641,7 +2649,7 @@ ProcessTab(Widget w, XEvent *ev, String *params, Cardinal *num_params)
 static void
 ProcessUp(Widget w, XEvent *ev, String *params, Cardinal *num_params)
 {
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "ProcessUp\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "ProcessUp\n"));
 
     MovePreviousLine(w, ev, params, num_params);
 }
@@ -2657,7 +2665,7 @@ RedrawDisplay(Widget w, XEvent *ev, String *params, Cardinal *num_params)
 static void
 ScrollOneLineUp(Widget w, XEvent *ev, String *params, Cardinal *num_params)
 {
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "ScrollOneLineUp\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "ScrollOneLineUp\n"));
     XmTextScroll(w, -1);
 }
 
@@ -2665,35 +2673,35 @@ ScrollOneLineUp(Widget w, XEvent *ev, String *params, Cardinal *num_params)
 static void
 SecondaryAdjust(Widget w, XEvent *ev, String *params, Cardinal *num_params)
 {
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "SecondaryAdjust\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "SecondaryAdjust\n"));
 }
 
 
 static void
 SecondaryNotify(Widget w, XEvent *ev, String *params, Cardinal *num_params)
 {
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "SecondaryNotify\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "SecondaryNotify\n"));
 }
 
 
 static void
 SecondaryStart(Widget w, XEvent *ev, String *params, Cardinal *num_params)
 {
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "SecondaryStart\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "SecondaryStart\n"));
 }
 
 
 static void
 SelectAll(Widget w, XEvent *ev, String *params, Cardinal *num_params)
 {
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "SelectAll\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "SelectAll\n"));
 }
 
 
 static void
 StartExtendSelection(Widget w, XEvent *ev, String *params, Cardinal *num_params)
 {
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "StartExtendSelection\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "StartExtendSelection\n"));
 
     DoGrabFocus(w, ev, params, num_params);
 }
@@ -2708,7 +2716,7 @@ SelfInsert(Widget w, XEvent *ev, String *params, Cardinal *num_params)
     KeySym keysym;
     int len, status;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "SelfInsert"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "SelfInsert"));
 
     len = XmImMbLookupString((Widget)w, (XKeyPressedEvent *)ev, buf, INSERTCHARBUFSIZ, &keysym, &status);
 
@@ -2721,8 +2729,8 @@ SelfInsert(Widget w, XEvent *ev, String *params, Cardinal *num_params)
 
     if (_LtDebugInDebug(__FILE__, w))
     {
-	DEBUGOUT(_LtDebugDebug(__FILE__, w, "XmImMbLookupString => %d\n", len));
-	DEBUGOUT(_LtDebugDebug0(__FILE__, w, "\tStatus %s\n",
+	DEBUGOUT(_LtDebug(__FILE__, w, "XmImMbLookupString => %d\n", len));
+	DEBUGOUT(_LtDebug0(__FILE__, w, "\tStatus %s\n",
 			   (status == XLookupNone) ? "none" :
 			   (status == XLookupChars) ? "chars" :
 			   (status == XLookupBoth) ? "both" :
@@ -2731,19 +2739,19 @@ SelfInsert(Widget w, XEvent *ev, String *params, Cardinal *num_params)
 
 	if (status == XLookupBoth || status == XLookupKeySym)
 	{
-	    DEBUGOUT(_LtDebugDebug0(__FILE__, w, "\tKeySym 0x%X\n", keysym));
+	    DEBUGOUT(_LtDebug0(__FILE__, w, "\tKeySym 0x%X\n", keysym));
 	}
 
 	if (len > 0)
 	{
 	    int i;
 
-	    DEBUGOUT(_LtDebugDebug0(__FILE__, w, "\tBuffer "));
+	    DEBUGOUT(_LtDebug0(__FILE__, w, "\tBuffer "));
 	    for (i = 0; i < len; i++)
 	    {
-		DEBUGOUT(_LtDebugDebug(__FILE__, w, " %X", 0xFF & buf[i]));
+		DEBUGOUT(_LtDebug(__FILE__, w, " %X", 0xFF & buf[i]));
 	    }
-	    DEBUGOUT(_LtDebugDebug0(__FILE__, w, "\n"));
+	    DEBUGOUT(_LtDebug0(__FILE__, w, "\n"));
 	}
     }
 
@@ -2760,7 +2768,7 @@ SelfInsert(Widget w, XEvent *ev, String *params, Cardinal *num_params)
 static void
 SetAnchor(Widget w, XEvent *ev, String *params, Cardinal *num_params)
 {
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "SetAnchor\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "SetAnchor\n"));
 
     Text_DestPosition(w) = (*Text_Output(w)->XYToPos)
 	((XmTextWidget)w, ev->xbutton.x, ev->xbutton.y);
@@ -2769,33 +2777,33 @@ SetAnchor(Widget w, XEvent *ev, String *params, Cardinal *num_params)
 static void
 SetCursorPosition(Widget w, XEvent *ev, String *params, Cardinal *num_params)
 {
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "SetCursorPosition\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "SetCursorPosition\n"));
 }
 
 static void
 SetSelectionHint(Widget w, XEvent *ev, String *params, Cardinal *num_params)
 {
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "SetSelectionHint\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "SetSelectionHint\n"));
 }
 
 static void
 ScrollCursorVertically(Widget w, XEvent *ev, String *params, Cardinal *num_params)
 {
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "ScrollCursorVertically\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "ScrollCursorVertically\n"));
 }
 
 
 static void
 ScrollOneLineDown(Widget w, XEvent *ev, String *params, Cardinal *num_params)
 {
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "ScrollOneLineDown\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "ScrollOneLineDown\n"));
     XmTextScroll(w, 1);
 }
 
 static void
 ToggleAddMode(Widget w, XEvent *ev, String *params, Cardinal *num_params)
 {
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "ToggleAddMode\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "ToggleAddMode\n"));
     Text_AddMode(w) = ! Text_AddMode(w);
 }
 
@@ -2803,20 +2811,20 @@ ToggleAddMode(Widget w, XEvent *ev, String *params, Cardinal *num_params)
 static void
 ToggleOverstrike(Widget w, XEvent *ev, String *params, Cardinal *num_params)
 {
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "ToggleOverstrike\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "ToggleOverstrike\n"));
     Text_InputData(w) -> overstrike = ! Text_InputData(w) -> overstrike ;
 }
 
 static void
 TextLeave(Widget w, XEvent *ev, String *params, Cardinal *num_params)
 {
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "TextLeave\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "TextLeave\n"));
 }
 
 static void
 TraverseHome(Widget w, XEvent *ev, String *params, Cardinal *num_params)
 {
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "TraverseHome\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "TraverseHome\n"));
 
     XtCallActionProc(w, "PrimitiveTraverseHome", ev, params, *num_params);
 }
@@ -2824,7 +2832,7 @@ TraverseHome(Widget w, XEvent *ev, String *params, Cardinal *num_params)
 static void
 TraverseDown(Widget w, XEvent *ev, String *params, Cardinal *num_params)
 {
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "TraverseDown\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "TraverseDown\n"));
 
     XtCallActionProc(w, "PrimitiveTraverseDown", ev, params, *num_params);
 }
@@ -2832,7 +2840,7 @@ TraverseDown(Widget w, XEvent *ev, String *params, Cardinal *num_params)
 static void
 TraverseUp(Widget w, XEvent *ev, String *params, Cardinal *num_params)
 {
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "TraverseUp\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "TraverseUp\n"));
 
     XtCallActionProc(w, "PrimitiveTraverseUp", ev, params, *num_params);
 }
@@ -2845,7 +2853,7 @@ TextFocusIn(Widget w, XEvent *ev, String *params, Cardinal *num_params)
     OutputData o = Text_OutputData(w);
 #endif
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "TextFocusIn"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "TextFocusIn"));
 
     if (Text_Editable(w))
     {
@@ -2885,7 +2893,7 @@ TextFocusOut(Widget w, XEvent *ev, String *params, Cardinal *num_params)
     OutputData o = Text_OutputData(w);
 #endif
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "TextFocusOut\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "TextFocusOut\n"));
 
     if (Text_Editable(w))
     {
@@ -2919,13 +2927,13 @@ TextFocusOut(Widget w, XEvent *ev, String *params, Cardinal *num_params)
 static void
 UnKill(Widget w, XEvent *ev, String *params, Cardinal *num_params)
 {
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "UnKill\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "UnKill\n"));
 }
 
 static void
 VoidAction(Widget w, XEvent *ev, String *params, Cardinal *num_params)
 {
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "VoidAction\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "VoidAction\n"));
 }
 
 
