@@ -1,9 +1,9 @@
 /**
  *
- * $Header: /cvsroot/lesstif/lesstif/lib/Xm/TextOut.c,v 1.99 2001/05/21 08:36:52 amai Exp $
+ * $Header: /cvsroot/lesstif/lesstif/lib/Xm/TextOut.c,v 1.111 2002/05/12 00:44:13 amai Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
- * Copyright (C) 1995-2001 LessTif Development Team
+ * Copyright  1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -23,7 +23,11 @@
  *
  **/
 
-static const char rcsid[] = "$Header: /cvsroot/lesstif/lesstif/lib/Xm/TextOut.c,v 1.99 2001/05/21 08:36:52 amai Exp $";
+static const char rcsid[] = "$Header: /cvsroot/lesstif/lesstif/lib/Xm/TextOut.c,v 1.111 2002/05/12 00:44:13 amai Exp $";
+
+/* Use this to use XtAllocateGC/XtGetGC, otherwise XCreateGC */
+/* Similar for the free operations */
+#define	USE_XT_GC	1
 
 #include <LTconfig.h>
 
@@ -46,16 +50,8 @@ static const char rcsid[] = "$Header: /cvsroot/lesstif/lesstif/lib/Xm/TextOut.c,
 
 #undef VERBOSE
 
-#ifndef _XmMin
-#define _XmMin(a,b)  ((a) < (b)) ? (a) : (b)
-#endif
-#ifndef _XmMax
-#define _XmMax(a,b)  ((a) > (b)) ? (a) : (b)
-#endif
-
 static void Draw(XmTextWidget w, LineNum num, XmTextPosition start, XmTextPosition end, XmHighlightMode highlight);
 
-
 #define Offset(field) XtOffsetOf(XmTextInnerRec, inner.out.field)
 
 
@@ -181,79 +177,67 @@ _XmFontCalculateAverageCharacterWidth(Widget w, XFontStruct *fs)
 static void
 FontInit(XmTextWidget w)
 {
-    OutputData o = Text_OutputData(w);
-    XmFontListEntry entry = NULL;
-    XFontStruct *fs;
-    int i;
+	OutputData o = Text_OutputData(w);
+	XmFontListEntry entry = NULL;
+	XmFontList oldlist = Out_FontList(o);
+	XFontStruct *fs;
+	int i;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, (Widget)w, "FontInit"));
+	DEBUGOUT(_LtDebug(__FILE__, (Widget)w, "FontInit(fontlist %p)\n", oldlist));
 
-    /* This part is probably all wrong ... FIX ME */
-    for (i = 0; Out_FontList(o)[i].tag != NULL; i++)
-    {
-	if (strcmp(XmFONTLIST_DEFAULT_TAG, Out_FontList(o)[i].tag) == 0 ||
-	    strcmp(XmSTRING_DEFAULT_CHARSET, Out_FontList(o)[i].tag) == 0)
-	{
-	    entry = &Out_FontList(o)[i];
+	/* This part is probably all wrong ... FIX ME */
+	for (i = 0; Out_FontList(o)->renditions[i]->tag != NULL; i++) {
+		if (strcmp(XmFONTLIST_DEFAULT_TAG,
+				Out_FontList(o)->renditions[i]->tag) == 0 ||
+				strcmp(XmSTRING_DEFAULT_CHARSET,
+				Out_FontList(o)->renditions[i]->tag) == 0) {
+			entry = Out_FontList(o)->renditions[i];
 
-	    if (entry->font == NULL)
-	    {
-		entry = NULL;
-		continue;
-	    }
+			if (entry->font == NULL) {
+				entry = NULL;
+				continue;
+			}
 
-	    break;
-	}
-    }
-
-    if (!entry)
-    {
-	for (i = 0; Out_FontList(o)[i].tag != NULL; i++)
-	{
-	    if (Out_FontList(o)[i].type == XmFONT_IS_FONTSET)
-	    {
-		entry = &Out_FontList(o)[i];
-
-		if (entry->font == NULL)
-		{
-		    entry = NULL;
-
-		    continue;
+			break;
 		}
-
-		break;
-	    }
 	}
-    }
 
-    if (!entry)
-    {
-	for (i = 0; Out_FontList(o)[i].tag != NULL; i++)
-	{
-	    if (Out_FontList(o)[i].type == XmFONT_IS_FONT)
-	    {
-		entry = &Out_FontList(o)[i];
+	if (!entry) {
+		for (i = 0; Out_FontList(o)->renditions[i]->tag != NULL; i++) {
+			if (Out_FontList(o)->renditions[i]->type == XmFONT_IS_FONTSET) {
+				entry = Out_FontList(o)->renditions[i];
 
-		if (entry->font == NULL)
-		{
-		    entry = NULL;
-		    continue;
+				if (entry->font == NULL) {
+					entry = NULL;
+					continue;
+				}
+
+				break;
+			}
 		}
-
-		break;
-	    }
 	}
-    }
-    /* (Hopefully) end of the all wrong part */
+
+	if (!entry) {
+		for (i = 0; Out_FontList(o)->renditions[i]->tag != NULL; i++) {
+			if (Out_FontList(o)->renditions[i]->type == XmFONT_IS_FONT) {
+				entry = Out_FontList(o)->renditions[i];
+
+				if (entry->font == NULL) {
+					entry = NULL;
+					continue;
+				}
+
+				break;
+			}
+		}
+	}
+	/* (Hopefully) end of the all wrong part */
 
     /* This should only be the very very last resort. */
-    if (entry == NULL || entry->font == NULL)
-    {
-	Out_FontList(o) = entry =
-	    _XmFontListCreateDefault(XtDisplay((Widget)w));
-    }
-    else       /* Make copy. Original will be free */
-    {
+    if (entry == NULL || entry->font == NULL) {
+	Out_FontList(o) = _XmFontListCreateDefault(XtDisplay((Widget)w));
+	entry = Out_FontList(o)->renditions[0];
+    } else {	/* Make copy. Original will be free */
       /*  amai, 20010313:
        *  I do not understand why this is necessary, but
        *  it seems to be ...
@@ -262,10 +246,10 @@ FontInit(XmTextWidget w)
        *  The original will _not_ be freed, or at least it won't be
        *  always freed, see test/Xm/text/test11, the leak check!
        */
-      Out_FontList(o) = XmFontListCopy(entry);
-      if (Out_FontListCreated(o))
-         XmFontListFree(entry);       
-      entry = Out_FontList(o);
+	Out_FontList(o) = XmFontListAppendEntry(NULL, entry);
+	if (Out_FontListCreated(o))
+		XmFontListFree(oldlist);
+	entry = Out_FontList(o)->renditions[0];
 	Out_FontListCreated(o) = True;
     }
 
@@ -285,16 +269,16 @@ FontInit(XmTextWidget w)
 	int r, i, max, min;
 
 	r = XFontsOfFontSet((XFontSet)entry->font, &fsl, &nl);
-	DEBUGOUT(_LtDebugDebug(__FILE__, (Widget)w, "XFontsOfFontSet : %d\n", r));
+	DEBUGOUT(_LtDebug(__FILE__, (Widget)w, "XFontsOfFontSet : %d\n", r));
 	for (i = 0; i < r; i++)
 	{
-	    DEBUGOUT(_LtDebugDebug0(__FILE__, NULL, "\t%s\n", nl[i]));
+	    DEBUGOUT(_LtDebug0(__FILE__, NULL, "\t%s\n", nl[i]));
 	}
 
 	/* FIX ME - just pick the first one */
 	if (r == 0)
 	{
-	    DEBUGOUT(_LtDebugDebug(__FILE__, NULL, "No font in fontset\n"));
+	    DEBUGOUT(_LtDebug(__FILE__, NULL, "No font in fontset\n"));
 
 	    abort();
 	}
@@ -313,21 +297,22 @@ FontInit(XmTextWidget w)
 /*	Out_UseFontSet(o) = True;
 */    }
 
-    Out_Font(o) = fs;
+	Out_Font(o) = fs;
 
-    if ( Out_FontAverageWidth(o) <= 0 )
-	{
-	Out_FontAverageWidth(o) = _XmFontCalculateAverageCharacterWidth((Widget)w, fs);
+	if ( Out_FontAverageWidth(o) <= 0 ) {
+		Out_FontAverageWidth(o) = _XmFontCalculateAverageCharacterWidth((Widget)w, fs);
 	}
-    Out_TabWidth(o) = 8 * Out_FontAverageWidth(o);
-    Out_Font_Ascent(o) = Out_FontAscent(o);
-    Out_Font_Descent(o) = Out_FontDescent(o);
-    Out_FontHeight(o) = Out_FontAscent(o) + Out_FontDescent(o);
-    Out_CursorHeight(o) = Out_FontHeight(o);
-    DEBUGOUT(_LtDebugDebug(__FILE__, (Widget)w,
-		      "font: ascent=%d descent=%d height=%d avewidth=%d\n",
-		      Out_FontAscent(o), Out_FontDescent(o),
-		      Out_FontHeight(o), Out_FontAverageWidth(o)));
+	Out_TabWidth(o) = 8 * Out_FontAverageWidth(o);
+	Out_Font_Ascent(o) = Out_FontAscent(o);
+	Out_Font_Descent(o) = Out_FontDescent(o);
+	Out_FontHeight(o) = Out_FontAscent(o) + Out_FontDescent(o);
+	Out_CursorHeight(o) = Out_FontHeight(o);
+
+	DEBUGOUT(_LtDebug(__FILE__, (Widget)w,
+		"FontInit - fl %p font %p : ascent=%d descent=%d height=%d avewidth=%d\n",
+		Out_FontList(o), Out_Font(o),
+		Out_FontAscent(o), Out_FontDescent(o),
+		Out_FontHeight(o), Out_FontAverageWidth(o)));
 }
 
 
@@ -364,7 +349,20 @@ GCInitialize(XmTextWidget w)
 	GCForeground | GCBackground;
     dontcare = 0;
 
-    Out_DrawGC(o) = XCreateGC(XtDisplay(w), XtWindow(w), mask, &values);
+    if (! w->core.sensitive) {
+	Screen	*s = XtScreen((Widget)w);
+
+	mask |= GCStipple;
+	values.fill_style = FillStippled;
+	values.stipple = XmGetPixmapByDepth(s, "50_foreground", 1, 0, 1);
+    }
+
+#ifdef	USE_XT_GC
+    Out_DrawGC(o) = XtAllocateGC((Widget)w, w->core.depth,
+	mask, &values, dynamic, dontcare);
+#else
+    Out_DrawGC(o) = XCreateGC(XtDisplay((Widget)w), XtWindow(w), mask, &values);
+#endif
     Out_DrawGCInverted(o) = False;
 
     /*
@@ -382,7 +380,12 @@ GCInitialize(XmTextWidget w)
 
     dontcare = 0;
 
-    Out_CursorGC(o) = XCreateGC(XtDisplay(w), XtWindow(w), mask, &values);
+#ifdef USE_XT_GC
+    Out_CursorGC(o) = XtAllocateGC((Widget)w, w->core.depth,
+	mask, &values, dynamic, dontcare);
+#else
+    Out_CursorGC(o) = XCreateGC(XtDisplay((Widget)w), XtWindow(w), mask, &values);
+#endif
 
     /*
      * CopyGC
@@ -562,7 +565,7 @@ SizeRecalc(XmTextWidget w)
 		      XtWidth(w), XtHeight(w), Out_Rows(o), Out_Columns(o));
 #endif
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, (Widget)w,
+    DEBUGOUT(_LtDebug(__FILE__, (Widget)w,
 		      "SizeRecalc wid %d ht %d -> rows %d cols %d\n",
 		      XtWidth(w), XtHeight(w), Out_Rows(o), Out_Columns(o)));
 }
@@ -655,7 +658,7 @@ DrawAll(XmTextWidget w)
 	Line next = &Text_Line(w)[i + 1];
 
 #ifdef VERBOSE
-	DEBUGOUT(_LtDebugDebug(__FILE__, (Widget)w,
+	DEBUGOUT(_LtDebug(__FILE__, (Widget)w,
 		   "DrawAll: line[%d]: start=%d end=%d, highlight change %d\n",
 			  i, line->start, next->start - 1, np));
 #endif
@@ -804,13 +807,13 @@ _XmTextNextX(XmTextWidget w, int x, char *ptr, int len)
 	else
 	{
 
-	    if (Out_FontList(o)->type == XmFONT_IS_FONT)
+	    if (Out_FontList(o)->renditions[0]->type == XmFONT_IS_FONT)
 	    {
                 x += XTextWidth(fs, ptr, len);
             }
-	    else if (Out_FontList(o)->type == XmFONT_IS_FONTSET)
+	    else if (Out_FontList(o)->renditions[0]->type == XmFONT_IS_FONTSET)
 	    {
-                XmbTextExtents((XFontSet)Out_FontList(o)->font, ptr, len, &ink, &log);
+                XmbTextExtents((XFontSet)Out_FontList(o)->renditions[0]->font, ptr, len, &ink, &log);
                 x += log.width;
             }
 	    else
@@ -829,7 +832,7 @@ _XmTextNextX(XmTextWidget w, int x, char *ptr, int len)
 		 * Updated 8 nov 2000 by Tom Pollard pollard@schrodinger.com
 		 */
 		if (c < fs->min_char_or_byte2 || c > fs->max_char_or_byte2) {
-			DEBUGOUT(_LtDebugDebug(__FILE__, (Widget)w, 
+			DEBUGOUT(_LtDebug(__FILE__, (Widget)w, 
 				"_XmTextNextX: fs->default_char %d -> 32\n",
 				c));
 			c = 32;
@@ -872,7 +875,7 @@ FontTextWidth(XmTextWidget w, XmTextPosition pos, XmTextPosition end)
     width = _XmTextNextX(w, 0, block.ptr, block.length);
 
 #ifdef VERBOSE
-    DEBUGOUT(_LtDebugDebug(__FILE__, (Widget)w,
+    DEBUGOUT(_LtDebug(__FILE__, (Widget)w,
 		      "FontTextWidth(%s) => %d\n", block.ptr, width));
 #endif
 
@@ -891,7 +894,7 @@ XToPos(XmTextWidget w, LineNum row, int x)
     XmTextPosition start, end, pos;
     XmTextBlockRec block;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, (Widget)w,
+    DEBUGOUT(_LtDebug(__FILE__, (Widget)w,
 		      "XToPos(row %d, x %d) TotalLines %d\n",
 		      row, x, Text_TotalLines(w)));
 
@@ -977,7 +980,7 @@ XToPos(XmTextWidget w, LineNum row, int x)
 
     XtFree(block.ptr);
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, (Widget)w,
+    DEBUGOUT(_LtDebug(__FILE__, (Widget)w,
 		 "XToPos: x=%d start=%d end=%d pos=%d\n", x, start, end, pos));
 
     return pos;
@@ -998,7 +1001,7 @@ YToLineNum(XmTextWidget w, Position y)
 	line = Text_LineCount(w);
     }
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, (Widget)w,
+    DEBUGOUT(_LtDebug(__FILE__, (Widget)w,
 		"YToLineNum: y=%d line=%d (l %d Text_LineCount %d)\n",
 		y, line, l, Text_LineCount(w)));
 
@@ -1014,7 +1017,7 @@ DrawText(XmTextWidget w, int x, int y, char *ptr, int len,
     int xoff, xstart = x, xend;
 
 #ifdef VERBOSE
-    DEBUGOUT(_LtDebugDebug(__FILE__, (Widget)w,
+    DEBUGOUT(_LtDebug(__FILE__, (Widget)w,
 		      "DrawText: x %d y %d '%s' len %d hl %d\n",
 		      x, y, (ptr == 0) ? "(NULL)" : ptr, len, highlight));
 #endif
@@ -1061,12 +1064,15 @@ DrawText(XmTextWidget w, int x, int y, char *ptr, int len,
 
 	    if (count > 0)
 	    {
-		if (Out_FontList(o)->type == XmFONT_IS_FONT) {
-			XDrawImageString(XtDisplay(w), XtWindow(w), Out_DrawGC(o),
-				 x + xoff, y, start, count);
-		} else if (Out_FontList(o)->type == XmFONT_IS_FONTSET) {
-			XmbDrawImageString(XtDisplay(w), XtWindow(w), (XFontSet)Out_FontList(o)->font, Out_DrawGC(o),
+		if (Out_FontList(o)->renditions[0]->type == XmFONT_IS_FONT) {
+			XDrawString(XtDisplay(w), XtWindow(w), Out_DrawGC(o),
 				 x + xoff, y, start, count);
+		} else if (Out_FontList(o)->renditions[0]->type == XmFONT_IS_FONTSET) {
+			XmbDrawString(XtDisplay(w), XtWindow(w),
+				(XFontSet)Out_FontList(o)->renditions[0]->font,
+				Out_DrawGC(o),
+				x + xoff, y,
+				start, count);
 		} else {
 			/* ??? */
 		}
@@ -1080,7 +1086,7 @@ DrawText(XmTextWidget w, int x, int y, char *ptr, int len,
 
 		strncpy(temp, start, count);
 		temp[count] = '\0';
-		DEBUGOUT(_LtDebugDebug(__FILE__, (Widget)w,
+		DEBUGOUT(_LtDebug(__FILE__, (Widget)w,
 				  "Draw: x=%d y=%d -->%s<--\n", x, y, temp));
 	    }
 #endif
@@ -1138,7 +1144,7 @@ ChangeHOffset(XmTextWidget w, int offset)
 {
     OutputData o = Text_OutputData(w);
 
-	DEBUGOUT(_LtDebugDebug(__FILE__, (Widget)w, "ChangeHOffset(%d)\n", offset));
+	DEBUGOUT(_LtDebug(__FILE__, (Widget)w, "ChangeHOffset(%d)\n", offset));
 
     if (Out_XOffset(o) == offset)
     {
@@ -1213,10 +1219,10 @@ _XmRedisplayHBar(XmTextWidget w, int offset)
 		      NULL);
     }
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, (Widget)w,
+    DEBUGOUT(_LtDebug(__FILE__, (Widget)w,
 	       "_XmRedisplayHBar: oldmax=%d newmax=%d oldsize=%d newsize=%d\n",
 		      oldMax, maxWidth, oldSize, displayWidth));
-    DEBUGOUT(_LtDebugDebug(__FILE__, (Widget)w,
+    DEBUGOUT(_LtDebug(__FILE__, (Widget)w,
 		      "_XmRedisplayHBar: oldvalue=%d newvalue=%d\n",
 		      oldValue, newValue));
 
@@ -1230,13 +1236,13 @@ _XmChangeVSB(XmTextWidget w, XmTextPosition pos)
     int top_index, pos_index, newValue;
     int oldMin = 0, oldMax = 0, oldSize = 0, oldValue = 0, newMax;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, (Widget)w,
+    DEBUGOUT(_LtDebug(__FILE__, (Widget)w,
 		      "_XmChangeVSB: pos=%d\n", pos));
 
     top_index = _XmTextGetTableIndex(w, Text_TopPos(w));
     pos_index = _XmTextGetTableIndex(w, pos);
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, (Widget)w,
+    DEBUGOUT(_LtDebug(__FILE__, (Widget)w,
 		      "_XmChangeVSB: top_index=%d pos_index=%d\n",
 		      top_index, pos_index));
 
@@ -1296,11 +1302,11 @@ _XmChangeVSB(XmTextWidget w, XmTextPosition pos)
 	XtCallCallbacks(Out_Vbar(o), XmNvalueChangedCallback, &cbs);
     }
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, (Widget)w,
+    DEBUGOUT(_LtDebug(__FILE__, (Widget)w,
 		   "_XmChangeVSB: oldmax=%d newmax=%d oldsize=%d newsize=%d\n",
 		      oldMax, newMax, oldSize, Out_Rows(o)));
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, (Widget)w,
+    DEBUGOUT(_LtDebug(__FILE__, (Widget)w,
 		      "_XmChangeVSB: oldvalue=%d newvalue=%d\n",
 		      oldValue, newValue));
 
@@ -1354,7 +1360,7 @@ CursorSaveUnderIBeam(XmTextWidget w, Position x, Position y)
     }
 
 #ifdef VERBOSE
-    DEBUGOUT(_LtDebugDebug(__FILE__, (Widget)w, "CursorSaveUnderIBeam\n"));
+    DEBUGOUT(_LtDebug(__FILE__, (Widget)w, "CursorSaveUnderIBeam\n"));
 #endif
 
     /* Make sure that the text is drawn before saving the cursor */
@@ -1384,7 +1390,7 @@ CursorRestoreUnderIBeam(XmTextWidget w, Position x, Position y)
     }
 
 #ifdef VERBOSE
-    DEBUGOUT(_LtDebugDebug(__FILE__, (Widget)w, "CursorRestoreUnderIBeam\n"));
+    DEBUGOUT(_LtDebug(__FILE__, (Widget)w, "CursorRestoreUnderIBeam\n"));
 #endif
 
     /* Make sure that the text is drawn before erasing the cursor */
@@ -1409,7 +1415,7 @@ CursorDrawIBeam(XmTextWidget w, int x, int y)
     /* Bail if the GC's don't exist yet. */
     if (!XtIsRealized((Widget)w))
     {
-	DEBUGOUT(_LtDebugDebug(__FILE__, (Widget)w, "CursorDrawIBeam: no GC\n"));
+	DEBUGOUT(_LtDebug(__FILE__, (Widget)w, "CursorDrawIBeam: no GC\n"));
 	return;
     }
 
@@ -1479,7 +1485,7 @@ HandleHBar(Widget sw, XtPointer client_data, XtPointer call_data)
     switch (cbs->reason)
     {
     case XmCR_DECREMENT:
-	DEBUGOUT(_LtDebugDebug(__FILE__, (Widget)w,
+	DEBUGOUT(_LtDebug(__FILE__, (Widget)w,
 		  "HandleHbar reason=XmCR_DECREMENT value= %d\n", cbs->value));
 
 	newOffset = Out_XOffset(o) > Out_FontAverageWidth(o) ?
@@ -1487,7 +1493,7 @@ HandleHBar(Widget sw, XtPointer client_data, XtPointer call_data)
 	break;
 
     case XmCR_DRAG:
-	DEBUGOUT(_LtDebugDebug(__FILE__, (Widget)w,
+	DEBUGOUT(_LtDebug(__FILE__, (Widget)w,
 			"HandleHbar reason=XmCR_DRAG value=%d\n", cbs->value));
 
 	newOffset = cbs->value / Out_FontAverageWidth(o) *
@@ -1495,7 +1501,7 @@ HandleHBar(Widget sw, XtPointer client_data, XtPointer call_data)
 	break;
 
     case XmCR_INCREMENT:
-	DEBUGOUT(_LtDebugDebug(__FILE__, (Widget)w,
+	DEBUGOUT(_LtDebug(__FILE__, (Widget)w,
 		   "HandleHbar reason=XmCR_INCREMENT value=%d\n", cbs->value));
 
 	displayWidth = XtWidth(w) - ( Out_RightMargin(o) + Out_LeftMargin(o) );
@@ -1511,7 +1517,7 @@ HandleHBar(Widget sw, XtPointer client_data, XtPointer call_data)
 	break;
 
     case XmCR_PAGE_DECREMENT:
-	DEBUGOUT(_LtDebugDebug(__FILE__, (Widget)w,
+	DEBUGOUT(_LtDebug(__FILE__, (Widget)w,
 			  "HandleHbar reason=XmCR_PAGE_DECREMENT value=%d\n",
 			  cbs->value));
 
@@ -1525,7 +1531,7 @@ HandleHBar(Widget sw, XtPointer client_data, XtPointer call_data)
 	break;
 
     case XmCR_PAGE_INCREMENT:
-	DEBUGOUT(_LtDebugDebug(__FILE__, (Widget)w,
+	DEBUGOUT(_LtDebug(__FILE__, (Widget)w,
 			  "HandleHbar reason=XmCR_PAGE_INCREMENT value=%d\n",
 			  cbs->value));
 
@@ -1552,7 +1558,7 @@ HandleHBar(Widget sw, XtPointer client_data, XtPointer call_data)
 	break;
 
     case XmCR_TO_BOTTOM:
-	DEBUGOUT(_LtDebugDebug(__FILE__, (Widget)w,
+	DEBUGOUT(_LtDebug(__FILE__, (Widget)w,
 			"HandleHbar reason=XmCR_TO_BOTTOM value=%d pixel=%d\n",
 			  cbs->value, cbs->pixel));
 
@@ -1560,7 +1566,7 @@ HandleHBar(Widget sw, XtPointer client_data, XtPointer call_data)
 	break;
 
     case XmCR_TO_TOP:
-	DEBUGOUT(_LtDebugDebug(__FILE__, (Widget)w,
+	DEBUGOUT(_LtDebug(__FILE__, (Widget)w,
 			  "HandleHbar reason=XmCR_TO_TOP value=%d pixel=%d\n",
 			  cbs->value, cbs->pixel));
 
@@ -1570,7 +1576,7 @@ HandleHBar(Widget sw, XtPointer client_data, XtPointer call_data)
 	break;
 
     case XmCR_VALUE_CHANGED:
-	DEBUGOUT(_LtDebugDebug(__FILE__, (Widget)w,
+	DEBUGOUT(_LtDebug(__FILE__, (Widget)w,
 			  "HandleHbar reason=XmCR_VALUE_CHANGED value=%d\n",
 			  cbs->value));
 	newOffset = cbs->value / Out_FontAverageWidth(o) *
@@ -1599,14 +1605,14 @@ HandleVBar(Widget sw, XtPointer client_data, XtPointer call_data)
     switch (cbs->reason)
     {
     case XmCR_DECREMENT:
-	DEBUGOUT(_LtDebugDebug(__FILE__, (Widget)w,
+	DEBUGOUT(_LtDebug(__FILE__, (Widget)w,
 			  "HandleVbar reason=XmCR_DECREMENT\n"));
 
 	XmTextScroll((Widget)w, -1);
 	break;
 
     case XmCR_DRAG:
-	DEBUGOUT(_LtDebugDebug(__FILE__, (Widget)w,
+	DEBUGOUT(_LtDebug(__FILE__, (Widget)w,
 			  "HandleVbar reason=XmCR_DRAG value=%d\n",
 			  cbs->value));
 
@@ -1616,27 +1622,27 @@ HandleVBar(Widget sw, XtPointer client_data, XtPointer call_data)
 	break;
 
     case XmCR_INCREMENT:
-	DEBUGOUT(_LtDebugDebug(__FILE__, (Widget)w,
+	DEBUGOUT(_LtDebug(__FILE__, (Widget)w,
 			  "HandleVbar reason=XmCR_INCREMENT\n"));
 	XmTextScroll((Widget)w, 1);
 	break;
 
     case XmCR_PAGE_DECREMENT:
-	DEBUGOUT(_LtDebugDebug(__FILE__, (Widget)w,
+	DEBUGOUT(_LtDebug(__FILE__, (Widget)w,
 			  "HandleVbar reason=XmCR_PAGE_DECREMENT\n"));
 
 	XmTextScroll((Widget)w, -Out_Rows(o));
 	break;
 
     case XmCR_PAGE_INCREMENT:
-	DEBUGOUT(_LtDebugDebug(__FILE__, (Widget)w,
+	DEBUGOUT(_LtDebug(__FILE__, (Widget)w,
 			  "HandleVbar reason=XmCR_PAGE_INCREMENT\n"));
 
 	XmTextScroll((Widget)w, Out_Rows(o));
 	break;
 
     case XmCR_TO_BOTTOM:
-	DEBUGOUT(_LtDebugDebug(__FILE__, (Widget)w,
+	DEBUGOUT(_LtDebug(__FILE__, (Widget)w,
 			  "HandleVbar reason=XmCR_TO_BOTTOM\n"));
 
 	index = Text_TotalLines(w) - 1 - Out_Rows(o);
@@ -1645,7 +1651,7 @@ HandleVBar(Widget sw, XtPointer client_data, XtPointer call_data)
 	break;
 
     case XmCR_TO_TOP:
-	DEBUGOUT(_LtDebugDebug(__FILE__, (Widget)w,
+	DEBUGOUT(_LtDebug(__FILE__, (Widget)w,
 			  "HandleVbar reason=XmCR_TO_TOP\n"));
 
 	Text_TopPos(w) = Text_FirstPos(w);
@@ -1653,7 +1659,7 @@ HandleVBar(Widget sw, XtPointer client_data, XtPointer call_data)
 	break;
 
     case XmCR_VALUE_CHANGED:
-	DEBUGOUT(_LtDebugDebug(__FILE__, (Widget)w,
+	DEBUGOUT(_LtDebug(__FILE__, (Widget)w,
 			  "HandleVbar reason=XmVALUE_CHANGED\n"));
 
 	index = cbs->value;
@@ -1662,7 +1668,7 @@ HandleVBar(Widget sw, XtPointer client_data, XtPointer call_data)
 	break;
 
     default:
-	DEBUGOUT(_LtDebugDebug(__FILE__, (Widget)w,
+	DEBUGOUT(_LtDebug(__FILE__, (Widget)w,
 			  "HandleVbar reason=UNKNOWN\n %d", cbs->reason));
 	break;
     }
@@ -1683,7 +1689,7 @@ HandleFocusEvents(Widget aw, XtPointer client_data, XEvent* event, Boolean* cont
     XmTextWidget w = (XmTextWidget)aw;
     OutputData o = Text_OutputData(w);
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, (Widget)w, "HandleFocusEvent event=%s\n",
+    DEBUGOUT(_LtDebug(__FILE__, (Widget)w, "HandleFocusEvent event=%s\n",
 		      event->type == FocusIn ? "FocusIn" : "FocusOut"));
 
     if ( event->type == FocusIn && event->xany.send_event && !Out_HasFocus(o) )
@@ -1796,11 +1802,11 @@ MakePositionVisible(XmTextWidget w, XmTextPosition pos)
     Dimension xpos, last_xpos;
     Boolean UpdateVSB = False;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, (Widget)w,
+    DEBUGOUT(_LtDebug(__FILE__, (Widget)w,
 		      "MakePositionVisible pos=%d\n", pos));
 
     line = _XmTextGetTableIndex(w, pos);
-    DEBUGOUT(_LtDebugDebug(__FILE__, (Widget)w,
+    DEBUGOUT(_LtDebug(__FILE__, (Widget)w,
 		      "\tline=%d, top_line=%d, line_count=%d, rows=%d redisplay=%s refigure=%s\n", 
 		      line,
 		      Text_TopLine(w),
@@ -1886,7 +1892,7 @@ MeasureLine(XmTextWidget w, LineNum num, XmTextPosition pos,
     LineTableExtra e;
 
 #ifdef VERBOSE
-    DEBUGOUT(_LtDebugDebug(__FILE__, (Widget)w,
+    DEBUGOUT(_LtDebug(__FILE__, (Widget)w,
 	  "MeasureLine: line=%d pos=%d %s %s\n",
 	  num, pos, 
 	  next ? "wants next" : "",
@@ -1903,7 +1909,7 @@ MeasureLine(XmTextWidget w, LineNum num, XmTextPosition pos,
 	end = Text_LastPos(w);
     }
 #ifdef VERBOSE
-    DEBUGOUT(_LtDebugDebug(__FILE__, (Widget)w,
+    DEBUGOUT(_LtDebug(__FILE__, (Widget)w,
     	"\tmeasure from %d to %d\n", start, end));
 #endif
 
@@ -1913,7 +1919,7 @@ MeasureLine(XmTextWidget w, LineNum num, XmTextPosition pos,
 	{
 	    *next = (XmTextPosition)PASTENDPOS;
 #ifdef VERBOSE
-	    DEBUGOUT(_LtDebugDebug(__FILE__, (Widget)w,
+	    DEBUGOUT(_LtDebug(__FILE__, (Widget)w,
 		"\tnext PASTENDPOS\n"));
 #endif
 	}
@@ -1921,7 +1927,7 @@ MeasureLine(XmTextWidget w, LineNum num, XmTextPosition pos,
 	{
 	    *next = end + 1;
 #ifdef VERBOSE
-	    DEBUGOUT(_LtDebugDebug(__FILE__, (Widget)w,
+	    DEBUGOUT(_LtDebug(__FILE__, (Widget)w,
 		"\tnext %d\n", *next));
 #endif
 	}
@@ -1943,11 +1949,11 @@ MeasureLine(XmTextWidget w, LineNum num, XmTextPosition pos,
     if (_LtDebugInDebug(__FILE__, (Widget)w))
     {
 	if (next)
-	    DEBUGOUT(_LtDebugDebug(__FILE__, (Widget)w,
+	    DEBUGOUT(_LtDebug(__FILE__, (Widget)w,
 			      "MeasureLine: line=%d pos=%d next=%d width=%d\n",
 			      num, pos, *next, width));
 	else
-	    DEBUGOUT(_LtDebugDebug(__FILE__, (Widget)w,
+	    DEBUGOUT(_LtDebug(__FILE__, (Widget)w,
 			    "MeasureLine: line=%d pos=%d next=NULL width=%d\n",
 			      num, pos, width));
     }
@@ -2023,7 +2029,7 @@ question with #if 1, it needs a little more investigation.....
     }
 
 #ifdef VERBOSE
-    DEBUGOUT(_LtDebugDebug(__FILE__, (Widget)w,
+    DEBUGOUT(_LtDebug(__FILE__, (Widget)w,
 	      "DrawInsertionPoint Cursor : Pos %d, Save %sValid, %s Visible\n",
 		      pos, Out_CursorSaveValid(o) ? "" : "not ",
 		      Out_CursorPositionVisible(o) ? "" : "not"));
@@ -2076,7 +2082,7 @@ question with #if 1, it needs a little more investigation.....
 #endif
 
 #ifdef VERBOSE
-	    DEBUGOUT(_LtDebugDebug(__FILE__, (Widget)w, "Draw cursor at %d %d\n",
+	    DEBUGOUT(_LtDebug(__FILE__, (Widget)w, "Draw cursor at %d %d\n",
 			      Out_CursorX(o), Out_CursorY(o)));
 #endif
 
@@ -2087,7 +2093,7 @@ question with #if 1, it needs a little more investigation.....
 #if VERBOSE
     if (_LtDebugInDebug(__FILE__, (Widget)w))
     {
-	DEBUGOUT(_LtDebugDebug(__FILE__, (Widget)w,
+	DEBUGOUT(_LtDebug(__FILE__, (Widget)w,
 			  "DrawInsertionPoint: x=%d pos=%d state=%s\n",
 			  Out_CursorX(o), pos, (state == on ? "on" : "off")));
     }
@@ -2183,28 +2189,28 @@ OutputGetValues(Widget w, ArgList args, Cardinal num_args)
 
 #if VERBOSE
     /* Just print a list of resources requested */
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "OutputGetValues"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "OutputGetValues"));
 
     if (_LtDebugInDebug(__FILE__, w) && num_args != 0)
     {
 	int i;
 
-	DEBUGOUT(_LtDebugDebug0(__FILE__, w, "("));
+	DEBUGOUT(_LtDebug0(__FILE__, w, "("));
 	for (i = 0; i < num_args - 1; i++)
 	{
-	    DEBUGOUT(_LtDebugDebug0(__FILE__, w, "%s, ", args[i].name));
+	    DEBUGOUT(_LtDebug0(__FILE__, w, "%s, ", args[i].name));
 	}
 
-	DEBUGOUT(_LtDebugDebug0(__FILE__, w, "%s)", args[num_args - 1].name));
+	DEBUGOUT(_LtDebug0(__FILE__, w, "%s)", args[num_args - 1].name));
     }
-    DEBUGOUT(_LtDebugDebug0(__FILE__, w, "\n"));
+    DEBUGOUT(_LtDebug0(__FILE__, w, "\n"));
 #endif
 
     XtGetSubvalues(iw, output_resources, XtNumber(output_resources),
 		   args, num_args);
     if (_LtDebugInDebug(__FILE__, w))
     {
-	DEBUGOUT(_LtDebugDebug(__FILE__, w, "OutputGetValues :\n"));
+	DEBUGOUT(_LtDebug(__FILE__, w, "OutputGetValues :\n"));
 	_LtDebugPrintArgList(__FILE__, w, args, num_args, True);
     }
 }
@@ -2236,7 +2242,7 @@ OutputSetValues(Widget old, Widget request, Widget new_w,
     Boolean redraw = False;
 
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, new_w,
+    DEBUGOUT(_LtDebug(__FILE__, new_w,
 		      "OutputSetValues: %i args\n"
 		      "\t    old X %5i Y %5i W %5i H %5i\n"
 		      "\trequest X %5i Y %5i W %5i H %5i\n"
@@ -2277,7 +2283,7 @@ OutputSetValues(Widget old, Widget request, Widget new_w,
 
     if (Out_FontList(od) != Out_FontList(nd))
     {
-	DEBUGOUT(_LtDebugDebug(__FILE__, new_w,
+	DEBUGOUT(_LtDebug(__FILE__, new_w,
 			  "OutputSetValues: FontList change.\n"));
 
 	/* T. Straumann: make a copy of the font list and free the old one */
@@ -2327,7 +2333,7 @@ OutputSetValues(Widget old, Widget request, Widget new_w,
 
     if (Out_WordWrap(od) != Out_WordWrap(nd))
     {
-	DEBUGOUT(_LtDebugDebug(__FILE__, new_w,
+	DEBUGOUT(_LtDebug(__FILE__, new_w,
 			  "OutputSetValues: WordWrap change.\n"));
 		/*CP:15 May 1999:rebuild the line table */
 	_XmTextUpdateLineTable(new_w, 0, 0, NULL, False); 
@@ -2336,7 +2342,7 @@ OutputSetValues(Widget old, Widget request, Widget new_w,
 
     if (Out_CursorPositionVisible(od) != Out_CursorPositionVisible(nd))
     {
-	DEBUGOUT(_LtDebugDebug(__FILE__, new_w,
+	DEBUGOUT(_LtDebug(__FILE__, new_w,
 			  "OutputSetValues: CursorPosVis change.\n"));
 
 	/* FIX ME ?? */
@@ -2347,7 +2353,7 @@ OutputSetValues(Widget old, Widget request, Widget new_w,
 
     if (Out_Rows(od) != Out_Rows(nd))
     {
-	DEBUGOUT(_LtDebugDebug(__FILE__, new_w, "OutputSetValues: Rows change.\n"));
+	DEBUGOUT(_LtDebug(__FILE__, new_w, "OutputSetValues: Rows change.\n"));
 
 	/* FIX ME ? */
 	XtHeight(new_w) = Out_Rows(nd) * Out_FontHeight(nd)
@@ -2358,7 +2364,7 @@ OutputSetValues(Widget old, Widget request, Widget new_w,
 
     if (Out_Columns(od) != Out_Columns(nd))
     {
-	DEBUGOUT(_LtDebugDebug(__FILE__, new_w, "OutputSetValues: Columns change.\n"));
+	DEBUGOUT(_LtDebug(__FILE__, new_w, "OutputSetValues: Columns change.\n"));
 
 	/* FIX ME ? */
 #ifdef USE_AVERAGE_WIDTH
@@ -2441,7 +2447,7 @@ destroy(Widget aw)
     XmTextWidget w = (XmTextWidget)aw;
     OutputData o = Text_OutputData(w);
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, aw, "destroy\n"));
+    DEBUGOUT(_LtDebug(__FILE__, aw, "destroy\n"));
 
     if (o && Out_TimerId(o))
     {
@@ -2451,11 +2457,19 @@ destroy(Widget aw)
 
     if (o && Out_DrawGC(o))
     {
+#ifdef	USE_XT_GC
+	XtReleaseGC(aw, Out_DrawGC(o));
+#else
 	XFreeGC(XtDisplay(w), Out_DrawGC(o));
+#endif
     }
     if (o && Out_CursorGC(o))
     {
+#ifdef	USE_XT_GC
+	XtReleaseGC(aw, Out_CursorGC(o));
+#else
 	XFreeGC(XtDisplay(w), Out_CursorGC(o));
+#endif
     }
     if (o && Out_CopyGC(o))
     {
@@ -2489,7 +2503,7 @@ OutputExpose(Widget aw, XEvent *event, Region region)
 {
     XmTextWidget w = (XmTextWidget)aw;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, aw, "OutputExpose: cursor pos: %d\n",
+    DEBUGOUT(_LtDebug(__FILE__, aw, "OutputExpose: cursor pos: %d\n",
 		      Text_CursorPos(w)));
 
     if (!XtIsRealized(aw))
@@ -2536,17 +2550,18 @@ OutputExpose(Widget aw, XEvent *event, Region region)
 static void
 OutputRealize(Widget aw, XtValueMask *value_mask, XSetWindowAttributes *attributes)
 {
-    XmTextWidget w = (XmTextWidget)aw;
+	XmTextWidget w = (XmTextWidget)aw;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, aw, "OutputRealize\n"));
+	DEBUGOUT(_LtDebug(__FILE__, aw, "OutputRealize (fl %p)\n",
+		Out_FontList(Text_OutputData(aw))));
 
-    GCInitialize(w);
-    GCClip(w);
+	GCInitialize(w);
+	GCClip(w);
 
-    CursorSet(w, False);
+	CursorSet(w, False);
 
 #if 0
-    CursorSaveUnderIBeam(w, 0, 0);
+	CursorSaveUnderIBeam(w, 0, 0);
 #endif
 }
 
@@ -2608,9 +2623,9 @@ _XmTextOutputCreate(Widget aw, ArgList args, Cardinal num_args)
     XmTextInnerWidget iw = (XmTextInnerWidget)w->text.inner_widget;
     Dimension width, height;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, aw, "_XmTextOutputCreate("));
+    DEBUGOUT(_LtDebug(__FILE__, aw, "_XmTextOutputCreate("));
     DEBUGOUT(_LtDebugPrintArgList(__FILE__, aw, args, num_args, False));
-    DEBUGOUT(_LtDebugDebug0(__FILE__, aw, ")\n"));
+    DEBUGOUT(_LtDebug0(__FILE__, aw, ")\n"));
 
     Text_Output(w) = (Output)XtMalloc(sizeof(OutputRec));
     memcpy(Text_Output(w), &outputRec, sizeof(OutputRec));
@@ -2662,7 +2677,7 @@ _XmTextOutputCreate(Widget aw, ArgList args, Cardinal num_args)
 
     FontInit(w);
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, aw,
+    DEBUGOUT(_LtDebug(__FILE__, aw,
 		      "OutputCreate (initially) : rows %d cols %d\n",
 		      Out_Rows(o), Out_Columns(o)));
 
@@ -2712,7 +2727,7 @@ _XmTextOutputCreate(Widget aw, ArgList args, Cardinal num_args)
 	}
     }
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, aw,
+    DEBUGOUT(_LtDebug(__FILE__, aw,
 		      "OutputCreate: rows %d cols %d\n",
 		      Out_Rows(o), Out_Columns(o)));
     Out_ColumnsSet(o) = Out_Columns(o);
@@ -2724,7 +2739,7 @@ _XmTextOutputCreate(Widget aw, ArgList args, Cardinal num_args)
 	XtWidth(w) = width;
 	XtHeight(w) = height;
 
-	DEBUGOUT(_LtDebugDebug(__FILE__, aw, "GetPreferredSize -> wid %d ht %d\n",
+	DEBUGOUT(_LtDebug(__FILE__, aw, "GetPreferredSize -> wid %d ht %d\n",
 			  width, height));
     }
 
@@ -3031,7 +3046,7 @@ _XmTextFindLineEnd(XmTextWidget w, XmTextPosition pos, LineTableExtra *extra)
     width = FontTextWidth(w, pos, end);
     if (width < avail)
     {
-	DEBUGOUT(_LtDebugDebug(__FILE__, (Widget)w,
+	DEBUGOUT(_LtDebug(__FILE__, (Widget)w,
 			  "_XmTextFindLineEnd(%d) => %d [avail %d width %d]\n",
 			  pos, end, avail, width));
 
@@ -3080,7 +3095,7 @@ _XmTextFindLineEnd(XmTextWidget w, XmTextPosition pos, LineTableExtra *extra)
     /* Take the previous position */
     if (last < end)
     {
-	DEBUGOUT(_LtDebugDebug(__FILE__, (Widget)w,
+	DEBUGOUT(_LtDebug(__FILE__, (Widget)w,
 			  "_XmTextFindLineEnd(%d) => %d [avail %d width %d]\n",
 			  pos, last, avail, width));
 
@@ -3088,7 +3103,7 @@ _XmTextFindLineEnd(XmTextWidget w, XmTextPosition pos, LineTableExtra *extra)
     }
     else
     {
-	DEBUGOUT(_LtDebugDebug(__FILE__, (Widget)w,
+	DEBUGOUT(_LtDebug(__FILE__, (Widget)w,
 			  "_XmTextFindLineEnd(%d) => %d [avail %d width %d]\n",
 			  pos, PASTENDPOS, avail, width));
 
@@ -3100,9 +3115,7 @@ _XmTextFindLineEnd(XmTextWidget w, XmTextPosition pos, LineTableExtra *extra)
 extern void
 _XmTextMovingCursorPosition(XmTextWidget tw, XmTextPosition position)
 {
-/*CP
-    OutputData o = Text_OutputData(tw);
-    (*Text_Output(tw)->DrawInsertionPoint) (tw, position, Out_BlinkState(o)); */
+	XmTextShowPosition((Widget)tw, position);
 }
 
 
@@ -3118,13 +3131,13 @@ extern int
 _XmOut_FontTextWidth(OutputData o, char *s, int l)
 {
 
-    if (Out_FontList(o)->type == XmFONT_IS_FONT)
+    if (Out_FontList(o)->renditions[0]->type == XmFONT_IS_FONT)
     {
 	return XTextWidth(Out_Font(o), s, l);
     }
     else
     {
-	return XmbTextEscapement((XFontSet)Out_FontList(o)->font, s, l);
+	return XmbTextEscapement((XFontSet)Out_FontList(o)->renditions[0]->font, s, l);
     }
 
 }
@@ -3135,7 +3148,7 @@ extern int
 _XmOut_FontMaxWidth(OutputData o)
 {
 
-    if (Out_FontList(o)->type == XmFONT_IS_FONT)
+    if (Out_FontList(o)->renditions[0]->type == XmFONT_IS_FONT)
     {
 	return Out_Font(o)->max_bounds.width;
     }
@@ -3145,7 +3158,7 @@ _XmOut_FontMaxWidth(OutputData o)
 	char **nl;
 	int i, num, max;
 
-	num = XFontsOfFontSet((XFontSet)Out_FontList(o)->font, &fsl, &nl);
+	num = XFontsOfFontSet((XFontSet)Out_FontList(o)->renditions[0]->font, &fsl, &nl);
 	max = 0;
 	for(i=0; i<num; i++){
 	    if (fsl[i]->max_bounds.width  > max)
