@@ -1,9 +1,9 @@
 /**
  *
- * $Header: /cvsroot/lesstif/lesstif/lib/Xm/TextStrSo.c,v 1.55 2001/05/14 19:46:11 amai Exp $
+ * $Header: /cvsroot/lesstif/lesstif/lib/Xm/TextStrSo.c,v 1.58 2001/11/26 19:40:24 dannybackx Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
- * Copyright (C) 1995-2001 LessTif Development Team
+ * Copyright  1995, 1996, 1997, 1998, 1999, 2000, 2001 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -23,7 +23,7 @@
  *
  **/
 
-static const char rcsid[] = "$Id: TextStrSo.c,v 1.55 2001/05/14 19:46:11 amai Exp $";
+static const char rcsid[] = "$Id: TextStrSo.c,v 1.58 2001/11/26 19:40:24 dannybackx Exp $";
 
 /*
  * Empirical evidence (fooling around with the structures found in Motif
@@ -40,7 +40,7 @@ static const char rcsid[] = "$Id: TextStrSo.c,v 1.55 2001/05/14 19:46:11 amai Ex
 #define	DO_SANITY
 
 /* Defining this is a bit too verbose for my liking ... */
-#undef VERBOSE__LtDebugDebug
+#undef VERBOSE__LtDebug
 
 #include <LTconfig.h>
 
@@ -273,7 +273,7 @@ CheckSize(XmSourceData d, int len)
 	d->maxlength += i + 1;
 	d->ptr = XtRealloc(d->ptr, d->maxlength);
 
-	DEBUGOUT(_LtDebugDebug(__FILE__, NULL,
+	DEBUGOUT(_LtDebug(__FILE__, NULL,
 			  "*source->CheckSize: Alloced new space\n"));
     }
 }
@@ -471,7 +471,7 @@ Replace(XmTextWidget w,
 			      block->length - end + start);
 	}
 
-#if 0
+#if 1
 	/* Update the insertion position */
 	for (i = 0; i < d->numwidgets; i++)
 	{
@@ -480,9 +480,9 @@ Replace(XmTextWidget w,
 	    if (p < *startret) {
 		    /* no action */
 	    } else if (p < *endret) {
-		    _XmTextSetCursorPosition(d->widgets[i], *startret);
+		    _XmTextSetCursorPosition((Widget)d->widgets[i], *startret);
 	    } else {
-		    _XmTextSetCursorPosition(d->widgets[i], p + block->length);
+		    _XmTextSetCursorPosition((Widget)d->widgets[i], p + block->length);
 	    }
 	}
 #endif
@@ -517,7 +517,7 @@ Scan(XmTextSource source, XmTextPosition pos, XmTextScanType type,
     XmSourceData d = source->data;
     Boolean found = False;
     char *ptr;
-#ifdef VERBOSE__LtDebugDebug
+#ifdef VERBOSE__LtDebug
     XmTextPosition ipos = pos;
 #endif
 
@@ -612,8 +612,8 @@ Scan(XmTextSource source, XmTextPosition pos, XmTextScanType type,
 
 	    if (found)
 	    {
-#ifdef VERBOSE__LtDebugDebug
-		DEBUGOUT(_LtDebugDebug(__FILE__, (Widget)d->widgets[0],
+#ifdef VERBOSE__LtDebug
+		DEBUGOUT(_LtDebug(__FILE__, (Widget)d->widgets[0],
 				  "Scan(%d)=>%d\n", ipos, pos));
 #endif
 		count--;
@@ -674,8 +674,8 @@ Scan(XmTextSource source, XmTextPosition pos, XmTextScanType type,
 
 	    if (found)
 	    {
-#ifdef VERBOSE__LtDebugDebug
-		DEBUGOUT(_LtDebugDebug(__FILE__, (Widget)d->widgets[0],
+#ifdef VERBOSE__LtDebug
+		DEBUGOUT(_LtDebug(__FILE__, (Widget)d->widgets[0],
 				  "Scan(%d)=>%d\n", ipos, pos));
 #endif
 		count--;
@@ -694,8 +694,8 @@ Scan(XmTextSource source, XmTextPosition pos, XmTextScanType type,
 	}
     }
 
-#ifdef VERBOSE__LtDebugDebug
-    DEBUGOUT(_LtDebugDebug(__FILE__, (Widget)d->widgets[0],
+#ifdef VERBOSE__LtDebug
+    DEBUGOUT(_LtDebug(__FILE__, (Widget)d->widgets[0],
 		      "Scan(%d)=>%d\n", ipos, pos));
 #endif
     if ( dir == XmsdRight && pos != d->length )
@@ -743,7 +743,7 @@ _XmTextConvertSelection(Widget w, Atom *selection, Atom *target, Atom *type,
 {
     XmSourceData d = Text_Source(w)->data;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "_XmTextConvertSelection\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "_XmTextConvertSelection\n"));
 
     if (d->hasselection)
     {
@@ -816,7 +816,7 @@ _XmTextLoseSelection(Widget w, Atom *selection)
 
     if (*selection == XA_PRIMARY)
     {
-	DEBUGOUT(_LtDebugDebug(__FILE__, w, "_XmTextLoseSelection(PRIMARY)\n"));
+	DEBUGOUT(_LtDebug(__FILE__, w, "_XmTextLoseSelection(PRIMARY)\n"));
 
 	XmTextSetHighlight(w, 0, XmTextGetLastPosition(w),
 			   XmHIGHLIGHT_NORMAL);
@@ -833,7 +833,7 @@ _XmTextLoseSelection(Widget w, Atom *selection)
     }
     else
     {
-	DEBUGOUT(_LtDebugDebug(__FILE__, w, "_XmTextLoseSelection(?)\n"));
+	DEBUGOUT(_LtDebug(__FILE__, w, "_XmTextLoseSelection(?)\n"));
 	/* ??? */
     }
 }
@@ -855,7 +855,7 @@ SetSelection(XmTextSource source, XmTextPosition left,
     int i;
     Boolean gain = False;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, NULL, "XmTextStrSource SetSelection %d %d\n",
+    DEBUGOUT(_LtDebug(__FILE__, NULL, "XmTextStrSource SetSelection %d %d\n",
 		      left, right));
 
     if (left >= right)
@@ -892,7 +892,7 @@ SetSelection(XmTextSource source, XmTextPosition left,
     source->data->prim_time = time;
 
     /* Xt, callbacks */
-    DEBUGOUT(_LtDebugDebug(__FILE__, (Widget)d->widgets[0],
+    DEBUGOUT(_LtDebug(__FILE__, (Widget)d->widgets[0],
 		      "XtOwnSelection(_, XA_PRIMARY, ...)\n"));
 
     if (!XtOwnSelection((Widget)d->widgets[0], XA_PRIMARY, time,
@@ -1009,7 +1009,7 @@ _XmStringSourceGetValue(XmTextSource source, Boolean want_wchar)
 
     if (want_wchar)
     {
-	DEBUGOUT(_LtDebugDebug(__FILE__, NULL,
+	DEBUGOUT(_LtDebug(__FILE__, NULL,
 	   "_XmStringSourceGetValue: wide characters not implemented yet.\n"));
 
 	/* Returning NULL seems to do strange things */
@@ -1023,7 +1023,7 @@ _XmStringSourceGetValue(XmTextSource source, Boolean want_wchar)
     strncpy(txt, d->ptr, d->length);
     txt[d->length] = '\0';
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, NULL,
+    DEBUGOUT(_LtDebug(__FILE__, NULL,
 		      "_XmStringSourceGetValue => %p '%s'\n", txt, txt));
 
     return txt;
@@ -1176,7 +1176,7 @@ _XmStringSourceGetString(XmTextWidget w,
 #else
     if (want_wchar)
     {
-	DEBUGOUT(_LtDebugDebug(__FILE__, NULL,
+	DEBUGOUT(_LtDebug(__FILE__, NULL,
 	  "_XmStringSourceGetString: wide characters not implemented yet.\n"));
 
 	return NULL;
