@@ -1,9 +1,9 @@
 /**
  *
- * $Id: ToggleBG.c,v 1.77 2001/05/14 19:46:11 amai Exp $
+ * $Header: /cvsroot/lesstif/lesstif/lib/Xm/ToggleBG.c,v 1.84 2002/04/20 18:32:33 dannybackx Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
- * Copyright (C) 1995-2001 LessTif Development Team
+ * Copyright  1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -23,7 +23,7 @@
  *
  **/
 
-static const char rcsid[] = "$Id: ToggleBG.c,v 1.77 2001/05/14 19:46:11 amai Exp $";
+static const char rcsid[] = "$Header: /cvsroot/lesstif/lesstif/lib/Xm/ToggleBG.c,v 1.84 2002/04/20 18:32:33 dannybackx Exp $";
 
 #include <LTconfig.h>
 
@@ -141,6 +141,7 @@ static void draw_toggle(Widget w, XEvent *event, Region region,
 			int is_expose, int visual_set);
 
 static int implicit_indicator(Widget w);
+static void _XmUnselectColorDefault(Widget, int, XrmValue *);
 
 /*
  * resources
@@ -201,7 +202,14 @@ static XtResource cache_resources[] =
 	XmNselectColor, XmCSelectColor, XmRPixel,
 	sizeof(Pixel), Offset(select_color),
 	XmRCallProc, (XtPointer)_XmSelectColorDefault
+    },
+#if XmVERSION > 1
+    {
+	XmNunselectColor, XmCUnselectColor, XmRPixel,
+	sizeof(Pixel), Offset(unselect_color),
+	XmRCallProc, (XtPointer)_XmUnselectColorDefault
     }
+#endif
 };
 
 static XmSyntheticResource cache_syn_resources[] =
@@ -217,7 +225,7 @@ static XmSyntheticResource cache_syn_resources[] =
 	_XmFromVerticalPixels, _XmToVerticalPixels
     }
 };
-/* *INDENT-OFF* */
+
 XmToggleButtonGCacheObjClassRec xmToggleButtonGCacheObjClassRec = {
     /* Object class part */
     {
@@ -383,6 +391,9 @@ static XmGadgetClassExtRec _XmToggleBGadgetClassExtRec = {
     /* size                      */ sizeof(XmGadgetClassExtRec),
     /* widget_baseline_proc      */ XmInheritBaselineProc,
     /* display_rect_proc         */ XmInheritDisplayRectProc,
+#if XmVERSION >= 2
+    /* margins_proc              */ XmInheritMarginsProc,
+#endif
 };
 
 XmToggleButtonGadgetClassRec xmToggleButtonGadgetClassRec = {
@@ -448,7 +459,6 @@ XmToggleButtonGadgetClassRec xmToggleButtonGadgetClassRec = {
 	/* extension */ NULL
     },
 };
-/* *INDENT-ON* */
 
 
 WidgetClass xmToggleButtonGadgetClass = (WidgetClass)&xmToggleButtonGadgetClassRec;
@@ -472,7 +482,7 @@ secondary_object_create(Widget request,
     XmWidgetExtData ed;
     Cardinal size;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, new_w,
+    DEBUGOUT(_LtDebug(__FILE__, new_w,
 		      "ToggleButtonGCacheRec %s being initialized.\n",
 		      XtName(new_w)));
 
@@ -602,6 +612,11 @@ CreateSelectGC(Widget w)
     values.background = XmParentBackground(w);
 
     TBG_SelectGC(w) = XtGetGC(w, mask, &values);
+
+#if XmVERSION > 1
+    values.foreground = TBG_UnselectColor(w);
+    TBG_UnselectGC(w) = XtGetGC(w, mask, &values);
+#endif
 }
 
 static void
@@ -630,7 +645,7 @@ initialize_posthook(Widget request, Widget new_w,
 {
     XmWidgetExtData ext;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, new_w, "ToggleBG InitializePosthook\n"));
+    DEBUGOUT(_LtDebug(__FILE__, new_w, "ToggleBG InitializePosthook\n"));
 
     /* don't let the null fool you */
     LabG_Cache(new_w) = (XmLabelGCacheObjPart *)
@@ -826,6 +841,10 @@ destroy(Widget w)
 {
     XtReleaseGC(w, TBG_SelectGC(w));
     XtReleaseGC(w, TBG_BackgroundGC(w));
+#if XmVERSION > 1
+    XtReleaseGC(w, TBG_UnselectGC(w));
+#endif
+
     _XmCacheDelete((XtPointer)TBG_Cache(w));
 }
 
@@ -940,7 +959,7 @@ set_values(Widget old, Widget request, Widget new_w,
 {
     Boolean refresh_needed = False;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, new_w, "ToggleBG set_values\n"));
+    DEBUGOUT(_LtDebug(__FILE__, new_w, "ToggleBG set_values\n"));
 
     if (TBG_IndType(old) != TBG_IndType(new_w) &&
 	!XmRepTypeValidValue(XmRepTypeGetId(XmRIndicatorType),
@@ -1273,7 +1292,7 @@ resize(Widget w)
 static void
 expose(Widget w, XEvent *event, Region region)
 {
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "ToggleBG Expose\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "ToggleBG Expose\n"));
     draw_toggle(w, event, region, True, 0);
 }
 
@@ -1334,6 +1353,8 @@ Select(Widget w, XEvent *event, String *params, Cardinal *num_params)
 	{
 	    RC_MenuMenuCallback(w, &cbs);
 	}
+	/* Menu callback might cancel the set (radioAlwaysOne). */
+	cbs.set = TBG_Set(w);
 	if (!LabG_SkipCallback(w) && TBG_ValueChangedCallback(w))
 	{
 	    XFlush(XtDisplay(w));
@@ -1620,7 +1641,7 @@ input_dispatch(Widget gadget, XEvent *event, Mask event_mask)
     {
     case XmARM_EVENT:
     case XmMULTI_ARM_EVENT:
-	DEBUGOUT(_LtDebugDebug(__FILE__, gadget,
+	DEBUGOUT(_LtDebug(__FILE__, gadget,
 			  "ToggleButtonGadget got arm event\n"));
 	if (IN_MENU(gadget))
 	{
@@ -1634,7 +1655,7 @@ input_dispatch(Widget gadget, XEvent *event, Mask event_mask)
 
     case XmACTIVATE_EVENT:
     case XmMULTI_ACTIVATE_EVENT:
-	DEBUGOUT(_LtDebugDebug(__FILE__, gadget,
+	DEBUGOUT(_LtDebug(__FILE__, gadget,
 			  "ToggleButtonGadget got activate event\n"));
 	if (IN_MENU(gadget))
 	{
@@ -1648,19 +1669,19 @@ input_dispatch(Widget gadget, XEvent *event, Mask event_mask)
 	break;
 
     case XmENTER_EVENT:
-	DEBUGOUT(_LtDebugDebug(__FILE__, gadget,
+	DEBUGOUT(_LtDebug(__FILE__, gadget,
 			  "ToggleButtonGadget enter window\n"));
 	EnterWindow(gadget, event, NULL, &num_params);
 	break;
 
     case XmLEAVE_EVENT:
-	DEBUGOUT(_LtDebugDebug(__FILE__, gadget,
+	DEBUGOUT(_LtDebug(__FILE__, gadget,
 			  "ToggleButtonGadget leave window\n"));
 	LeaveWindow(gadget, event, NULL, &num_params);
 	break;
 
     case XmMOTION_EVENT:
-	DEBUGOUT(_LtDebugDebug(__FILE__, gadget,
+	DEBUGOUT(_LtDebug(__FILE__, gadget,
 			  "ToggleButtonGadget motion event\n"));
 	break;
 
@@ -2095,6 +2116,7 @@ draw_toggle(Widget w, XEvent *event, Region region, int is_expose,
 				       dim - (delta << 1), dim - (delta << 1));
 		    }
 #if XmVERSION > 1
+#if 0	/* HACK Danny */
 		    if ((TBG_IndOn(w) & ~INDICATOR_BOX_MASK) &&
 			(visual_set || !(is_expose || TBG_FillOnSelect(w))))
 		    {
@@ -2106,7 +2128,32 @@ draw_toggle(Widget w, XEvent *event, Region region, int is_expose,
 					   : TBG_BackgroundGC(w),
 					 x, y, dim, dim, delta,
 					 TBG_IndOn(w));
-		    }
+		     }
+#else	/* Hack Danny */
+			if (visual_set == XmUNSET) {
+				XFillRectangle(XtDisplayOfObject(w),
+					XtWindowOfObject(w),
+					TBG_UnselectGC(w),
+					x, y, dim, dim);
+
+				_XmDrawShadows(XtDisplay(w), XtWindow(w),
+#if XmVERSION == 1
+				   XmParentTopShadowGC(w), XmParentBottomShadowGC(w),
+#else
+				   visual_set == XmINDETERMINATE
+				   ? LabG_InsensitiveGC(w)
+				   : (TBG_IndOn(w) & INDICATOR_BOX_MASK)
+				   == XmINDICATOR_FLAT_BOX
+				   ? XmParentBottomShadowGC(w)
+				   : XmParentTopShadowGC(w),
+				   visual_set == XmINDETERMINATE
+				   ? LabG_InsensitiveGC(w)
+				   : XmParentBottomShadowGC(w),
+#endif
+				   x, y, dim, dim, DETAIL_SHADOW_THICKNESS(w),
+				   visual_set ? XmSHADOW_IN : XmSHADOW_OUT);
+			}
+#endif
 #endif
 		}
 	    }
@@ -2132,15 +2179,21 @@ draw_toggle(Widget w, XEvent *event, Region region, int is_expose,
 #endif
 
 	default: /* XmONE_OF_MANY[_DIAMOND] */
-	    _XmDrawDiamond(XtDisplay(w), XtWindow(w), visual_set
-			   ? XmParentBottomShadowGC(w) : TBG_Visible(w)
-			     ? XmParentTopShadowGC(w) : TBG_BackgroundGC(w),
-			   visual_set ? XmParentTopShadowGC(w) : TBG_Visible(w)
-			     ? XmParentBottomShadowGC(w) : TBG_BackgroundGC(w),
-			   (is_expose || TBG_FillOnSelect(w))
-			   ? visual_set && TBG_FillOnSelect(w)
-			     ? TBG_SelectGC(w) : TBG_BackgroundGC(w) : NULL,
-			   x, y, dim, dim, DETAIL_SHADOW_THICKNESS(w),
+	    _XmDrawDiamond(XtDisplay(w), XtWindow(w),
+		visual_set ? XmParentBottomShadowGC(w) :
+			TBG_Visible(w) ? XmParentTopShadowGC(w) : TBG_BackgroundGC(w),
+		visual_set ? XmParentTopShadowGC(w) :
+			TBG_Visible(w) ? XmParentBottomShadowGC(w) : TBG_BackgroundGC(w),
+		(is_expose || TBG_FillOnSelect(w))
+			? (visual_set && TBG_FillOnSelect(w))
+				? TBG_SelectGC(w)
+#if XmVERSION > 1
+				: TBG_UnselectGC(w)
+#else
+				: TBG_BackgroundGC(w)
+#endif
+			: NULL,
+		x, y, dim, dim, DETAIL_SHADOW_THICKNESS(w),
 #if XmVERSION == 1
 			   fill);
 #else
@@ -2238,6 +2291,8 @@ XmToggleButtonGadgetSetState(Widget w, Boolean state, Boolean notify)
 	    {
 		RC_MenuMenuCallback(w, &cbs);
 	    }
+	    /* Menu callback might cancel the set (radioAlwaysOne). */
+	    cbs.set = TBG_Set(w);
 	    if (!LabG_SkipCallback(w) && TBG_ValueChangedCallback(w))
 	    {
 		XFlush(XtDisplay(w));
@@ -2248,3 +2303,27 @@ XmToggleButtonGadgetSetState(Widget w, Boolean state, Boolean notify)
     }
     _XmObjectUnlock(w);
 }
+
+static void
+_XmUnselectColorDefault(Widget w, int offset, XrmValue *val)
+{
+	DEBUGOUT(_LtDebug(__FILE__, w, "_XmUnselectColorDefault\n"));
+
+#if XmVERSION > 1
+	/*
+	 * XmNunselectColor
+	 * This resource's default for a color display is XmNbackground.
+	 * For a monochrome display, the default is set to the background color.
+	 * To set the background of the button to XmNunselectColor when
+	 * XmNindicatorOn is XmINDICATOR_NONE, the value of XmNfillOnSelect must
+	 * be explicitly set to True.
+	 */
+	val->size = sizeof(Pixel);
+	val->addr = (XtPointer)&CoreBackground(w);
+#if 0
+	if (DefaultDepth(XtDisplay(w), 0) == 1) {	/* Mono */
+	} else {					/* Colour */
+	}
+#endif
+#endif
+}
