@@ -1,9 +1,9 @@
 /**
  *
- * $Id: Vendor.c,v 1.77 2001/05/20 11:27:21 amai Exp $
+ * $Header: /cvsroot/lesstif/lesstif/lib/Xm/Vendor.c,v 1.92 2002/03/23 18:24:41 dannybackx Exp $
  *
  * Copyright (C) 1996 Free Software Foundation, Inc.
- * Copyright (C) 1996-2001 LessTif Development Team
+ * Copyright  1996, 1997, 1998, 1999, 2000, 2001, 2002 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -23,7 +23,7 @@
  *
  **/
 
-static const char rcsid[] = "$Id: Vendor.c,v 1.77 2001/05/20 11:27:21 amai Exp $";
+static const char rcsid[] = "$Id: Vendor.c,v 1.92 2002/03/23 18:24:41 dannybackx Exp $";
 
 #include <LTconfig.h>
 
@@ -31,7 +31,7 @@ static const char rcsid[] = "$Id: Vendor.c,v 1.77 2001/05/20 11:27:21 amai Exp $
 #include <stdlib.h>
 #include <string.h>
 
-/* amai: This is not very nice ...
+/* amai, 5/2001: (This is not very nice ...)
    Later on we use some internal stuff from the Intrinsics which we 
    should _not_ use. In rare conditions we may lack some stuff from the
    headers if this setting is not done (-> e.g. _XtBoolean).
@@ -46,7 +46,10 @@ static const char rcsid[] = "$Id: Vendor.c,v 1.77 2001/05/20 11:27:21 amai Exp $
 #include <X11/ShellP.h>
 #include <X11/Vendor.h>
 #include <X11/VendorP.h>
+
 #include <XmI/XmI.h>
+#include <XmI/AtomMgrI.h>
+
 #include <Xm/XmP.h>
 #include <Xm/AtomMgr.h>
 #include <Xm/BulletinBP.h>
@@ -62,19 +65,21 @@ static const char rcsid[] = "$Id: Vendor.c,v 1.77 2001/05/20 11:27:21 amai Exp $
 #include <Xm/DialogSEP.h>
 #include <Xm/ExtObjectP.h>
 #include <Xm/VendorS.h>
-#include <XmI/AtomMgrI.h>
-
-#include <XmI/DebugUtil.h>
-
 
 #if XmVERSION > 1
 #include <Xm/TraitP.h>
 #endif
 
-/* We use a 'private', i.e. non-declared but actually
-   exported call from OpenGroup's Intrinsic sources
-   (lib/Xt/Callback.c) in this file.
-   Note that we don't give the precise type here ...
+#include <XmI/DebugUtil.h>
+
+#ifdef __EMX__
+extern void _LtXmFixupVendorShell(void);
+unsigned long _DLL_InitTerm(unsigned long mod_handle, unsigned long flag);
+#endif
+
+/* We use a 'private', i.e. non-declared, but actually exported call
+    from the original Intrinsic sources (lib/Xt/Callback.c) here.
+    Note that we don't give the precise prototype:
  */
 extern void 
 _XtRemoveCallback (
@@ -141,6 +146,7 @@ static void LTShellPopupCallback(Widget w,
 static void LTShellPopdownCallback(Widget w,
 				   XtPointer ClientData,
 				   XtPointer CallbackData);
+static void LTGrabRelatives(XmVendorShellExtObject grabber);
 static void VendorFromHorizontalPixels(Widget w, int offset, XtArgVal *value);
 static void VendorFromVerticalPixels(Widget w, int offset, XtArgVal *value);
 static XmImportOperator VendorToHorizontalPixels(Widget w, int offset,
@@ -148,6 +154,8 @@ static XmImportOperator VendorToHorizontalPixels(Widget w, int offset,
 static XmImportOperator VendorToVerticalPixels(Widget w, int offset,
 					       XtArgVal *value);
 
+static Bool ConfigEventForMe(Display *dpy, XEvent *event, char *arg);
+
 /*
  * the following is for the extension record for LessTif Vendor Shells
  * this is needed before the shell record as the shell's base class extension
@@ -263,6 +271,19 @@ static XtResource ext_resources[] =
 	sizeof(int), Offset(foreground_threshold),
 	XtRImmediate, (XtPointer)0
     },
+#if XmVERSION > 1
+    /* FIX ME which version does this originate at ? */
+    {
+	XmNlayoutDirection, XmCLayoutDirection, XmRDirection,
+	sizeof(XmDirection), Offset(layout_direction),
+	XtRImmediate, (XtPointer)XmLEFT_TO_RIGHT
+    },
+    {
+	XmNinputPolicy, XmCInputPolicy, XmRInputPolicy,
+	sizeof(XmInputPolicy), Offset(input_policy),
+	XtRImmediate, (XtPointer)XmPER_SHELL
+    },
+#endif
 };
 
 
@@ -730,7 +751,7 @@ class_part_initialize(WidgetClass widget_class)
     CompositeClassExtension ext, *extptr;
     VendorShellWidgetClass vsclass = (VendorShellWidgetClass)widget_class;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, NULL,
+    DEBUGOUT(_LtDebug(__FILE__, NULL,
 		      "Vendor Shell's class_part_initialize()\n"));
 
     extptr = (CompositeClassExtension *)_XmGetClassExtensionPtr((XmGenericClassExt *)&(vsclass->composite_class.extension),
@@ -903,6 +924,8 @@ secondary_object_create(Widget req, Widget new_w,
 
     bce = _XmGetBaseClassExtPtr(XtClass(new_w), XmQmotif);
 
+    DEBUGOUT(_LtDebug(__FILE__, new_w, "secondary_object_create\n"));
+
     /*
      * The shell extension objects have their XmNdesktopParent set pointing
      * to the next higher level within the shells' hierarchy. The other
@@ -955,10 +978,12 @@ secondary_object_create(Widget req, Widget new_w,
     /*
      * Now install some callbacks for use with the grab mechanism...
      */
+    DEBUGOUT(_LtDebug2(__FILE__, new_w, ed->widget, "Install pop up/down callbacks\n"));
+
     XtAddCallback(new_w, XmNpopupCallback,
-		  LTShellPopupCallback, ed->widget);
+		  LTShellPopupCallback, (XtPointer)ed->widget);
     XtAddCallback(new_w, XmNpopdownCallback,
-		  LTShellPopdownCallback, ed->widget);
+		  LTShellPopdownCallback, (XtPointer)ed->widget);
 }
 
 
@@ -1014,8 +1039,7 @@ initialize(Widget req, Widget new_w,
     XtEventHandler str_not;
     XmShellExtClassRec *shellc;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, new_w,
-		      "####VendorShell %s initialize\n", XtName(new_w)));
+    DEBUGOUT(_LtDebug(__FILE__, new_w, "####VendorShell initialize\n"));
 
     ((WMShellWidget)new_w)->wm.wait_for_wm = True;
 
@@ -1038,7 +1062,7 @@ initialize(Widget req, Widget new_w,
 			  (XtEventHandler)_XmNSEEditResCheckMessages, NULL);
 #endif
 
-	DEBUGOUT(_LtDebugDebug(__FILE__, new_w,
+	DEBUGOUT(_LtDebug(__FILE__, new_w,
 			  "Setting up virtual key bindings\n"));
 
 	XtSetKeyTranslator(XtDisplay(new_w), (XtKeyProc)XmTranslateKey);
@@ -1074,12 +1098,12 @@ destroy(Widget w)
 {
     XmWidgetExtData data;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "VendorShell Destroy()\n"));
-    DEBUGOUT(_LtDebugDebug("NEDIT", w, "VendorShell Destroy()\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "VendorShell Destroy()\n"));
+    DEBUGOUT(_LtDebug("NEDIT", w, "VendorShell Destroy()\n"));
 
     _XmPopWidgetExtData(w, &data, XmSHELL_EXTENSION);
     if (data != NULL) {
-	DEBUGOUT(_LtDebugDebug2(__FILE__, w, data->widget,
+	DEBUGOUT(_LtDebug2(__FILE__, w, data->widget,
 		"VendorShell Destroy: destroy child\n"));
 
 	/* mitch
@@ -1098,7 +1122,7 @@ _XmVendorExtDestroy(Widget w)
 	Atom wm_delete_window;
 	Widget shell = ExtObj_LogicalParent(w);
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "VendorShellExt Destroy()\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "VendorShellExt Destroy()\n"));
 
 	if (VSEP_DefaultFontList(ve))
 	{
@@ -1134,11 +1158,9 @@ _XmVendorExtDestroy(Widget w)
 
 
 static void
-realize(Widget w,
-	XtValueMask *value_mask,
-	XSetWindowAttributes *attributes)
+realize(Widget w, XtValueMask *value_mask, XSetWindowAttributes *attributes)
 {
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "Realize\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "VendorRealize\n"));
 
     if (XtWidth(w) == 0)
     	XtWidth(w) = 1;
@@ -1182,7 +1204,7 @@ WmProtocolHandler(Widget w, XtPointer client, XtPointer call)
     XmVendorShellExtObject ve = (XmVendorShellExtObject)client;
     Cardinal i;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "WmProtocolHandler\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "WmProtocolHandler\n"));
 
     switch (VSEP_DeleteResponse(ve))
     {
@@ -1190,30 +1212,22 @@ WmProtocolHandler(Widget w, XtPointer client, XtPointer call)
 	XtDestroyWidget(w);
 	if (XtIsApplicationShell(w))
 	{
-	    DEBUGOUT(_LtDebugDebug(__FILE__, w,
+	    DEBUGOUT(_LtDebug(__FILE__, w,
 			      "WmProtocolHandler(DeleteResponse XmDESTROY) "
 			      "- Exiting (WM_DELETE_WINDOW)\n"));
 	    XtDestroyApplicationContext(XtWidgetToApplicationContext(w));
 	    exit(0);
 	}
-	DEBUGOUT(_LtDebugDebug(__FILE__, w,
+	DEBUGOUT(_LtDebug(__FILE__, w,
 			  "WmProtocolHandler(DeleteResponse XmDESTROY)\n"));
 	break;
 
     case XmUNMAP:
-	/* The word says UNMAP but we really have to unMANAGE */
-	for (i = 0; i < MGR_NumChildren(w); i++)
-	    if (XtIsManaged(MGR_Children(w)[i]))
-	    {
-		DEBUGOUT(_LtDebugDebug2(__FILE__, w, MGR_Children(w)[i],
-				   "XtUnmanageChild(child)\n"));
-		XtUnmanageChild(MGR_Children(w)[i]);
-		return;		/* Shells have only one managed child */
-	    }
+	XtPopdown(w);
 	break;
 
     case XmDO_NOTHING:
-	DEBUGOUT(_LtDebugDebug(__FILE__, w,
+	DEBUGOUT(_LtDebug(__FILE__, w,
 			  "WmProtocolHandler(DeleteResponse XmNO_NOTHING)\n"));
 	return;
     }
@@ -1272,7 +1286,7 @@ set_values_prehook(Widget old, Widget req, Widget new_w,
 
     _XmPushWidgetExtData(new_w, data, XmSHELL_EXTENSION);
 
-    XtSetSubvalues(data->widget,
+    XtSetSubvalues((XtPointer)data->widget,
                    (*bce)->secondaryObjectClass->core_class.resources,
                    (*bce)->secondaryObjectClass->core_class.num_resources,
                    args, *num_args);
@@ -1299,44 +1313,51 @@ set_values_posthook(Widget old, Widget req, Widget new_w,
     return False;
 }
 
-
 static Boolean
-set_values(Widget old, Widget req, Widget new_w,
-	   ArgList args, Cardinal *num_args)
+set_values(Widget old, Widget req, Widget new_w, ArgList args, Cardinal *num_args)
 {
-    XmWidgetExtData data;
-    Boolean refresh = False;
+	XmWidgetExtData		data;
+	Boolean			refresh = False;
+	XmVendorShellExtObject	ve;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, new_w,
-		      "%s:set_values(%d): %i args\n"
-		      "\t    old X %5i Y %5i W %5i H %5i\n"
-		      "\trequest X %5i Y %5i W %5i H %5i\n"
-		      "\t  new_w X %5i Y %5i W %5i H %5i\n",
-		      __FILE__, __LINE__,
-		      *num_args,
-		      XtX(old), XtY(old),
-		      XtWidth(old), XtHeight(old),
-		      XtX(req), XtY(req),
-		      XtWidth(req), XtHeight(req),
-		      XtX(new_w), XtY(new_w),
-		      XtWidth(new_w), XtHeight(new_w)));
-    DEBUGOUT(_LtDebugPrintArgList(__FILE__, new_w, args, *num_args, False));
+	DEBUGOUT(_LtDebug(__FILE__, new_w,
+		"VendorSetValues: %i args\n"
+		"\t    old X %5i Y %5i W %5i H %5i\n"
+		"\trequest X %5i Y %5i W %5i H %5i\n"
+		"\t  new_w X %5i Y %5i W %5i H %5i\n",
+		*num_args,
+		XtX(old), XtY(old),
+		XtWidth(old), XtHeight(old),
+		XtX(req), XtY(req),
+		XtWidth(req), XtHeight(req),
+		XtX(new_w), XtY(new_w),
+		XtWidth(new_w), XtHeight(new_w)));
+	DEBUGOUT(_LtDebugPrintArgList(__FILE__, new_w, args, *num_args, False));
 
-    data = _XmGetWidgetExtData(new_w, XmSHELL_EXTENSION);
-    if (data)
-    {
-	refresh = _XmVendorExtSetValues(data->oldWidget, data->reqWidget,
+	data = _XmGetWidgetExtData(new_w, XmSHELL_EXTENSION);
+	if (data) {
+		refresh = _XmVendorExtSetValues(data->oldWidget, data->reqWidget,
 					data->widget, args, num_args);
-    }
+	}
 
-    return refresh;
+	return refresh;
 }
 
+extern void
+_LtVendorUnmap(Widget child)
+{
+	XmWidgetExtData data = _XmGetWidgetExtData(XtParent(child), XmSHELL_EXTENSION);
+	XmVendorShellExtObject ve;
+
+	DEBUGOUT(_LtDebug2(__FILE__, XtParent(child), child, "_LtVendorUnmap\n"));
+	if (data) {
+		ve = (XmVendorShellExtObject)data->widget;
+		LTRemoveGrab(NULL, ve, True);
+	}
+}
 
 static void
-get_values_prehook(Widget widget,
-		   ArgList args,
-		   Cardinal *num_args)
+get_values_prehook(Widget widget, ArgList args, Cardinal *num_args)
 {
     XmBaseClassExt *bce;
     XmWidgetExtData data;
@@ -1358,7 +1379,7 @@ get_values_prehook(Widget widget,
 
     _XmPushWidgetExtData(widget, data, XmSHELL_EXTENSION);
 
-    XtGetSubvalues(data->widget,
+    XtGetSubvalues((XtPointer)data->widget,
                    (*bce)->secondaryObjectClass->core_class.resources,
                    (*bce)->secondaryObjectClass->core_class.num_resources,
 		   args, *num_args);
@@ -1368,26 +1389,21 @@ get_values_prehook(Widget widget,
 
 
 static void
-get_values_posthook(Widget widget,
-		    ArgList args,
-		    Cardinal *num_args)
+get_values_posthook(Widget widget, ArgList args, Cardinal *num_args)
 {
-    XmWidgetExtData ext;
+	XmWidgetExtData ext;
 
-    _XmPopWidgetExtData(widget, &ext, XmSHELL_EXTENSION);
-
-    _XmExtObjFree((XtPointer)ext->widget);
-
-    XtFree((char *)ext);
+	_XmPopWidgetExtData(widget, &ext, XmSHELL_EXTENSION);
+	_XmExtObjFree((XtPointer)ext->widget);
+	XtFree((char *)ext);
 }
 
-
 static void
 change_managed(Widget wid)
 {
     int i;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, wid, "change_managed()\n"));
+    DEBUGOUT(_LtDebug(__FILE__, wid, "VendorChangeManaged()\n"));
 #define superclass (&wmShellClassRec)
     (*superclass->composite_class.change_managed) (wid);
 #undef superclass
@@ -1402,19 +1418,17 @@ change_managed(Widget wid)
     }
 }
 
-
 static void
 insert_child(Widget w)
 {
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "insert_child()\n"));
-    /* Keep those pesky objects OUT of the child list */
-    if (!XtIsRectObj(w))
-    {
-	return;
-    }
+	DEBUGOUT(_LtDebug(__FILE__, w, "insert_child()\n"));
+	/* Keep those pesky objects OUT of the child list */
+	if (!XtIsRectObj(w)) {
+		return;
+	}
 
 #define superclass (&wmShellClassRec)
-    (*superclass->composite_class.insert_child) (w);
+	(*superclass->composite_class.insert_child) (w);
 #undef superclass
 }
 
@@ -1422,8 +1436,8 @@ insert_child(Widget w)
 static void
 delete_child(Widget w)
 {
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "delete_child()\n"));
-    DEBUGOUT(_LtDebugDebug2("RWS", XtParent(w), w,"%s:delete_child(%d)\n",
+    DEBUGOUT(_LtDebug(__FILE__, w, "delete_child()\n"));
+    DEBUGOUT(_LtDebug2("RWS", XtParent(w), w,"%s:delete_child(%d)\n",
     	__FILE__, __LINE__
     	));
     /* Keep those pesky objects OUT of the child list */
@@ -1456,10 +1470,10 @@ dump_grab_list(Widget w)
 
     if (_LtDebugInDebug(__FILE__, w))
     {
-	DEBUGOUT(_LtDebugDebug(__FILE__, w, "Current Grab List\n"));
+	DEBUGOUT(_LtDebug(__FILE__, w, "Current Grab List\n"));
 	for (i = 0; i < Display_NumModals(w); i++)
 	{
-	    DEBUGOUT(_LtDebugDebug(__FILE__, w, " Wid: %p (%s) ve: %p grabber: %p exclusive: %d sprung: %d\n",
+	    DEBUGOUT(_LtDebug(__FILE__, w, " Wid: %p (%s) ve: %p grabber: %p exclusive: %d sprung: %d\n",
 		   Display_Modals(w)[i].wid,
 		   XtName(Display_Modals(w)[i].wid),
 		   Display_Modals(w)[i].ve,
@@ -1484,74 +1498,80 @@ static void
 LTAddGrab(Widget wid, Boolean exclusive, Boolean spring_loaded,
 	  XmVendorShellExtObject ve, XmVendorShellExtObject grabber)
 {
-    Widget d;
-    XmModalData modal;
+	Widget d;
+	XmModalData	modal = NULL, ps;
+	int i;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, wid, "LTAddGrab\n"));
-    /*
-     * If there's no widget wid specified, we'll take the logical parent
-     * of the vendor shell extension object as the grab destination instead.
-     */
-    if (wid == NULL)
-    {
-	wid = ExtObj_LogicalParent(ve);
-    }
-
-    d = XmGetXmDisplay(XtDisplayOfObject(wid));
-    {
-    int i;
-    XmModalData ps = Display_Modals(d);
-
-	for (i = Display_NumModals(d); i > 0; i--, ps++)
-	{
-	    if (ps->wid == wid)
-	    {
-		return;
-	    }
+	/*
+	 * If there's no widget wid specified, we'll take the logical parent
+	 * of the vendor shell extension object as the grab destination instead.
+	 */
+	if (wid == NULL) {
+		wid = ExtObj_LogicalParent(ve);
+		DEBUGOUT(_LtDebug(__FILE__, wid, "LTAddGrab(NULL)\n"));
+	} else {
+		DEBUGOUT(_LtDebug(__FILE__, wid, "LTAddGrab\n"));
 	}
-    }
-    dump_grab_list(d);
 
-    /* grow the modal list, if necessary */
-    if (Display_NumModals(d) >= Display_MaxModals(d))
-    {
-	Display_MaxModals(d) += 8;
-	Display_Modals(d) = (XmModalData)XtRealloc((char *)Display_Modals(d),
-						   sizeof(XmModalDataRec) *
-						   Display_MaxModals(d));
-    }
+	d = XmGetXmDisplay(XtDisplayOfObject(wid));
+	ps = Display_Modals(d);
+	for (i = Display_NumModals(d); i > 0; i--, ps++) {
+		if (ps->wid == wid) {
+			DEBUGOUT(_LtDebug(__FILE__, wid,
+				"LTAddGrab(double) [%d %d] old [%d %d]\n",
+				ps->exclusive, ps->springLoaded,
+				exclusive, spring_loaded));
+			/*
+			 * FIX ME this tests for a known problem, it may be
+			 * necessary to handle more cases.
+			 */
+			if (exclusive == ps->exclusive)
+				return;
+			modal = ps;
+		}
+	}
+	dump_grab_list(d);
 
-    /*
-     * Now occupy a free entry and pollute it with information about the
-     * grab. Then introduce the grab to the Intrinsics and make sure the
-     * grab gets removed if the grab widget should ever be destroyed
-     * before releasing the grab. This is necessary so LessTif's grab list
-     * stays in sync with the Intrinsics's list.
-     */
-    modal = Display_Modals(d) + Display_NumModals(d);
-    modal->wid = wid;
-    modal->ve = ve;
-    modal->grabber = grabber;
-    modal->exclusive = exclusive;
-    modal->springLoaded = spring_loaded;
+	if (modal == 0) {
+		/* grow the modal list, if necessary */
+		if (Display_NumModals(d) >= Display_MaxModals(d)) {
+			Display_MaxModals(d) += 8;
+			Display_Modals(d) = (XmModalData)XtRealloc(
+				(char *)Display_Modals(d),
+				sizeof(XmModalDataRec) * Display_MaxModals(d));
+		}
+		modal = Display_Modals(d) + Display_NumModals(d);
+		Display_NumModals(d)++;
+	}
 
-    Display_NumModals(d)++;
+	/*
+	 * Now occupy a free entry and pollute it with information about the
+	 * grab. Then introduce the grab to the Intrinsics and make sure the
+	 * grab gets removed if the grab widget should ever be destroyed
+	 * before releasing the grab. This is necessary so LessTif's grab list
+	 * stays in sync with the Intrinsics's list.
+	 */
+	modal->wid = wid;
+	modal->ve = ve;
+	modal->grabber = grabber;
+	modal->exclusive = exclusive;
+	modal->springLoaded = spring_loaded;
 
-    DEBUGOUT(_LtDebugDebug("GRAB", wid, "%s:XtAddGrab(%d) - %s %s\n", 
-    	__FILE__, __LINE__,
-    	exclusive ? "True" : "False",
-    	spring_loaded ? "True" : "False"));
-    XtAddGrab(wid, exclusive, spring_loaded);
+	DEBUGOUT(_LtDebug("GRAB", wid, "%s:XtAddGrab(%d) - %s %s\n", 
+		__FILE__, __LINE__,
+		exclusive ? "True" : "False",
+		spring_loaded ? "True" : "False"));
+	XtAddGrab(wid, exclusive, spring_loaded);
 
-    /*
-     * Never, NEVER, add this callback before you'd set up the grab. See
-     * below ( RemoveLessTifGrab() ) for some explanation.
-     */
-    XtAddCallback(wid, XmNdestroyCallback,
-		  (XtCallbackProc)LTRemoveGrabCallback,
-		  (XtPointer)ve);
-    DEBUGOUT(_LtDebugDebug(__FILE__, wid, "LTAddGrab - After it is added\n"));
-    dump_grab_list(d);
+	/*
+	 * Never, NEVER, add this callback before you'd set up the grab. See
+	 * below ( RemoveLessTifGrab() ) for some explanation.
+	 */
+	XtAddCallback(wid, XmNdestroyCallback,
+		(XtCallbackProc)LTRemoveGrabCallback,
+		(XtPointer)ve);
+	DEBUGOUT(_LtDebug(__FILE__, wid, "LTAddGrab - After it is added\n"));
+	dump_grab_list(d);
 }
 
 
@@ -1565,7 +1585,7 @@ LTAddGrab(Widget wid, Boolean exclusive, Boolean spring_loaded,
 extern void
 _XmAddGrab(Widget wid, Boolean exclusive, Boolean spring_loaded)
 {
-    DEBUGOUT(_LtDebugDebug(__FILE__, wid, "_XmAddGrab()\n"));
+    DEBUGOUT(_LtDebug(__FILE__, wid, "_XmAddGrab()\n"));
     LTAddGrab(wid, exclusive, spring_loaded,
 	      (XmVendorShellExtObject)NULL, (XmVendorShellExtObject)NULL);
 }
@@ -1600,7 +1620,7 @@ LTRemoveGrab(Widget wid, XmVendorShellExtObject ve,
     XmModalData pd, ps;
     int i, skipped;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, wid, "LTRemoveGrab\n"));
+    DEBUGOUT(_LtDebug(__FILE__, wid, "LTRemoveGrab\n"));
     if (wid == NULL)
     {
 	wid = ExtObj_LogicalParent(ve);
@@ -1641,11 +1661,10 @@ LTRemoveGrab(Widget wid, XmVendorShellExtObject ve,
 	This 'fix' in turn triggered XtRemoveGrabs with bogus arguments, leading
 	to Xt warning messages. See comments at beginning of LTRemoveGrab()!
 */
-	if ((XtParent(wid) == NULL) ||
-	    ((ps->wid == wid) && !CoreBeingDestroyed(wid) &&
-	     !XtIsTopLevelShell(wid) && remove_grab_physically))
+	if ((ps->wid == wid) && !CoreBeingDestroyed(wid) &&
+	     !XtIsTopLevelShell(wid) && remove_grab_physically)
 	{
-	    DEBUGOUT(_LtDebugDebug2("GRAB", XtParent(wid), wid, "%s:XtRemoveGrab(%d) - %s %s\n",
+	    DEBUGOUT(_LtDebug2("GRAB", XtParent(wid), wid, "%s:XtRemoveGrab(%d) - %s %s\n",
 	                       __FILE__, __LINE__,
 			       XtIsShell(wid) ? "True" : "False",
                                CoreBeingDestroyed(wid) ? "True" : "False"));
@@ -1695,7 +1714,7 @@ LTRemoveGrab(Widget wid, XmVendorShellExtObject ve,
 	if (pd != ps)
 	{
 	    *pd = *ps;
-	    DEBUGOUT(_LtDebugDebug("GRAB", pd->wid, "%s:XtAddGrab(%d) - %s %s\n", 
+	    DEBUGOUT(_LtDebug("GRAB", pd->wid, "%s:XtAddGrab(%d) - %s %s\n", 
 		__FILE__, __LINE__,
 		pd->exclusive ? "True" : "False",
 		pd->springLoaded ? "True" : "False"));
@@ -1719,8 +1738,8 @@ static void
 LTRemoveGrabCallback(Widget wid, XtPointer client_data,
 		     XtPointer callback_data)
 {
-    DEBUGOUT(_LtDebugDebug(__FILE__, wid, "LTRemoveGrabCallback()\n"));
-    DEBUGOUT(_LtDebugDebug("GRAB", wid, "LTRemoveGrabCallback()\n"));
+    DEBUGOUT(_LtDebug(__FILE__, wid, "LTRemoveGrabCallback()\n"));
+    DEBUGOUT(_LtDebug("GRAB", wid, "LTRemoveGrabCallback()\n"));
 #if 0
     /* rws 14 Feb 1998
        This is the cause of the segfault in ddd when pressing OK from
@@ -1763,7 +1782,7 @@ LTRemoveGrabCallback(Widget wid, XtPointer client_data,
 extern void
 _XmRemoveGrab(Widget wid)
 {
-    DEBUGOUT(_LtDebugDebug(__FILE__, wid, "_XmRemoveGrab()\n"));
+    DEBUGOUT(_LtDebug(__FILE__, wid, "_XmRemoveGrab()\n"));
     LTRemoveGrab(wid, NULL, True);
 }
 
@@ -1786,7 +1805,7 @@ LTGrabKids(XmVendorShellExtObject ve,
     WidgetList kids;
     Widget logParent;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, NULL, "LTGrabKids()\n"));
+    DEBUGOUT(_LtDebug(__FILE__, NULL, "LTGrabKids()\n"));
     /*
      * Depending on the class of object within the shadow shell hierarchy
      * we've to choose one out of three different ways to get the object's
@@ -1876,7 +1895,7 @@ LTGrabRelatives(XmVendorShellExtObject grabber)
 {
     XmVendorShellExtObject eo, skip_branch;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, NULL, "LTGrabRelatives()\n"));
+    DEBUGOUT(_LtDebug(__FILE__, NULL, "LTGrabRelatives()\n"));
     eo = (XmVendorShellExtObject)Desktop_Parent(grabber);
     skip_branch = grabber;
     for (;;)
@@ -1920,7 +1939,8 @@ LTShellPopupCallback(Widget w, XtPointer ClientData, XtPointer CallbackData)
     XtGrabKind GrabKind = XtGrabNone;
     Boolean GrabRelatives = False;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "ShellPopup callback\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "LTShellPopupCallback(%s)\n",
+	_LtDebugMwmInput2String(VSEP_MwmHints(ve).input_mode)));
 
     ws = XmGetXmScreen(XtScreenOfObject(w));
 
@@ -2001,11 +2021,11 @@ LTShellPopdownCallback(Widget w, XtPointer ClientData, XtPointer CallbackData)
 {
     XmVendorShellExtObject ve = (XmVendorShellExtObject)ClientData;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "ShellPopdown callback\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "ShellPopdown callback\n"));
 
     if (VSEP_GrabKind(ve) != XtGrabNone)
     {
-	DEBUGOUT(_LtDebugDebug(__FILE__, w, "Remove grab\n"));
+	DEBUGOUT(_LtDebug(__FILE__, w, "Remove grab\n"));
 
 	LTRemoveGrab(NULL, ve, True);
     }
@@ -2428,7 +2448,7 @@ _XmRootGeometryManager(Widget wid,
 		 * this way.
 		 */
 
-		DEBUGOUT(_LtDebugDebug(__FILE__, (Widget)w,
+		DEBUGOUT(_LtDebug(__FILE__, (Widget)w,
 				  "Returning XtGeometryNo because config "
 				  "differed\n"));
 
@@ -2462,7 +2482,7 @@ _XmRootGeometryManager(Widget wid,
 	{
 	    PutBackGeometry();
 
-	    DEBUGOUT(_LtDebugDebug(__FILE__, (Widget)w,
+	    DEBUGOUT(_LtDebug(__FILE__, (Widget)w,
 			      "Returning XtGeometryNo because config "
 			      "denied\n"));
 
@@ -2512,14 +2532,62 @@ QueryStruct;
 
 /* A prototype for a private libXt function ... */
 extern int _XtWaitForSomething(XtAppContext app,
-			       _XtBoolean ignoreEvents, _XtBoolean ignoreTimers,
+			       _XtBoolean ignoreEvents,
+			       _XtBoolean ignoreTimers,
 			       _XtBoolean ignoreInputs,
-			       _XtBoolean ignoreSignals, _XtBoolean block,
+			       _XtBoolean ignoreSignals,
+			       _XtBoolean block,
 #ifdef XTHREADS
 			       _XtBoolean drop_lock,
 #endif
 			       unsigned long *howlong);
 
+/* amai: citing the docs, e.g. from
+ *     ftp://ftp.x.org/pub/R6.6/xc/lib/Xt/NextEvent.c
+ * for that
+ * Routine to block in the toolkit.  This should be the only call to select.
+ *
+ * This routine returns when there is something to be done.
+ *
+ * Before calling this with ignoreInputs==False, app->outstandingQueue should
+ * be checked; this routine will not verify that an alternate input source
+ * has not already been enqueued.
+ *
+ *
+ * _XtWaitForSomething( appContext, 
+ *                      ignoreEvent, ignoreTimers, ignoreInputs, ignoreSignals,
+ *			block, drop_lock, howlong)
+ * XtAppContext app;	     (Displays to check wait on)
+ *
+ * Boolean ignoreEvents;     (Don't return if XEvents are available
+ *                              Also implies forget XEvents exist)
+ *
+ * Boolean ignoreTimers;     (Ditto for timers)
+ *
+ * Boolean ignoreInputs;     (Ditto for input callbacks )
+ *
+ * Boolean ignoreSignals;    (Ditto for signals)
+ *
+ * Boolean block;	     (Okay to block)
+ *
+ * Boolean drop_lock         (drop lock before going into select/poll)
+ *
+ * TimeVal howlong;	     (howlong to wait for if blocking and not
+ *				doing Timers... Null means forever.
+ *				Maybe should mean shortest of both)
+ * Returns display for which input is available, if any
+ * and if ignoreEvents==False, else returns -1
+ *
+ * if ignoring everything && block=True && howlong=NULL, you'll have
+ * lots of time for coffee; better not try it!  In fact, it probably
+ * makes little sense to do this regardless of the value of howlong
+ * (bottom line is, we don't bother checking here).
+ *
+ * If drop_lock is FALSE, the app->lock->mutex is not unlocked before
+ * entering select/poll. It is illegal for drop_lock to be FALSE if
+ * ignoreTimers, ignoreInputs, or ignoreSignals is FALSE.
+ */
+
 static Bool
 ConfigEventForMe(Display *dpy, XEvent *event, char *arg)
 {
@@ -2597,10 +2665,27 @@ WaitForWM(ShellWidget w, XEvent *event, unsigned long request_num)
 	}
     }
 
+/*
+  amai: we have to get rid of this _XtWaitForSomething ASAP:
+    this call changes it's signature based on compile-time options
+    for the X libraries :-(
+    So beyond the pure annoying fact of using a non-documented, private call
+    from libXt we also break cross-compiling.
+    And no, a run-time if-clause is not a "real" solution IMHO.
+    A proposal is to install an even handler and a timer 
+       XtAppAddTimeOut()
+       XtAddEventHandler()
+    and then do the remaining job in the triggered callbacks.
+    WaitForWM() is only called once in the code, one has to check
+    what is done _there_.
+*/
     while (timeout > 0)
     {
 	if (_XtWaitForSomething(app,
-				FALSE, TRUE, TRUE, TRUE,
+				FALSE,
+				TRUE,
+				TRUE,
+				TRUE,
 				TRUE,
 #ifdef XTHREADS
 				FALSE,
@@ -2617,7 +2702,6 @@ WaitForWM(ShellWidget w, XEvent *event, unsigned long request_num)
 	    }
 	}
     }
-
     return FALSE;
 }
 
@@ -2820,7 +2904,7 @@ _XmRootGeometryManager(Widget gw,
 		 * this way.
 		 */
 
-		DEBUGOUT(_LtDebugDebug(__FILE__, (Widget)w,
+		DEBUGOUT(_LtDebug(__FILE__, (Widget)w,
 				  "Returning XtGeometryNo because config "
 				  "differed\n"));
 
@@ -2851,7 +2935,7 @@ _XmRootGeometryManager(Widget gw,
 	{
 	    PutBackGeometry();
 
-	    DEBUGOUT(_LtDebugDebug(__FILE__, (Widget)w,
+	    DEBUGOUT(_LtDebug(__FILE__, (Widget)w,
 			      "Returning XtGeometryNo because not "
 			      "WMShell\n"));
 
@@ -2878,6 +2962,7 @@ _XmRootGeometryManager(Widget gw,
 
 #endif /* XtSpecificationRelease < 6 */
 
+
 /*
  * if this doesn't exist, the BaseClass geometry wrapper won't work.
  */
@@ -2889,14 +2974,14 @@ geometry_manager(Widget wid,
     ShellWidget shell = (ShellWidget)XtParent(wid);
     XtWidgetGeometry req;
 
-    DEBUGOUT(_LtDebugDebug2(__FILE__, XtParent(wid), wid, "%s:geometry_manager(%d) - request (%s)\n",
+    DEBUGOUT(_LtDebug2(__FILE__, XtParent(wid), wid, "%s:geometry_manager(%d) - request (%s)\n",
     	__FILE__, __LINE__,
     	_LtDebugWidgetGeometry2String(request)));
 
     if ((request->width == 0 && (request->request_mode & CWWidth)) ||
 	(request->height == 0 && (request->request_mode & CWHeight)))
     {
-	DEBUGOUT(_LtDebugDebug(__FILE__, wid,
+	DEBUGOUT(_LtDebug(__FILE__, wid,
 		          "Returning XtGeometryNo because asked "
 		          "for 0 w/h\n"));
 
@@ -2905,7 +2990,7 @@ geometry_manager(Widget wid,
 
     if (shell->shell.allow_shell_resize == False && XtIsRealized(wid) && (request->request_mode & (CWWidth | CWHeight)))
     {
-	DEBUGOUT(_LtDebugDebug(__FILE__, wid,
+	DEBUGOUT(_LtDebug(__FILE__, wid,
 		          "Returning XtGeometryNo because "
 		          "no shell resize\n"));
 
@@ -2916,7 +3001,7 @@ geometry_manager(Widget wid,
        mgs bubble help
     if (request->request_mode & (CWX | CWY))
     {
-	DEBUGOUT(_LtDebugDebug(__FILE__, wid,
+	DEBUGOUT(_LtDebug(__FILE__, wid,
 		          "Returning XtGeometryNo because "
 		          "asked for x/y\n"));
 
@@ -2979,7 +3064,7 @@ geometry_manager(Widget wid,
 	return XtGeometryYes;
     }
 
-   DEBUGOUT(_LtDebugDebug(__FILE__, wid,
+   DEBUGOUT(_LtDebug(__FILE__, wid,
 		     "Returning XtGeometryNo because "
 		     "XtMakeGeometryRequest failed\n"));
 
@@ -2996,8 +3081,7 @@ _XmVendorExtInitialize(Widget req,
     XmVendorShellExtObject ve = (XmVendorShellExtObject)new_w;
     Atom wm_delete_window;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, new_w,
-		      "VendorShellExt %s initialize\n", XtName(new_w)));
+    DEBUGOUT(_LtDebug(__FILE__, new_w, "VendorShellExtInitialize\n"));
 
     if (VSEP_DefaultFontList(ve) != NULL)
     {
@@ -3096,16 +3180,16 @@ _XmVendorExtInitialize(Widget req,
 			 VSEPC_DeleteWindowHandler(new_w), (XtPointer)new_w);
 }
 
-
 static Boolean
-_XmVendorExtSetValues(Widget cw, Widget rw, Widget nw,
-		      ArgList args, Cardinal *nargs)
+_XmVendorExtSetValues(Widget cw, Widget rw, Widget nw, ArgList args, Cardinal *nargs)
 {
     Atom at;
     long prop32[5];
+    XmVendorShellExtObject o= (XmVendorShellExtObject)nw;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, nw,
-		      "VendorShellExt %s SetValues\n", XtName(nw)));
+    DEBUGOUT(_LtDebug(__FILE__, nw,
+		      "VendorShellExtSetValues, args:%d\n",
+		      *nargs));
 
     if (VSEP_ButtonFontList(nw) != VSEP_ButtonFontList(cw))
     {
@@ -3188,7 +3272,46 @@ _XmVendorExtSetValues(Widget cw, Widget rw, Widget nw,
 	}
     }
 
-    return False;
+	/* This really appears to belong in set_values() for the ext object */
+	/* Well, here it is. */
+	if (VSEP_MwmHints(nw).input_mode != VSEP_MwmHints(cw).input_mode)
+	{
+		XtGrabKind GrabKind = XtGrabNone;
+		Boolean GrabRelatives = False;
+
+		switch (VSEP_MwmHints(nw).input_mode) {
+		case MWM_INPUT_PRIMARY_APPLICATION_MODAL:
+			GrabKind = XtGrabExclusive;
+#if 1
+			/* Maybe we can get away with always doing this */
+			GrabRelatives = True;
+#else
+			if (Screen_MwmPresent(ws)) {
+				GrabRelatives = True;
+			}
+#endif
+			break;
+		case MWM_INPUT_SYSTEM_MODAL:
+		case MWM_INPUT_FULL_APPLICATION_MODAL:
+			GrabKind = XtGrabExclusive;
+			break;
+		case MWM_INPUT_MODELESS:
+		default:
+			GrabKind = XtGrabNonexclusive;
+			break;
+		}
+
+		if (GrabKind != XtGrabNone) {
+			LTAddGrab(NULL,
+				GrabKind == XtGrabExclusive ? True : False, False,
+				o, o);
+		}
+		VSEP_GrabKind(nw) = GrabKind;
+		if (GrabRelatives) {
+			LTGrabRelatives(o);
+		}
+	}
+	return False;
 }
 
 
@@ -3200,7 +3323,9 @@ _XmVendorExtRealize(Widget w, XtPointer closure, XtPointer call_data)
     Cardinal i;
     long prop32[5];
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "XmVendorExtRealize\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "XmVendorExtRealize\n"));
+
+	_XmPickupUnspecifiedPixmaps(XtDisplay(w));
 
     par = ExtObj_LogicalParent(w);
 
@@ -3209,7 +3334,7 @@ _XmVendorExtRealize(Widget w, XtPointer closure, XtPointer call_data)
 	_XmInstallProtocols(par);
     }
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, w,
+    DEBUGOUT(_LtDebug(__FILE__, w,
 		 "_XmVendorExtRealize[flags %d, functions %d, decorations %d, "
 		      "input_mode %d, status %d\n",
 		      VSEP_MwmHints(w).flags,
@@ -3300,7 +3425,7 @@ extern unsigned char
 _XmGetAudibleWarning(Widget w)
 {
     XmWidgetExtData data;
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "_XmGetAudibleWarning\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "_XmGetAudibleWarning\n"));
     if ( XmIsVendorShell (w) && ( data = _XmGetWidgetExtData(w, XmSHELL_EXTENSION ) ) )
 	{
 	XmVendorShellExtObject vSE = (XmVendorShellExtObject)data -> widget ;
@@ -3357,16 +3482,14 @@ _LtFindVendorExt(Widget w)
 
 
 /*
-From: Martin Simmons <martin@harlequin.co.uk>
+  From: Martin Simmons:
+    Perhaps LessTif can guard against this common linking problem?  
+    E.g. the following function will check the VendorShell for consistency:
 
-  Perhaps LessTif can guard against this common linking problem?  
-  E.g. the following function will check the VendorShell for consistency:
-*/
-
-/* To be used for sanity checking:
-     return True if successful, i.e. everything's fine
-     return False if no widget was supplied as an argument
-     _XmError()s if linkage was wrong */
+     returns     True if successful, i.e. everything's fine
+     returns     False if no widget was supplied as an argument
+     _XmError()s if linkage is/was wrong
+ */
 extern Boolean
 _LtCheckClassOfVendorShell(Widget w)
 {
@@ -3380,7 +3503,7 @@ _LtCheckClassOfVendorShell(Widget w)
             if (widget_class->core_class.extension == (XtPointer)&_XmVendorSCoreClassExtRec)
                 return True;
             else
-                _XmError(w, "Application not linked correctly: try putting Xm before Xt.");
+                _XmError(w, "Application not linked correctly: try putting -lXm before -lXt.");
         }
     }
 
@@ -3392,12 +3515,12 @@ _LtCheckClassOfVendorShell(Widget w)
    This corrects for the (shared) library loading mechanism in OS/2 
    which differs from those on many standard Unix systems.
    The routine should be called before any other function,
-   done by the _DLL_InitTerm-function under OS/2.
-   On un*x/ELF systems this seems to be ensured by specifying the
-   libs in correct, canonical order on the linker command line.
-   amai (20010112): Well, I once decided to make it static, but
-     this was an error: to call it from a static libXm one
-     may need this symbol ...
+   actually done by the _DLL_InitTerm-function.
+   On un*x/ELF systems the problem addressed here seems to be avoided
+   by specifying the libraries in correct, canonical order on the linker
+   command line.
+   amai (20010112): I once decided to make it static, but this was an error:
+   to call it from a static libXm one may need this symbol.
  */
 #ifdef __EMX__
 extern void
@@ -3405,9 +3528,9 @@ _LtXmFixupVendorShell(void)
 {
 
     transientShellWidgetClass->core_class.superclass =
-	(WidgetClass)&vendorShellClassRec;
+       (WidgetClass)&vendorShellClassRec;
     topLevelShellWidgetClass->core_class.superclass =
-	(WidgetClass)&vendorShellClassRec;
+       (WidgetClass)&vendorShellClassRec;
 }
 
 
@@ -3416,8 +3539,8 @@ _DLL_InitTerm(unsigned long mod_handle, unsigned long flag)
 {
     if (flag == 0UL)  /* initialize DLL */
     {
-	_LtXmFixupVendorShell();
-	return 1; /* success */
+	    _LtXmFixupVendorShell();
+	    return 1; /* success */
     }
     else     /* terminate DLL */
     {
