@@ -1,9 +1,9 @@
 /**
  *
- * $Id: XmIm.c,v 1.29 2001/05/29 12:51:02 amai Exp $
+ * $Id: XmIm.c,v 1.33 2002/04/12 23:38:44 amai Exp $
  *
  * Copyright  1995 Free Software Foundation, Inc.
- * Copyright  1995-2001 LessTif Development Team
+ * Copyright  1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -23,7 +23,7 @@
  *
  **/
 
-static const char rcsid[] = "$Id: XmIm.c,v 1.29 2001/05/29 12:51:02 amai Exp $";
+static const char rcsid[] = "$Id: XmIm.c,v 1.33 2002/04/12 23:38:44 amai Exp $";
 
 #include <LTconfig.h>
 
@@ -44,7 +44,7 @@ static const char rcsid[] = "$Id: XmIm.c,v 1.29 2001/05/29 12:51:02 amai Exp $";
 #include <Xm/XmIm.h>
 #endif
 
-#include "LTmisc.h"
+#include <XmI/LTmisc.h>
 
 #include <XmI/DebugUtil.h>
 
@@ -205,12 +205,12 @@ XmImGetXIC(Widget w,
 
     if (v == 0)
     {
-	DEBUGOUT(_LtDebugDebug(__FILE__, w,
+	DEBUGOUT(_LtDebug(__FILE__, w,
 			  "XmImRegister: no vendor shell extension found\n"));
 	return 0;
     }
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "XmImRegister: InputMethodString '%s'\n",
+    DEBUGOUT(_LtDebug(__FILE__, w, "XmImRegister: InputMethodString '%s'\n",
 		      v->vendor.input_method_string
 		      ? v->vendor.input_method_string
 		      : "(null)"));
@@ -263,7 +263,7 @@ XmImGetXIC(Widget w,
 	    stuff->count = 0;	/* Don't count, we're a reference ! */
 	    s->count++;
 
-	    DEBUGOUT(_LtDebugDebug(__FILE__, w, "XmImGetXIC: reuse XIM %p (count %d)\n", xim, s->count));
+	    DEBUGOUT(_LtDebug(__FILE__, w, "XmImGetXIC: reuse XIM %p (count %d)\n", xim, s->count));
 	    break;
 	}
     }
@@ -290,7 +290,7 @@ XmImGetXIC(Widget w,
 		    xim = XOpenIM(XtDisplay(w), NULL, NULL, NULL);
 
 		    if (xim) {
-			DEBUGOUT(_LtDebugDebug(__FILE__, w,
+			DEBUGOUT(_LtDebug(__FILE__, w,
 			    "XOpenIM succeeded with XSetLocaleModifiers(%s) -> xim %p\n",
 			    buf, xim));
 		    }
@@ -321,7 +321,7 @@ XmImGetXIC(Widget w,
 	    /*if ((p = XSetLocaleModifiers("@im=none")) != NULL) {
 		xim = XOpenIM(XtDisplay(w), NULL, NULL, NULL);
 		if (xim) {
-		    DEBUGOUT(_LtDebugDebug(__FILE__, w,
+		    DEBUGOUT(_LtDebug(__FILE__, w,
 			"XOpenIM succeeded with XSetLocaleModifiers(%s)\n",
 			"@im=none"));
 		}
@@ -332,7 +332,7 @@ XmImGetXIC(Widget w,
 	{
 	    xim = XOpenIM(XtDisplay(w), NULL, NULL, NULL);
 	    if (xim) {
-		DEBUGOUT(_LtDebugDebug(__FILE__, w,
+		DEBUGOUT(_LtDebug(__FILE__, w,
 			"XOpenIM succeeded with XSetLocaleModifiers('')\n"));
 	    }
 	}
@@ -340,14 +340,14 @@ XmImGetXIC(Widget w,
 
     if (!xim)
     {
-	DEBUGOUT(_LtDebugDebug(__FILE__, w, "Failed to open input method\n"));
+	DEBUGOUT(_LtDebug(__FILE__, w, "Failed to open input method\n"));
 	return 0;
     }
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "XOpenIM -> %p\n", xim));
+    DEBUGOUT(_LtDebug(__FILE__, w, "XOpenIM -> %p\n", xim));
     if (XGetIMValues(xim, XNQueryInputStyle, &xim_styles, NULL) || xim_styles == NULL)
     {
-	DEBUGOUT(_LtDebugDebug(__FILE__, w,
+	DEBUGOUT(_LtDebug(__FILE__, w,
 			  "Input method doesn't support any style\n"));
 	XCloseIM(xim);
 	return 0;
@@ -355,40 +355,40 @@ XmImGetXIC(Widget w,
 
 #if 0
     if (_LtDebugInDebug(__FILE__, w)) {
-	DEBUGOUT(_LtDebugDebug(__FILE__, w,
+	DEBUGOUT(_LtDebug(__FILE__, w,
 			  "XmImRegister - Supported styles :\n"));
 	for (j = 0; j < xim_styles->count_styles; j++)
 	{
-	    DEBUGOUT(_LtDebugDebug0(__FILE__, w, " (%d) %X %s", j,
+	    DEBUGOUT(_LtDebug0(__FILE__, w, " (%d) %X %s", j,
 			       xim_styles->supported_styles[j],
 			   (xim_styles->supported_styles[j] & XIMStatusNothing)
 			       ? "XIMStatusNothing" : ""));
-	    DEBUGOUT(_LtDebugDebug0(__FILE__, w, " %s",
+	    DEBUGOUT(_LtDebug0(__FILE__, w, " %s",
 			       (xim_styles->supported_styles[j] & XIMStatusArea)
 			       ? "XIMStatusArea" : ""));
-	    DEBUGOUT(_LtDebugDebug0(__FILE__, w, " %s",
+	    DEBUGOUT(_LtDebug0(__FILE__, w, " %s",
 			 (xim_styles->supported_styles[j] & XIMStatusCallbacks)
 			       ? "XIMStatusCallbacks" : ""));
-	    DEBUGOUT(_LtDebugDebug0(__FILE__, w, " %s",
+	    DEBUGOUT(_LtDebug0(__FILE__, w, " %s",
 			       (xim_styles->supported_styles[j] & XIMStatusNone)
 			       ? "XIMStatusNone" : ""));
-	    DEBUGOUT(_LtDebugDebug0(__FILE__, w, " %s",
+	    DEBUGOUT(_LtDebug0(__FILE__, w, " %s",
 			  (xim_styles->supported_styles[j] & XIMPreeditNothing)
 			       ? "XIMPreeditNothing" : ""));
-	    DEBUGOUT(_LtDebugDebug0(__FILE__, w, " %s",
+	    DEBUGOUT(_LtDebug0(__FILE__, w, " %s",
 			 (xim_styles->supported_styles[j] & XIMPreeditPosition)
 			       ? "XIMPreeditPosition" : ""));
-	    DEBUGOUT(_LtDebugDebug0(__FILE__, w, " %s",
+	    DEBUGOUT(_LtDebug0(__FILE__, w, " %s",
 			(xim_styles->supported_styles[j] & XIMPreeditCallbacks)
 			       ? "XIMPreeditCallbacks" : ""));
-	    DEBUGOUT(_LtDebugDebug0(__FILE__, w, " %s",
+	    DEBUGOUT(_LtDebug0(__FILE__, w, " %s",
 			     (xim_styles->supported_styles[j] & XIMPreeditNone)
 			       ? "XIMPreeditNone" : ""));
-	    DEBUGOUT(_LtDebugDebug0(__FILE__, w, " %s",
+	    DEBUGOUT(_LtDebug0(__FILE__, w, " %s",
 			     (xim_styles->supported_styles[j] & XIMPreeditArea)
 			       ? "XIMPreeditArea" : ""));
 
-	    DEBUGOUT(_LtDebugDebug0(__FILE__, w, "\n"));
+	    DEBUGOUT(_LtDebug0(__FILE__, w, "\n"));
 	}
     }
 #endif
@@ -403,7 +403,7 @@ XmImGetXIC(Widget w,
     for (i = 0, found = False; styles[i] && !found; i++)
     {
 #if 0
-	DEBUGOUT(_LtDebugDebug(__FILE__, w,
+	DEBUGOUT(_LtDebug(__FILE__, w,
 			  "Trying %s (0x%X)\n", styles[i], style_bits[i]));
 #endif
 
@@ -425,7 +425,7 @@ XmImGetXIC(Widget w,
 
     if (!found)
     {
-	DEBUGOUT(_LtDebugDebug(__FILE__, w,
+	DEBUGOUT(_LtDebug(__FILE__, w,
 	     "XmImRegister: input method doesn't support our preedit type\n"));
 	XCloseIM(xim);
 	return 0;
@@ -435,7 +435,7 @@ XmImGetXIC(Widget w,
 
     if (!XtIsRealized(XtParent(v)))
     {
-	DEBUGOUT(_LtDebugDebug(__FILE__, w, "XmImRegister: not realized yet\n"));
+	DEBUGOUT(_LtDebug(__FILE__, w, "XmImRegister: not realized yet\n"));
     }
     else
     {
@@ -451,18 +451,18 @@ XmImGetXIC(Widget w,
 
 	if (XmIsTextField(w))
 	{
-	    if (TextF_FontList(w)->type == XmFONT_IS_FONTSET)
+	    if (TextF_FontList(w)->renditions[0]->type == XmFONT_IS_FONTSET)
 	    {
-		fontset = (XFontSet)TextF_FontList(w)->font;
+		fontset = (XFontSet)TextF_FontList(w)->renditions[0]->font;
 		fontheight = TextF_FontHeight(w);
 	    }
         }
 	else if (XmIsText(w))
 	{
 	    o = Text_OutputData(w);
-	    if (Out_FontList(o)->type == XmFONT_IS_FONTSET)
+	    if (Out_FontList(o)->renditions[0]->type == XmFONT_IS_FONTSET)
 	    {
-	        fontset = (XFontSet)Out_FontList(o)->font;
+	        fontset = (XFontSet)Out_FontList(o)->renditions[0]->font;
 		fontheight = Out_FontHeight(o);
 	    }
 	}
@@ -583,11 +583,11 @@ XmImGetXIC(Widget w,
 
 	if (stuff->xic)
 	{
-	    DEBUGOUT(_LtDebugDebug(__FILE__, w, "We have an IC\n"));
+	    DEBUGOUT(_LtDebug(__FILE__, w, "We have an IC\n"));
 	}
 	else
 	{
-	    DEBUGOUT(_LtDebugDebug(__FILE__, w, "IC Creation failed\n"));
+	    DEBUGOUT(_LtDebug(__FILE__, w, "IC Creation failed\n"));
 	    XCloseIM(xim);
 	}
     }
@@ -681,7 +681,7 @@ XmImRegister(Widget w,
 extern void
 XmImUnregister(Widget w)
 {
-    DEBUGOUT(_LtDebugDebug(__FILE__, w,
+    DEBUGOUT(_LtDebug(__FILE__, w,
 		      "XmImUnregister is not implemented yet.\n"));
 }
 
@@ -702,11 +702,11 @@ XmImSetFocusValues(Widget w, ArgList args, Cardinal num_args)
 
     if (stuff == NULL)
     {
-	DEBUGOUT(_LtDebugDebug(__FILE__, w, "XmImSetFocusValues (no IC found)\n"));
+	DEBUGOUT(_LtDebug(__FILE__, w, "XmImSetFocusValues (no IC found)\n"));
 	return;
     }
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "XmImSetFocusValues\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "XmImSetFocusValues\n"));
 
     XmImSetValues(w, args, num_args);
 
@@ -782,11 +782,11 @@ XmImSetValues(Widget w,
     XVaNestedList preedit_attr = NULL;
 
     if (stuff == NULL || stuff->xic == NULL) {
-	DEBUGOUT(_LtDebugDebug(__FILE__, NULL, "XmImSetValues(NULL)\n"));
+	DEBUGOUT(_LtDebug(__FILE__, NULL, "XmImSetValues(NULL)\n"));
 	return;
     }
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, NULL, "XmImSetValues()\n"));
+    DEBUGOUT(_LtDebug(__FILE__, NULL, "XmImSetValues()\n"));
     DEBUGOUT(_LtDebugPrintArgList(__FILE__, NULL, args, num_args, False));
 
     for (i = 0; i < num_args; i++)
@@ -809,11 +809,12 @@ XmImSetValues(Widget w,
 	else if (strcmp(args[i].name, XmNfontList) == 0)
 	{
 	    XmFontList fontlist = (XmFontList)args[i].value;
-	    if (fontlist->type == XmFONT_IS_FONTSET)
+	    if (fontlist->renditions[0]->type == XmFONT_IS_FONTSET)
 	    {
-    	        preedit_attr = XVaCreateNestedList(0, XNFontSet, fontlist->font, NULL);
+    	        preedit_attr = XVaCreateNestedList(0,
+			XNFontSet, fontlist->renditions[0]->font, NULL);
 		font_changed = True;
-		fontset = (XFontSet)fontlist->font;
+		fontset = (XFontSet)fontlist->renditions[0]->font;
 	    }
 	    else
 	        continue;
@@ -904,7 +905,7 @@ XmImUnsetFocus(Widget w)
 	return;
     }
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, w, "XmImUnsetFocus\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "XmImUnsetFocus\n"));
 
     if (stuff->text == w && stuff->xic)
     {
@@ -975,7 +976,7 @@ XmImMbLookupString(Widget w,
 	default:
 		st = "??";
 	}
-	DEBUGOUT(_LtDebugDebug(__FILE__, w,
+	DEBUGOUT(_LtDebug(__FILE__, w,
 		"XmImMbLookupString -> %d (status %s) buf %c\n",
 		r, st, buf[0]));
 	return r;
@@ -1076,10 +1077,10 @@ XmImCloseXIM(Widget w)
 	if (stuff->orig_xim->count == 0) {
 		if (stuff->xim)
 		   XCloseIM(stuff->xim);
-		DEBUGOUT(_LtDebugDebug(__FILE__, w, "XCloseIM(%p)\n", stuff->xim));
+		DEBUGOUT(_LtDebug(__FILE__, w, "XCloseIM(%p)\n", stuff->xim));
 		stuff->orig_xim->xim = NULL;
 	} else {
-		DEBUGOUT(_LtDebugDebug(__FILE__, w, "XmImCloseXIM(%p), count -> %d\n",
+		DEBUGOUT(_LtDebug(__FILE__, w, "XmImCloseXIM(%p), count -> %d\n",
 			stuff->xim, stuff->orig_xim->count));
 	}
 	stuff->xim = NULL;
@@ -1092,16 +1093,16 @@ XmImCloseXIM(Widget w)
 		   /* that if () avoids the crash upon closing File Open
 		      or Goto Line dialogs within NEdit */
 		   XCloseIM(stuff->xim);
-		DEBUGOUT(_LtDebugDebug(__FILE__, w, "XCloseIM(%p)\n", stuff->xim));
+		DEBUGOUT(_LtDebug(__FILE__, w, "XCloseIM(%p)\n", stuff->xim));
 		stuff->xim = NULL;
 	} else {
-		DEBUGOUT(_LtDebugDebug(__FILE__, w, "XmImCloseXIM(%p), count -> %d\n",
+		DEBUGOUT(_LtDebug(__FILE__, w, "XmImCloseXIM(%p), count -> %d\n",
 			stuff->xim, stuff->count));
 	}
 	stuff->xim = NULL;
     } else if (stuff->xim) {
 	XCloseIM(stuff->xim);
-	DEBUGOUT(_LtDebugDebug(__FILE__, w, "XCloseIM(%p)\n", stuff->xim));
+	DEBUGOUT(_LtDebug(__FILE__, w, "XCloseIM(%p)\n", stuff->xim));
 		stuff->orig_xim->xim = NULL;
 	stuff->xim = NULL;
     }
