@@ -1,9 +1,9 @@
 /**
  *
- * $Id: Xmos.c,v 1.42 2001/05/14 19:46:11 amai Exp $
+ * $Header: /cvsroot/lesstif/lesstif/lib/Xm/Xmos.c,v 1.46 2002/04/12 23:38:44 amai Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
- * Copyright (C) 1995-2001 LessTif Development Team
+ * Copyright (C) 1995-2002 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -23,7 +23,7 @@
  *
  **/
 
-static const char rcsid[] = "$Id: Xmos.c,v 1.42 2001/05/14 19:46:11 amai Exp $";
+static const char rcsid[] = "$Id: Xmos.c,v 1.46 2002/04/12 23:38:44 amai Exp $";
 
 #include <LTconfig.h>
 
@@ -55,9 +55,8 @@ static const char rcsid[] = "$Id: Xmos.c,v 1.42 2001/05/14 19:46:11 amai Exp $";
 #include <XmI/XmI.h>
 #include <Xm/XmP.h>
 #include <Xm/XmosP.h>
-#include <LTglob.h>
-
-#include "LTmisc.h"
+#include <XmI/LTglob.h>
+#include <XmI/LTmisc.h>
 
 
 #ifdef __EMX__   /* -> OS/2 drive letters support */
@@ -131,8 +130,12 @@ _XmOSGetLocalizedString(char *reserved,
 			String resourceName,
 			String value)
 {
+#if XmVERSION < 2
     /* THIS IS A BIG HACK --- FIX ME  --- DON'T KNOW HOW... SORRY */
     return XmStringCreateSimple(value);
+#else
+    return XmStringCreateLocalized(value);
+#endif
 }
 
 
@@ -292,16 +295,19 @@ convertTwiddle(char *dir)
     ptr1 = strchr(ptr, '/');
     if (ptr == ptr1)
     {
-	home = _XmOSGetHomeDirName();
+	home = XtNewString(_XmOSGetHomeDirName());
     }
     else
     {
 	String name, ptr2;
+#if defined(HAVE_GETPWNAM)
 	struct passwd *pw;
+#endif
 
     	name = XtNewString(ptr);
       ptr2=strchr(name, '/');
-      if (ptr2) *ptr2='\0';
+      if (ptr2)
+         *ptr2='\0';
 #if defined(HAVE_GETPWNAM)
     	pw = getpwnam(name);
     	if (pw)
@@ -318,6 +324,8 @@ convertTwiddle(char *dir)
     newdir = XtMalloc(strlen(home) + strlen(ptr1) + 1);
     strcpy(newdir, home);
     strcat(newdir, ptr1);
+    
+    XtFree(home);
 
     return newdir;
 }
@@ -339,19 +347,31 @@ _XmOSQualifyFileSpec(String dirSpec,
     String dir, filt;
     char *tmp, *tmp2;
 
-    if (!dirSpec) dirSpec = "";
+    if (!dirSpec) 
+       dirSpec = "";
     /* no dir string? get cwd */
     if (strlen(dirSpec) == 0 ||
 	strncmp(dirSpec, ".", 1) == 0 || strncmp(dirSpec, "..", 2) == 0)
     {
 #if HAVE_GETCWD
-	if ((tmp = (char *)getcwd(NULL, MAX_PATH_LEN)) == NULL)
+      tmp=XtMalloc(MAX_PATH_LEN);
+      /* this is not proper POSIX coding:
+         MAX_PATH_LEN is by now means an upper limit, so we may
+         actually miss to resolve the CWD */
+	if (getcwd(tmp, MAX_PATH_LEN) != NULL) 
+	{
+      }
+      else
+      {
+	    XtFree(tmp);
+#else
+	{
 #endif
 	    tmp = XtNewString(_XmOSGetHomeDirName());
+      }
 
 	dir = (String)XtMalloc(strlen(tmp) + 1);
 	strcpy(dir, tmp);
-
 	XtFree(tmp);
 
 	while (strncmp(dirSpec, "..", 2) == 0)
@@ -401,10 +421,11 @@ _XmOSQualifyFileSpec(String dirSpec,
 	XtFree(dir);
 	dir = newdir;
     }
+
     /* if the dir doesn't start in a '/', add the cwd */
     if (dir[0] != '/')
     {
-    String tmp, tmp1;
+	String tmp, tmp1;
 
 	if ((tmp = (char *)getcwd(NULL, MAX_PATH_LEN)) == NULL)
 	    tmp = XtNewString(_XmOSGetHomeDirName());
@@ -610,7 +631,7 @@ _XmOSGetDirEntries(String qualifiedDir,
     String slash, tmp, *ret = NULL;
     int flags = GLOB_MARK | (matchDotsLiterally ? 0 : GLOB_PERIOD);
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, NULL,
+    DEBUGOUT(_LtDebug(__FILE__, NULL,
 		   "_XmOSGetDirEntries(%s,%s)\n", qualifiedDir, matchPattern));
 
     _XmOSGetDotDot(qualifiedDir);
@@ -653,7 +674,7 @@ _XmOSGetDirEntries(String qualifiedDir,
 	strcat(buf, matchPattern);
     }
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, NULL,
+    DEBUGOUT(_LtDebug(__FILE__, NULL,
 		      "_XmOSGetDirEntries -> work on '%s'\n", buf));
 
     memset((void *)&result, 0, sizeof(result));
@@ -783,11 +804,11 @@ _XmOSGetDirEntries(String qualifiedDir,
     {
 	int i;
 
-	DEBUGOUT(_LtDebugDebug(__FILE__, NULL,
+	DEBUGOUT(_LtDebug(__FILE__, NULL,
 			  "_XmOSGetDirEntries: %d results\n", cnt));
 	for (i = 0; i < cnt; i++)
 	{
-	    DEBUGOUT(_LtDebugDebug(__FILE__, NULL, "\t[%d] - %s\n", i, ret[i]));
+	    DEBUGOUT(_LtDebug(__FILE__, NULL, "\t[%d] - %s\n", i, ret[i]));
 	}
     }
 }
@@ -810,7 +831,7 @@ _XmOSBuildFileList(String dirPath,
     String *ret = NULL;
     int flags = GLOB_MARK | GLOB_PERIOD | GLOB_NOSORT;
 
-    DEBUGOUT(_LtDebugDebug(__FILE__, NULL,
+    DEBUGOUT(_LtDebug(__FILE__, NULL,
 		      "_XmOSBuildFileList(%s,%s)\n", dirPath, pattern));
 
     *pEntries = NULL;
@@ -839,7 +860,7 @@ _XmOSBuildFileList(String dirPath,
     if (i)
 	return;
 
-    DEBUGOUT(_LtDebugDebug0(__FILE__, NULL,
+    DEBUGOUT(_LtDebug0(__FILE__, NULL,
 	"WARNING: _XmOSBuildFileList: Resetting initial list\n"));
     *pNumAlloc = *pNumEntries = 0;
     *pEntries = NULL;
@@ -912,11 +933,11 @@ _XmOSBuildFileList(String dirPath,
     {
 	int i;
 
-	DEBUGOUT(_LtDebugDebug(__FILE__, NULL,
+	DEBUGOUT(_LtDebug(__FILE__, NULL,
 			  "_XmOSBuildFileList: %d results\n", cnt));
 	for (i = 0; i < cnt; i++)
 	{
-	    DEBUGOUT(_LtDebugDebug(__FILE__, NULL, "\t[%d] - %s\n", i, ret[i]));
+	    DEBUGOUT(_LtDebug(__FILE__, NULL, "\t[%d] - %s\n", i, ret[i]));
 	}
     }
 }
